<?php

/*
 * This file is part of PHPExifTool.
 *
 * (c) 2012 Romain Neutron <imprec@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace PHPExiftool\Driver;

class TagProvider extends \Pimple
{

    public function __construct()
    {
        $this['AFCP'] = $this->share(function(){
            return array(
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\AFCP\ThumbnailImage(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\AFCP\PreviewImage(),
                'Text' => new \PHPExiftool\Driver\Tag\AFCP\Text(),
            );
        });
        $this['AIFF'] = $this->share(function(){
            return array(
                'CommentTime' => new \PHPExiftool\Driver\Tag\AIFF\CommentTime(),
                'MarkerID' => new \PHPExiftool\Driver\Tag\AIFF\MarkerID(),
                'Comment' => new \PHPExiftool\Driver\Tag\AIFF\Comment(),
                'NumChannels' => new \PHPExiftool\Driver\Tag\AIFF\NumChannels(),
                'NumSampleFrames' => new \PHPExiftool\Driver\Tag\AIFF\NumSampleFrames(),
                'SampleSize' => new \PHPExiftool\Driver\Tag\AIFF\SampleSize(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\AIFF\SampleRate(),
                'CompressionType' => new \PHPExiftool\Driver\Tag\AIFF\CompressionType(),
                'CompressorName' => new \PHPExiftool\Driver\Tag\AIFF\CompressorName(),
                'FormatVersionTime' => new \PHPExiftool\Driver\Tag\AIFF\FormatVersionTime(),
                'Copyright' => new \PHPExiftool\Driver\Tag\AIFF\Copyright(),
                'Annotation' => new \PHPExiftool\Driver\Tag\AIFF\Annotation(),
                'Author' => new \PHPExiftool\Driver\Tag\AIFF\Author(),
                'Name' => new \PHPExiftool\Driver\Tag\AIFF\Name(),
            );
        });
        $this['APE'] = $this->share(function(){
            return array(
                'Album' => new \PHPExiftool\Driver\Tag\APE\Album(),
                'Artist' => new \PHPExiftool\Driver\Tag\APE\Artist(),
                'Genre' => new \PHPExiftool\Driver\Tag\APE\Genre(),
                'Title' => new \PHPExiftool\Driver\Tag\APE\Title(),
                'ToolName' => new \PHPExiftool\Driver\Tag\APE\ToolName(),
                'ToolVersion' => new \PHPExiftool\Driver\Tag\APE\ToolVersion(),
                'Track' => new \PHPExiftool\Driver\Tag\APE\Track(),
                'Year' => new \PHPExiftool\Driver\Tag\APE\Year(),
            );
        });
        $this['MAC'] = $this->share(function(){
            return array(
                'CompressionLevel' => new \PHPExiftool\Driver\Tag\MAC\CompressionLevel(),
                'BlocksPerFrame' => new \PHPExiftool\Driver\Tag\MAC\BlocksPerFrame(),
                'FinalFrameBlocks' => new \PHPExiftool\Driver\Tag\MAC\FinalFrameBlocks(),
                'TotalFrames' => new \PHPExiftool\Driver\Tag\MAC\TotalFrames(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\MAC\BitsPerSample(),
                'Channels' => new \PHPExiftool\Driver\Tag\MAC\Channels(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\MAC\SampleRate(),
                'APEVersion' => new \PHPExiftool\Driver\Tag\MAC\APEVersion(),
            );
        });
        $this['Ducky'] = $this->share(function(){
            return array(
                'Quality' => new \PHPExiftool\Driver\Tag\Ducky\Quality(),
                'Comment' => new \PHPExiftool\Driver\Tag\Ducky\Comment(),
                'Copyright' => new \PHPExiftool\Driver\Tag\Ducky\Copyright(),
            );
        });
        $this['PictureInfo'] = $this->share(function(){
            return array(
                'Aperture' => new \PHPExiftool\Driver\Tag\PictureInfo\Aperture(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\PictureInfo\ColorMode(),
                'ConTake' => new \PHPExiftool\Driver\Tag\PictureInfo\ConTake(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\PictureInfo\ExposureCompensation(),
                'FNumber' => new \PHPExiftool\Driver\Tag\PictureInfo\FNumber(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\PictureInfo\FirmwareVersion(),
                'Flash' => new \PHPExiftool\Driver\Tag\PictureInfo\Flash(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\PictureInfo\FocusMode(),
                'FocusPos' => new \PHPExiftool\Driver\Tag\PictureInfo\FocusPos(),
                'ID' => new \PHPExiftool\Driver\Tag\PictureInfo\ID(),
                'ImageSize' => new \PHPExiftool\Driver\Tag\PictureInfo\ImageSize(),
                'LightS' => new \PHPExiftool\Driver\Tag\PictureInfo\LightS(),
                'Macro' => new \PHPExiftool\Driver\Tag\PictureInfo\Macro(),
                'Protect' => new \PHPExiftool\Driver\Tag\PictureInfo\Protect(),
                'Quality' => new \PHPExiftool\Driver\Tag\PictureInfo\Quality(),
                'Resolution' => new \PHPExiftool\Driver\Tag\PictureInfo\Resolution(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\PictureInfo\SerialNumber(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\PictureInfo\ExposureTime(),
                'StrobeTime' => new \PHPExiftool\Driver\Tag\PictureInfo\StrobeTime(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\PictureInfo\DateTimeOriginal(),
                'CameraType' => new \PHPExiftool\Driver\Tag\PictureInfo\CameraType(),
                'Version' => new \PHPExiftool\Driver\Tag\PictureInfo\Version(),
                'YTarget' => new \PHPExiftool\Driver\Tag\PictureInfo\YTarget(),
                'Zoom' => new \PHPExiftool\Driver\Tag\PictureInfo\Zoom(),
                'ZoomPos' => new \PHPExiftool\Driver\Tag\PictureInfo\ZoomPos(),
                'YLevel' => new \PHPExiftool\Driver\Tag\PictureInfo\YLevel(),
            );
        });
        $this['ASF'] = $this->share(function(){
            return array(
                'AudioCodecDescription' => new \PHPExiftool\Driver\Tag\ASF\AudioCodecDescription(),
                'AudioCodecName' => new \PHPExiftool\Driver\Tag\ASF\AudioCodecName(),
                'OtherCodecDescription' => new \PHPExiftool\Driver\Tag\ASF\OtherCodecDescription(),
                'OtherCodecName' => new \PHPExiftool\Driver\Tag\ASF\OtherCodecName(),
                'VideoCodecDescription' => new \PHPExiftool\Driver\Tag\ASF\VideoCodecDescription(),
                'VideoCodecName' => new \PHPExiftool\Driver\Tag\ASF\VideoCodecName(),
                'BannerImageType' => new \PHPExiftool\Driver\Tag\ASF\BannerImageType(),
                'BannerImage' => new \PHPExiftool\Driver\Tag\ASF\BannerImage(),
                'BannerImageURL' => new \PHPExiftool\Driver\Tag\ASF\BannerImageURL(),
                'CopyrightURL' => new \PHPExiftool\Driver\Tag\ASF\CopyrightURL(),
                'Title' => new \PHPExiftool\Driver\Tag\ASF\Title(),
                'Author' => new \PHPExiftool\Driver\Tag\ASF\Author(),
                'Copyright' => new \PHPExiftool\Driver\Tag\ASF\Copyright(),
                'Description' => new \PHPExiftool\Driver\Tag\ASF\Description(),
                'Rating' => new \PHPExiftool\Driver\Tag\ASF\Rating(),
                'ASFLeakyBucketPairs' => new \PHPExiftool\Driver\Tag\ASF\ASFLeakyBucketPairs(),
                'ASFPacketCount' => new \PHPExiftool\Driver\Tag\ASF\ASFPacketCount(),
                'ASFSecurityObjectsSize' => new \PHPExiftool\Driver\Tag\ASF\ASFSecurityObjectsSize(),
                'AlbumArtist' => new \PHPExiftool\Driver\Tag\ASF\AlbumArtist(),
                'AlbumCoverURL' => new \PHPExiftool\Driver\Tag\ASF\AlbumCoverURL(),
                'AlbumTitle' => new \PHPExiftool\Driver\Tag\ASF\AlbumTitle(),
                'AspectRatioX' => new \PHPExiftool\Driver\Tag\ASF\AspectRatioX(),
                'AspectRatioY' => new \PHPExiftool\Driver\Tag\ASF\AspectRatioY(),
                'AudioFileURL' => new \PHPExiftool\Driver\Tag\ASF\AudioFileURL(),
                'AudioSourceURL' => new \PHPExiftool\Driver\Tag\ASF\AudioSourceURL(),
                'AuthorURL' => new \PHPExiftool\Driver\Tag\ASF\AuthorURL(),
                'AverageLevel' => new \PHPExiftool\Driver\Tag\ASF\AverageLevel(),
                'BannerImageData' => new \PHPExiftool\Driver\Tag\ASF\BannerImageData(),
                'BeatsPerMinute' => new \PHPExiftool\Driver\Tag\ASF\BeatsPerMinute(),
                'Bitrate' => new \PHPExiftool\Driver\Tag\ASF\Bitrate(),
                'Broadcast' => new \PHPExiftool\Driver\Tag\ASF\Broadcast(),
                'BufferAverage' => new \PHPExiftool\Driver\Tag\ASF\BufferAverage(),
                'Can_Skip_Backward' => new \PHPExiftool\Driver\Tag\ASF\CanSkipBackward(),
                'Can_Skip_Forward' => new \PHPExiftool\Driver\Tag\ASF\CanSkipForward(),
                'Category' => new \PHPExiftool\Driver\Tag\ASF\Category(),
                'Codec' => new \PHPExiftool\Driver\Tag\ASF\Codec(),
                'Composer' => new \PHPExiftool\Driver\Tag\ASF\Composer(),
                'Conductor' => new \PHPExiftool\Driver\Tag\ASF\Conductor(),
                'ContainerFormat' => new \PHPExiftool\Driver\Tag\ASF\ContainerFormat(),
                'ContentDistributor' => new \PHPExiftool\Driver\Tag\ASF\ContentDistributor(),
                'ContentGroupDescription' => new \PHPExiftool\Driver\Tag\ASF\ContentGroupDescription(),
                'CurrentBitrate' => new \PHPExiftool\Driver\Tag\ASF\CurrentBitrate(),
                'DRM' => new \PHPExiftool\Driver\Tag\ASF\DRM(),
                'DRM_ContentID' => new \PHPExiftool\Driver\Tag\ASF\DRMContentID(),
                'DRM_DRMHeader' => new \PHPExiftool\Driver\Tag\ASF\DRMDRMHeader(),
                'DRM_DRMHeader_ContentDistributor' => new \PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderContentDistributor(),
                'DRM_DRMHeader_ContentID' => new \PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderContentID(),
                'DRM_DRMHeader_IndividualizedVersion' => new \PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderIndividualizedVersion(),
                'DRM_DRMHeader_KeyID' => new \PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderKeyID(),
                'DRM_DRMHeader_LicenseAcqURL' => new \PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderLicenseAcqURL(),
                'DRM_DRMHeader_SubscriptionContentID' => new \PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderSubscriptionContentID(),
                'DRM_IndividualizedVersion' => new \PHPExiftool\Driver\Tag\ASF\DRMIndividualizedVersion(),
                'DRM_KeyID' => new \PHPExiftool\Driver\Tag\ASF\DRMKeyID(),
                'DRM_LASignatureCert' => new \PHPExiftool\Driver\Tag\ASF\DRMLASignatureCert(),
                'DRM_LASignatureLicSrvCert' => new \PHPExiftool\Driver\Tag\ASF\DRMLASignatureLicSrvCert(),
                'DRM_LASignaturePrivKey' => new \PHPExiftool\Driver\Tag\ASF\DRMLASignaturePrivKey(),
                'DRM_LASignatureRootCert' => new \PHPExiftool\Driver\Tag\ASF\DRMLASignatureRootCert(),
                'DRM_LicenseAcqURL' => new \PHPExiftool\Driver\Tag\ASF\DRMLicenseAcqURL(),
                'DRM_V1LicenseAcqURL' => new \PHPExiftool\Driver\Tag\ASF\DRMV1LicenseAcqURL(),
                'DVDID' => new \PHPExiftool\Driver\Tag\ASF\DVDID(),
                'Director' => new \PHPExiftool\Driver\Tag\ASF\Director(),
                'Duration' => new \PHPExiftool\Driver\Tag\ASF\Duration(),
                'EncodedBy' => new \PHPExiftool\Driver\Tag\ASF\EncodedBy(),
                'EncodingSettings' => new \PHPExiftool\Driver\Tag\ASF\EncodingSettings(),
                'EncodingTime' => new \PHPExiftool\Driver\Tag\ASF\EncodingTime(),
                'FileSize' => new \PHPExiftool\Driver\Tag\ASF\FileSize(),
                'Genre' => new \PHPExiftool\Driver\Tag\ASF\Genre(),
                'GenreID' => new \PHPExiftool\Driver\Tag\ASF\GenreID(),
                'HasArbitraryDataStream' => new \PHPExiftool\Driver\Tag\ASF\HasArbitraryDataStream(),
                'HasAttachedImages' => new \PHPExiftool\Driver\Tag\ASF\HasAttachedImages(),
                'HasAudio' => new \PHPExiftool\Driver\Tag\ASF\HasAudio(),
                'HasFileTransferStream' => new \PHPExiftool\Driver\Tag\ASF\HasFileTransferStream(),
                'HasImage' => new \PHPExiftool\Driver\Tag\ASF\HasImage(),
                'HasScript' => new \PHPExiftool\Driver\Tag\ASF\HasScript(),
                'HasVideo' => new \PHPExiftool\Driver\Tag\ASF\HasVideo(),
                'ISRC' => new \PHPExiftool\Driver\Tag\ASF\ISRC(),
                'InitialKey' => new \PHPExiftool\Driver\Tag\ASF\InitialKey(),
                'IsVBR' => new \PHPExiftool\Driver\Tag\ASF\IsVBR(),
                'Is_Protected' => new \PHPExiftool\Driver\Tag\ASF\IsProtected(),
                'Is_Trusted' => new \PHPExiftool\Driver\Tag\ASF\IsTrusted(),
                'Language' => new \PHPExiftool\Driver\Tag\ASF\Language(),
                'Lyrics' => new \PHPExiftool\Driver\Tag\ASF\Lyrics(),
                'Lyrics_Synchronised' => new \PHPExiftool\Driver\Tag\ASF\LyricsSynchronised(),
                'MCDI' => new \PHPExiftool\Driver\Tag\ASF\MCDI(),
                'MediaClassPrimaryID' => new \PHPExiftool\Driver\Tag\ASF\MediaClassPrimaryID(),
                'MediaClassSecondaryID' => new \PHPExiftool\Driver\Tag\ASF\MediaClassSecondaryID(),
                'MediaCredits' => new \PHPExiftool\Driver\Tag\ASF\MediaCredits(),
                'MediaIsDelay' => new \PHPExiftool\Driver\Tag\ASF\MediaIsDelay(),
                'MediaIsFinale' => new \PHPExiftool\Driver\Tag\ASF\MediaIsFinale(),
                'MediaIsLive' => new \PHPExiftool\Driver\Tag\ASF\MediaIsLive(),
                'MediaIsPremiere' => new \PHPExiftool\Driver\Tag\ASF\MediaIsPremiere(),
                'MediaIsRepeat' => new \PHPExiftool\Driver\Tag\ASF\MediaIsRepeat(),
                'MediaIsSAP' => new \PHPExiftool\Driver\Tag\ASF\MediaIsSAP(),
                'MediaIsStereo' => new \PHPExiftool\Driver\Tag\ASF\MediaIsStereo(),
                'MediaIsSubtitled' => new \PHPExiftool\Driver\Tag\ASF\MediaIsSubtitled(),
                'MediaIsTape' => new \PHPExiftool\Driver\Tag\ASF\MediaIsTape(),
                'MediaNetworkAffiliation' => new \PHPExiftool\Driver\Tag\ASF\MediaNetworkAffiliation(),
                'MediaOriginalBroadcastDateTime' => new \PHPExiftool\Driver\Tag\ASF\MediaOriginalBroadcastDateTime(),
                'MediaOriginalChannel' => new \PHPExiftool\Driver\Tag\ASF\MediaOriginalChannel(),
                'MediaStationCallSign' => new \PHPExiftool\Driver\Tag\ASF\MediaStationCallSign(),
                'MediaStationName' => new \PHPExiftool\Driver\Tag\ASF\MediaStationName(),
                'ModifiedBy' => new \PHPExiftool\Driver\Tag\ASF\ModifiedBy(),
                'Mood' => new \PHPExiftool\Driver\Tag\ASF\Mood(),
                'NSC_Address' => new \PHPExiftool\Driver\Tag\ASF\NSCAddress(),
                'NSC_Description' => new \PHPExiftool\Driver\Tag\ASF\NSCDescription(),
                'NSC_Email' => new \PHPExiftool\Driver\Tag\ASF\NSCEmail(),
                'NSC_Name' => new \PHPExiftool\Driver\Tag\ASF\NSCName(),
                'NSC_Phone' => new \PHPExiftool\Driver\Tag\ASF\NSCPhone(),
                'NumberOfFrames' => new \PHPExiftool\Driver\Tag\ASF\NumberOfFrames(),
                'OptimalBitrate' => new \PHPExiftool\Driver\Tag\ASF\OptimalBitrate(),
                'OriginalAlbumTitle' => new \PHPExiftool\Driver\Tag\ASF\OriginalAlbumTitle(),
                'OriginalArtist' => new \PHPExiftool\Driver\Tag\ASF\OriginalArtist(),
                'OriginalFilename' => new \PHPExiftool\Driver\Tag\ASF\OriginalFilename(),
                'OriginalLyricist' => new \PHPExiftool\Driver\Tag\ASF\OriginalLyricist(),
                'OriginalReleaseTime' => new \PHPExiftool\Driver\Tag\ASF\OriginalReleaseTime(),
                'OriginalReleaseYear' => new \PHPExiftool\Driver\Tag\ASF\OriginalReleaseYear(),
                'ParentalRating' => new \PHPExiftool\Driver\Tag\ASF\ParentalRating(),
                'ParentalRatingReason' => new \PHPExiftool\Driver\Tag\ASF\ParentalRatingReason(),
                'PartOfSet' => new \PHPExiftool\Driver\Tag\ASF\PartOfSet(),
                'PeakBitrate' => new \PHPExiftool\Driver\Tag\ASF\PeakBitrate(),
                'PeakValue' => new \PHPExiftool\Driver\Tag\ASF\PeakValue(),
                'Period' => new \PHPExiftool\Driver\Tag\ASF\Period(),
                'PlaylistDelay' => new \PHPExiftool\Driver\Tag\ASF\PlaylistDelay(),
                'Producer' => new \PHPExiftool\Driver\Tag\ASF\Producer(),
                'PromotionURL' => new \PHPExiftool\Driver\Tag\ASF\PromotionURL(),
                'ProtectionType' => new \PHPExiftool\Driver\Tag\ASF\ProtectionType(),
                'Provider' => new \PHPExiftool\Driver\Tag\ASF\Provider(),
                'ProviderCopyright' => new \PHPExiftool\Driver\Tag\ASF\ProviderCopyright(),
                'ProviderRating' => new \PHPExiftool\Driver\Tag\ASF\ProviderRating(),
                'ProviderStyle' => new \PHPExiftool\Driver\Tag\ASF\ProviderStyle(),
                'Publisher' => new \PHPExiftool\Driver\Tag\ASF\Publisher(),
                'RadioStationName' => new \PHPExiftool\Driver\Tag\ASF\RadioStationName(),
                'RadioStationOwner' => new \PHPExiftool\Driver\Tag\ASF\RadioStationOwner(),
                'Seekable' => new \PHPExiftool\Driver\Tag\ASF\Seekable(),
                'SharedUserRating' => new \PHPExiftool\Driver\Tag\ASF\SharedUserRating(),
                'Signature_Name' => new \PHPExiftool\Driver\Tag\ASF\SignatureName(),
                'StreamTypeInfo' => new \PHPExiftool\Driver\Tag\ASF\StreamTypeInfo(),
                'Stridable' => new \PHPExiftool\Driver\Tag\ASF\Stridable(),
                'SubTitle' => new \PHPExiftool\Driver\Tag\ASF\SubTitle(),
                'SubTitleDescription' => new \PHPExiftool\Driver\Tag\ASF\SubTitleDescription(),
                'SubscriptionContentID' => new \PHPExiftool\Driver\Tag\ASF\SubscriptionContentID(),
                'Text' => new \PHPExiftool\Driver\Tag\ASF\Text(),
                'ToolName' => new \PHPExiftool\Driver\Tag\ASF\ToolName(),
                'ToolVersion' => new \PHPExiftool\Driver\Tag\ASF\ToolVersion(),
                'Track' => new \PHPExiftool\Driver\Tag\ASF\Track(),
                'TrackNumber' => new \PHPExiftool\Driver\Tag\ASF\TrackNumber(),
                'UniqueFileIdentifier' => new \PHPExiftool\Driver\Tag\ASF\UniqueFileIdentifier(),
                'UserWebURL' => new \PHPExiftool\Driver\Tag\ASF\UserWebURL(),
                'VBRPeak' => new \PHPExiftool\Driver\Tag\ASF\VBRPeak(),
                'VideoClosedCaptioning' => new \PHPExiftool\Driver\Tag\ASF\VideoClosedCaptioning(),
                'VideoFrameRate' => new \PHPExiftool\Driver\Tag\ASF\VideoFrameRate(),
                'VideoHeight' => new \PHPExiftool\Driver\Tag\ASF\VideoHeight(),
                'VideoWidth' => new \PHPExiftool\Driver\Tag\ASF\VideoWidth(),
                'WMADRCAverageReference' => new \PHPExiftool\Driver\Tag\ASF\WMADRCAverageReference(),
                'WMADRCAverageTarget' => new \PHPExiftool\Driver\Tag\ASF\WMADRCAverageTarget(),
                'WMADRCPeakReference' => new \PHPExiftool\Driver\Tag\ASF\WMADRCPeakReference(),
                'WMADRCPeakTarget' => new \PHPExiftool\Driver\Tag\ASF\WMADRCPeakTarget(),
                'WMCollectionGroupID' => new \PHPExiftool\Driver\Tag\ASF\WMCollectionGroupID(),
                'WMCollectionID' => new \PHPExiftool\Driver\Tag\ASF\WMCollectionID(),
                'WMContentID' => new \PHPExiftool\Driver\Tag\ASF\WMContentID(),
                'Writer' => new \PHPExiftool\Driver\Tag\ASF\Writer(),
                'Year' => new \PHPExiftool\Driver\Tag\ASF\Year(),
                'FileID' => new \PHPExiftool\Driver\Tag\ASF\FileID(),
                'FileLength' => new \PHPExiftool\Driver\Tag\ASF\FileLength(),
                'CreationDate' => new \PHPExiftool\Driver\Tag\ASF\CreationDate(),
                'DataPackets' => new \PHPExiftool\Driver\Tag\ASF\DataPackets(),
                'PlayDuration' => new \PHPExiftool\Driver\Tag\ASF\PlayDuration(),
                'SendDuration' => new \PHPExiftool\Driver\Tag\ASF\SendDuration(),
                'Preroll' => new \PHPExiftool\Driver\Tag\ASF\Preroll(),
                'Flags' => new \PHPExiftool\Driver\Tag\ASF\Flags(),
                'MinPacketSize' => new \PHPExiftool\Driver\Tag\ASF\MinPacketSize(),
                'MaxPacketSize' => new \PHPExiftool\Driver\Tag\ASF\MaxPacketSize(),
                'MaxBitrate' => new \PHPExiftool\Driver\Tag\ASF\MaxBitrate(),
                'Padding' => new \PHPExiftool\Driver\Tag\ASF\Padding(),
                'ScriptCommand' => new \PHPExiftool\Driver\Tag\ASF\ScriptCommand(),
                'ContentEncryption' => new \PHPExiftool\Driver\Tag\ASF\ContentEncryption(),
                'DigitalSignature' => new \PHPExiftool\Driver\Tag\ASF\DigitalSignature(),
                'ExtendedContentEncryption' => new \PHPExiftool\Driver\Tag\ASF\ExtendedContentEncryption(),
                'ErrorCorrection' => new \PHPExiftool\Driver\Tag\ASF\ErrorCorrection(),
                'StreamBitrateProps' => new \PHPExiftool\Driver\Tag\ASF\StreamBitrateProps(),
                'BitrateMutualExclusion' => new \PHPExiftool\Driver\Tag\ASF\BitrateMutualExclusion(),
                'Marker' => new \PHPExiftool\Driver\Tag\ASF\Marker(),
                'ExtendedStreamProps' => new \PHPExiftool\Driver\Tag\ASF\ExtendedStreamProps(),
                'AdvancedContentEncryption' => new \PHPExiftool\Driver\Tag\ASF\AdvancedContentEncryption(),
                'TimecodeIndexParms' => new \PHPExiftool\Driver\Tag\ASF\TimecodeIndexParms(),
                'Compatibility' => new \PHPExiftool\Driver\Tag\ASF\Compatibility(),
                'LanguageList' => new \PHPExiftool\Driver\Tag\ASF\LanguageList(),
                'AdvancedMutualExcl' => new \PHPExiftool\Driver\Tag\ASF\AdvancedMutualExcl(),
                'BandwidthSharing' => new \PHPExiftool\Driver\Tag\ASF\BandwidthSharing(),
                'Reserved1' => new \PHPExiftool\Driver\Tag\ASF\Reserved1(),
                'GroupMutualExclusion' => new \PHPExiftool\Driver\Tag\ASF\GroupMutualExclusion(),
                'StreamPrioritization' => new \PHPExiftool\Driver\Tag\ASF\StreamPrioritization(),
                'IndexParameters' => new \PHPExiftool\Driver\Tag\ASF\IndexParameters(),
                'SimpleIndex' => new \PHPExiftool\Driver\Tag\ASF\SimpleIndex(),
                'TimecodeIndex' => new \PHPExiftool\Driver\Tag\ASF\TimecodeIndex(),
                'Data' => new \PHPExiftool\Driver\Tag\ASF\Data(),
                'Index' => new \PHPExiftool\Driver\Tag\ASF\Index(),
                'MediaIndex' => new \PHPExiftool\Driver\Tag\ASF\MediaIndex(),
                'PictureType' => new \PHPExiftool\Driver\Tag\ASF\PictureType(),
                'PictureMimeType' => new \PHPExiftool\Driver\Tag\ASF\PictureMimeType(),
                'PictureDescription' => new \PHPExiftool\Driver\Tag\ASF\PictureDescription(),
                'Picture' => new \PHPExiftool\Driver\Tag\ASF\Picture(),
                'StreamType' => new \PHPExiftool\Driver\Tag\ASF\StreamType(),
                'ErrorCorrectionType' => new \PHPExiftool\Driver\Tag\ASF\ErrorCorrectionType(),
                'TimeOffset' => new \PHPExiftool\Driver\Tag\ASF\TimeOffset(),
                'StreamNumber' => new \PHPExiftool\Driver\Tag\ASF\StreamNumber(),
                'AudioCodecID' => new \PHPExiftool\Driver\Tag\ASF\AudioCodecID(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\ASF\ImageWidth(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\ASF\AudioChannels(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\ASF\AudioSampleRate(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\ASF\ImageHeight(),
            );
        });
        $this['File'] = $this->share(function(){
            return array(
                'ImageWidth' => new \PHPExiftool\Driver\Tag\File\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\File\ImageHeight(),
                'Planes' => new \PHPExiftool\Driver\Tag\File\Planes(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\File\BitDepth(),
                'Compression' => new \PHPExiftool\Driver\Tag\File\Compression(),
                'ImageLength' => new \PHPExiftool\Driver\Tag\File\ImageLength(),
                'PixelsPerMeterX' => new \PHPExiftool\Driver\Tag\File\PixelsPerMeterX(),
                'PixelsPerMeterY' => new \PHPExiftool\Driver\Tag\File\PixelsPerMeterY(),
                'NumColors' => new \PHPExiftool\Driver\Tag\File\NumColors(),
                'NumImportantColors' => new \PHPExiftool\Driver\Tag\File\NumImportantColors(),
                'Comment' => new \PHPExiftool\Driver\Tag\File\Comment(),
                'CurrentIPTCDigest' => new \PHPExiftool\Driver\Tag\File\CurrentIPTCDigest(),
                'ExifByteOrder' => new \PHPExiftool\Driver\Tag\File\ExifByteOrder(),
                'ExifUnicodeByteOrder' => new \PHPExiftool\Driver\Tag\File\ExifUnicodeByteOrder(),
                'FileType' => new \PHPExiftool\Driver\Tag\File\FileType(),
                'Geosync' => new \PHPExiftool\Driver\Tag\File\Geosync(),
                'Geotag' => new \PHPExiftool\Driver\Tag\File\Geotag(),
                'Geotime' => new \PHPExiftool\Driver\Tag\File\Geotime(),
                'ID3Size' => new \PHPExiftool\Driver\Tag\File\ID3Size(),
                'JPEGDigest' => new \PHPExiftool\Driver\Tag\File\JPEGDigest(),
                'MIMEType' => new \PHPExiftool\Driver\Tag\File\MIMEType(),
                'MaxVal' => new \PHPExiftool\Driver\Tag\File\MaxVal(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\File\PreviewImage(),
                'PreviewPNG' => new \PHPExiftool\Driver\Tag\File\PreviewPNG(),
                'PreviewWMF' => new \PHPExiftool\Driver\Tag\File\PreviewWMF(),
                'RAFVersion' => new \PHPExiftool\Driver\Tag\File\RAFVersion(),
                'XResolution' => new \PHPExiftool\Driver\Tag\File\XResolution(),
                'YResolution' => new \PHPExiftool\Driver\Tag\File\YResolution(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\File\BitsPerSample(),
                'ColorComponents' => new \PHPExiftool\Driver\Tag\File\ColorComponents(),
                'EncodingProcess' => new \PHPExiftool\Driver\Tag\File\EncodingProcess(),
                'YCbCrSubSampling' => new \PHPExiftool\Driver\Tag\File\YCbCrSubSampling(),
                'PGFVersion' => new \PHPExiftool\Driver\Tag\File\PGFVersion(),
                'PyramidLevels' => new \PHPExiftool\Driver\Tag\File\PyramidLevels(),
                'Quality' => new \PHPExiftool\Driver\Tag\File\Quality(),
                'BitsPerPixel' => new \PHPExiftool\Driver\Tag\File\BitsPerPixel(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\File\ColorMode(),
                'BackgroundColor' => new \PHPExiftool\Driver\Tag\File\BackgroundColor(),
            );
        });
        $this['Canon'] = $this->share(function(){
            return array(
                'NumAFPoints' => new \PHPExiftool\Driver\Tag\Canon\NumAFPoints(),
                'ValidAFPoints' => new \PHPExiftool\Driver\Tag\Canon\ValidAFPoints(),
                'CanonImageWidth' => new \PHPExiftool\Driver\Tag\Canon\CanonImageWidth(),
                'CanonImageHeight' => new \PHPExiftool\Driver\Tag\Canon\CanonImageHeight(),
                'AFImageWidth' => new \PHPExiftool\Driver\Tag\Canon\AFImageWidth(),
                'AFImageHeight' => new \PHPExiftool\Driver\Tag\Canon\AFImageHeight(),
                'AFAreaWidth' => new \PHPExiftool\Driver\Tag\Canon\AFAreaWidth(),
                'AFAreaHeight' => new \PHPExiftool\Driver\Tag\Canon\AFAreaHeight(),
                'AFAreaXPositions' => new \PHPExiftool\Driver\Tag\Canon\AFAreaXPositions(),
                'AFAreaYPositions' => new \PHPExiftool\Driver\Tag\Canon\AFAreaYPositions(),
                'AFPointsInFocus' => new \PHPExiftool\Driver\Tag\Canon\AFPointsInFocus(),
                'PrimaryAFPoint' => new \PHPExiftool\Driver\Tag\Canon\PrimaryAFPoint(),
                'Canon_AFInfo_0x000b' => new \PHPExiftool\Driver\Tag\Canon\CanonAFInfo0x000b(),
                'AFInfoSize' => new \PHPExiftool\Driver\Tag\Canon\AFInfoSize(),
                'AFAreaMode' => new \PHPExiftool\Driver\Tag\Canon\AFAreaMode(),
                'AFAreaWidths' => new \PHPExiftool\Driver\Tag\Canon\AFAreaWidths(),
                'AFAreaHeights' => new \PHPExiftool\Driver\Tag\Canon\AFAreaHeights(),
                'AFPointsSelected' => new \PHPExiftool\Driver\Tag\Canon\AFPointsSelected(),
                'Canon_AFInfo2_0x000d' => new \PHPExiftool\Driver\Tag\Canon\CanonAFInfo20x000d(),
                'AFMicroAdjMode' => new \PHPExiftool\Driver\Tag\Canon\AFMicroAdjMode(),
                'AFMicroAdjValue' => new \PHPExiftool\Driver\Tag\Canon\AFMicroAdjValue(),
                'AmbienceSelection' => new \PHPExiftool\Driver\Tag\Canon\AmbienceSelection(),
                'AspectRatio' => new \PHPExiftool\Driver\Tag\Canon\AspectRatio(),
                'CroppedImageWidth' => new \PHPExiftool\Driver\Tag\Canon\CroppedImageWidth(),
                'CroppedImageHeight' => new \PHPExiftool\Driver\Tag\Canon\CroppedImageHeight(),
                'CroppedImageLeft' => new \PHPExiftool\Driver\Tag\Canon\CroppedImageLeft(),
                'CroppedImageTop' => new \PHPExiftool\Driver\Tag\Canon\CroppedImageTop(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\Canon\ThumbnailImage(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Canon\FNumber(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Canon\ExposureTime(),
                'ISO' => new \PHPExiftool\Driver\Tag\Canon\ISO(),
                'FlashMeteringMode' => new \PHPExiftool\Driver\Tag\Canon\FlashMeteringMode(),
                'CameraTemperature' => new \PHPExiftool\Driver\Tag\Canon\CameraTemperature(),
                'MacroMagnification' => new \PHPExiftool\Driver\Tag\Canon\MacroMagnification(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Canon\FocalLength(),
                'CameraOrientation' => new \PHPExiftool\Driver\Tag\Canon\CameraOrientation(),
                'FocusDistanceUpper' => new \PHPExiftool\Driver\Tag\Canon\FocusDistanceUpper(),
                'FocusDistanceLower' => new \PHPExiftool\Driver\Tag\Canon\FocusDistanceLower(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Canon\WhiteBalance(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\Canon\ColorTemperature(),
                'LensType' => new \PHPExiftool\Driver\Tag\Canon\LensType(),
                'MinFocalLength' => new \PHPExiftool\Driver\Tag\Canon\MinFocalLength(),
                'MaxFocalLength' => new \PHPExiftool\Driver\Tag\Canon\MaxFocalLength(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\Canon\FirmwareVersion(),
                'DirectoryIndex' => new \PHPExiftool\Driver\Tag\Canon\DirectoryIndex(),
                'FileIndex' => new \PHPExiftool\Driver\Tag\Canon\FileIndex(),
                'LensModel' => new \PHPExiftool\Driver\Tag\Canon\LensModel(),
                'SharpnessFrequency' => new \PHPExiftool\Driver\Tag\Canon\SharpnessFrequency(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Canon\Sharpness(),
                'PictureStyle' => new \PHPExiftool\Driver\Tag\Canon\PictureStyle(),
                'FirmwareVersionLookAhead' => new \PHPExiftool\Driver\Tag\Canon\FirmwareVersionLookAhead(),
                'FocalType' => new \PHPExiftool\Driver\Tag\Canon\FocalType(),
                'CanonImageSize' => new \PHPExiftool\Driver\Tag\Canon\CanonImageSize(),
                'JPEGQuality' => new \PHPExiftool\Driver\Tag\Canon\JPEGQuality(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Canon\Saturation(),
                'ColorTone' => new \PHPExiftool\Driver\Tag\Canon\ColorTone(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Canon\Contrast(),
                'ShutterCount' => new \PHPExiftool\Driver\Tag\Canon\ShutterCount(),
                'TimeStamp1' => new \PHPExiftool\Driver\Tag\Canon\TimeStamp1(),
                'TimeStamp' => new \PHPExiftool\Driver\Tag\Canon\TimeStamp(),
                'HighlightTonePriority' => new \PHPExiftool\Driver\Tag\Canon\HighlightTonePriority(),
                'MeasuredEV2' => new \PHPExiftool\Driver\Tag\Canon\MeasuredEV2(),
                'MeasuredEV3' => new \PHPExiftool\Driver\Tag\Canon\MeasuredEV3(),
                'OwnerName' => new \PHPExiftool\Driver\Tag\Canon\OwnerName(),
                'HighISONoiseReduction' => new \PHPExiftool\Driver\Tag\Canon\HighISONoiseReduction(),
                'AutoLightingOptimizer' => new \PHPExiftool\Driver\Tag\Canon\AutoLightingOptimizer(),
                'AFPointsInFocus5D' => new \PHPExiftool\Driver\Tag\Canon\AFPointsInFocus5D(),
                'FirmwareRevision' => new \PHPExiftool\Driver\Tag\Canon\FirmwareRevision(),
                'ShortOwnerName' => new \PHPExiftool\Driver\Tag\Canon\ShortOwnerName(),
                'ContrastStandard' => new \PHPExiftool\Driver\Tag\Canon\ContrastStandard(),
                'ContrastPortrait' => new \PHPExiftool\Driver\Tag\Canon\ContrastPortrait(),
                'ContrastLandscape' => new \PHPExiftool\Driver\Tag\Canon\ContrastLandscape(),
                'ContrastNeutral' => new \PHPExiftool\Driver\Tag\Canon\ContrastNeutral(),
                'ContrastFaithful' => new \PHPExiftool\Driver\Tag\Canon\ContrastFaithful(),
                'ContrastMonochrome' => new \PHPExiftool\Driver\Tag\Canon\ContrastMonochrome(),
                'ContrastUserDef1' => new \PHPExiftool\Driver\Tag\Canon\ContrastUserDef1(),
                'ContrastUserDef2' => new \PHPExiftool\Driver\Tag\Canon\ContrastUserDef2(),
                'ContrastUserDef3' => new \PHPExiftool\Driver\Tag\Canon\ContrastUserDef3(),
                'SharpnessStandard' => new \PHPExiftool\Driver\Tag\Canon\SharpnessStandard(),
                'SharpnessPortrait' => new \PHPExiftool\Driver\Tag\Canon\SharpnessPortrait(),
                'SharpnessLandscape' => new \PHPExiftool\Driver\Tag\Canon\SharpnessLandscape(),
                'SharpnessNeutral' => new \PHPExiftool\Driver\Tag\Canon\SharpnessNeutral(),
                'SharpnessFaithful' => new \PHPExiftool\Driver\Tag\Canon\SharpnessFaithful(),
                'SharpnessMonochrome' => new \PHPExiftool\Driver\Tag\Canon\SharpnessMonochrome(),
                'SharpnessUserDef1' => new \PHPExiftool\Driver\Tag\Canon\SharpnessUserDef1(),
                'SharpnessUserDef2' => new \PHPExiftool\Driver\Tag\Canon\SharpnessUserDef2(),
                'SharpnessUserDef3' => new \PHPExiftool\Driver\Tag\Canon\SharpnessUserDef3(),
                'SaturationStandard' => new \PHPExiftool\Driver\Tag\Canon\SaturationStandard(),
                'SaturationPortrait' => new \PHPExiftool\Driver\Tag\Canon\SaturationPortrait(),
                'SaturationLandscape' => new \PHPExiftool\Driver\Tag\Canon\SaturationLandscape(),
                'SaturationNeutral' => new \PHPExiftool\Driver\Tag\Canon\SaturationNeutral(),
                'SaturationFaithful' => new \PHPExiftool\Driver\Tag\Canon\SaturationFaithful(),
                'FilterEffectMonochrome' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectMonochrome(),
                'SaturationUserDef1' => new \PHPExiftool\Driver\Tag\Canon\SaturationUserDef1(),
                'SaturationUserDef2' => new \PHPExiftool\Driver\Tag\Canon\SaturationUserDef2(),
                'SaturationUserDef3' => new \PHPExiftool\Driver\Tag\Canon\SaturationUserDef3(),
                'ColorToneStandard' => new \PHPExiftool\Driver\Tag\Canon\ColorToneStandard(),
                'ColorTonePortrait' => new \PHPExiftool\Driver\Tag\Canon\ColorTonePortrait(),
                'ColorToneLandscape' => new \PHPExiftool\Driver\Tag\Canon\ColorToneLandscape(),
                'ColorToneNeutral' => new \PHPExiftool\Driver\Tag\Canon\ColorToneNeutral(),
                'ColorToneFaithful' => new \PHPExiftool\Driver\Tag\Canon\ColorToneFaithful(),
                'ToningEffectMonochrome' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectMonochrome(),
                'ColorToneUserDef1' => new \PHPExiftool\Driver\Tag\Canon\ColorToneUserDef1(),
                'ColorToneUserDef2' => new \PHPExiftool\Driver\Tag\Canon\ColorToneUserDef2(),
                'ColorToneUserDef3' => new \PHPExiftool\Driver\Tag\Canon\ColorToneUserDef3(),
                'UserDef1PictureStyle' => new \PHPExiftool\Driver\Tag\Canon\UserDef1PictureStyle(),
                'UserDef2PictureStyle' => new \PHPExiftool\Driver\Tag\Canon\UserDef2PictureStyle(),
                'UserDef3PictureStyle' => new \PHPExiftool\Driver\Tag\Canon\UserDef3PictureStyle(),
                'FileIndex2' => new \PHPExiftool\Driver\Tag\Canon\FileIndex2(),
                'DirectoryIndex2' => new \PHPExiftool\Driver\Tag\Canon\DirectoryIndex2(),
                'MeasuredEV' => new \PHPExiftool\Driver\Tag\Canon\MeasuredEV(),
                'Rotation' => new \PHPExiftool\Driver\Tag\Canon\Rotation(),
                'MacroMode' => new \PHPExiftool\Driver\Tag\Canon\MacroMode(),
                'SelfTimer' => new \PHPExiftool\Driver\Tag\Canon\SelfTimer(),
                'Quality' => new \PHPExiftool\Driver\Tag\Canon\Quality(),
                'CanonFlashMode' => new \PHPExiftool\Driver\Tag\Canon\CanonFlashMode(),
                'ContinuousDrive' => new \PHPExiftool\Driver\Tag\Canon\ContinuousDrive(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Canon\FocusMode(),
                'RecordMode' => new \PHPExiftool\Driver\Tag\Canon\RecordMode(),
                'EasyMode' => new \PHPExiftool\Driver\Tag\Canon\EasyMode(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Canon\DigitalZoom(),
                'CameraISO' => new \PHPExiftool\Driver\Tag\Canon\CameraISO(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Canon\MeteringMode(),
                'FocusRange' => new \PHPExiftool\Driver\Tag\Canon\FocusRange(),
                'AFPoint' => new \PHPExiftool\Driver\Tag\Canon\AFPoint(),
                'CanonExposureMode' => new \PHPExiftool\Driver\Tag\Canon\CanonExposureMode(),
                'FocalUnits' => new \PHPExiftool\Driver\Tag\Canon\FocalUnits(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\Canon\MaxAperture(),
                'MinAperture' => new \PHPExiftool\Driver\Tag\Canon\MinAperture(),
                'FlashActivity' => new \PHPExiftool\Driver\Tag\Canon\FlashActivity(),
                'FlashBits' => new \PHPExiftool\Driver\Tag\Canon\FlashBits(),
                'FocusContinuous' => new \PHPExiftool\Driver\Tag\Canon\FocusContinuous(),
                'AESetting' => new \PHPExiftool\Driver\Tag\Canon\AESetting(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\Canon\ImageStabilization(),
                'DisplayAperture' => new \PHPExiftool\Driver\Tag\Canon\DisplayAperture(),
                'ZoomSourceWidth' => new \PHPExiftool\Driver\Tag\Canon\ZoomSourceWidth(),
                'ZoomTargetWidth' => new \PHPExiftool\Driver\Tag\Canon\ZoomTargetWidth(),
                'SpotMeteringMode' => new \PHPExiftool\Driver\Tag\Canon\SpotMeteringMode(),
                'PhotoEffect' => new \PHPExiftool\Driver\Tag\Canon\PhotoEffect(),
                'ManualFlashOutput' => new \PHPExiftool\Driver\Tag\Canon\ManualFlashOutput(),
                'SRAWQuality' => new \PHPExiftool\Driver\Tag\Canon\SRAWQuality(),
                'WB_RGGBLevelsAuto' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsAuto(),
                'WB_RGGBLevelsDaylight' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsDaylight(),
                'WB_RGGBLevelsShade' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsShade(),
                'WB_RGGBLevelsCloudy' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsCloudy(),
                'WB_RGGBLevelsTungsten' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsTungsten(),
                'WB_RGGBLevelsFluorescent' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsFluorescent(),
                'WB_RGGBLevelsFlash' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsFlash(),
                'WB_RGGBLevelsCustom' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsCustom(),
                'WB_RGGBLevelsKelvin' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsKelvin(),
                'CameraColorCalibration01' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration01(),
                'CameraColorCalibration02' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration02(),
                'CameraColorCalibration03' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration03(),
                'CameraColorCalibration04' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration04(),
                'CameraColorCalibration05' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration05(),
                'CameraColorCalibration06' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration06(),
                'CameraColorCalibration07' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration07(),
                'CameraColorCalibration08' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration08(),
                'CameraColorCalibration09' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration09(),
                'CameraColorCalibration10' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration10(),
                'CameraColorCalibration11' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration11(),
                'CameraColorCalibration12' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration12(),
                'CameraColorCalibration13' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration13(),
                'CameraColorCalibration14' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration14(),
                'CameraColorCalibration15' => new \PHPExiftool\Driver\Tag\Canon\CameraColorCalibration15(),
                'WB_RGGBLevelsAsShot' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsAsShot(),
                'ColorTempAsShot' => new \PHPExiftool\Driver\Tag\Canon\ColorTempAsShot(),
                'ColorTempAuto' => new \PHPExiftool\Driver\Tag\Canon\ColorTempAuto(),
                'WB_RGGBLevelsMeasured' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsMeasured(),
                'ColorTempMeasured' => new \PHPExiftool\Driver\Tag\Canon\ColorTempMeasured(),
                'WB_RGGBLevelsUnknown' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown(),
                'ColorTempUnknown' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown(),
                'ColorTempDaylight' => new \PHPExiftool\Driver\Tag\Canon\ColorTempDaylight(),
                'ColorTempShade' => new \PHPExiftool\Driver\Tag\Canon\ColorTempShade(),
                'ColorTempCloudy' => new \PHPExiftool\Driver\Tag\Canon\ColorTempCloudy(),
                'ColorTempTungsten' => new \PHPExiftool\Driver\Tag\Canon\ColorTempTungsten(),
                'ColorTempFluorescent' => new \PHPExiftool\Driver\Tag\Canon\ColorTempFluorescent(),
                'ColorTempKelvin' => new \PHPExiftool\Driver\Tag\Canon\ColorTempKelvin(),
                'ColorTempFlash' => new \PHPExiftool\Driver\Tag\Canon\ColorTempFlash(),
                'WB_RGGBLevelsUnknown2' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown2(),
                'ColorTempUnknown2' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown2(),
                'WB_RGGBLevelsUnknown3' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown3(),
                'ColorTempUnknown3' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown3(),
                'WB_RGGBLevelsUnknown4' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown4(),
                'ColorTempUnknown4' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown4(),
                'WB_RGGBLevelsUnknown5' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown5(),
                'ColorTempUnknown5' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown5(),
                'WB_RGGBLevelsUnknown6' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown6(),
                'ColorTempUnknown6' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown6(),
                'WB_RGGBLevelsUnknown7' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown7(),
                'ColorTempUnknown7' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown7(),
                'WB_RGGBLevelsUnknown8' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown8(),
                'ColorTempUnknown8' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown8(),
                'WB_RGGBLevelsUnknown9' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown9(),
                'ColorTempUnknown9' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown9(),
                'WB_RGGBLevelsUnknown10' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown10(),
                'ColorTempUnknown10' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown10(),
                'WB_RGGBLevelsUnknown11' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown11(),
                'ColorTempUnknown11' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown11(),
                'WB_RGGBLevelsUnknown12' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown12(),
                'ColorTempUnknown12' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown12(),
                'WB_RGGBLevelsUnknown13' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown13(),
                'ColorTempUnknown13' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown13(),
                'WB_RGGBLevelsCustom1' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsCustom1(),
                'ColorTempCustom1' => new \PHPExiftool\Driver\Tag\Canon\ColorTempCustom1(),
                'WB_RGGBLevelsCustom2' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsCustom2(),
                'ColorTempCustom2' => new \PHPExiftool\Driver\Tag\Canon\ColorTempCustom2(),
                'WB_RGGBLevelsUnknown14' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown14(),
                'ColorTempUnknown14' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown14(),
                'WB_RGGBLevelsUnknown15' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown15(),
                'ColorTempUnknown15' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown15(),
                'WB_RGGBLevelsPC1' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsPC1(),
                'ColorTempPC1' => new \PHPExiftool\Driver\Tag\Canon\ColorTempPC1(),
                'WB_RGGBLevelsPC2' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsPC2(),
                'ColorTempPC2' => new \PHPExiftool\Driver\Tag\Canon\ColorTempPC2(),
                'WB_RGGBLevelsPC3' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsPC3(),
                'ColorTempPC3' => new \PHPExiftool\Driver\Tag\Canon\ColorTempPC3(),
                'WB_RGGBLevelsUnknown16' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown16(),
                'ColorTempUnknown16' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown16(),
                'RawMeasuredRGGB' => new \PHPExiftool\Driver\Tag\Canon\RawMeasuredRGGB(),
                'ColorDataVersion' => new \PHPExiftool\Driver\Tag\Canon\ColorDataVersion(),
                'ColorTempCustom' => new \PHPExiftool\Driver\Tag\Canon\ColorTempCustom(),
                'FlashOutput' => new \PHPExiftool\Driver\Tag\Canon\FlashOutput(),
                'FlashBatteryLevel' => new \PHPExiftool\Driver\Tag\Canon\FlashBatteryLevel(),
                'ColorTempFlashData' => new \PHPExiftool\Driver\Tag\Canon\ColorTempFlashData(),
                'MeasuredRGGBData' => new \PHPExiftool\Driver\Tag\Canon\MeasuredRGGBData(),
                'WB_RGGBLevelsUnknown17' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown17(),
                'ColorTempUnknown17' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown17(),
                'WB_RGGBLevelsUnknown18' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown18(),
                'ColorTempUnknown18' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown18(),
                'WB_RGGBLevelsUnknown19' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown19(),
                'ColorTempUnknown19' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown19(),
                'WB_RGGBLevelsUnknown20' => new \PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown20(),
                'ColorTempUnknown20' => new \PHPExiftool\Driver\Tag\Canon\ColorTempUnknown20(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Canon\ColorSpace(),
                'IntelligentContrast' => new \PHPExiftool\Driver\Tag\Canon\IntelligentContrast(),
                'CropLeftMargin' => new \PHPExiftool\Driver\Tag\Canon\CropLeftMargin(),
                'CropRightMargin' => new \PHPExiftool\Driver\Tag\Canon\CropRightMargin(),
                'CropTopMargin' => new \PHPExiftool\Driver\Tag\Canon\CropTopMargin(),
                'CropBottomMargin' => new \PHPExiftool\Driver\Tag\Canon\CropBottomMargin(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Canon\FacesDetected(),
                'FaceDetectFrameSize' => new \PHPExiftool\Driver\Tag\Canon\FaceDetectFrameSize(),
                'Face1Position' => new \PHPExiftool\Driver\Tag\Canon\Face1Position(),
                'Face2Position' => new \PHPExiftool\Driver\Tag\Canon\Face2Position(),
                'Face3Position' => new \PHPExiftool\Driver\Tag\Canon\Face3Position(),
                'Face4Position' => new \PHPExiftool\Driver\Tag\Canon\Face4Position(),
                'Face5Position' => new \PHPExiftool\Driver\Tag\Canon\Face5Position(),
                'Face6Position' => new \PHPExiftool\Driver\Tag\Canon\Face6Position(),
                'Face7Position' => new \PHPExiftool\Driver\Tag\Canon\Face7Position(),
                'Face8Position' => new \PHPExiftool\Driver\Tag\Canon\Face8Position(),
                'Face9Position' => new \PHPExiftool\Driver\Tag\Canon\Face9Position(),
                'FaceWidth' => new \PHPExiftool\Driver\Tag\Canon\FaceWidth(),
                'FileNumber' => new \PHPExiftool\Driver\Tag\Canon\FileNumber(),
                'BracketMode' => new \PHPExiftool\Driver\Tag\Canon\BracketMode(),
                'BracketValue' => new \PHPExiftool\Driver\Tag\Canon\BracketValue(),
                'BracketShotNumber' => new \PHPExiftool\Driver\Tag\Canon\BracketShotNumber(),
                'RawJpgQuality' => new \PHPExiftool\Driver\Tag\Canon\RawJpgQuality(),
                'RawJpgSize' => new \PHPExiftool\Driver\Tag\Canon\RawJpgSize(),
                'LongExposureNoiseReduction2' => new \PHPExiftool\Driver\Tag\Canon\LongExposureNoiseReduction2(),
                'WBBracketMode' => new \PHPExiftool\Driver\Tag\Canon\WBBracketMode(),
                'WBBracketValueAB' => new \PHPExiftool\Driver\Tag\Canon\WBBracketValueAB(),
                'WBBracketValueGM' => new \PHPExiftool\Driver\Tag\Canon\WBBracketValueGM(),
                'FilterEffect' => new \PHPExiftool\Driver\Tag\Canon\FilterEffect(),
                'ToningEffect' => new \PHPExiftool\Driver\Tag\Canon\ToningEffect(),
                'LiveViewShooting' => new \PHPExiftool\Driver\Tag\Canon\LiveViewShooting(),
                'FlashExposureLock' => new \PHPExiftool\Driver\Tag\Canon\FlashExposureLock(),
                'GrainyBWFilter' => new \PHPExiftool\Driver\Tag\Canon\GrainyBWFilter(),
                'SoftFocusFilter' => new \PHPExiftool\Driver\Tag\Canon\SoftFocusFilter(),
                'ToyCameraFilter' => new \PHPExiftool\Driver\Tag\Canon\ToyCameraFilter(),
                'MiniatureFilter' => new \PHPExiftool\Driver\Tag\Canon\MiniatureFilter(),
                'MiniatureFilterOrientation' => new \PHPExiftool\Driver\Tag\Canon\MiniatureFilterOrientation(),
                'MiniatureFilterPosition' => new \PHPExiftool\Driver\Tag\Canon\MiniatureFilterPosition(),
                'ModifiedParamFlag' => new \PHPExiftool\Driver\Tag\Canon\ModifiedParamFlag(),
                'FocalPlaneXSize' => new \PHPExiftool\Driver\Tag\Canon\FocalPlaneXSize(),
                'FocalPlaneXUnknown' => new \PHPExiftool\Driver\Tag\Canon\FocalPlaneXUnknown(),
                'FocalPlaneYSize' => new \PHPExiftool\Driver\Tag\Canon\FocalPlaneYSize(),
                'FocalPlaneYUnknown' => new \PHPExiftool\Driver\Tag\Canon\FocalPlaneYUnknown(),
                'LensSerialNumber' => new \PHPExiftool\Driver\Tag\Canon\LensSerialNumber(),
                'CanonFlashInfo' => new \PHPExiftool\Driver\Tag\Canon\CanonFlashInfo(),
                'CanonImageType' => new \PHPExiftool\Driver\Tag\Canon\CanonImageType(),
                'CanonFirmwareVersion' => new \PHPExiftool\Driver\Tag\Canon\CanonFirmwareVersion(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Canon\SerialNumber(),
                'CanonFileLength' => new \PHPExiftool\Driver\Tag\Canon\CanonFileLength(),
                'CanonModelID' => new \PHPExiftool\Driver\Tag\Canon\CanonModelID(),
                'ThumbnailImageValidArea' => new \PHPExiftool\Driver\Tag\Canon\ThumbnailImageValidArea(),
                'SerialNumberFormat' => new \PHPExiftool\Driver\Tag\Canon\SerialNumberFormat(),
                'SuperMacro' => new \PHPExiftool\Driver\Tag\Canon\SuperMacro(),
                'DateStampMode' => new \PHPExiftool\Driver\Tag\Canon\DateStampMode(),
                'Categories' => new \PHPExiftool\Driver\Tag\Canon\Categories(),
                'ImageUniqueID' => new \PHPExiftool\Driver\Tag\Canon\ImageUniqueID(),
                'RawDataOffset' => new \PHPExiftool\Driver\Tag\Canon\RawDataOffset(),
                'OriginalDecisionDataOffset' => new \PHPExiftool\Driver\Tag\Canon\OriginalDecisionDataOffset(),
                'AFPointsInFocus1D' => new \PHPExiftool\Driver\Tag\Canon\AFPointsInFocus1D(),
                'InternalSerialNumber' => new \PHPExiftool\Driver\Tag\Canon\InternalSerialNumber(),
                'DustRemovalData' => new \PHPExiftool\Driver\Tag\Canon\DustRemovalData(),
                'ToneCurveTable' => new \PHPExiftool\Driver\Tag\Canon\ToneCurveTable(),
                'SharpnessTable' => new \PHPExiftool\Driver\Tag\Canon\SharpnessTable(),
                'SharpnessFreqTable' => new \PHPExiftool\Driver\Tag\Canon\SharpnessFreqTable(),
                'WhiteBalanceTable' => new \PHPExiftool\Driver\Tag\Canon\WhiteBalanceTable(),
                'ToneCurveMatching' => new \PHPExiftool\Driver\Tag\Canon\ToneCurveMatching(),
                'WhiteBalanceMatching' => new \PHPExiftool\Driver\Tag\Canon\WhiteBalanceMatching(),
                'VRDOffset' => new \PHPExiftool\Driver\Tag\Canon\VRDOffset(),
                'CRWParam' => new \PHPExiftool\Driver\Tag\Canon\CRWParam(),
                'Flavor' => new \PHPExiftool\Driver\Tag\Canon\Flavor(),
                'BlackLevel' => new \PHPExiftool\Driver\Tag\Canon\BlackLevel(),
                'CustomPictureStyleFileName' => new \PHPExiftool\Driver\Tag\Canon\CustomPictureStyleFileName(),
                'MeasuredRGGB' => new \PHPExiftool\Driver\Tag\Canon\MeasuredRGGB(),
                'ModifiedToneCurve' => new \PHPExiftool\Driver\Tag\Canon\ModifiedToneCurve(),
                'ModifiedSharpness' => new \PHPExiftool\Driver\Tag\Canon\ModifiedSharpness(),
                'ModifiedSharpnessFreq' => new \PHPExiftool\Driver\Tag\Canon\ModifiedSharpnessFreq(),
                'ModifiedSensorRedLevel' => new \PHPExiftool\Driver\Tag\Canon\ModifiedSensorRedLevel(),
                'ModifiedSensorBlueLevel' => new \PHPExiftool\Driver\Tag\Canon\ModifiedSensorBlueLevel(),
                'ModifiedWhiteBalanceRed' => new \PHPExiftool\Driver\Tag\Canon\ModifiedWhiteBalanceRed(),
                'ModifiedWhiteBalanceBlue' => new \PHPExiftool\Driver\Tag\Canon\ModifiedWhiteBalanceBlue(),
                'ModifiedWhiteBalance' => new \PHPExiftool\Driver\Tag\Canon\ModifiedWhiteBalance(),
                'ModifiedColorTemp' => new \PHPExiftool\Driver\Tag\Canon\ModifiedColorTemp(),
                'ModifiedPictureStyle' => new \PHPExiftool\Driver\Tag\Canon\ModifiedPictureStyle(),
                'ModifiedDigitalGain' => new \PHPExiftool\Driver\Tag\Canon\ModifiedDigitalGain(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\Canon\FrameRate(),
                'FrameCount' => new \PHPExiftool\Driver\Tag\Canon\FrameCount(),
                'Duration' => new \PHPExiftool\Driver\Tag\Canon\Duration(),
                'AudioBitrate' => new \PHPExiftool\Driver\Tag\Canon\AudioBitrate(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\Canon\AudioSampleRate(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\Canon\AudioChannels(),
                'VideoCodec' => new \PHPExiftool\Driver\Tag\Canon\VideoCodec(),
                'MyColorMode' => new \PHPExiftool\Driver\Tag\Canon\MyColorMode(),
                'FilterEffectStandard' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectStandard(),
                'ToningEffectStandard' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectStandard(),
                'FilterEffectPortrait' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectPortrait(),
                'ToningEffectPortrait' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectPortrait(),
                'FilterEffectLandscape' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectLandscape(),
                'ToningEffectLandscape' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectLandscape(),
                'FilterEffectNeutral' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectNeutral(),
                'ToningEffectNeutral' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectNeutral(),
                'FilterEffectFaithful' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectFaithful(),
                'ToningEffectFaithful' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectFaithful(),
                'SaturationMonochrome' => new \PHPExiftool\Driver\Tag\Canon\SaturationMonochrome(),
                'ColorToneMonochrome' => new \PHPExiftool\Driver\Tag\Canon\ColorToneMonochrome(),
                'FilterEffectUserDef1' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectUserDef1(),
                'ToningEffectUserDef1' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectUserDef1(),
                'FilterEffectUserDef2' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectUserDef2(),
                'ToningEffectUserDef2' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectUserDef2(),
                'FilterEffectUserDef3' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectUserDef3(),
                'ToningEffectUserDef3' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectUserDef3(),
                'ContrastUnknown' => new \PHPExiftool\Driver\Tag\Canon\ContrastUnknown(),
                'SharpnessUnknown' => new \PHPExiftool\Driver\Tag\Canon\SharpnessUnknown(),
                'SaturationUnknown' => new \PHPExiftool\Driver\Tag\Canon\SaturationUnknown(),
                'ColorToneUnknown' => new \PHPExiftool\Driver\Tag\Canon\ColorToneUnknown(),
                'FilterEffectUnknown' => new \PHPExiftool\Driver\Tag\Canon\FilterEffectUnknown(),
                'ToningEffectUnknown' => new \PHPExiftool\Driver\Tag\Canon\ToningEffectUnknown(),
                'PanoramaFrameNumber' => new \PHPExiftool\Driver\Tag\Canon\PanoramaFrameNumber(),
                'PanoramaDirection' => new \PHPExiftool\Driver\Tag\Canon\PanoramaDirection(),
                'PreviewQuality' => new \PHPExiftool\Driver\Tag\Canon\PreviewQuality(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Canon\PreviewImageLength(),
                'PreviewImageWidth' => new \PHPExiftool\Driver\Tag\Canon\PreviewImageWidth(),
                'PreviewImageHeight' => new \PHPExiftool\Driver\Tag\Canon\PreviewImageHeight(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Canon\PreviewImageStart(),
                'ToneCurve' => new \PHPExiftool\Driver\Tag\Canon\ToneCurve(),
                'SensorRedLevel' => new \PHPExiftool\Driver\Tag\Canon\SensorRedLevel(),
                'SensorBlueLevel' => new \PHPExiftool\Driver\Tag\Canon\SensorBlueLevel(),
                'WhiteBalanceRed' => new \PHPExiftool\Driver\Tag\Canon\WhiteBalanceRed(),
                'WhiteBalanceBlue' => new \PHPExiftool\Driver\Tag\Canon\WhiteBalanceBlue(),
                'DigitalGain' => new \PHPExiftool\Driver\Tag\Canon\DigitalGain(),
                'WBShiftAB' => new \PHPExiftool\Driver\Tag\Canon\WBShiftAB(),
                'WBShiftGM' => new \PHPExiftool\Driver\Tag\Canon\WBShiftGM(),
                'SensorWidth' => new \PHPExiftool\Driver\Tag\Canon\SensorWidth(),
                'SensorHeight' => new \PHPExiftool\Driver\Tag\Canon\SensorHeight(),
                'SensorLeftBorder' => new \PHPExiftool\Driver\Tag\Canon\SensorLeftBorder(),
                'SensorTopBorder' => new \PHPExiftool\Driver\Tag\Canon\SensorTopBorder(),
                'SensorRightBorder' => new \PHPExiftool\Driver\Tag\Canon\SensorRightBorder(),
                'SensorBottomBorder' => new \PHPExiftool\Driver\Tag\Canon\SensorBottomBorder(),
                'BlackMaskLeftBorder' => new \PHPExiftool\Driver\Tag\Canon\BlackMaskLeftBorder(),
                'BlackMaskTopBorder' => new \PHPExiftool\Driver\Tag\Canon\BlackMaskTopBorder(),
                'BlackMaskRightBorder' => new \PHPExiftool\Driver\Tag\Canon\BlackMaskRightBorder(),
                'BlackMaskBottomBorder' => new \PHPExiftool\Driver\Tag\Canon\BlackMaskBottomBorder(),
                'AutoISO' => new \PHPExiftool\Driver\Tag\Canon\AutoISO(),
                'BaseISO' => new \PHPExiftool\Driver\Tag\Canon\BaseISO(),
                'TargetAperture' => new \PHPExiftool\Driver\Tag\Canon\TargetAperture(),
                'TargetExposureTime' => new \PHPExiftool\Driver\Tag\Canon\TargetExposureTime(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Canon\ExposureCompensation(),
                'SlowShutter' => new \PHPExiftool\Driver\Tag\Canon\SlowShutter(),
                'SequenceNumber' => new \PHPExiftool\Driver\Tag\Canon\SequenceNumber(),
                'OpticalZoomCode' => new \PHPExiftool\Driver\Tag\Canon\OpticalZoomCode(),
                'FlashGuideNumber' => new \PHPExiftool\Driver\Tag\Canon\FlashGuideNumber(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\Canon\FlashExposureComp(),
                'AutoExposureBracketing' => new \PHPExiftool\Driver\Tag\Canon\AutoExposureBracketing(),
                'AEBBracketValue' => new \PHPExiftool\Driver\Tag\Canon\AEBBracketValue(),
                'ControlMode' => new \PHPExiftool\Driver\Tag\Canon\ControlMode(),
                'BulbDuration' => new \PHPExiftool\Driver\Tag\Canon\BulbDuration(),
                'CameraType' => new \PHPExiftool\Driver\Tag\Canon\CameraType(),
                'AutoRotate' => new \PHPExiftool\Driver\Tag\Canon\AutoRotate(),
                'NDFilter' => new \PHPExiftool\Driver\Tag\Canon\NDFilter(),
                'SelfTimer2' => new \PHPExiftool\Driver\Tag\Canon\SelfTimer2(),
                'Unknown_CNDB' => new \PHPExiftool\Driver\Tag\Canon\UnknownCNDB(),
                'TimeZone' => new \PHPExiftool\Driver\Tag\Canon\TimeZone(),
                'TimeZoneCity' => new \PHPExiftool\Driver\Tag\Canon\TimeZoneCity(),
                'DaylightSavings' => new \PHPExiftool\Driver\Tag\Canon\DaylightSavings(),
                'PeripheralLighting' => new \PHPExiftool\Driver\Tag\Canon\PeripheralLighting(),
                'PeripheralLightingValue' => new \PHPExiftool\Driver\Tag\Canon\PeripheralLightingValue(),
                'OriginalImageWidth' => new \PHPExiftool\Driver\Tag\Canon\OriginalImageWidth(),
                'OriginalImageHeight' => new \PHPExiftool\Driver\Tag\Canon\OriginalImageHeight(),
                'PeripheralLightingSetting' => new \PHPExiftool\Driver\Tag\Canon\PeripheralLightingSetting(),
            );
        });
        $this['CanonCustom'] = $this->share(function(){
            return array(
                'SetButtonWhenShooting' => new \PHPExiftool\Driver\Tag\CanonCustom\SetButtonWhenShooting(),
                'ShutterReleaseNoCFCard' => new \PHPExiftool\Driver\Tag\CanonCustom\ShutterReleaseNoCFCard(),
                'FlashSyncSpeedAv' => new \PHPExiftool\Driver\Tag\CanonCustom\FlashSyncSpeedAv(),
                'Shutter-AELock' => new \PHPExiftool\Driver\Tag\CanonCustom\ShutterAELock(),
                'AFAssist' => new \PHPExiftool\Driver\Tag\CanonCustom\AFAssist(),
                'ExposureLevelIncrements' => new \PHPExiftool\Driver\Tag\CanonCustom\ExposureLevelIncrements(),
                'AFPointRegistration' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointRegistration(),
                'RawAndJpgRecording' => new \PHPExiftool\Driver\Tag\CanonCustom\RawAndJpgRecording(),
                'AEBSequenceAutoCancel' => new \PHPExiftool\Driver\Tag\CanonCustom\AEBSequenceAutoCancel(),
                'SuperimposedDisplay' => new \PHPExiftool\Driver\Tag\CanonCustom\SuperimposedDisplay(),
                'MenuButtonDisplayPosition' => new \PHPExiftool\Driver\Tag\CanonCustom\MenuButtonDisplayPosition(),
                'MirrorLockup' => new \PHPExiftool\Driver\Tag\CanonCustom\MirrorLockup(),
                'AssistButtonFunction' => new \PHPExiftool\Driver\Tag\CanonCustom\AssistButtonFunction(),
                'FillFlashAutoReduction' => new \PHPExiftool\Driver\Tag\CanonCustom\FillFlashAutoReduction(),
                'ShutterCurtainSync' => new \PHPExiftool\Driver\Tag\CanonCustom\ShutterCurtainSync(),
                'SafetyShiftInAvOrTv' => new \PHPExiftool\Driver\Tag\CanonCustom\SafetyShiftInAvOrTv(),
                'LensAFStopButton' => new \PHPExiftool\Driver\Tag\CanonCustom\LensAFStopButton(),
                'FocusingScreen' => new \PHPExiftool\Driver\Tag\CanonCustom\FocusingScreen(),
                'FinderDisplayDuringExposure' => new \PHPExiftool\Driver\Tag\CanonCustom\FinderDisplayDuringExposure(),
                'ISOSpeedExpansion' => new \PHPExiftool\Driver\Tag\CanonCustom\ISOSpeedExpansion(),
                'ShutterAELButton' => new \PHPExiftool\Driver\Tag\CanonCustom\ShutterAELButton(),
                'ManualTv' => new \PHPExiftool\Driver\Tag\CanonCustom\ManualTv(),
                'USMLensElectronicMF' => new \PHPExiftool\Driver\Tag\CanonCustom\USMLensElectronicMF(),
                'LCDPanels' => new \PHPExiftool\Driver\Tag\CanonCustom\LCDPanels(),
                'AFPointIllumination' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointIllumination(),
                'AFPointSelection' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointSelection(),
                'AFPointSpotMetering' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointSpotMetering(),
                'AFPointActivationArea' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointActivationArea(),
                'SwitchToRegisteredAFPoint' => new \PHPExiftool\Driver\Tag\CanonCustom\SwitchToRegisteredAFPoint(),
                'AIServoTrackingSensitivity' => new \PHPExiftool\Driver\Tag\CanonCustom\AIServoTrackingSensitivity(),
                'AIServoContinuousShooting' => new \PHPExiftool\Driver\Tag\CanonCustom\AIServoContinuousShooting(),
                'ISOSpeedIncrements' => new \PHPExiftool\Driver\Tag\CanonCustom\ISOSpeedIncrements(),
                'ISOSpeedRange' => new \PHPExiftool\Driver\Tag\CanonCustom\ISOSpeedRange(),
                'ISOExpansion' => new \PHPExiftool\Driver\Tag\CanonCustom\ISOExpansion(),
                'AEBAutoCancel' => new \PHPExiftool\Driver\Tag\CanonCustom\AEBAutoCancel(),
                'AEBSequence' => new \PHPExiftool\Driver\Tag\CanonCustom\AEBSequence(),
                'AEBShotCount' => new \PHPExiftool\Driver\Tag\CanonCustom\AEBShotCount(),
                'SpotMeterLinkToAFPoint' => new \PHPExiftool\Driver\Tag\CanonCustom\SpotMeterLinkToAFPoint(),
                'SafetyShift' => new \PHPExiftool\Driver\Tag\CanonCustom\SafetyShift(),
                'UsableShootingModes' => new \PHPExiftool\Driver\Tag\CanonCustom\UsableShootingModes(),
                'UsableMeteringModes' => new \PHPExiftool\Driver\Tag\CanonCustom\UsableMeteringModes(),
                'ExposureModeInManual' => new \PHPExiftool\Driver\Tag\CanonCustom\ExposureModeInManual(),
                'ShutterSpeedRange' => new \PHPExiftool\Driver\Tag\CanonCustom\ShutterSpeedRange(),
                'ApertureRange' => new \PHPExiftool\Driver\Tag\CanonCustom\ApertureRange(),
                'ApplyShootingMeteringMode' => new \PHPExiftool\Driver\Tag\CanonCustom\ApplyShootingMeteringMode(),
                'FEMicroadjustment' => new \PHPExiftool\Driver\Tag\CanonCustom\FEMicroadjustment(),
                'AEMicroadjustment' => new \PHPExiftool\Driver\Tag\CanonCustom\AEMicroadjustment(),
                'LongExposureNoiseReduction' => new \PHPExiftool\Driver\Tag\CanonCustom\LongExposureNoiseReduction(),
                'HighISONoiseReduction' => new \PHPExiftool\Driver\Tag\CanonCustom\HighISONoiseReduction(),
                'HighlightTonePriority' => new \PHPExiftool\Driver\Tag\CanonCustom\HighlightTonePriority(),
                'AutoLightingOptimizer' => new \PHPExiftool\Driver\Tag\CanonCustom\AutoLightingOptimizer(),
                'ETTLII' => new \PHPExiftool\Driver\Tag\CanonCustom\ETTLII(),
                'FlashFiring' => new \PHPExiftool\Driver\Tag\CanonCustom\FlashFiring(),
                'ViewInfoDuringExposure' => new \PHPExiftool\Driver\Tag\CanonCustom\ViewInfoDuringExposure(),
                'LCDIlluminationDuringBulb' => new \PHPExiftool\Driver\Tag\CanonCustom\LCDIlluminationDuringBulb(),
                'InfoButtonWhenShooting' => new \PHPExiftool\Driver\Tag\CanonCustom\InfoButtonWhenShooting(),
                'ViewfinderWarnings' => new \PHPExiftool\Driver\Tag\CanonCustom\ViewfinderWarnings(),
                'LVShootingAreaDisplay' => new \PHPExiftool\Driver\Tag\CanonCustom\LVShootingAreaDisplay(),
                'AIServoImagePriority' => new \PHPExiftool\Driver\Tag\CanonCustom\AIServoImagePriority(),
                'AIServoTrackingMethod' => new \PHPExiftool\Driver\Tag\CanonCustom\AIServoTrackingMethod(),
                'LensDriveNoAF' => new \PHPExiftool\Driver\Tag\CanonCustom\LensDriveNoAF(),
                'AFMicroadjustment' => new \PHPExiftool\Driver\Tag\CanonCustom\AFMicroadjustment(),
                'AFPointAreaExpansion' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointAreaExpansion(),
                'SelectableAFPoint' => new \PHPExiftool\Driver\Tag\CanonCustom\SelectableAFPoint(),
                'AFPointAutoSelection' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointAutoSelection(),
                'AFPointDisplayDuringFocus' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointDisplayDuringFocus(),
                'AFPointBrightness' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointBrightness(),
                'AFAssistBeam' => new \PHPExiftool\Driver\Tag\CanonCustom\AFAssistBeam(),
                'AFPointSelectionMethod' => new \PHPExiftool\Driver\Tag\CanonCustom\AFPointSelectionMethod(),
                'VFDisplayIllumination' => new \PHPExiftool\Driver\Tag\CanonCustom\VFDisplayIllumination(),
                'AFDuringLiveView' => new \PHPExiftool\Driver\Tag\CanonCustom\AFDuringLiveView(),
                'SelectAFAreaSelectMode' => new \PHPExiftool\Driver\Tag\CanonCustom\SelectAFAreaSelectMode(),
                'ManualAFPointSelectPattern' => new \PHPExiftool\Driver\Tag\CanonCustom\ManualAFPointSelectPattern(),
                'DisplayAllAFPoints' => new \PHPExiftool\Driver\Tag\CanonCustom\DisplayAllAFPoints(),
                'FocusDisplayAIServoAndMF' => new \PHPExiftool\Driver\Tag\CanonCustom\FocusDisplayAIServoAndMF(),
                'OrientationLinkedAFPoint' => new \PHPExiftool\Driver\Tag\CanonCustom\OrientationLinkedAFPoint(),
                'MultiControllerWhileMetering' => new \PHPExiftool\Driver\Tag\CanonCustom\MultiControllerWhileMetering(),
                'AccelerationTracking' => new \PHPExiftool\Driver\Tag\CanonCustom\AccelerationTracking(),
                'AIServoFirstImagePriority' => new \PHPExiftool\Driver\Tag\CanonCustom\AIServoFirstImagePriority(),
                'AIServoSecondImagePriority' => new \PHPExiftool\Driver\Tag\CanonCustom\AIServoSecondImagePriority(),
                'ContinuousShootingSpeed' => new \PHPExiftool\Driver\Tag\CanonCustom\ContinuousShootingSpeed(),
                'ContinuousShotLimit' => new \PHPExiftool\Driver\Tag\CanonCustom\ContinuousShotLimit(),
                'AFAndMeteringButtons' => new \PHPExiftool\Driver\Tag\CanonCustom\AFAndMeteringButtons(),
                'ShutterButtonAFOnButton' => new \PHPExiftool\Driver\Tag\CanonCustom\ShutterButtonAFOnButton(),
                'AFOnAELockButtonSwitch' => new \PHPExiftool\Driver\Tag\CanonCustom\AFOnAELockButtonSwitch(),
                'QuickControlDialInMeter' => new \PHPExiftool\Driver\Tag\CanonCustom\QuickControlDialInMeter(),
                'DialDirectionTvAv' => new \PHPExiftool\Driver\Tag\CanonCustom\DialDirectionTvAv(),
                'AvSettingWithoutLens' => new \PHPExiftool\Driver\Tag\CanonCustom\AvSettingWithoutLens(),
                'WBMediaImageSizeSetting' => new \PHPExiftool\Driver\Tag\CanonCustom\WBMediaImageSizeSetting(),
                'LockMicrophoneButton' => new \PHPExiftool\Driver\Tag\CanonCustom\LockMicrophoneButton(),
                'ButtonFunctionControlOff' => new \PHPExiftool\Driver\Tag\CanonCustom\ButtonFunctionControlOff(),
                'AssignFuncButton' => new \PHPExiftool\Driver\Tag\CanonCustom\AssignFuncButton(),
                'CustomControls' => new \PHPExiftool\Driver\Tag\CanonCustom\CustomControls(),
                'StartMovieShooting' => new \PHPExiftool\Driver\Tag\CanonCustom\StartMovieShooting(),
                'FlashButtonFunction' => new \PHPExiftool\Driver\Tag\CanonCustom\FlashButtonFunction(),
                'MultiFunctionLock' => new \PHPExiftool\Driver\Tag\CanonCustom\MultiFunctionLock(),
                'TimerLength' => new \PHPExiftool\Driver\Tag\CanonCustom\TimerLength(),
                'ShortReleaseTimeLag' => new \PHPExiftool\Driver\Tag\CanonCustom\ShortReleaseTimeLag(),
                'AddAspectRatioInfo' => new \PHPExiftool\Driver\Tag\CanonCustom\AddAspectRatioInfo(),
                'AddOriginalDecisionData' => new \PHPExiftool\Driver\Tag\CanonCustom\AddOriginalDecisionData(),
                'LiveViewExposureSimulation' => new \PHPExiftool\Driver\Tag\CanonCustom\LiveViewExposureSimulation(),
                'LCDDisplayAtPowerOn' => new \PHPExiftool\Driver\Tag\CanonCustom\LCDDisplayAtPowerOn(),
                'DefaultEraseOption' => new \PHPExiftool\Driver\Tag\CanonCustom\DefaultEraseOption(),
                'SetFunctionWhenShooting' => new \PHPExiftool\Driver\Tag\CanonCustom\SetFunctionWhenShooting(),
                'MagnifiedView' => new \PHPExiftool\Driver\Tag\CanonCustom\MagnifiedView(),
                'SetButtonCrossKeysFunc' => new \PHPExiftool\Driver\Tag\CanonCustom\SetButtonCrossKeysFunc(),
                'LCDDisplayReturnToShoot' => new \PHPExiftool\Driver\Tag\CanonCustom\LCDDisplayReturnToShoot(),
                'MenuButtonReturn' => new \PHPExiftool\Driver\Tag\CanonCustom\MenuButtonReturn(),
                'SensorCleaning' => new \PHPExiftool\Driver\Tag\CanonCustom\SensorCleaning(),
                'PF1Value' => new \PHPExiftool\Driver\Tag\CanonCustom\PF1Value(),
                'PF2Value' => new \PHPExiftool\Driver\Tag\CanonCustom\PF2Value(),
                'PF3Value' => new \PHPExiftool\Driver\Tag\CanonCustom\PF3Value(),
                'PF4ExposureTimeMin' => new \PHPExiftool\Driver\Tag\CanonCustom\PF4ExposureTimeMin(),
                'PF4ExposureTimeMax' => new \PHPExiftool\Driver\Tag\CanonCustom\PF4ExposureTimeMax(),
                'PF5ApertureMin' => new \PHPExiftool\Driver\Tag\CanonCustom\PF5ApertureMin(),
                'PF5ApertureMax' => new \PHPExiftool\Driver\Tag\CanonCustom\PF5ApertureMax(),
                'PF8BracketShots' => new \PHPExiftool\Driver\Tag\CanonCustom\PF8BracketShots(),
                'PF19ShootingSpeedLow' => new \PHPExiftool\Driver\Tag\CanonCustom\PF19ShootingSpeedLow(),
                'PF19ShootingSpeedHigh' => new \PHPExiftool\Driver\Tag\CanonCustom\PF19ShootingSpeedHigh(),
                'PF20MaxContinousShots' => new \PHPExiftool\Driver\Tag\CanonCustom\PF20MaxContinousShots(),
                'PF23ShutterButtonTime' => new \PHPExiftool\Driver\Tag\CanonCustom\PF23ShutterButtonTime(),
                'PF23FELockTime' => new \PHPExiftool\Driver\Tag\CanonCustom\PF23FELockTime(),
                'PF23PostReleaseTime' => new \PHPExiftool\Driver\Tag\CanonCustom\PF23PostReleaseTime(),
                'PF25AEMode' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25AEMode(),
                'PF25MeteringMode' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25MeteringMode(),
                'PF25DriveMode' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25DriveMode(),
                'PF25AFMode' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25AFMode(),
                'PF25AFPointSel' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25AFPointSel(),
                'PF25ImageSize' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25ImageSize(),
                'PF25WBMode' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25WBMode(),
                'PF25Parameters' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25Parameters(),
                'PF25ColorMatrix' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25ColorMatrix(),
                'PF27Value' => new \PHPExiftool\Driver\Tag\CanonCustom\PF27Value(),
                'PF0CustomFuncRegistration' => new \PHPExiftool\Driver\Tag\CanonCustom\PF0CustomFuncRegistration(),
                'PF1DisableShootingModes' => new \PHPExiftool\Driver\Tag\CanonCustom\PF1DisableShootingModes(),
                'PF2DisableMeteringModes' => new \PHPExiftool\Driver\Tag\CanonCustom\PF2DisableMeteringModes(),
                'PF3ManualExposureMetering' => new \PHPExiftool\Driver\Tag\CanonCustom\PF3ManualExposureMetering(),
                'PF4ExposureTimeLimits' => new \PHPExiftool\Driver\Tag\CanonCustom\PF4ExposureTimeLimits(),
                'PF5ApertureLimits' => new \PHPExiftool\Driver\Tag\CanonCustom\PF5ApertureLimits(),
                'PF6PresetShootingModes' => new \PHPExiftool\Driver\Tag\CanonCustom\PF6PresetShootingModes(),
                'PF7BracketContinuousShoot' => new \PHPExiftool\Driver\Tag\CanonCustom\PF7BracketContinuousShoot(),
                'PF8SetBracketShots' => new \PHPExiftool\Driver\Tag\CanonCustom\PF8SetBracketShots(),
                'PF9ChangeBracketSequence' => new \PHPExiftool\Driver\Tag\CanonCustom\PF9ChangeBracketSequence(),
                'PF10RetainProgramShift' => new \PHPExiftool\Driver\Tag\CanonCustom\PF10RetainProgramShift(),
                'PF13DrivePriority' => new \PHPExiftool\Driver\Tag\CanonCustom\PF13DrivePriority(),
                'PF14DisableFocusSearch' => new \PHPExiftool\Driver\Tag\CanonCustom\PF14DisableFocusSearch(),
                'PF15DisableAFAssistBeam' => new \PHPExiftool\Driver\Tag\CanonCustom\PF15DisableAFAssistBeam(),
                'PF16AutoFocusPointShoot' => new \PHPExiftool\Driver\Tag\CanonCustom\PF16AutoFocusPointShoot(),
                'PF17DisableAFPointSel' => new \PHPExiftool\Driver\Tag\CanonCustom\PF17DisableAFPointSel(),
                'PF18EnableAutoAFPointSel' => new \PHPExiftool\Driver\Tag\CanonCustom\PF18EnableAutoAFPointSel(),
                'PF19ContinuousShootSpeed' => new \PHPExiftool\Driver\Tag\CanonCustom\PF19ContinuousShootSpeed(),
                'PF20LimitContinousShots' => new \PHPExiftool\Driver\Tag\CanonCustom\PF20LimitContinousShots(),
                'PF21EnableQuietOperation' => new \PHPExiftool\Driver\Tag\CanonCustom\PF21EnableQuietOperation(),
                'PF23SetTimerLengths' => new \PHPExiftool\Driver\Tag\CanonCustom\PF23SetTimerLengths(),
                'PF24LightLCDDuringBulb' => new \PHPExiftool\Driver\Tag\CanonCustom\PF24LightLCDDuringBulb(),
                'PF25DefaultClearSettings' => new \PHPExiftool\Driver\Tag\CanonCustom\PF25DefaultClearSettings(),
                'PF26ShortenReleaseLag' => new \PHPExiftool\Driver\Tag\CanonCustom\PF26ShortenReleaseLag(),
                'PF27ReverseDialRotation' => new \PHPExiftool\Driver\Tag\CanonCustom\PF27ReverseDialRotation(),
                'PF28NoQuickDialExpComp' => new \PHPExiftool\Driver\Tag\CanonCustom\PF28NoQuickDialExpComp(),
                'PF29QuickDialSwitchOff' => new \PHPExiftool\Driver\Tag\CanonCustom\PF29QuickDialSwitchOff(),
                'PF30EnlargementMode' => new \PHPExiftool\Driver\Tag\CanonCustom\PF30EnlargementMode(),
                'PF31OriginalDecisionData' => new \PHPExiftool\Driver\Tag\CanonCustom\PF31OriginalDecisionData(),
            );
        });
        $this['CanonRaw'] = $this->share(function(){
            return array(
                'DecoderTableNumber' => new \PHPExiftool\Driver\Tag\CanonRaw\DecoderTableNumber(),
                'CompressedDataOffset' => new \PHPExiftool\Driver\Tag\CanonRaw\CompressedDataOffset(),
                'CompressedDataLength' => new \PHPExiftool\Driver\Tag\CanonRaw\CompressedDataLength(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\CanonRaw\ExposureCompensation(),
                'ShutterSpeedValue' => new \PHPExiftool\Driver\Tag\CanonRaw\ShutterSpeedValue(),
                'ApertureValue' => new \PHPExiftool\Driver\Tag\CanonRaw\ApertureValue(),
                'FlashGuideNumber' => new \PHPExiftool\Driver\Tag\CanonRaw\FlashGuideNumber(),
                'FlashThreshold' => new \PHPExiftool\Driver\Tag\CanonRaw\FlashThreshold(),
                'FileFormat' => new \PHPExiftool\Driver\Tag\CanonRaw\FileFormat(),
                'TargetCompressionRatio' => new \PHPExiftool\Driver\Tag\CanonRaw\TargetCompressionRatio(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\CanonRaw\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\CanonRaw\ImageHeight(),
                'PixelAspectRatio' => new \PHPExiftool\Driver\Tag\CanonRaw\PixelAspectRatio(),
                'Rotation' => new \PHPExiftool\Driver\Tag\CanonRaw\Rotation(),
                'ComponentBitDepth' => new \PHPExiftool\Driver\Tag\CanonRaw\ComponentBitDepth(),
                'ColorBitDepth' => new \PHPExiftool\Driver\Tag\CanonRaw\ColorBitDepth(),
                'ColorBW' => new \PHPExiftool\Driver\Tag\CanonRaw\ColorBW(),
                'NullRecord' => new \PHPExiftool\Driver\Tag\CanonRaw\NullRecord(),
                'FreeBytes' => new \PHPExiftool\Driver\Tag\CanonRaw\FreeBytes(),
                'CanonColorInfo1' => new \PHPExiftool\Driver\Tag\CanonRaw\CanonColorInfo1(),
                'CanonFileDescription' => new \PHPExiftool\Driver\Tag\CanonRaw\CanonFileDescription(),
                'UserComment' => new \PHPExiftool\Driver\Tag\CanonRaw\UserComment(),
                'CanonFirmwareVersion' => new \PHPExiftool\Driver\Tag\CanonRaw\CanonFirmwareVersion(),
                'ComponentVersion' => new \PHPExiftool\Driver\Tag\CanonRaw\ComponentVersion(),
                'ROMOperationMode' => new \PHPExiftool\Driver\Tag\CanonRaw\ROMOperationMode(),
                'OwnerName' => new \PHPExiftool\Driver\Tag\CanonRaw\OwnerName(),
                'CanonImageType' => new \PHPExiftool\Driver\Tag\CanonRaw\CanonImageType(),
                'OriginalFileName' => new \PHPExiftool\Driver\Tag\CanonRaw\OriginalFileName(),
                'ThumbnailFileName' => new \PHPExiftool\Driver\Tag\CanonRaw\ThumbnailFileName(),
                'TargetImageType' => new \PHPExiftool\Driver\Tag\CanonRaw\TargetImageType(),
                'ShutterReleaseMethod' => new \PHPExiftool\Driver\Tag\CanonRaw\ShutterReleaseMethod(),
                'ShutterReleaseTiming' => new \PHPExiftool\Driver\Tag\CanonRaw\ShutterReleaseTiming(),
                'ReleaseSetting' => new \PHPExiftool\Driver\Tag\CanonRaw\ReleaseSetting(),
                'BaseISO' => new \PHPExiftool\Driver\Tag\CanonRaw\BaseISO(),
                'CanonFlashInfo' => new \PHPExiftool\Driver\Tag\CanonRaw\CanonFlashInfo(),
                'CanonColorInfo2' => new \PHPExiftool\Driver\Tag\CanonRaw\CanonColorInfo2(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\CanonRaw\ColorTemperature(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\CanonRaw\ColorSpace(),
                'RecordID' => new \PHPExiftool\Driver\Tag\CanonRaw\RecordID(),
                'SelfTimerTime' => new \PHPExiftool\Driver\Tag\CanonRaw\SelfTimerTime(),
                'TargetDistanceSetting' => new \PHPExiftool\Driver\Tag\CanonRaw\TargetDistanceSetting(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\CanonRaw\SerialNumber(),
                'UnknownNumber' => new \PHPExiftool\Driver\Tag\CanonRaw\UnknownNumber(),
                'MeasuredEV' => new \PHPExiftool\Driver\Tag\CanonRaw\MeasuredEV(),
                'FileNumber' => new \PHPExiftool\Driver\Tag\CanonRaw\FileNumber(),
                'CanonModelID' => new \PHPExiftool\Driver\Tag\CanonRaw\CanonModelID(),
                'SerialNumberFormat' => new \PHPExiftool\Driver\Tag\CanonRaw\SerialNumberFormat(),
                'RawData' => new \PHPExiftool\Driver\Tag\CanonRaw\RawData(),
                'JpgFromRaw' => new \PHPExiftool\Driver\Tag\CanonRaw\JpgFromRaw(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\CanonRaw\ThumbnailImage(),
                'Make' => new \PHPExiftool\Driver\Tag\CanonRaw\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\CanonRaw\Model(),
                'RawJpgQuality' => new \PHPExiftool\Driver\Tag\CanonRaw\RawJpgQuality(),
                'RawJpgSize' => new \PHPExiftool\Driver\Tag\CanonRaw\RawJpgSize(),
                'RawJpgWidth' => new \PHPExiftool\Driver\Tag\CanonRaw\RawJpgWidth(),
                'RawJpgHeight' => new \PHPExiftool\Driver\Tag\CanonRaw\RawJpgHeight(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\CanonRaw\DateTimeOriginal(),
                'TimeZoneCode' => new \PHPExiftool\Driver\Tag\CanonRaw\TimeZoneCode(),
                'TimeZoneInfo' => new \PHPExiftool\Driver\Tag\CanonRaw\TimeZoneInfo(),
                'WhiteSampleWidth' => new \PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleWidth(),
                'WhiteSampleHeight' => new \PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleHeight(),
                'WhiteSampleLeftBorder' => new \PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleLeftBorder(),
                'WhiteSampleTopBorder' => new \PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleTopBorder(),
                'WhiteSampleBits' => new \PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleBits(),
            );
        });
        $this['CanonVRD'] = $this->share(function(){
            return array(
                'IHL_EXIF' => new \PHPExiftool\Driver\Tag\CanonVRD\IHLEXIF(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\CanonVRD\ThumbnailImage(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\CanonVRD\PreviewImage(),
                'RawCodecVersion' => new \PHPExiftool\Driver\Tag\CanonVRD\RawCodecVersion(),
                'CRCDevelParams' => new \PHPExiftool\Driver\Tag\CanonVRD\CRCDevelParams(),
                'XMP' => new \PHPExiftool\Driver\Tag\CanonVRD\XMP(),
                'StampToolCount' => new \PHPExiftool\Driver\Tag\CanonVRD\StampToolCount(),
                'VRDVersion' => new \PHPExiftool\Driver\Tag\CanonVRD\VRDVersion(),
                'WBAdjRGGBLevels' => new \PHPExiftool\Driver\Tag\CanonVRD\WBAdjRGGBLevels(),
                'WhiteBalanceAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\WhiteBalanceAdj(),
                'WBAdjColorTemp' => new \PHPExiftool\Driver\Tag\CanonVRD\WBAdjColorTemp(),
                'WBFineTuneActive' => new \PHPExiftool\Driver\Tag\CanonVRD\WBFineTuneActive(),
                'WBFineTuneSaturation' => new \PHPExiftool\Driver\Tag\CanonVRD\WBFineTuneSaturation(),
                'WBFineTuneTone' => new \PHPExiftool\Driver\Tag\CanonVRD\WBFineTuneTone(),
                'RawColorAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\RawColorAdj(),
                'RawCustomSaturation' => new \PHPExiftool\Driver\Tag\CanonVRD\RawCustomSaturation(),
                'RawCustomTone' => new \PHPExiftool\Driver\Tag\CanonVRD\RawCustomTone(),
                'RawBrightnessAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\RawBrightnessAdj(),
                'ToneCurveProperty' => new \PHPExiftool\Driver\Tag\CanonVRD\ToneCurveProperty(),
                'DynamicRangeMin' => new \PHPExiftool\Driver\Tag\CanonVRD\DynamicRangeMin(),
                'DynamicRangeMax' => new \PHPExiftool\Driver\Tag\CanonVRD\DynamicRangeMax(),
                'ToneCurveActive' => new \PHPExiftool\Driver\Tag\CanonVRD\ToneCurveActive(),
                'ToneCurveMode' => new \PHPExiftool\Driver\Tag\CanonVRD\ToneCurveMode(),
                'BrightnessAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\BrightnessAdj(),
                'ContrastAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\ContrastAdj(),
                'SaturationAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\SaturationAdj(),
                'ColorToneAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\ColorToneAdj(),
                'LuminanceCurvePoints' => new \PHPExiftool\Driver\Tag\CanonVRD\LuminanceCurvePoints(),
                'LuminanceCurveLimits' => new \PHPExiftool\Driver\Tag\CanonVRD\LuminanceCurveLimits(),
                'ToneCurveInterpolation' => new \PHPExiftool\Driver\Tag\CanonVRD\ToneCurveInterpolation(),
                'RedCurvePoints' => new \PHPExiftool\Driver\Tag\CanonVRD\RedCurvePoints(),
                'RedCurveLimits' => new \PHPExiftool\Driver\Tag\CanonVRD\RedCurveLimits(),
                'GreenCurvePoints' => new \PHPExiftool\Driver\Tag\CanonVRD\GreenCurvePoints(),
                'GreenCurveLimits' => new \PHPExiftool\Driver\Tag\CanonVRD\GreenCurveLimits(),
                'BlueCurvePoints' => new \PHPExiftool\Driver\Tag\CanonVRD\BlueCurvePoints(),
                'BlueCurveLimits' => new \PHPExiftool\Driver\Tag\CanonVRD\BlueCurveLimits(),
                'RGBCurvePoints' => new \PHPExiftool\Driver\Tag\CanonVRD\RGBCurvePoints(),
                'RGBCurveLimits' => new \PHPExiftool\Driver\Tag\CanonVRD\RGBCurveLimits(),
                'CropActive' => new \PHPExiftool\Driver\Tag\CanonVRD\CropActive(),
                'CropLeft' => new \PHPExiftool\Driver\Tag\CanonVRD\CropLeft(),
                'CropTop' => new \PHPExiftool\Driver\Tag\CanonVRD\CropTop(),
                'CropWidth' => new \PHPExiftool\Driver\Tag\CanonVRD\CropWidth(),
                'CropHeight' => new \PHPExiftool\Driver\Tag\CanonVRD\CropHeight(),
                'SharpnessAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\SharpnessAdj(),
                'CropAspectRatio' => new \PHPExiftool\Driver\Tag\CanonVRD\CropAspectRatio(),
                'ConstrainedCropWidth' => new \PHPExiftool\Driver\Tag\CanonVRD\ConstrainedCropWidth(),
                'ConstrainedCropHeight' => new \PHPExiftool\Driver\Tag\CanonVRD\ConstrainedCropHeight(),
                'CheckMark' => new \PHPExiftool\Driver\Tag\CanonVRD\CheckMark(),
                'Rotation' => new \PHPExiftool\Driver\Tag\CanonVRD\Rotation(),
                'WorkColorSpace' => new \PHPExiftool\Driver\Tag\CanonVRD\WorkColorSpace(),
                'PictureStyle' => new \PHPExiftool\Driver\Tag\CanonVRD\PictureStyle(),
                'IsCustomPictureStyle' => new \PHPExiftool\Driver\Tag\CanonVRD\IsCustomPictureStyle(),
                'StandardRawColorTone' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawColorTone(),
                'StandardRawSaturation' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawSaturation(),
                'StandardRawContrast' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawContrast(),
                'StandardRawLinear' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawLinear(),
                'StandardRawSharpness' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawSharpness(),
                'StandardRawHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawHighlightPoint(),
                'StandardRawShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawShadowPoint(),
                'StandardOutputHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardOutputHighlightPoint(),
                'StandardOutputShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardOutputShadowPoint(),
                'PortraitRawColorTone' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawColorTone(),
                'PortraitRawSaturation' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawSaturation(),
                'PortraitRawContrast' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawContrast(),
                'PortraitRawLinear' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawLinear(),
                'PortraitRawSharpness' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawSharpness(),
                'PortraitRawHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawHighlightPoint(),
                'PortraitRawShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawShadowPoint(),
                'PortraitOutputHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitOutputHighlightPoint(),
                'PortraitOutputShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitOutputShadowPoint(),
                'LandscapeRawColorTone' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawColorTone(),
                'LandscapeRawSaturation' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawSaturation(),
                'LandscapeRawContrast' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawContrast(),
                'LandscapeRawLinear' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawLinear(),
                'LandscapeRawSharpness' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawSharpness(),
                'LandscapeRawHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawHighlightPoint(),
                'LandscapeRawShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawShadowPoint(),
                'LandscapeOutputHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeOutputHighlightPoint(),
                'LandscapeOutputShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeOutputShadowPoint(),
                'NeutralRawColorTone' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawColorTone(),
                'NeutralRawSaturation' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawSaturation(),
                'NeutralRawContrast' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawContrast(),
                'NeutralRawLinear' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawLinear(),
                'NeutralRawSharpness' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawSharpness(),
                'NeutralRawHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawHighlightPoint(),
                'NeutralRawShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawShadowPoint(),
                'NeutralOutputHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralOutputHighlightPoint(),
                'NeutralOutputShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralOutputShadowPoint(),
                'FaithfulRawColorTone' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawColorTone(),
                'FaithfulRawSaturation' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawSaturation(),
                'FaithfulRawContrast' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawContrast(),
                'FaithfulRawLinear' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawLinear(),
                'FaithfulRawSharpness' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawSharpness(),
                'FaithfulRawHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawHighlightPoint(),
                'FaithfulRawShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawShadowPoint(),
                'FaithfulOutputHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulOutputHighlightPoint(),
                'FaithfulOutputShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulOutputShadowPoint(),
                'MonochromeFilterEffect' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeFilterEffect(),
                'MonochromeToningEffect' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeToningEffect(),
                'MonochromeContrast' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeContrast(),
                'MonochromeLinear' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeLinear(),
                'MonochromeSharpness' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeSharpness(),
                'MonochromeRawHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeRawHighlightPoint(),
                'MonochromeRawShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeRawShadowPoint(),
                'MonochromeOutputHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeOutputHighlightPoint(),
                'MonochromeOutputShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeOutputShadowPoint(),
                'UnknownContrast' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownContrast(),
                'UnknownLinear' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownLinear(),
                'UnknownSharpness' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownSharpness(),
                'UnknownRawHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownRawHighlightPoint(),
                'UnknownRawShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownRawShadowPoint(),
                'UnknownOutputHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownOutputHighlightPoint(),
                'UnknownOutputShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownOutputShadowPoint(),
                'CustomContrast' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomContrast(),
                'CustomLinear' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomLinear(),
                'CustomSharpness' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomSharpness(),
                'CustomRawHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomRawHighlightPoint(),
                'CustomRawShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomRawShadowPoint(),
                'CustomOutputHighlightPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomOutputHighlightPoint(),
                'CustomOutputShadowPoint' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomOutputShadowPoint(),
                'CustomPictureStyleData' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomPictureStyleData(),
                'ChrominanceNoiseReduction' => new \PHPExiftool\Driver\Tag\CanonVRD\ChrominanceNoiseReduction(),
                'LuminanceNoiseReduction' => new \PHPExiftool\Driver\Tag\CanonVRD\LuminanceNoiseReduction(),
                'ChrominanceNR_TIFF_JPEG' => new \PHPExiftool\Driver\Tag\CanonVRD\ChrominanceNRTIFFJPEG(),
                'ChromaticAberrationOn' => new \PHPExiftool\Driver\Tag\CanonVRD\ChromaticAberrationOn(),
                'DistortionCorrectionOn' => new \PHPExiftool\Driver\Tag\CanonVRD\DistortionCorrectionOn(),
                'PeripheralIlluminationOn' => new \PHPExiftool\Driver\Tag\CanonVRD\PeripheralIlluminationOn(),
                'ColorBlur' => new \PHPExiftool\Driver\Tag\CanonVRD\ColorBlur(),
                'ChromaticAberration' => new \PHPExiftool\Driver\Tag\CanonVRD\ChromaticAberration(),
                'DistortionCorrection' => new \PHPExiftool\Driver\Tag\CanonVRD\DistortionCorrection(),
                'PeripheralIllumination' => new \PHPExiftool\Driver\Tag\CanonVRD\PeripheralIllumination(),
                'AberrationCorrectionDistance' => new \PHPExiftool\Driver\Tag\CanonVRD\AberrationCorrectionDistance(),
                'ChromaticAberrationRed' => new \PHPExiftool\Driver\Tag\CanonVRD\ChromaticAberrationRed(),
                'ChromaticAberrationBlue' => new \PHPExiftool\Driver\Tag\CanonVRD\ChromaticAberrationBlue(),
                'LuminanceNR_TIFF_JPEG' => new \PHPExiftool\Driver\Tag\CanonVRD\LuminanceNRTIFFJPEG(),
                'AutoLightingOptimizerOn' => new \PHPExiftool\Driver\Tag\CanonVRD\AutoLightingOptimizerOn(),
                'AutoLightingOptimizer' => new \PHPExiftool\Driver\Tag\CanonVRD\AutoLightingOptimizer(),
                'StandardRawHighlight' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawHighlight(),
                'PortraitRawHighlight' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawHighlight(),
                'LandscapeRawHighlight' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawHighlight(),
                'NeutralRawHighlight' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawHighlight(),
                'FaithfulRawHighlight' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawHighlight(),
                'MonochromeRawHighlight' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeRawHighlight(),
                'UnknownRawHighlight' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownRawHighlight(),
                'CustomRawHighlight' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomRawHighlight(),
                'StandardRawShadow' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardRawShadow(),
                'PortraitRawShadow' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitRawShadow(),
                'LandscapeRawShadow' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawShadow(),
                'NeutralRawShadow' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralRawShadow(),
                'FaithfulRawShadow' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawShadow(),
                'MonochromeRawShadow' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeRawShadow(),
                'UnknownRawShadow' => new \PHPExiftool\Driver\Tag\CanonVRD\UnknownRawShadow(),
                'CustomRawShadow' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomRawShadow(),
                'AngleAdj' => new \PHPExiftool\Driver\Tag\CanonVRD\AngleAdj(),
                'CheckMark2' => new \PHPExiftool\Driver\Tag\CanonVRD\CheckMark2(),
                'UnsharpMask' => new \PHPExiftool\Driver\Tag\CanonVRD\UnsharpMask(),
                'StandardUnsharpMaskStrength' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardUnsharpMaskStrength(),
                'StandardUnsharpMaskFineness' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardUnsharpMaskFineness(),
                'StandardUnsharpMaskThreshold' => new \PHPExiftool\Driver\Tag\CanonVRD\StandardUnsharpMaskThreshold(),
                'PortraitUnsharpMaskStrength' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitUnsharpMaskStrength(),
                'PortraitUnsharpMaskFineness' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitUnsharpMaskFineness(),
                'PortraitUnsharpMaskThreshold' => new \PHPExiftool\Driver\Tag\CanonVRD\PortraitUnsharpMaskThreshold(),
                'LandscapeUnsharpMaskStrength' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeUnsharpMaskStrength(),
                'LandscapeUnsharpMaskFineness' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeUnsharpMaskFineness(),
                'LandscapeUnsharpMaskThreshold' => new \PHPExiftool\Driver\Tag\CanonVRD\LandscapeUnsharpMaskThreshold(),
                'NeutraUnsharpMaskStrength' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutraUnsharpMaskStrength(),
                'NeutralUnsharpMaskFineness' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralUnsharpMaskFineness(),
                'NeutralUnsharpMaskThreshold' => new \PHPExiftool\Driver\Tag\CanonVRD\NeutralUnsharpMaskThreshold(),
                'FaithfulUnsharpMaskStrength' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulUnsharpMaskStrength(),
                'FaithfulUnsharpMaskFineness' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulUnsharpMaskFineness(),
                'FaithfulUnsharpMaskThreshold' => new \PHPExiftool\Driver\Tag\CanonVRD\FaithfulUnsharpMaskThreshold(),
                'MonochromeUnsharpMaskStrength' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeUnsharpMaskStrength(),
                'MonochromeUnsharpMaskFineness' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeUnsharpMaskFineness(),
                'MonochromeUnsharpMaskThreshold' => new \PHPExiftool\Driver\Tag\CanonVRD\MonochromeUnsharpMaskThreshold(),
                'CustomUnsharpMaskStrength' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomUnsharpMaskStrength(),
                'CustomUnsharpMaskFineness' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomUnsharpMaskFineness(),
                'CustomUnsharpMaskThreshold' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomUnsharpMaskThreshold(),
                'CustomDefaultUnsharpStrength' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomDefaultUnsharpStrength(),
                'CustomDefaultUnsharpFineness' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomDefaultUnsharpFineness(),
                'CustomDefaultUnsharpThreshold' => new \PHPExiftool\Driver\Tag\CanonVRD\CustomDefaultUnsharpThreshold(),
                'CropCircleActive' => new \PHPExiftool\Driver\Tag\CanonVRD\CropCircleActive(),
                'CropCircleX' => new \PHPExiftool\Driver\Tag\CanonVRD\CropCircleX(),
                'CropCircleY' => new \PHPExiftool\Driver\Tag\CanonVRD\CropCircleY(),
                'CropCircleRadius' => new \PHPExiftool\Driver\Tag\CanonVRD\CropCircleRadius(),
                'DLOOn' => new \PHPExiftool\Driver\Tag\CanonVRD\DLOOn(),
                'DLOSetting' => new \PHPExiftool\Driver\Tag\CanonVRD\DLOSetting(),
                'DLOShootingDistance' => new \PHPExiftool\Driver\Tag\CanonVRD\DLOShootingDistance(),
                'DLODataLength' => new \PHPExiftool\Driver\Tag\CanonVRD\DLODataLength(),
                'DLOSettingApplied' => new \PHPExiftool\Driver\Tag\CanonVRD\DLOSettingApplied(),
                'DLOVersion' => new \PHPExiftool\Driver\Tag\CanonVRD\DLOVersion(),
                'DLOData' => new \PHPExiftool\Driver\Tag\CanonVRD\DLOData(),
                'CanonVRD' => new \PHPExiftool\Driver\Tag\CanonVRD\CanonVRD(),
            );
        });
        $this['Casio'] = $this->share(function(){
            return array(
                'Software' => new \PHPExiftool\Driver\Tag\Casio\Software(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Casio\FacesDetected(),
                'FaceDetectFrameSize' => new \PHPExiftool\Driver\Tag\Casio\FaceDetectFrameSize(),
                'Face1Position' => new \PHPExiftool\Driver\Tag\Casio\Face1Position(),
                'Face2Position' => new \PHPExiftool\Driver\Tag\Casio\Face2Position(),
                'Face3Position' => new \PHPExiftool\Driver\Tag\Casio\Face3Position(),
                'Face4Position' => new \PHPExiftool\Driver\Tag\Casio\Face4Position(),
                'Face5Position' => new \PHPExiftool\Driver\Tag\Casio\Face5Position(),
                'Face6Position' => new \PHPExiftool\Driver\Tag\Casio\Face6Position(),
                'Face7Position' => new \PHPExiftool\Driver\Tag\Casio\Face7Position(),
                'Face8Position' => new \PHPExiftool\Driver\Tag\Casio\Face8Position(),
                'Face9Position' => new \PHPExiftool\Driver\Tag\Casio\Face9Position(),
                'Face10Position' => new \PHPExiftool\Driver\Tag\Casio\Face10Position(),
                'FaceOrientation' => new \PHPExiftool\Driver\Tag\Casio\FaceOrientation(),
                'RecordingMode' => new \PHPExiftool\Driver\Tag\Casio\RecordingMode(),
                'Quality' => new \PHPExiftool\Driver\Tag\Casio\Quality(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Casio\FocusMode(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Casio\FlashMode(),
                'FlashIntensity' => new \PHPExiftool\Driver\Tag\Casio\FlashIntensity(),
                'ObjectDistance' => new \PHPExiftool\Driver\Tag\Casio\ObjectDistance(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Casio\WhiteBalance(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Casio\DigitalZoom(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Casio\Sharpness(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Casio\Contrast(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Casio\Saturation(),
                'ISO' => new \PHPExiftool\Driver\Tag\Casio\ISO(),
                'FirmwareDate' => new \PHPExiftool\Driver\Tag\Casio\FirmwareDate(),
                'Enhancement' => new \PHPExiftool\Driver\Tag\Casio\Enhancement(),
                'ColorFilter' => new \PHPExiftool\Driver\Tag\Casio\ColorFilter(),
                'AFPoint' => new \PHPExiftool\Driver\Tag\Casio\AFPoint(),
                'CasioQuality' => new \PHPExiftool\Driver\Tag\Casio\CasioQuality(),
                'FocalRange' => new \PHPExiftool\Driver\Tag\Casio\FocalRange(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\Casio\DateTimeOriginal(),
                'ModelType' => new \PHPExiftool\Driver\Tag\Casio\ModelType(),
                'ManufactureIndex' => new \PHPExiftool\Driver\Tag\Casio\ManufactureIndex(),
                'ManufactureCode' => new \PHPExiftool\Driver\Tag\Casio\ManufactureCode(),
                'PreviewImageSize' => new \PHPExiftool\Driver\Tag\Casio\PreviewImageSize(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Casio\PreviewImageLength(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Casio\PreviewImageStart(),
                'QualityMode' => new \PHPExiftool\Driver\Tag\Casio\QualityMode(),
                'CasioImageSize' => new \PHPExiftool\Driver\Tag\Casio\CasioImageSize(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Casio\FocalLength(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Casio\PreviewImage(),
                'WhiteBalanceBias' => new \PHPExiftool\Driver\Tag\Casio\WhiteBalanceBias(),
                'AFPointPosition' => new \PHPExiftool\Driver\Tag\Casio\AFPointPosition(),
                'FlashDistance' => new \PHPExiftool\Driver\Tag\Casio\FlashDistance(),
                'SpecialEffectMode' => new \PHPExiftool\Driver\Tag\Casio\SpecialEffectMode(),
                'FaceInfoUnknown' => new \PHPExiftool\Driver\Tag\Casio\FaceInfoUnknown(),
                'RecordMode' => new \PHPExiftool\Driver\Tag\Casio\RecordMode(),
                'ReleaseMode' => new \PHPExiftool\Driver\Tag\Casio\ReleaseMode(),
                'HometownCity' => new \PHPExiftool\Driver\Tag\Casio\HometownCity(),
                'BestShotMode' => new \PHPExiftool\Driver\Tag\Casio\BestShotMode(),
                'AutoISO' => new \PHPExiftool\Driver\Tag\Casio\AutoISO(),
                'AFMode' => new \PHPExiftool\Driver\Tag\Casio\AFMode(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Casio\ColorMode(),
                'ArtMode' => new \PHPExiftool\Driver\Tag\Casio\ArtMode(),
                'SequenceNumber' => new \PHPExiftool\Driver\Tag\Casio\SequenceNumber(),
                'BracketSequence' => new \PHPExiftool\Driver\Tag\Casio\BracketSequence(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\Casio\ImageStabilization(),
                'LightingMode' => new \PHPExiftool\Driver\Tag\Casio\LightingMode(),
                'PortraitRefiner' => new \PHPExiftool\Driver\Tag\Casio\PortraitRefiner(),
                'SpecialEffectLevel' => new \PHPExiftool\Driver\Tag\Casio\SpecialEffectLevel(),
                'SpecialEffectSetting' => new \PHPExiftool\Driver\Tag\Casio\SpecialEffectSetting(),
                'DriveMode' => new \PHPExiftool\Driver\Tag\Casio\DriveMode(),
                'ArtModeParameters' => new \PHPExiftool\Driver\Tag\Casio\ArtModeParameters(),
                'CaptureFrameRate' => new \PHPExiftool\Driver\Tag\Casio\CaptureFrameRate(),
                'VideoQuality' => new \PHPExiftool\Driver\Tag\Casio\VideoQuality(),
            );
        });
        $this['Composite'] = $this->share(function(){
            return array(
                'AdvancedSceneMode' => new \PHPExiftool\Driver\Tag\Composite\AdvancedSceneMode(),
                'Aperture' => new \PHPExiftool\Driver\Tag\Composite\Aperture(),
                'AudioBitrate' => new \PHPExiftool\Driver\Tag\Composite\AudioBitrate(),
                'AutoFocus' => new \PHPExiftool\Driver\Tag\Composite\AutoFocus(),
                'AvgBitrate' => new \PHPExiftool\Driver\Tag\Composite\AvgBitrate(),
                'BlueBalance' => new \PHPExiftool\Driver\Tag\Composite\BlueBalance(),
                'CFAPattern' => new \PHPExiftool\Driver\Tag\Composite\CFAPattern(),
                'CircleOfConfusion' => new \PHPExiftool\Driver\Tag\Composite\CircleOfConfusion(),
                'ConditionalFEC' => new \PHPExiftool\Driver\Tag\Composite\ConditionalFEC(),
                'DOF' => new \PHPExiftool\Driver\Tag\Composite\DOF(),
                'DateCreated' => new \PHPExiftool\Driver\Tag\Composite\DateCreated(),
                'DateTimeCreated' => new \PHPExiftool\Driver\Tag\Composite\DateTimeCreated(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\Composite\DateTimeOriginal(),
                'DigitalCreationDateTime' => new \PHPExiftool\Driver\Tag\Composite\DigitalCreationDateTime(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Composite\DigitalZoom(),
                'DriveMode' => new \PHPExiftool\Driver\Tag\Composite\DriveMode(),
                'Duration' => new \PHPExiftool\Driver\Tag\Composite\Duration(),
                'ExtenderStatus' => new \PHPExiftool\Driver\Tag\Composite\ExtenderStatus(),
                'FOV' => new \PHPExiftool\Driver\Tag\Composite\FOV(),
                'FileNumber' => new \PHPExiftool\Driver\Tag\Composite\FileNumber(),
                'Flash' => new \PHPExiftool\Driver\Tag\Composite\Flash(),
                'FlashType' => new \PHPExiftool\Driver\Tag\Composite\FlashType(),
                'FocalLength35efl' => new \PHPExiftool\Driver\Tag\Composite\FocalLength35efl(),
                'FocusDistance' => new \PHPExiftool\Driver\Tag\Composite\FocusDistance(),
                'GPSAltitude' => new \PHPExiftool\Driver\Tag\Composite\GPSAltitude(),
                'GPSAltitudeRef' => new \PHPExiftool\Driver\Tag\Composite\GPSAltitudeRef(),
                'GPSDateTime' => new \PHPExiftool\Driver\Tag\Composite\GPSDateTime(),
                'GPSLatitude' => new \PHPExiftool\Driver\Tag\Composite\GPSLatitude(),
                'GPSLatitudeRef' => new \PHPExiftool\Driver\Tag\Composite\GPSLatitudeRef(),
                'GPSLongitude' => new \PHPExiftool\Driver\Tag\Composite\GPSLongitude(),
                'GPSLongitudeRef' => new \PHPExiftool\Driver\Tag\Composite\GPSLongitudeRef(),
                'GPSPosition' => new \PHPExiftool\Driver\Tag\Composite\GPSPosition(),
                'HyperfocalDistance' => new \PHPExiftool\Driver\Tag\Composite\HyperfocalDistance(),
                'IDCPreviewImage' => new \PHPExiftool\Driver\Tag\Composite\IDCPreviewImage(),
                'ISO' => new \PHPExiftool\Driver\Tag\Composite\ISO(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\Composite\ImageHeight(),
                'ImageSize' => new \PHPExiftool\Driver\Tag\Composite\ImageSize(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\Composite\ImageWidth(),
                'JpgFromRaw' => new \PHPExiftool\Driver\Tag\Composite\JpgFromRaw(),
                'Lens' => new \PHPExiftool\Driver\Tag\Composite\Lens(),
                'Lens35efl' => new \PHPExiftool\Driver\Tag\Composite\Lens35efl(),
                'LensID' => new \PHPExiftool\Driver\Tag\Composite\LensID(),
                'LensSpec' => new \PHPExiftool\Driver\Tag\Composite\LensSpec(),
                'LightValue' => new \PHPExiftool\Driver\Tag\Composite\LightValue(),
                'MPImage' => new \PHPExiftool\Driver\Tag\Composite\MPImage(),
                'OriginalDecisionData' => new \PHPExiftool\Driver\Tag\Composite\OriginalDecisionData(),
                'OtherImage' => new \PHPExiftool\Driver\Tag\Composite\OtherImage(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Composite\PreviewImage(),
                'PreviewImageSize' => new \PHPExiftool\Driver\Tag\Composite\PreviewImageSize(),
                'RedBalance' => new \PHPExiftool\Driver\Tag\Composite\RedBalance(),
                'RedEyeReduction' => new \PHPExiftool\Driver\Tag\Composite\RedEyeReduction(),
                'Rotation' => new \PHPExiftool\Driver\Tag\Composite\Rotation(),
                'ScaleFactor35efl' => new \PHPExiftool\Driver\Tag\Composite\ScaleFactor35efl(),
                'ShootingMode' => new \PHPExiftool\Driver\Tag\Composite\ShootingMode(),
                'ShutterCurtainHack' => new \PHPExiftool\Driver\Tag\Composite\ShutterCurtainHack(),
                'ShutterSpeed' => new \PHPExiftool\Driver\Tag\Composite\ShutterSpeed(),
                'SubSecCreateDate' => new \PHPExiftool\Driver\Tag\Composite\SubSecCreateDate(),
                'SubSecDateTimeOriginal' => new \PHPExiftool\Driver\Tag\Composite\SubSecDateTimeOriginal(),
                'SubSecModifyDate' => new \PHPExiftool\Driver\Tag\Composite\SubSecModifyDate(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\Composite\ThumbnailImage(),
                'WB_RGBLevels' => new \PHPExiftool\Driver\Tag\Composite\WBRGBLevels(),
                'WB_RGGBLevels' => new \PHPExiftool\Driver\Tag\Composite\WBRGGBLevels(),
                'ZoomedPreviewImage' => new \PHPExiftool\Driver\Tag\Composite\ZoomedPreviewImage(),
            );
        });
        $this['DICOM'] = $this->share(function(){
            return array(
                'FileMetaInfoGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\FileMetaInfoGroupLength(),
                'FileMetaInfoVersion' => new \PHPExiftool\Driver\Tag\DICOM\FileMetaInfoVersion(),
                'MediaStorageSOPClassUID' => new \PHPExiftool\Driver\Tag\DICOM\MediaStorageSOPClassUID(),
                'MediaStorageSOPInstanceUID' => new \PHPExiftool\Driver\Tag\DICOM\MediaStorageSOPInstanceUID(),
                'TransferSyntaxUID' => new \PHPExiftool\Driver\Tag\DICOM\TransferSyntaxUID(),
                'ImplementationClassUID' => new \PHPExiftool\Driver\Tag\DICOM\ImplementationClassUID(),
                'ImplementationVersionName' => new \PHPExiftool\Driver\Tag\DICOM\ImplementationVersionName(),
                'SourceApplicationEntityTitle' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicationEntityTitle(),
                'PrivateInformationCreatorUID' => new \PHPExiftool\Driver\Tag\DICOM\PrivateInformationCreatorUID(),
                'PrivateInformation' => new \PHPExiftool\Driver\Tag\DICOM\PrivateInformation(),
                'FileSetID' => new \PHPExiftool\Driver\Tag\DICOM\FileSetID(),
                'FileSetDescriptorFileID' => new \PHPExiftool\Driver\Tag\DICOM\FileSetDescriptorFileID(),
                'SpecificCharacterSetOfFile' => new \PHPExiftool\Driver\Tag\DICOM\SpecificCharacterSetOfFile(),
                'FirstDirectoryRecordOffset' => new \PHPExiftool\Driver\Tag\DICOM\FirstDirectoryRecordOffset(),
                'LastDirectoryRecordOffset' => new \PHPExiftool\Driver\Tag\DICOM\LastDirectoryRecordOffset(),
                'FileSetConsistencyFlag' => new \PHPExiftool\Driver\Tag\DICOM\FileSetConsistencyFlag(),
                'DirectoryRecordSequence' => new \PHPExiftool\Driver\Tag\DICOM\DirectoryRecordSequence(),
                'OffsetOfNextDirectoryRecord' => new \PHPExiftool\Driver\Tag\DICOM\OffsetOfNextDirectoryRecord(),
                'RecordInUseFlag' => new \PHPExiftool\Driver\Tag\DICOM\RecordInUseFlag(),
                'LowerLevelDirectoryEntityOffset' => new \PHPExiftool\Driver\Tag\DICOM\LowerLevelDirectoryEntityOffset(),
                'DirectoryRecordType' => new \PHPExiftool\Driver\Tag\DICOM\DirectoryRecordType(),
                'PrivateRecordUID' => new \PHPExiftool\Driver\Tag\DICOM\PrivateRecordUID(),
                'ReferencedFileID' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFileID(),
                'MRDRDirectoryRecordOffset' => new \PHPExiftool\Driver\Tag\DICOM\MRDRDirectoryRecordOffset(),
                'ReferencedSOPClassUIDInFile' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSOPClassUIDInFile(),
                'ReferencedSOPInstanceUIDInFile' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSOPInstanceUIDInFile(),
                'ReferencedTransferSyntaxUIDInFile' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedTransferSyntaxUIDInFile(),
                'ReferencedRelatedSOPClassUIDInFile' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedRelatedSOPClassUIDInFile(),
                'NumberOfReferences' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfReferences(),
                'IdentifyingGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\IdentifyingGroupLength(),
                'LengthToEnd' => new \PHPExiftool\Driver\Tag\DICOM\LengthToEnd(),
                'SpecificCharacterSet' => new \PHPExiftool\Driver\Tag\DICOM\SpecificCharacterSet(),
                'LanguageCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\LanguageCodeSequence(),
                'ImageType' => new \PHPExiftool\Driver\Tag\DICOM\ImageType(),
                'RecognitionCode' => new \PHPExiftool\Driver\Tag\DICOM\RecognitionCode(),
                'InstanceCreationDate' => new \PHPExiftool\Driver\Tag\DICOM\InstanceCreationDate(),
                'InstanceCreationTime' => new \PHPExiftool\Driver\Tag\DICOM\InstanceCreationTime(),
                'InstanceCreatorUID' => new \PHPExiftool\Driver\Tag\DICOM\InstanceCreatorUID(),
                'SOPClassUID' => new \PHPExiftool\Driver\Tag\DICOM\SOPClassUID(),
                'SOPInstanceUID' => new \PHPExiftool\Driver\Tag\DICOM\SOPInstanceUID(),
                'RelatedGeneralSOPClassUID' => new \PHPExiftool\Driver\Tag\DICOM\RelatedGeneralSOPClassUID(),
                'OriginalSpecializedSOPClassUID' => new \PHPExiftool\Driver\Tag\DICOM\OriginalSpecializedSOPClassUID(),
                'StudyDate' => new \PHPExiftool\Driver\Tag\DICOM\StudyDate(),
                'SeriesDate' => new \PHPExiftool\Driver\Tag\DICOM\SeriesDate(),
                'AcquisitionDate' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionDate(),
                'ContentDate' => new \PHPExiftool\Driver\Tag\DICOM\ContentDate(),
                'OverlayDate' => new \PHPExiftool\Driver\Tag\DICOM\OverlayDate(),
                'CurveDate' => new \PHPExiftool\Driver\Tag\DICOM\CurveDate(),
                'AcquisitionDateTime' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionDateTime(),
                'StudyTime' => new \PHPExiftool\Driver\Tag\DICOM\StudyTime(),
                'SeriesTime' => new \PHPExiftool\Driver\Tag\DICOM\SeriesTime(),
                'AcquisitionTime' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionTime(),
                'ContentTime' => new \PHPExiftool\Driver\Tag\DICOM\ContentTime(),
                'OverlayTime' => new \PHPExiftool\Driver\Tag\DICOM\OverlayTime(),
                'CurveTime' => new \PHPExiftool\Driver\Tag\DICOM\CurveTime(),
                'DataSetType' => new \PHPExiftool\Driver\Tag\DICOM\DataSetType(),
                'DataSetSubtype' => new \PHPExiftool\Driver\Tag\DICOM\DataSetSubtype(),
                'NuclearMedicineSeriesType' => new \PHPExiftool\Driver\Tag\DICOM\NuclearMedicineSeriesType(),
                'AccessionNumber' => new \PHPExiftool\Driver\Tag\DICOM\AccessionNumber(),
                'QueryRetrieveLevel' => new \PHPExiftool\Driver\Tag\DICOM\QueryRetrieveLevel(),
                'RetrieveAETitle' => new \PHPExiftool\Driver\Tag\DICOM\RetrieveAETitle(),
                'InstanceAvailability' => new \PHPExiftool\Driver\Tag\DICOM\InstanceAvailability(),
                'FailedSOPInstanceUIDList' => new \PHPExiftool\Driver\Tag\DICOM\FailedSOPInstanceUIDList(),
                'Modality' => new \PHPExiftool\Driver\Tag\DICOM\Modality(),
                'ModalitiesInStudy' => new \PHPExiftool\Driver\Tag\DICOM\ModalitiesInStudy(),
                'SOPClassesInStudy' => new \PHPExiftool\Driver\Tag\DICOM\SOPClassesInStudy(),
                'ConversionType' => new \PHPExiftool\Driver\Tag\DICOM\ConversionType(),
                'PresentationIntentType' => new \PHPExiftool\Driver\Tag\DICOM\PresentationIntentType(),
                'Manufacturer' => new \PHPExiftool\Driver\Tag\DICOM\Manufacturer(),
                'InstitutionName' => new \PHPExiftool\Driver\Tag\DICOM\InstitutionName(),
                'InstitutionAddress' => new \PHPExiftool\Driver\Tag\DICOM\InstitutionAddress(),
                'InstitutionCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\InstitutionCodeSequence(),
                'ReferringPhysicianName' => new \PHPExiftool\Driver\Tag\DICOM\ReferringPhysicianName(),
                'ReferringPhysicianAddress' => new \PHPExiftool\Driver\Tag\DICOM\ReferringPhysicianAddress(),
                'ReferringPhysicianTelephoneNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferringPhysicianTelephoneNumber(),
                'ReferringPhysicianIDSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferringPhysicianIDSequence(),
                'CodeValue' => new \PHPExiftool\Driver\Tag\DICOM\CodeValue(),
                'CodingSchemeDesignator' => new \PHPExiftool\Driver\Tag\DICOM\CodingSchemeDesignator(),
                'CodingSchemeVersion' => new \PHPExiftool\Driver\Tag\DICOM\CodingSchemeVersion(),
                'CodeMeaning' => new \PHPExiftool\Driver\Tag\DICOM\CodeMeaning(),
                'MappingResource' => new \PHPExiftool\Driver\Tag\DICOM\MappingResource(),
                'ContextGroupVersion' => new \PHPExiftool\Driver\Tag\DICOM\ContextGroupVersion(),
                'ContextGroupLocalVersion' => new \PHPExiftool\Driver\Tag\DICOM\ContextGroupLocalVersion(),
                'ContextGroupExtensionFlag' => new \PHPExiftool\Driver\Tag\DICOM\ContextGroupExtensionFlag(),
                'CodingSchemeUID' => new \PHPExiftool\Driver\Tag\DICOM\CodingSchemeUID(),
                'ContextGroupExtensionCreatorUID' => new \PHPExiftool\Driver\Tag\DICOM\ContextGroupExtensionCreatorUID(),
                'ContextIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\ContextIdentifier(),
                'CodingSchemeIDSequence' => new \PHPExiftool\Driver\Tag\DICOM\CodingSchemeIDSequence(),
                'CodingSchemeRegistry' => new \PHPExiftool\Driver\Tag\DICOM\CodingSchemeRegistry(),
                'CodingSchemeExternalID' => new \PHPExiftool\Driver\Tag\DICOM\CodingSchemeExternalID(),
                'CodingSchemeName' => new \PHPExiftool\Driver\Tag\DICOM\CodingSchemeName(),
                'ResponsibleOrganization' => new \PHPExiftool\Driver\Tag\DICOM\ResponsibleOrganization(),
                'ContextUID' => new \PHPExiftool\Driver\Tag\DICOM\ContextUID(),
                'TimezoneOffsetFromUTC' => new \PHPExiftool\Driver\Tag\DICOM\TimezoneOffsetFromUTC(),
                'NetworkID' => new \PHPExiftool\Driver\Tag\DICOM\NetworkID(),
                'StationName' => new \PHPExiftool\Driver\Tag\DICOM\StationName(),
                'StudyDescription' => new \PHPExiftool\Driver\Tag\DICOM\StudyDescription(),
                'ProcedureCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ProcedureCodeSequence(),
                'SeriesDescription' => new \PHPExiftool\Driver\Tag\DICOM\SeriesDescription(),
                'InstitutionalDepartmentName' => new \PHPExiftool\Driver\Tag\DICOM\InstitutionalDepartmentName(),
                'PhysiciansOfRecord' => new \PHPExiftool\Driver\Tag\DICOM\PhysiciansOfRecord(),
                'PhysiciansOfRecordIDSequence' => new \PHPExiftool\Driver\Tag\DICOM\PhysiciansOfRecordIDSequence(),
                'PerformingPhysicianName' => new \PHPExiftool\Driver\Tag\DICOM\PerformingPhysicianName(),
                'PerformingPhysicianIDSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerformingPhysicianIDSequence(),
                'NameOfPhysicianReadingStudy' => new \PHPExiftool\Driver\Tag\DICOM\NameOfPhysicianReadingStudy(),
                'PhysicianReadingStudyIDSequence' => new \PHPExiftool\Driver\Tag\DICOM\PhysicianReadingStudyIDSequence(),
                'OperatorsName' => new \PHPExiftool\Driver\Tag\DICOM\OperatorsName(),
                'OperatorIDSequence' => new \PHPExiftool\Driver\Tag\DICOM\OperatorIDSequence(),
                'AdmittingDiagnosesDescription' => new \PHPExiftool\Driver\Tag\DICOM\AdmittingDiagnosesDescription(),
                'AdmittingDiagnosesCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\AdmittingDiagnosesCodeSequence(),
                'ManufacturersModelName' => new \PHPExiftool\Driver\Tag\DICOM\ManufacturersModelName(),
                'ReferencedResultsSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedResultsSequence(),
                'ReferencedStudySequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedStudySequence(),
                'ReferencedProcedureStepSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedProcedureStepSequence(),
                'ReferencedSeriesSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSeriesSequence(),
                'ReferencedPatientSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedPatientSequence(),
                'ReferencedVisitSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedVisitSequence(),
                'ReferencedOverlaySequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedOverlaySequence(),
                'ReferencedWaveformSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedWaveformSequence(),
                'ReferencedImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedImageSequence(),
                'ReferencedCurveSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedCurveSequence(),
                'ReferencedInstanceSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedInstanceSequence(),
                'ReferencedSOPClassUID' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSOPClassUID(),
                'ReferencedSOPInstanceUID' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSOPInstanceUID(),
                'SOPClassesSupported' => new \PHPExiftool\Driver\Tag\DICOM\SOPClassesSupported(),
                'ReferencedFrameNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFrameNumber(),
                'SimpleFrameList' => new \PHPExiftool\Driver\Tag\DICOM\SimpleFrameList(),
                'CalculatedFrameList' => new \PHPExiftool\Driver\Tag\DICOM\CalculatedFrameList(),
                'TimeRange' => new \PHPExiftool\Driver\Tag\DICOM\TimeRange(),
                'FrameExtractionSequence' => new \PHPExiftool\Driver\Tag\DICOM\FrameExtractionSequence(),
                'TransactionUID' => new \PHPExiftool\Driver\Tag\DICOM\TransactionUID(),
                'FailureReason' => new \PHPExiftool\Driver\Tag\DICOM\FailureReason(),
                'FailedSOPSequence' => new \PHPExiftool\Driver\Tag\DICOM\FailedSOPSequence(),
                'ReferencedSOPSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSOPSequence(),
                'OtherReferencedStudiesSequence' => new \PHPExiftool\Driver\Tag\DICOM\OtherReferencedStudiesSequence(),
                'RelatedSeriesSequence' => new \PHPExiftool\Driver\Tag\DICOM\RelatedSeriesSequence(),
                'LossyImageCompression' => new \PHPExiftool\Driver\Tag\DICOM\LossyImageCompression(),
                'DerivationDescription' => new \PHPExiftool\Driver\Tag\DICOM\DerivationDescription(),
                'SourceImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\SourceImageSequence(),
                'StageName' => new \PHPExiftool\Driver\Tag\DICOM\StageName(),
                'StageNumber' => new \PHPExiftool\Driver\Tag\DICOM\StageNumber(),
                'NumberOfStages' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfStages(),
                'ViewName' => new \PHPExiftool\Driver\Tag\DICOM\ViewName(),
                'ViewNumber' => new \PHPExiftool\Driver\Tag\DICOM\ViewNumber(),
                'NumberOfEventTimers' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfEventTimers(),
                'NumberOfViewsInStage' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInStage(),
                'EventElapsedTimes' => new \PHPExiftool\Driver\Tag\DICOM\EventElapsedTimes(),
                'EventTimerNames' => new \PHPExiftool\Driver\Tag\DICOM\EventTimerNames(),
                'EventTimerSequence' => new \PHPExiftool\Driver\Tag\DICOM\EventTimerSequence(),
                'EventTimeOffset' => new \PHPExiftool\Driver\Tag\DICOM\EventTimeOffset(),
                'EventCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\EventCodeSequence(),
                'StartTrim' => new \PHPExiftool\Driver\Tag\DICOM\StartTrim(),
                'StopTrim' => new \PHPExiftool\Driver\Tag\DICOM\StopTrim(),
                'RecommendedDisplayFrameRate' => new \PHPExiftool\Driver\Tag\DICOM\RecommendedDisplayFrameRate(),
                'TransducerPosition' => new \PHPExiftool\Driver\Tag\DICOM\TransducerPosition(),
                'TransducerOrientation' => new \PHPExiftool\Driver\Tag\DICOM\TransducerOrientation(),
                'AnatomicStructure' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicStructure(),
                'AnatomicRegionSequence' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicRegionSequence(),
                'AnatomicRegionModifierSequence' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicRegionModifierSequence(),
                'PrimaryAnatomicStructureSequence' => new \PHPExiftool\Driver\Tag\DICOM\PrimaryAnatomicStructureSequence(),
                'AnatomicStructureOrRegionSequence' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicStructureOrRegionSequence(),
                'AnatomicStructureModifierSequence' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicStructureModifierSequence(),
                'TransducerPositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\TransducerPositionSequence(),
                'TransducerPositionModifierSequence' => new \PHPExiftool\Driver\Tag\DICOM\TransducerPositionModifierSequence(),
                'TransducerOrientationSequence' => new \PHPExiftool\Driver\Tag\DICOM\TransducerOrientationSequence(),
                'TransducerOrientationModifierSeq' => new \PHPExiftool\Driver\Tag\DICOM\TransducerOrientationModifierSeq(),
                'AnatomicEntrancePortalCodeSeqTrial' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicEntrancePortalCodeSeqTrial(),
                'AnatomicApproachDirCodeSeqTrial' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicApproachDirCodeSeqTrial(),
                'AnatomicPerspectiveDescrTrial' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicPerspectiveDescrTrial(),
                'AnatomicPerspectiveCodeSeqTrial' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicPerspectiveCodeSeqTrial(),
                'AlternateRepresentationSequence' => new \PHPExiftool\Driver\Tag\DICOM\AlternateRepresentationSequence(),
                'IrradiationEventUID' => new \PHPExiftool\Driver\Tag\DICOM\IrradiationEventUID(),
                'IdentifyingComments' => new \PHPExiftool\Driver\Tag\DICOM\IdentifyingComments(),
                'FrameType' => new \PHPExiftool\Driver\Tag\DICOM\FrameType(),
                'ReferencedImageEvidenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedImageEvidenceSequence(),
                'ReferencedRawDataSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedRawDataSequence(),
                'CreatorVersionUID' => new \PHPExiftool\Driver\Tag\DICOM\CreatorVersionUID(),
                'DerivationImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\DerivationImageSequence(),
                'SourceImageEvidenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\SourceImageEvidenceSequence(),
                'PixelPresentation' => new \PHPExiftool\Driver\Tag\DICOM\PixelPresentation(),
                'VolumetricProperties' => new \PHPExiftool\Driver\Tag\DICOM\VolumetricProperties(),
                'VolumeBasedCalculationTechnique' => new \PHPExiftool\Driver\Tag\DICOM\VolumeBasedCalculationTechnique(),
                'ComplexImageComponent' => new \PHPExiftool\Driver\Tag\DICOM\ComplexImageComponent(),
                'AcquisitionContrast' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionContrast(),
                'DerivationCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\DerivationCodeSequence(),
                'GrayscalePresentationStateSequence' => new \PHPExiftool\Driver\Tag\DICOM\GrayscalePresentationStateSequence(),
                'ReferencedOtherPlaneSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedOtherPlaneSequence(),
                'FrameDisplaySequence' => new \PHPExiftool\Driver\Tag\DICOM\FrameDisplaySequence(),
                'RecommendedDisplayFrameRateInFloat' => new \PHPExiftool\Driver\Tag\DICOM\RecommendedDisplayFrameRateInFloat(),
                'SkipFrameRangeFlag' => new \PHPExiftool\Driver\Tag\DICOM\SkipFrameRangeFlag(),
                'FullFidelity' => new \PHPExiftool\Driver\Tag\DICOM\FullFidelity(),
                'SuiteID' => new \PHPExiftool\Driver\Tag\DICOM\SuiteID(),
                'ProductID' => new \PHPExiftool\Driver\Tag\DICOM\ProductID(),
                'ImageActualDate' => new \PHPExiftool\Driver\Tag\DICOM\ImageActualDate(),
                'ServiceID' => new \PHPExiftool\Driver\Tag\DICOM\ServiceID(),
                'MobileLocationNumber' => new \PHPExiftool\Driver\Tag\DICOM\MobileLocationNumber(),
                'EquipmentUID' => new \PHPExiftool\Driver\Tag\DICOM\EquipmentUID(),
                'GenesisVersionNow' => new \PHPExiftool\Driver\Tag\DICOM\GenesisVersionNow(),
                'ExamRecordChecksum' => new \PHPExiftool\Driver\Tag\DICOM\ExamRecordChecksum(),
                'ActualSeriesDataTimeStamp' => new \PHPExiftool\Driver\Tag\DICOM\ActualSeriesDataTimeStamp(),
                'PatientGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\PatientGroupLength(),
                'PatientName' => new \PHPExiftool\Driver\Tag\DICOM\PatientName(),
                'PatientID' => new \PHPExiftool\Driver\Tag\DICOM\PatientID(),
                'IssuerOfPatientID' => new \PHPExiftool\Driver\Tag\DICOM\IssuerOfPatientID(),
                'TypeOfPatientID' => new \PHPExiftool\Driver\Tag\DICOM\TypeOfPatientID(),
                'PatientBirthDate' => new \PHPExiftool\Driver\Tag\DICOM\PatientBirthDate(),
                'PatientBirthTime' => new \PHPExiftool\Driver\Tag\DICOM\PatientBirthTime(),
                'PatientSex' => new \PHPExiftool\Driver\Tag\DICOM\PatientSex(),
                'PatientInsurancePlanCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PatientInsurancePlanCodeSequence(),
                'PatientPrimaryLanguageCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\PatientPrimaryLanguageCodeSeq(),
                'PatientPrimaryLanguageCodeModSeq' => new \PHPExiftool\Driver\Tag\DICOM\PatientPrimaryLanguageCodeModSeq(),
                'OtherPatientIDs' => new \PHPExiftool\Driver\Tag\DICOM\OtherPatientIDs(),
                'OtherPatientNames' => new \PHPExiftool\Driver\Tag\DICOM\OtherPatientNames(),
                'OtherPatientIDsSequence' => new \PHPExiftool\Driver\Tag\DICOM\OtherPatientIDsSequence(),
                'PatientBirthName' => new \PHPExiftool\Driver\Tag\DICOM\PatientBirthName(),
                'PatientAge' => new \PHPExiftool\Driver\Tag\DICOM\PatientAge(),
                'PatientSize' => new \PHPExiftool\Driver\Tag\DICOM\PatientSize(),
                'PatientWeight' => new \PHPExiftool\Driver\Tag\DICOM\PatientWeight(),
                'PatientAddress' => new \PHPExiftool\Driver\Tag\DICOM\PatientAddress(),
                'InsurancePlanIdentification' => new \PHPExiftool\Driver\Tag\DICOM\InsurancePlanIdentification(),
                'PatientMotherBirthName' => new \PHPExiftool\Driver\Tag\DICOM\PatientMotherBirthName(),
                'MilitaryRank' => new \PHPExiftool\Driver\Tag\DICOM\MilitaryRank(),
                'BranchOfService' => new \PHPExiftool\Driver\Tag\DICOM\BranchOfService(),
                'MedicalRecordLocator' => new \PHPExiftool\Driver\Tag\DICOM\MedicalRecordLocator(),
                'MedicalAlerts' => new \PHPExiftool\Driver\Tag\DICOM\MedicalAlerts(),
                'Allergies' => new \PHPExiftool\Driver\Tag\DICOM\Allergies(),
                'CountryOfResidence' => new \PHPExiftool\Driver\Tag\DICOM\CountryOfResidence(),
                'RegionOfResidence' => new \PHPExiftool\Driver\Tag\DICOM\RegionOfResidence(),
                'PatientTelephoneNumbers' => new \PHPExiftool\Driver\Tag\DICOM\PatientTelephoneNumbers(),
                'EthnicGroup' => new \PHPExiftool\Driver\Tag\DICOM\EthnicGroup(),
                'Occupation' => new \PHPExiftool\Driver\Tag\DICOM\Occupation(),
                'SmokingStatus' => new \PHPExiftool\Driver\Tag\DICOM\SmokingStatus(),
                'AdditionalPatientHistory' => new \PHPExiftool\Driver\Tag\DICOM\AdditionalPatientHistory(),
                'PregnancyStatus' => new \PHPExiftool\Driver\Tag\DICOM\PregnancyStatus(),
                'LastMenstrualDate' => new \PHPExiftool\Driver\Tag\DICOM\LastMenstrualDate(),
                'PatientReligiousPreference' => new \PHPExiftool\Driver\Tag\DICOM\PatientReligiousPreference(),
                'PatientSpeciesDescription' => new \PHPExiftool\Driver\Tag\DICOM\PatientSpeciesDescription(),
                'PatientSpeciesCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PatientSpeciesCodeSequence(),
                'PatientSexNeutered' => new \PHPExiftool\Driver\Tag\DICOM\PatientSexNeutered(),
                'AnatomicalOrientationType' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicalOrientationType(),
                'PatientBreedDescription' => new \PHPExiftool\Driver\Tag\DICOM\PatientBreedDescription(),
                'PatientBreedCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PatientBreedCodeSequence(),
                'BreedRegistrationSequence' => new \PHPExiftool\Driver\Tag\DICOM\BreedRegistrationSequence(),
                'BreedRegistrationNumber' => new \PHPExiftool\Driver\Tag\DICOM\BreedRegistrationNumber(),
                'BreedRegistryCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\BreedRegistryCodeSequence(),
                'ResponsiblePerson' => new \PHPExiftool\Driver\Tag\DICOM\ResponsiblePerson(),
                'ResponsiblePersonRole' => new \PHPExiftool\Driver\Tag\DICOM\ResponsiblePersonRole(),
                'PatientComments' => new \PHPExiftool\Driver\Tag\DICOM\PatientComments(),
                'ExaminedBodyThickness' => new \PHPExiftool\Driver\Tag\DICOM\ExaminedBodyThickness(),
                'PatientStatus' => new \PHPExiftool\Driver\Tag\DICOM\PatientStatus(),
                'ClinicalTrialSponsorName' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSponsorName(),
                'ClinicalTrialProtocolID' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialProtocolID(),
                'ClinicalTrialProtocolName' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialProtocolName(),
                'ClinicalTrialSiteID' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSiteID(),
                'ClinicalTrialSiteName' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSiteName(),
                'ClinicalTrialSubjectID' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSubjectID(),
                'ClinicalTrialSubjectReadingID' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSubjectReadingID(),
                'ClinicalTrialTimePointID' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialTimePointID(),
                'ClinicalTrialTimePointDescription' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialTimePointDescription(),
                'ClinicalTrialCoordinatingCenter' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialCoordinatingCenter(),
                'PatientIdentityRemoved' => new \PHPExiftool\Driver\Tag\DICOM\PatientIdentityRemoved(),
                'DeidentificationMethod' => new \PHPExiftool\Driver\Tag\DICOM\DeidentificationMethod(),
                'DeidentificationMethodCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\DeidentificationMethodCodeSequence(),
                'ClinicalTrialSeriesID' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSeriesID(),
                'ClinicalTrialSeriesDescription' => new \PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSeriesDescription(),
                'DistributionType' => new \PHPExiftool\Driver\Tag\DICOM\DistributionType(),
                'ConsentForDistributionFlag' => new \PHPExiftool\Driver\Tag\DICOM\ConsentForDistributionFlag(),
                'AcquisitionGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionGroupLength(),
                'ContrastBolusAgent' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgent(),
                'ContrastBolusAgentSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentSequence(),
                'ContrastBolusAdministrationRoute' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusAdministrationRoute(),
                'BodyPartExamined' => new \PHPExiftool\Driver\Tag\DICOM\BodyPartExamined(),
                'ScanningSequence' => new \PHPExiftool\Driver\Tag\DICOM\ScanningSequence(),
                'SequenceVariant' => new \PHPExiftool\Driver\Tag\DICOM\SequenceVariant(),
                'ScanOptions' => new \PHPExiftool\Driver\Tag\DICOM\ScanOptions(),
                'MRAcquisitionType' => new \PHPExiftool\Driver\Tag\DICOM\MRAcquisitionType(),
                'SequenceName' => new \PHPExiftool\Driver\Tag\DICOM\SequenceName(),
                'AngioFlag' => new \PHPExiftool\Driver\Tag\DICOM\AngioFlag(),
                'InterventionDrugInformationSeq' => new \PHPExiftool\Driver\Tag\DICOM\InterventionDrugInformationSeq(),
                'InterventionDrugStopTime' => new \PHPExiftool\Driver\Tag\DICOM\InterventionDrugStopTime(),
                'InterventionDrugDose' => new \PHPExiftool\Driver\Tag\DICOM\InterventionDrugDose(),
                'InterventionDrugSequence' => new \PHPExiftool\Driver\Tag\DICOM\InterventionDrugSequence(),
                'AdditionalDrugSequence' => new \PHPExiftool\Driver\Tag\DICOM\AdditionalDrugSequence(),
                'Radionuclide' => new \PHPExiftool\Driver\Tag\DICOM\Radionuclide(),
                'Radiopharmaceutical' => new \PHPExiftool\Driver\Tag\DICOM\Radiopharmaceutical(),
                'EnergyWindowCenterline' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowCenterline(),
                'EnergyWindowTotalWidth' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowTotalWidth(),
                'InterventionDrugName' => new \PHPExiftool\Driver\Tag\DICOM\InterventionDrugName(),
                'InterventionDrugStartTime' => new \PHPExiftool\Driver\Tag\DICOM\InterventionDrugStartTime(),
                'InterventionSequence' => new \PHPExiftool\Driver\Tag\DICOM\InterventionSequence(),
                'TherapyType' => new \PHPExiftool\Driver\Tag\DICOM\TherapyType(),
                'InterventionStatus' => new \PHPExiftool\Driver\Tag\DICOM\InterventionStatus(),
                'TherapyDescription' => new \PHPExiftool\Driver\Tag\DICOM\TherapyDescription(),
                'InterventionDescription' => new \PHPExiftool\Driver\Tag\DICOM\InterventionDescription(),
                'CineRate' => new \PHPExiftool\Driver\Tag\DICOM\CineRate(),
                'InitialCineRunState' => new \PHPExiftool\Driver\Tag\DICOM\InitialCineRunState(),
                'SliceThickness' => new \PHPExiftool\Driver\Tag\DICOM\SliceThickness(),
                'KVP' => new \PHPExiftool\Driver\Tag\DICOM\KVP(),
                'CountsAccumulated' => new \PHPExiftool\Driver\Tag\DICOM\CountsAccumulated(),
                'AcquisitionTerminationCondition' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionTerminationCondition(),
                'EffectiveDuration' => new \PHPExiftool\Driver\Tag\DICOM\EffectiveDuration(),
                'AcquisitionStartCondition' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionStartCondition(),
                'AcquisitionStartConditionData' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionStartConditionData(),
                'AcquisitionEndConditionData' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionEndConditionData(),
                'RepetitionTime' => new \PHPExiftool\Driver\Tag\DICOM\RepetitionTime(),
                'EchoTime' => new \PHPExiftool\Driver\Tag\DICOM\EchoTime(),
                'InversionTime' => new \PHPExiftool\Driver\Tag\DICOM\InversionTime(),
                'NumberOfAverages' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfAverages(),
                'ImagingFrequency' => new \PHPExiftool\Driver\Tag\DICOM\ImagingFrequency(),
                'ImagedNucleus' => new \PHPExiftool\Driver\Tag\DICOM\ImagedNucleus(),
                'EchoNumber' => new \PHPExiftool\Driver\Tag\DICOM\EchoNumber(),
                'MagneticFieldStrength' => new \PHPExiftool\Driver\Tag\DICOM\MagneticFieldStrength(),
                'SpacingBetweenSlices' => new \PHPExiftool\Driver\Tag\DICOM\SpacingBetweenSlices(),
                'NumberOfPhaseEncodingSteps' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPhaseEncodingSteps(),
                'DataCollectionDiameter' => new \PHPExiftool\Driver\Tag\DICOM\DataCollectionDiameter(),
                'EchoTrainLength' => new \PHPExiftool\Driver\Tag\DICOM\EchoTrainLength(),
                'PercentSampling' => new \PHPExiftool\Driver\Tag\DICOM\PercentSampling(),
                'PercentPhaseFieldOfView' => new \PHPExiftool\Driver\Tag\DICOM\PercentPhaseFieldOfView(),
                'PixelBandwidth' => new \PHPExiftool\Driver\Tag\DICOM\PixelBandwidth(),
                'DeviceSerialNumber' => new \PHPExiftool\Driver\Tag\DICOM\DeviceSerialNumber(),
                'DeviceUID' => new \PHPExiftool\Driver\Tag\DICOM\DeviceUID(),
                'DeviceID' => new \PHPExiftool\Driver\Tag\DICOM\DeviceID(),
                'PlateID' => new \PHPExiftool\Driver\Tag\DICOM\PlateID(),
                'GeneratorID' => new \PHPExiftool\Driver\Tag\DICOM\GeneratorID(),
                'GridID' => new \PHPExiftool\Driver\Tag\DICOM\GridID(),
                'CassetteID' => new \PHPExiftool\Driver\Tag\DICOM\CassetteID(),
                'GantryID' => new \PHPExiftool\Driver\Tag\DICOM\GantryID(),
                'SecondaryCaptureDeviceID' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryCaptureDeviceID(),
                'HardcopyCreationDeviceID' => new \PHPExiftool\Driver\Tag\DICOM\HardcopyCreationDeviceID(),
                'DateOfSecondaryCapture' => new \PHPExiftool\Driver\Tag\DICOM\DateOfSecondaryCapture(),
                'TimeOfSecondaryCapture' => new \PHPExiftool\Driver\Tag\DICOM\TimeOfSecondaryCapture(),
                'SecondaryCaptureDeviceManufacturer' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryCaptureDeviceManufacturer(),
                'HardcopyDeviceManufacturer' => new \PHPExiftool\Driver\Tag\DICOM\HardcopyDeviceManufacturer(),
                'SecondaryCaptureDeviceModelName' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryCaptureDeviceModelName(),
                'SecondaryCaptureDeviceSoftwareVers' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryCaptureDeviceSoftwareVers(),
                'HardcopyDeviceSoftwareVersion' => new \PHPExiftool\Driver\Tag\DICOM\HardcopyDeviceSoftwareVersion(),
                'HardcopyDeviceModelName' => new \PHPExiftool\Driver\Tag\DICOM\HardcopyDeviceModelName(),
                'SoftwareVersion' => new \PHPExiftool\Driver\Tag\DICOM\SoftwareVersion(),
                'VideoImageFormatAcquired' => new \PHPExiftool\Driver\Tag\DICOM\VideoImageFormatAcquired(),
                'DigitalImageFormatAcquired' => new \PHPExiftool\Driver\Tag\DICOM\DigitalImageFormatAcquired(),
                'ProtocolName' => new \PHPExiftool\Driver\Tag\DICOM\ProtocolName(),
                'ContrastBolusRoute' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusRoute(),
                'ContrastBolusVolume' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusVolume(),
                'ContrastBolusStartTime' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusStartTime(),
                'ContrastBolusStopTime' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusStopTime(),
                'ContrastBolusTotalDose' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusTotalDose(),
                'SyringeCounts' => new \PHPExiftool\Driver\Tag\DICOM\SyringeCounts(),
                'ContrastFlowRate' => new \PHPExiftool\Driver\Tag\DICOM\ContrastFlowRate(),
                'ContrastFlowDuration' => new \PHPExiftool\Driver\Tag\DICOM\ContrastFlowDuration(),
                'ContrastBolusIngredient' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusIngredient(),
                'ContrastBolusConcentration' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusConcentration(),
                'SpatialResolution' => new \PHPExiftool\Driver\Tag\DICOM\SpatialResolution(),
                'TriggerTime' => new \PHPExiftool\Driver\Tag\DICOM\TriggerTime(),
                'TriggerSourceOrType' => new \PHPExiftool\Driver\Tag\DICOM\TriggerSourceOrType(),
                'NominalInterval' => new \PHPExiftool\Driver\Tag\DICOM\NominalInterval(),
                'FrameTime' => new \PHPExiftool\Driver\Tag\DICOM\FrameTime(),
                'CardiacFramingType' => new \PHPExiftool\Driver\Tag\DICOM\CardiacFramingType(),
                'FrameTimeVector' => new \PHPExiftool\Driver\Tag\DICOM\FrameTimeVector(),
                'FrameDelay' => new \PHPExiftool\Driver\Tag\DICOM\FrameDelay(),
                'ImageTriggerDelay' => new \PHPExiftool\Driver\Tag\DICOM\ImageTriggerDelay(),
                'MultiplexGroupTimeOffset' => new \PHPExiftool\Driver\Tag\DICOM\MultiplexGroupTimeOffset(),
                'TriggerTimeOffset' => new \PHPExiftool\Driver\Tag\DICOM\TriggerTimeOffset(),
                'SynchronizationTrigger' => new \PHPExiftool\Driver\Tag\DICOM\SynchronizationTrigger(),
                'SynchronizationChannel' => new \PHPExiftool\Driver\Tag\DICOM\SynchronizationChannel(),
                'TriggerSamplePosition' => new \PHPExiftool\Driver\Tag\DICOM\TriggerSamplePosition(),
                'RadiopharmaceuticalRoute' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalRoute(),
                'RadiopharmaceuticalVolume' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalVolume(),
                'RadiopharmaceuticalStartTime' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalStartTime(),
                'RadiopharmaceuticalStopTime' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalStopTime(),
                'RadionuclideTotalDose' => new \PHPExiftool\Driver\Tag\DICOM\RadionuclideTotalDose(),
                'RadionuclideHalfLife' => new \PHPExiftool\Driver\Tag\DICOM\RadionuclideHalfLife(),
                'RadionuclidePositronFraction' => new \PHPExiftool\Driver\Tag\DICOM\RadionuclidePositronFraction(),
                'RadiopharmaceuticalSpecActivity' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalSpecActivity(),
                'RadiopharmaceuticalStartDateTime' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalStartDateTime(),
                'RadiopharmaceuticalStopDateTime' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalStopDateTime(),
                'BeatRejectionFlag' => new \PHPExiftool\Driver\Tag\DICOM\BeatRejectionFlag(),
                'LowRRValue' => new \PHPExiftool\Driver\Tag\DICOM\LowRRValue(),
                'HighRRValue' => new \PHPExiftool\Driver\Tag\DICOM\HighRRValue(),
                'IntervalsAcquired' => new \PHPExiftool\Driver\Tag\DICOM\IntervalsAcquired(),
                'IntervalsRejected' => new \PHPExiftool\Driver\Tag\DICOM\IntervalsRejected(),
                'PVCRejection' => new \PHPExiftool\Driver\Tag\DICOM\PVCRejection(),
                'SkipBeats' => new \PHPExiftool\Driver\Tag\DICOM\SkipBeats(),
                'HeartRate' => new \PHPExiftool\Driver\Tag\DICOM\HeartRate(),
                'CardiacNumberOfImages' => new \PHPExiftool\Driver\Tag\DICOM\CardiacNumberOfImages(),
                'TriggerWindow' => new \PHPExiftool\Driver\Tag\DICOM\TriggerWindow(),
                'ReconstructionDiameter' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionDiameter(),
                'DistanceSourceToDetector' => new \PHPExiftool\Driver\Tag\DICOM\DistanceSourceToDetector(),
                'DistanceSourceToPatient' => new \PHPExiftool\Driver\Tag\DICOM\DistanceSourceToPatient(),
                'EstimatedRadiographicMagnification' => new \PHPExiftool\Driver\Tag\DICOM\EstimatedRadiographicMagnification(),
                'GantryDetectorTilt' => new \PHPExiftool\Driver\Tag\DICOM\GantryDetectorTilt(),
                'GantryDetectorSlew' => new \PHPExiftool\Driver\Tag\DICOM\GantryDetectorSlew(),
                'TableHeight' => new \PHPExiftool\Driver\Tag\DICOM\TableHeight(),
                'TableTraverse' => new \PHPExiftool\Driver\Tag\DICOM\TableTraverse(),
                'TableMotion' => new \PHPExiftool\Driver\Tag\DICOM\TableMotion(),
                'TableVerticalIncrement' => new \PHPExiftool\Driver\Tag\DICOM\TableVerticalIncrement(),
                'TableLateralIncrement' => new \PHPExiftool\Driver\Tag\DICOM\TableLateralIncrement(),
                'TableLongitudinalIncrement' => new \PHPExiftool\Driver\Tag\DICOM\TableLongitudinalIncrement(),
                'TableAngle' => new \PHPExiftool\Driver\Tag\DICOM\TableAngle(),
                'TableType' => new \PHPExiftool\Driver\Tag\DICOM\TableType(),
                'RotationDirection' => new \PHPExiftool\Driver\Tag\DICOM\RotationDirection(),
                'AngularPosition' => new \PHPExiftool\Driver\Tag\DICOM\AngularPosition(),
                'RadialPosition' => new \PHPExiftool\Driver\Tag\DICOM\RadialPosition(),
                'ScanArc' => new \PHPExiftool\Driver\Tag\DICOM\ScanArc(),
                'AngularStep' => new \PHPExiftool\Driver\Tag\DICOM\AngularStep(),
                'CenterOfRotationOffset' => new \PHPExiftool\Driver\Tag\DICOM\CenterOfRotationOffset(),
                'RotationOffset' => new \PHPExiftool\Driver\Tag\DICOM\RotationOffset(),
                'FieldOfViewShape' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewShape(),
                'FieldOfViewDimensions' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewDimensions(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\DICOM\ExposureTime(),
                'XRayTubeCurrent' => new \PHPExiftool\Driver\Tag\DICOM\XRayTubeCurrent(),
                'Exposure' => new \PHPExiftool\Driver\Tag\DICOM\Exposure(),
                'ExposureInMicroAmpSec' => new \PHPExiftool\Driver\Tag\DICOM\ExposureInMicroAmpSec(),
                'AveragePulseWidth' => new \PHPExiftool\Driver\Tag\DICOM\AveragePulseWidth(),
                'RadiationSetting' => new \PHPExiftool\Driver\Tag\DICOM\RadiationSetting(),
                'RectificationType' => new \PHPExiftool\Driver\Tag\DICOM\RectificationType(),
                'RadiationMode' => new \PHPExiftool\Driver\Tag\DICOM\RadiationMode(),
                'ImageAreaDoseProduct' => new \PHPExiftool\Driver\Tag\DICOM\ImageAreaDoseProduct(),
                'FilterType' => new \PHPExiftool\Driver\Tag\DICOM\FilterType(),
                'TypeOfFilters' => new \PHPExiftool\Driver\Tag\DICOM\TypeOfFilters(),
                'IntensifierSize' => new \PHPExiftool\Driver\Tag\DICOM\IntensifierSize(),
                'ImagerPixelSpacing' => new \PHPExiftool\Driver\Tag\DICOM\ImagerPixelSpacing(),
                'Grid' => new \PHPExiftool\Driver\Tag\DICOM\Grid(),
                'GeneratorPower' => new \PHPExiftool\Driver\Tag\DICOM\GeneratorPower(),
                'CollimatorGridName' => new \PHPExiftool\Driver\Tag\DICOM\CollimatorGridName(),
                'CollimatorType' => new \PHPExiftool\Driver\Tag\DICOM\CollimatorType(),
                'FocalDistance' => new \PHPExiftool\Driver\Tag\DICOM\FocalDistance(),
                'XFocusCenter' => new \PHPExiftool\Driver\Tag\DICOM\XFocusCenter(),
                'YFocusCenter' => new \PHPExiftool\Driver\Tag\DICOM\YFocusCenter(),
                'FocalSpots' => new \PHPExiftool\Driver\Tag\DICOM\FocalSpots(),
                'AnodeTargetMaterial' => new \PHPExiftool\Driver\Tag\DICOM\AnodeTargetMaterial(),
                'BodyPartThickness' => new \PHPExiftool\Driver\Tag\DICOM\BodyPartThickness(),
                'CompressionForce' => new \PHPExiftool\Driver\Tag\DICOM\CompressionForce(),
                'DateOfLastCalibration' => new \PHPExiftool\Driver\Tag\DICOM\DateOfLastCalibration(),
                'TimeOfLastCalibration' => new \PHPExiftool\Driver\Tag\DICOM\TimeOfLastCalibration(),
                'ConvolutionKernel' => new \PHPExiftool\Driver\Tag\DICOM\ConvolutionKernel(),
                'UpperLowerPixelValues' => new \PHPExiftool\Driver\Tag\DICOM\UpperLowerPixelValues(),
                'ActualFrameDuration' => new \PHPExiftool\Driver\Tag\DICOM\ActualFrameDuration(),
                'CountRate' => new \PHPExiftool\Driver\Tag\DICOM\CountRate(),
                'PreferredPlaybackSequencing' => new \PHPExiftool\Driver\Tag\DICOM\PreferredPlaybackSequencing(),
                'ReceiveCoilName' => new \PHPExiftool\Driver\Tag\DICOM\ReceiveCoilName(),
                'TransmitCoilName' => new \PHPExiftool\Driver\Tag\DICOM\TransmitCoilName(),
                'PlateType' => new \PHPExiftool\Driver\Tag\DICOM\PlateType(),
                'PhosphorType' => new \PHPExiftool\Driver\Tag\DICOM\PhosphorType(),
                'ScanVelocity' => new \PHPExiftool\Driver\Tag\DICOM\ScanVelocity(),
                'WholeBodyTechnique' => new \PHPExiftool\Driver\Tag\DICOM\WholeBodyTechnique(),
                'ScanLength' => new \PHPExiftool\Driver\Tag\DICOM\ScanLength(),
                'AcquisitionMatrix' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionMatrix(),
                'InPlanePhaseEncodingDirection' => new \PHPExiftool\Driver\Tag\DICOM\InPlanePhaseEncodingDirection(),
                'FlipAngle' => new \PHPExiftool\Driver\Tag\DICOM\FlipAngle(),
                'VariableFlipAngleFlag' => new \PHPExiftool\Driver\Tag\DICOM\VariableFlipAngleFlag(),
                'SAR' => new \PHPExiftool\Driver\Tag\DICOM\SAR(),
                'DB-Dt' => new \PHPExiftool\Driver\Tag\DICOM\DBDt(),
                'AcquisitionDeviceProcessingDescr' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionDeviceProcessingDescr(),
                'AcquisitionDeviceProcessingCode' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionDeviceProcessingCode(),
                'CassetteOrientation' => new \PHPExiftool\Driver\Tag\DICOM\CassetteOrientation(),
                'CassetteSize' => new \PHPExiftool\Driver\Tag\DICOM\CassetteSize(),
                'ExposuresOnPlate' => new \PHPExiftool\Driver\Tag\DICOM\ExposuresOnPlate(),
                'RelativeXRayExposure' => new \PHPExiftool\Driver\Tag\DICOM\RelativeXRayExposure(),
                'ColumnAngulation' => new \PHPExiftool\Driver\Tag\DICOM\ColumnAngulation(),
                'TomoLayerHeight' => new \PHPExiftool\Driver\Tag\DICOM\TomoLayerHeight(),
                'TomoAngle' => new \PHPExiftool\Driver\Tag\DICOM\TomoAngle(),
                'TomoTime' => new \PHPExiftool\Driver\Tag\DICOM\TomoTime(),
                'TomoType' => new \PHPExiftool\Driver\Tag\DICOM\TomoType(),
                'TomoClass' => new \PHPExiftool\Driver\Tag\DICOM\TomoClass(),
                'NumberOfTomosynthesisSourceImages' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTomosynthesisSourceImages(),
                'PositionerMotion' => new \PHPExiftool\Driver\Tag\DICOM\PositionerMotion(),
                'PositionerType' => new \PHPExiftool\Driver\Tag\DICOM\PositionerType(),
                'PositionerPrimaryAngle' => new \PHPExiftool\Driver\Tag\DICOM\PositionerPrimaryAngle(),
                'PositionerSecondaryAngle' => new \PHPExiftool\Driver\Tag\DICOM\PositionerSecondaryAngle(),
                'PositionerPrimaryAngleIncrement' => new \PHPExiftool\Driver\Tag\DICOM\PositionerPrimaryAngleIncrement(),
                'PositionerSecondaryAngleIncrement' => new \PHPExiftool\Driver\Tag\DICOM\PositionerSecondaryAngleIncrement(),
                'DetectorPrimaryAngle' => new \PHPExiftool\Driver\Tag\DICOM\DetectorPrimaryAngle(),
                'DetectorSecondaryAngle' => new \PHPExiftool\Driver\Tag\DICOM\DetectorSecondaryAngle(),
                'ShutterShape' => new \PHPExiftool\Driver\Tag\DICOM\ShutterShape(),
                'ShutterLeftVerticalEdge' => new \PHPExiftool\Driver\Tag\DICOM\ShutterLeftVerticalEdge(),
                'ShutterRightVerticalEdge' => new \PHPExiftool\Driver\Tag\DICOM\ShutterRightVerticalEdge(),
                'ShutterUpperHorizontalEdge' => new \PHPExiftool\Driver\Tag\DICOM\ShutterUpperHorizontalEdge(),
                'ShutterLowerHorizontalEdge' => new \PHPExiftool\Driver\Tag\DICOM\ShutterLowerHorizontalEdge(),
                'CenterOfCircularShutter' => new \PHPExiftool\Driver\Tag\DICOM\CenterOfCircularShutter(),
                'RadiusOfCircularShutter' => new \PHPExiftool\Driver\Tag\DICOM\RadiusOfCircularShutter(),
                'VerticesOfPolygonalShutter' => new \PHPExiftool\Driver\Tag\DICOM\VerticesOfPolygonalShutter(),
                'ShutterPresentationValue' => new \PHPExiftool\Driver\Tag\DICOM\ShutterPresentationValue(),
                'ShutterOverlayGroup' => new \PHPExiftool\Driver\Tag\DICOM\ShutterOverlayGroup(),
                'ShutterPresentationColorCIELabVal' => new \PHPExiftool\Driver\Tag\DICOM\ShutterPresentationColorCIELabVal(),
                'CollimatorShape' => new \PHPExiftool\Driver\Tag\DICOM\CollimatorShape(),
                'CollimatorLeftVerticalEdge' => new \PHPExiftool\Driver\Tag\DICOM\CollimatorLeftVerticalEdge(),
                'CollimatorRightVerticalEdge' => new \PHPExiftool\Driver\Tag\DICOM\CollimatorRightVerticalEdge(),
                'CollimatorUpperHorizontalEdge' => new \PHPExiftool\Driver\Tag\DICOM\CollimatorUpperHorizontalEdge(),
                'CollimatorLowerHorizontalEdge' => new \PHPExiftool\Driver\Tag\DICOM\CollimatorLowerHorizontalEdge(),
                'CenterOfCircularCollimator' => new \PHPExiftool\Driver\Tag\DICOM\CenterOfCircularCollimator(),
                'RadiusOfCircularCollimator' => new \PHPExiftool\Driver\Tag\DICOM\RadiusOfCircularCollimator(),
                'VerticesOfPolygonalCollimator' => new \PHPExiftool\Driver\Tag\DICOM\VerticesOfPolygonalCollimator(),
                'AcquisitionTimeSynchronized' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionTimeSynchronized(),
                'TimeSource' => new \PHPExiftool\Driver\Tag\DICOM\TimeSource(),
                'TimeDistributionProtocol' => new \PHPExiftool\Driver\Tag\DICOM\TimeDistributionProtocol(),
                'NTPSourceAddress' => new \PHPExiftool\Driver\Tag\DICOM\NTPSourceAddress(),
                'PageNumberVector' => new \PHPExiftool\Driver\Tag\DICOM\PageNumberVector(),
                'FrameLabelVector' => new \PHPExiftool\Driver\Tag\DICOM\FrameLabelVector(),
                'FramePrimaryAngleVector' => new \PHPExiftool\Driver\Tag\DICOM\FramePrimaryAngleVector(),
                'FrameSecondaryAngleVector' => new \PHPExiftool\Driver\Tag\DICOM\FrameSecondaryAngleVector(),
                'SliceLocationVector' => new \PHPExiftool\Driver\Tag\DICOM\SliceLocationVector(),
                'DisplayWindowLabelVector' => new \PHPExiftool\Driver\Tag\DICOM\DisplayWindowLabelVector(),
                'NominalScannedPixelSpacing' => new \PHPExiftool\Driver\Tag\DICOM\NominalScannedPixelSpacing(),
                'DigitizingDeviceTransportDirection' => new \PHPExiftool\Driver\Tag\DICOM\DigitizingDeviceTransportDirection(),
                'RotationOfScannedFilm' => new \PHPExiftool\Driver\Tag\DICOM\RotationOfScannedFilm(),
                'IVUSAcquisition' => new \PHPExiftool\Driver\Tag\DICOM\IVUSAcquisition(),
                'IVUSPullbackRate' => new \PHPExiftool\Driver\Tag\DICOM\IVUSPullbackRate(),
                'IVUSGatedRate' => new \PHPExiftool\Driver\Tag\DICOM\IVUSGatedRate(),
                'IVUSPullbackStartFrameNumber' => new \PHPExiftool\Driver\Tag\DICOM\IVUSPullbackStartFrameNumber(),
                'IVUSPullbackStopFrameNumber' => new \PHPExiftool\Driver\Tag\DICOM\IVUSPullbackStopFrameNumber(),
                'LesionNumber' => new \PHPExiftool\Driver\Tag\DICOM\LesionNumber(),
                'AcquisitionComments' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionComments(),
                'OutputPower' => new \PHPExiftool\Driver\Tag\DICOM\OutputPower(),
                'TransducerData' => new \PHPExiftool\Driver\Tag\DICOM\TransducerData(),
                'FocusDepth' => new \PHPExiftool\Driver\Tag\DICOM\FocusDepth(),
                'ProcessingFunction' => new \PHPExiftool\Driver\Tag\DICOM\ProcessingFunction(),
                'PostprocessingFunction' => new \PHPExiftool\Driver\Tag\DICOM\PostprocessingFunction(),
                'MechanicalIndex' => new \PHPExiftool\Driver\Tag\DICOM\MechanicalIndex(),
                'BoneThermalIndex' => new \PHPExiftool\Driver\Tag\DICOM\BoneThermalIndex(),
                'CranialThermalIndex' => new \PHPExiftool\Driver\Tag\DICOM\CranialThermalIndex(),
                'SoftTissueThermalIndex' => new \PHPExiftool\Driver\Tag\DICOM\SoftTissueThermalIndex(),
                'SoftTissueFocusThermalIndex' => new \PHPExiftool\Driver\Tag\DICOM\SoftTissueFocusThermalIndex(),
                'SoftTissueSurfaceThermalIndex' => new \PHPExiftool\Driver\Tag\DICOM\SoftTissueSurfaceThermalIndex(),
                'DynamicRange' => new \PHPExiftool\Driver\Tag\DICOM\DynamicRange(),
                'TotalGain' => new \PHPExiftool\Driver\Tag\DICOM\TotalGain(),
                'DepthOfScanField' => new \PHPExiftool\Driver\Tag\DICOM\DepthOfScanField(),
                'PatientPosition' => new \PHPExiftool\Driver\Tag\DICOM\PatientPosition(),
                'ViewPosition' => new \PHPExiftool\Driver\Tag\DICOM\ViewPosition(),
                'ProjectionEponymousNameCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\ProjectionEponymousNameCodeSeq(),
                'ImageTransformationMatrix' => new \PHPExiftool\Driver\Tag\DICOM\ImageTransformationMatrix(),
                'ImageTranslationVector' => new \PHPExiftool\Driver\Tag\DICOM\ImageTranslationVector(),
                'Sensitivity' => new \PHPExiftool\Driver\Tag\DICOM\Sensitivity(),
                'SequenceOfUltrasoundRegions' => new \PHPExiftool\Driver\Tag\DICOM\SequenceOfUltrasoundRegions(),
                'RegionSpatialFormat' => new \PHPExiftool\Driver\Tag\DICOM\RegionSpatialFormat(),
                'RegionDataType' => new \PHPExiftool\Driver\Tag\DICOM\RegionDataType(),
                'RegionFlags' => new \PHPExiftool\Driver\Tag\DICOM\RegionFlags(),
                'RegionLocationMinX0' => new \PHPExiftool\Driver\Tag\DICOM\RegionLocationMinX0(),
                'RegionLocationMinY0' => new \PHPExiftool\Driver\Tag\DICOM\RegionLocationMinY0(),
                'RegionLocationMaxX1' => new \PHPExiftool\Driver\Tag\DICOM\RegionLocationMaxX1(),
                'RegionLocationMaxY1' => new \PHPExiftool\Driver\Tag\DICOM\RegionLocationMaxY1(),
                'ReferencePixelX0' => new \PHPExiftool\Driver\Tag\DICOM\ReferencePixelX0(),
                'ReferencePixelY0' => new \PHPExiftool\Driver\Tag\DICOM\ReferencePixelY0(),
                'PhysicalUnitsXDirection' => new \PHPExiftool\Driver\Tag\DICOM\PhysicalUnitsXDirection(),
                'PhysicalUnitsYDirection' => new \PHPExiftool\Driver\Tag\DICOM\PhysicalUnitsYDirection(),
                'ReferencePixelPhysicalValueX' => new \PHPExiftool\Driver\Tag\DICOM\ReferencePixelPhysicalValueX(),
                'ReferencePixelPhysicalValueY' => new \PHPExiftool\Driver\Tag\DICOM\ReferencePixelPhysicalValueY(),
                'PhysicalDeltaX' => new \PHPExiftool\Driver\Tag\DICOM\PhysicalDeltaX(),
                'PhysicalDeltaY' => new \PHPExiftool\Driver\Tag\DICOM\PhysicalDeltaY(),
                'TransducerFrequency' => new \PHPExiftool\Driver\Tag\DICOM\TransducerFrequency(),
                'TransducerType' => new \PHPExiftool\Driver\Tag\DICOM\TransducerType(),
                'PulseRepetitionFrequency' => new \PHPExiftool\Driver\Tag\DICOM\PulseRepetitionFrequency(),
                'DopplerCorrectionAngle' => new \PHPExiftool\Driver\Tag\DICOM\DopplerCorrectionAngle(),
                'SteeringAngle' => new \PHPExiftool\Driver\Tag\DICOM\SteeringAngle(),
                'DopplerSampleVolumeXPosRetired' => new \PHPExiftool\Driver\Tag\DICOM\DopplerSampleVolumeXPosRetired(),
                'DopplerSampleVolumeXPosition' => new \PHPExiftool\Driver\Tag\DICOM\DopplerSampleVolumeXPosition(),
                'DopplerSampleVolumeYPosRetired' => new \PHPExiftool\Driver\Tag\DICOM\DopplerSampleVolumeYPosRetired(),
                'DopplerSampleVolumeYPosition' => new \PHPExiftool\Driver\Tag\DICOM\DopplerSampleVolumeYPosition(),
                'TMLinePositionX0Retired' => new \PHPExiftool\Driver\Tag\DICOM\TMLinePositionX0Retired(),
                'TMLinePositionX0' => new \PHPExiftool\Driver\Tag\DICOM\TMLinePositionX0(),
                'TMLinePositionY0Retired' => new \PHPExiftool\Driver\Tag\DICOM\TMLinePositionY0Retired(),
                'TMLinePositionY0' => new \PHPExiftool\Driver\Tag\DICOM\TMLinePositionY0(),
                'TMLinePositionX1Retired' => new \PHPExiftool\Driver\Tag\DICOM\TMLinePositionX1Retired(),
                'TMLinePositionX1' => new \PHPExiftool\Driver\Tag\DICOM\TMLinePositionX1(),
                'TMLinePositionY1Retired' => new \PHPExiftool\Driver\Tag\DICOM\TMLinePositionY1Retired(),
                'TMLinePositionY1' => new \PHPExiftool\Driver\Tag\DICOM\TMLinePositionY1(),
                'PixelComponentOrganization' => new \PHPExiftool\Driver\Tag\DICOM\PixelComponentOrganization(),
                'PixelComponentMask' => new \PHPExiftool\Driver\Tag\DICOM\PixelComponentMask(),
                'PixelComponentRangeStart' => new \PHPExiftool\Driver\Tag\DICOM\PixelComponentRangeStart(),
                'PixelComponentRangeStop' => new \PHPExiftool\Driver\Tag\DICOM\PixelComponentRangeStop(),
                'PixelComponentPhysicalUnits' => new \PHPExiftool\Driver\Tag\DICOM\PixelComponentPhysicalUnits(),
                'PixelComponentDataType' => new \PHPExiftool\Driver\Tag\DICOM\PixelComponentDataType(),
                'NumberOfTableBreakPoints' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTableBreakPoints(),
                'TableOfXBreakPoints' => new \PHPExiftool\Driver\Tag\DICOM\TableOfXBreakPoints(),
                'TableOfYBreakPoints' => new \PHPExiftool\Driver\Tag\DICOM\TableOfYBreakPoints(),
                'NumberOfTableEntries' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTableEntries(),
                'TableOfPixelValues' => new \PHPExiftool\Driver\Tag\DICOM\TableOfPixelValues(),
                'TableOfParameterValues' => new \PHPExiftool\Driver\Tag\DICOM\TableOfParameterValues(),
                'RWaveTimeVector' => new \PHPExiftool\Driver\Tag\DICOM\RWaveTimeVector(),
                'DetectorConditionsNominalFlag' => new \PHPExiftool\Driver\Tag\DICOM\DetectorConditionsNominalFlag(),
                'DetectorTemperature' => new \PHPExiftool\Driver\Tag\DICOM\DetectorTemperature(),
                'DetectorType' => new \PHPExiftool\Driver\Tag\DICOM\DetectorType(),
                'DetectorConfiguration' => new \PHPExiftool\Driver\Tag\DICOM\DetectorConfiguration(),
                'DetectorDescription' => new \PHPExiftool\Driver\Tag\DICOM\DetectorDescription(),
                'DetectorMode' => new \PHPExiftool\Driver\Tag\DICOM\DetectorMode(),
                'DetectorID' => new \PHPExiftool\Driver\Tag\DICOM\DetectorID(),
                'DateOfLastDetectorCalibration' => new \PHPExiftool\Driver\Tag\DICOM\DateOfLastDetectorCalibration(),
                'TimeOfLastDetectorCalibration' => new \PHPExiftool\Driver\Tag\DICOM\TimeOfLastDetectorCalibration(),
                'DetectorExposuresSinceCalibration' => new \PHPExiftool\Driver\Tag\DICOM\DetectorExposuresSinceCalibration(),
                'DetectorExposuresSinceManufactured' => new \PHPExiftool\Driver\Tag\DICOM\DetectorExposuresSinceManufactured(),
                'DetectorTimeSinceLastExposure' => new \PHPExiftool\Driver\Tag\DICOM\DetectorTimeSinceLastExposure(),
                'DetectorActiveTime' => new \PHPExiftool\Driver\Tag\DICOM\DetectorActiveTime(),
                'DetectorActiveOffsetFromExposure' => new \PHPExiftool\Driver\Tag\DICOM\DetectorActiveOffsetFromExposure(),
                'DetectorBinning' => new \PHPExiftool\Driver\Tag\DICOM\DetectorBinning(),
                'DetectorElementPhysicalSize' => new \PHPExiftool\Driver\Tag\DICOM\DetectorElementPhysicalSize(),
                'DetectorElementSpacing' => new \PHPExiftool\Driver\Tag\DICOM\DetectorElementSpacing(),
                'DetectorActiveShape' => new \PHPExiftool\Driver\Tag\DICOM\DetectorActiveShape(),
                'DetectorActiveDimensions' => new \PHPExiftool\Driver\Tag\DICOM\DetectorActiveDimensions(),
                'DetectorActiveOrigin' => new \PHPExiftool\Driver\Tag\DICOM\DetectorActiveOrigin(),
                'DetectorManufacturerName' => new \PHPExiftool\Driver\Tag\DICOM\DetectorManufacturerName(),
                'DetectorManufacturersModelName' => new \PHPExiftool\Driver\Tag\DICOM\DetectorManufacturersModelName(),
                'FieldOfViewOrigin' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewOrigin(),
                'FieldOfViewRotation' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewRotation(),
                'FieldOfViewHorizontalFlip' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewHorizontalFlip(),
                'GridAbsorbingMaterial' => new \PHPExiftool\Driver\Tag\DICOM\GridAbsorbingMaterial(),
                'GridSpacingMaterial' => new \PHPExiftool\Driver\Tag\DICOM\GridSpacingMaterial(),
                'GridThickness' => new \PHPExiftool\Driver\Tag\DICOM\GridThickness(),
                'GridPitch' => new \PHPExiftool\Driver\Tag\DICOM\GridPitch(),
                'GridAspectRatio' => new \PHPExiftool\Driver\Tag\DICOM\GridAspectRatio(),
                'GridPeriod' => new \PHPExiftool\Driver\Tag\DICOM\GridPeriod(),
                'GridFocalDistance' => new \PHPExiftool\Driver\Tag\DICOM\GridFocalDistance(),
                'FilterMaterial' => new \PHPExiftool\Driver\Tag\DICOM\FilterMaterial(),
                'FilterThicknessMinimum' => new \PHPExiftool\Driver\Tag\DICOM\FilterThicknessMinimum(),
                'FilterThicknessMaximum' => new \PHPExiftool\Driver\Tag\DICOM\FilterThicknessMaximum(),
                'ExposureControlMode' => new \PHPExiftool\Driver\Tag\DICOM\ExposureControlMode(),
                'ExposureControlModeDescription' => new \PHPExiftool\Driver\Tag\DICOM\ExposureControlModeDescription(),
                'ExposureStatus' => new \PHPExiftool\Driver\Tag\DICOM\ExposureStatus(),
                'PhototimerSetting' => new \PHPExiftool\Driver\Tag\DICOM\PhototimerSetting(),
                'ExposureTimeInMicroSec' => new \PHPExiftool\Driver\Tag\DICOM\ExposureTimeInMicroSec(),
                'XRayTubeCurrentInMicroAmps' => new \PHPExiftool\Driver\Tag\DICOM\XRayTubeCurrentInMicroAmps(),
                'ContentQualification' => new \PHPExiftool\Driver\Tag\DICOM\ContentQualification(),
                'PulseSequenceName' => new \PHPExiftool\Driver\Tag\DICOM\PulseSequenceName(),
                'MRImagingModifierSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRImagingModifierSequence(),
                'EchoPulseSequence' => new \PHPExiftool\Driver\Tag\DICOM\EchoPulseSequence(),
                'InversionRecovery' => new \PHPExiftool\Driver\Tag\DICOM\InversionRecovery(),
                'FlowCompensation' => new \PHPExiftool\Driver\Tag\DICOM\FlowCompensation(),
                'MultipleSpinEcho' => new \PHPExiftool\Driver\Tag\DICOM\MultipleSpinEcho(),
                'MultiPlanarExcitation' => new \PHPExiftool\Driver\Tag\DICOM\MultiPlanarExcitation(),
                'PhaseContrast' => new \PHPExiftool\Driver\Tag\DICOM\PhaseContrast(),
                'TimeOfFlightContrast' => new \PHPExiftool\Driver\Tag\DICOM\TimeOfFlightContrast(),
                'Spoiling' => new \PHPExiftool\Driver\Tag\DICOM\Spoiling(),
                'SteadyStatePulseSequence' => new \PHPExiftool\Driver\Tag\DICOM\SteadyStatePulseSequence(),
                'EchoPlanarPulseSequence' => new \PHPExiftool\Driver\Tag\DICOM\EchoPlanarPulseSequence(),
                'TagAngleFirstAxis' => new \PHPExiftool\Driver\Tag\DICOM\TagAngleFirstAxis(),
                'MagnetizationTransfer' => new \PHPExiftool\Driver\Tag\DICOM\MagnetizationTransfer(),
                'T2Preparation' => new \PHPExiftool\Driver\Tag\DICOM\T2Preparation(),
                'BloodSignalNulling' => new \PHPExiftool\Driver\Tag\DICOM\BloodSignalNulling(),
                'SaturationRecovery' => new \PHPExiftool\Driver\Tag\DICOM\SaturationRecovery(),
                'SpectrallySelectedSuppression' => new \PHPExiftool\Driver\Tag\DICOM\SpectrallySelectedSuppression(),
                'SpectrallySelectedExcitation' => new \PHPExiftool\Driver\Tag\DICOM\SpectrallySelectedExcitation(),
                'SpatialPresaturation' => new \PHPExiftool\Driver\Tag\DICOM\SpatialPresaturation(),
                'Tagging' => new \PHPExiftool\Driver\Tag\DICOM\Tagging(),
                'OversamplingPhase' => new \PHPExiftool\Driver\Tag\DICOM\OversamplingPhase(),
                'TagSpacingFirstDimension' => new \PHPExiftool\Driver\Tag\DICOM\TagSpacingFirstDimension(),
                'GeometryOfKSpaceTraversal' => new \PHPExiftool\Driver\Tag\DICOM\GeometryOfKSpaceTraversal(),
                'SegmentedKSpaceTraversal' => new \PHPExiftool\Driver\Tag\DICOM\SegmentedKSpaceTraversal(),
                'RectilinearPhaseEncodeReordering' => new \PHPExiftool\Driver\Tag\DICOM\RectilinearPhaseEncodeReordering(),
                'TagThickness' => new \PHPExiftool\Driver\Tag\DICOM\TagThickness(),
                'PartialFourierDirection' => new \PHPExiftool\Driver\Tag\DICOM\PartialFourierDirection(),
                'CardiacSynchronizationTechnique' => new \PHPExiftool\Driver\Tag\DICOM\CardiacSynchronizationTechnique(),
                'ReceiveCoilManufacturerName' => new \PHPExiftool\Driver\Tag\DICOM\ReceiveCoilManufacturerName(),
                'MRReceiveCoilSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRReceiveCoilSequence(),
                'ReceiveCoilType' => new \PHPExiftool\Driver\Tag\DICOM\ReceiveCoilType(),
                'QuadratureReceiveCoil' => new \PHPExiftool\Driver\Tag\DICOM\QuadratureReceiveCoil(),
                'MultiCoilDefinitionSequence' => new \PHPExiftool\Driver\Tag\DICOM\MultiCoilDefinitionSequence(),
                'MultiCoilConfiguration' => new \PHPExiftool\Driver\Tag\DICOM\MultiCoilConfiguration(),
                'MultiCoilElementName' => new \PHPExiftool\Driver\Tag\DICOM\MultiCoilElementName(),
                'MultiCoilElementUsed' => new \PHPExiftool\Driver\Tag\DICOM\MultiCoilElementUsed(),
                'MRTransmitCoilSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRTransmitCoilSequence(),
                'TransmitCoilManufacturerName' => new \PHPExiftool\Driver\Tag\DICOM\TransmitCoilManufacturerName(),
                'TransmitCoilType' => new \PHPExiftool\Driver\Tag\DICOM\TransmitCoilType(),
                'SpectralWidth' => new \PHPExiftool\Driver\Tag\DICOM\SpectralWidth(),
                'ChemicalShiftReference' => new \PHPExiftool\Driver\Tag\DICOM\ChemicalShiftReference(),
                'VolumeLocalizationTechnique' => new \PHPExiftool\Driver\Tag\DICOM\VolumeLocalizationTechnique(),
                'MRAcquisitionFrequencyEncodeSteps' => new \PHPExiftool\Driver\Tag\DICOM\MRAcquisitionFrequencyEncodeSteps(),
                'Decoupling' => new \PHPExiftool\Driver\Tag\DICOM\Decoupling(),
                'DecoupledNucleus' => new \PHPExiftool\Driver\Tag\DICOM\DecoupledNucleus(),
                'DecouplingFrequency' => new \PHPExiftool\Driver\Tag\DICOM\DecouplingFrequency(),
                'DecouplingMethod' => new \PHPExiftool\Driver\Tag\DICOM\DecouplingMethod(),
                'DecouplingChemicalShiftReference' => new \PHPExiftool\Driver\Tag\DICOM\DecouplingChemicalShiftReference(),
                'KSpaceFiltering' => new \PHPExiftool\Driver\Tag\DICOM\KSpaceFiltering(),
                'TimeDomainFiltering' => new \PHPExiftool\Driver\Tag\DICOM\TimeDomainFiltering(),
                'NumberOfZeroFills' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfZeroFills(),
                'BaselineCorrection' => new \PHPExiftool\Driver\Tag\DICOM\BaselineCorrection(),
                'ParallelReductionFactorInPlane' => new \PHPExiftool\Driver\Tag\DICOM\ParallelReductionFactorInPlane(),
                'CardiacRRIntervalSpecified' => new \PHPExiftool\Driver\Tag\DICOM\CardiacRRIntervalSpecified(),
                'AcquisitionDuration' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionDuration(),
                'FrameAcquisitionDateTime' => new \PHPExiftool\Driver\Tag\DICOM\FrameAcquisitionDateTime(),
                'DiffusionDirectionality' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionDirectionality(),
                'DiffusionGradientDirectionSequence' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionGradientDirectionSequence(),
                'ParallelAcquisition' => new \PHPExiftool\Driver\Tag\DICOM\ParallelAcquisition(),
                'ParallelAcquisitionTechnique' => new \PHPExiftool\Driver\Tag\DICOM\ParallelAcquisitionTechnique(),
                'InversionTimes' => new \PHPExiftool\Driver\Tag\DICOM\InversionTimes(),
                'MetaboliteMapDescription' => new \PHPExiftool\Driver\Tag\DICOM\MetaboliteMapDescription(),
                'PartialFourier' => new \PHPExiftool\Driver\Tag\DICOM\PartialFourier(),
                'EffectiveEchoTime' => new \PHPExiftool\Driver\Tag\DICOM\EffectiveEchoTime(),
                'MetaboliteMapCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\MetaboliteMapCodeSequence(),
                'ChemicalShiftSequence' => new \PHPExiftool\Driver\Tag\DICOM\ChemicalShiftSequence(),
                'CardiacSignalSource' => new \PHPExiftool\Driver\Tag\DICOM\CardiacSignalSource(),
                'DiffusionBValue' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionBValue(),
                'DiffusionGradientOrientation' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionGradientOrientation(),
                'VelocityEncodingDirection' => new \PHPExiftool\Driver\Tag\DICOM\VelocityEncodingDirection(),
                'VelocityEncodingMinimumValue' => new \PHPExiftool\Driver\Tag\DICOM\VelocityEncodingMinimumValue(),
                'NumberOfKSpaceTrajectories' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfKSpaceTrajectories(),
                'CoverageOfKSpace' => new \PHPExiftool\Driver\Tag\DICOM\CoverageOfKSpace(),
                'SpectroscopyAcquisitionPhaseRows' => new \PHPExiftool\Driver\Tag\DICOM\SpectroscopyAcquisitionPhaseRows(),
                'ParallelReductFactorInPlaneRetired' => new \PHPExiftool\Driver\Tag\DICOM\ParallelReductFactorInPlaneRetired(),
                'TransmitterFrequency' => new \PHPExiftool\Driver\Tag\DICOM\TransmitterFrequency(),
                'ResonantNucleus' => new \PHPExiftool\Driver\Tag\DICOM\ResonantNucleus(),
                'FrequencyCorrection' => new \PHPExiftool\Driver\Tag\DICOM\FrequencyCorrection(),
                'MRSpectroscopyFOV-GeometrySequence' => new \PHPExiftool\Driver\Tag\DICOM\MRSpectroscopyFOVGeometrySequence(),
                'SlabThickness' => new \PHPExiftool\Driver\Tag\DICOM\SlabThickness(),
                'SlabOrientation' => new \PHPExiftool\Driver\Tag\DICOM\SlabOrientation(),
                'MidSlabPosition' => new \PHPExiftool\Driver\Tag\DICOM\MidSlabPosition(),
                'MRSpatialSaturationSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRSpatialSaturationSequence(),
                'MRTimingAndRelatedParametersSeq' => new \PHPExiftool\Driver\Tag\DICOM\MRTimingAndRelatedParametersSeq(),
                'MREchoSequence' => new \PHPExiftool\Driver\Tag\DICOM\MREchoSequence(),
                'MRModifierSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRModifierSequence(),
                'MRDiffusionSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRDiffusionSequence(),
                'CardiacTriggerSequence' => new \PHPExiftool\Driver\Tag\DICOM\CardiacTriggerSequence(),
                'MRAveragesSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRAveragesSequence(),
                'MRFOV-GeometrySequence' => new \PHPExiftool\Driver\Tag\DICOM\MRFOVGeometrySequence(),
                'VolumeLocalizationSequence' => new \PHPExiftool\Driver\Tag\DICOM\VolumeLocalizationSequence(),
                'SpectroscopyAcquisitionDataColumns' => new \PHPExiftool\Driver\Tag\DICOM\SpectroscopyAcquisitionDataColumns(),
                'DiffusionAnisotropyType' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionAnisotropyType(),
                'FrameReferenceDateTime' => new \PHPExiftool\Driver\Tag\DICOM\FrameReferenceDateTime(),
                'MRMetaboliteMapSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRMetaboliteMapSequence(),
                'ParallelReductionFactorOutOfPlane' => new \PHPExiftool\Driver\Tag\DICOM\ParallelReductionFactorOutOfPlane(),
                'SpectroscopyOutOfPlanePhaseSteps' => new \PHPExiftool\Driver\Tag\DICOM\SpectroscopyOutOfPlanePhaseSteps(),
                'BulkMotionStatus' => new \PHPExiftool\Driver\Tag\DICOM\BulkMotionStatus(),
                'ParallelReductionFactSecondInPlane' => new \PHPExiftool\Driver\Tag\DICOM\ParallelReductionFactSecondInPlane(),
                'CardiacBeatRejectionTechnique' => new \PHPExiftool\Driver\Tag\DICOM\CardiacBeatRejectionTechnique(),
                'RespiratoryMotionCompTechnique' => new \PHPExiftool\Driver\Tag\DICOM\RespiratoryMotionCompTechnique(),
                'RespiratorySignalSource' => new \PHPExiftool\Driver\Tag\DICOM\RespiratorySignalSource(),
                'BulkMotionCompensationTechnique' => new \PHPExiftool\Driver\Tag\DICOM\BulkMotionCompensationTechnique(),
                'BulkMotionSignalSource' => new \PHPExiftool\Driver\Tag\DICOM\BulkMotionSignalSource(),
                'ApplicableSafetyStandardAgency' => new \PHPExiftool\Driver\Tag\DICOM\ApplicableSafetyStandardAgency(),
                'ApplicableSafetyStandardDescr' => new \PHPExiftool\Driver\Tag\DICOM\ApplicableSafetyStandardDescr(),
                'OperatingModeSequence' => new \PHPExiftool\Driver\Tag\DICOM\OperatingModeSequence(),
                'OperatingModeType' => new \PHPExiftool\Driver\Tag\DICOM\OperatingModeType(),
                'OperatingMode' => new \PHPExiftool\Driver\Tag\DICOM\OperatingMode(),
                'SpecificAbsorptionRateDefinition' => new \PHPExiftool\Driver\Tag\DICOM\SpecificAbsorptionRateDefinition(),
                'GradientOutputType' => new \PHPExiftool\Driver\Tag\DICOM\GradientOutputType(),
                'SpecificAbsorptionRateValue' => new \PHPExiftool\Driver\Tag\DICOM\SpecificAbsorptionRateValue(),
                'GradientOutput' => new \PHPExiftool\Driver\Tag\DICOM\GradientOutput(),
                'FlowCompensationDirection' => new \PHPExiftool\Driver\Tag\DICOM\FlowCompensationDirection(),
                'TaggingDelay' => new \PHPExiftool\Driver\Tag\DICOM\TaggingDelay(),
                'RespiratoryMotionCompTechDescr' => new \PHPExiftool\Driver\Tag\DICOM\RespiratoryMotionCompTechDescr(),
                'RespiratorySignalSourceID' => new \PHPExiftool\Driver\Tag\DICOM\RespiratorySignalSourceID(),
                'ChemicalShiftsMinIntegrateLimitHz' => new \PHPExiftool\Driver\Tag\DICOM\ChemicalShiftsMinIntegrateLimitHz(),
                'ChemicalShiftsMaxIntegrateLimitHz' => new \PHPExiftool\Driver\Tag\DICOM\ChemicalShiftsMaxIntegrateLimitHz(),
                'MRVelocityEncodingSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRVelocityEncodingSequence(),
                'FirstOrderPhaseCorrection' => new \PHPExiftool\Driver\Tag\DICOM\FirstOrderPhaseCorrection(),
                'WaterReferencedPhaseCorrection' => new \PHPExiftool\Driver\Tag\DICOM\WaterReferencedPhaseCorrection(),
                'MRSpectroscopyAcquisitionType' => new \PHPExiftool\Driver\Tag\DICOM\MRSpectroscopyAcquisitionType(),
                'RespiratoryCyclePosition' => new \PHPExiftool\Driver\Tag\DICOM\RespiratoryCyclePosition(),
                'VelocityEncodingMaximumValue' => new \PHPExiftool\Driver\Tag\DICOM\VelocityEncodingMaximumValue(),
                'TagSpacingSecondDimension' => new \PHPExiftool\Driver\Tag\DICOM\TagSpacingSecondDimension(),
                'TagAngleSecondAxis' => new \PHPExiftool\Driver\Tag\DICOM\TagAngleSecondAxis(),
                'FrameAcquisitionDuration' => new \PHPExiftool\Driver\Tag\DICOM\FrameAcquisitionDuration(),
                'MRImageFrameTypeSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRImageFrameTypeSequence(),
                'MRSpectroscopyFrameTypeSequence' => new \PHPExiftool\Driver\Tag\DICOM\MRSpectroscopyFrameTypeSequence(),
                'MRAcqPhaseEncodingStepsInPlane' => new \PHPExiftool\Driver\Tag\DICOM\MRAcqPhaseEncodingStepsInPlane(),
                'MRAcqPhaseEncodingStepsOutOfPlane' => new \PHPExiftool\Driver\Tag\DICOM\MRAcqPhaseEncodingStepsOutOfPlane(),
                'SpectroscopyAcqPhaseColumns' => new \PHPExiftool\Driver\Tag\DICOM\SpectroscopyAcqPhaseColumns(),
                'CardiacCyclePosition' => new \PHPExiftool\Driver\Tag\DICOM\CardiacCyclePosition(),
                'SpecificAbsorptionRateSequence' => new \PHPExiftool\Driver\Tag\DICOM\SpecificAbsorptionRateSequence(),
                'RFEchoTrainLength' => new \PHPExiftool\Driver\Tag\DICOM\RFEchoTrainLength(),
                'GradientEchoTrainLength' => new \PHPExiftool\Driver\Tag\DICOM\GradientEchoTrainLength(),
                'ChemicalShiftsMinIntegrateLimitPPM' => new \PHPExiftool\Driver\Tag\DICOM\ChemicalShiftsMinIntegrateLimitPPM(),
                'ChemicalShiftsMaxIntegrateLimitPPM' => new \PHPExiftool\Driver\Tag\DICOM\ChemicalShiftsMaxIntegrateLimitPPM(),
                'CTAcquisitionTypeSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTAcquisitionTypeSequence(),
                'AcquisitionType' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionType(),
                'TubeAngle' => new \PHPExiftool\Driver\Tag\DICOM\TubeAngle(),
                'CTAcquisitionDetailsSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTAcquisitionDetailsSequence(),
                'RevolutionTime' => new \PHPExiftool\Driver\Tag\DICOM\RevolutionTime(),
                'SingleCollimationWidth' => new \PHPExiftool\Driver\Tag\DICOM\SingleCollimationWidth(),
                'TotalCollimationWidth' => new \PHPExiftool\Driver\Tag\DICOM\TotalCollimationWidth(),
                'CTTableDynamicsSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTTableDynamicsSequence(),
                'TableSpeed' => new \PHPExiftool\Driver\Tag\DICOM\TableSpeed(),
                'TableFeedPerRotation' => new \PHPExiftool\Driver\Tag\DICOM\TableFeedPerRotation(),
                'SpiralPitchFactor' => new \PHPExiftool\Driver\Tag\DICOM\SpiralPitchFactor(),
                'CTGeometrySequence' => new \PHPExiftool\Driver\Tag\DICOM\CTGeometrySequence(),
                'DataCollectionCenterPatient' => new \PHPExiftool\Driver\Tag\DICOM\DataCollectionCenterPatient(),
                'CTReconstructionSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTReconstructionSequence(),
                'ReconstructionAlgorithm' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionAlgorithm(),
                'ConvolutionKernelGroup' => new \PHPExiftool\Driver\Tag\DICOM\ConvolutionKernelGroup(),
                'ReconstructionFieldOfView' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionFieldOfView(),
                'ReconstructionTargetCenterPatient' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionTargetCenterPatient(),
                'ReconstructionAngle' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionAngle(),
                'ImageFilter' => new \PHPExiftool\Driver\Tag\DICOM\ImageFilter(),
                'CTExposureSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTExposureSequence(),
                'ReconstructionPixelSpacing' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionPixelSpacing(),
                'ExposureModulationType' => new \PHPExiftool\Driver\Tag\DICOM\ExposureModulationType(),
                'EstimatedDoseSaving' => new \PHPExiftool\Driver\Tag\DICOM\EstimatedDoseSaving(),
                'CTXRayDetailsSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTXRayDetailsSequence(),
                'CTPositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTPositionSequence(),
                'TablePosition' => new \PHPExiftool\Driver\Tag\DICOM\TablePosition(),
                'ExposureTimeInMilliSec' => new \PHPExiftool\Driver\Tag\DICOM\ExposureTimeInMilliSec(),
                'CTImageFrameTypeSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTImageFrameTypeSequence(),
                'XRayTubeCurrentInMilliAmps' => new \PHPExiftool\Driver\Tag\DICOM\XRayTubeCurrentInMilliAmps(),
                'ExposureInMilliAmpSec' => new \PHPExiftool\Driver\Tag\DICOM\ExposureInMilliAmpSec(),
                'ConstantVolumeFlag' => new \PHPExiftool\Driver\Tag\DICOM\ConstantVolumeFlag(),
                'FluoroscopyFlag' => new \PHPExiftool\Driver\Tag\DICOM\FluoroscopyFlag(),
                'SourceToDataCollectionCenterDist' => new \PHPExiftool\Driver\Tag\DICOM\SourceToDataCollectionCenterDist(),
                'ContrastBolusAgentNumber' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentNumber(),
                'ContrastBolusIngredientCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusIngredientCodeSeq(),
                'ContrastAdministrationProfileSeq' => new \PHPExiftool\Driver\Tag\DICOM\ContrastAdministrationProfileSeq(),
                'ContrastBolusUsageSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusUsageSequence(),
                'ContrastBolusAgentAdministered' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentAdministered(),
                'ContrastBolusAgentDetected' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentDetected(),
                'ContrastBolusAgentPhase' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentPhase(),
                'CTDIvol' => new \PHPExiftool\Driver\Tag\DICOM\CTDIvol(),
                'CTDIPhantomTypeCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTDIPhantomTypeCodeSequence(),
                'CalciumScoringMassFactorPatient' => new \PHPExiftool\Driver\Tag\DICOM\CalciumScoringMassFactorPatient(),
                'CalciumScoringMassFactorDevice' => new \PHPExiftool\Driver\Tag\DICOM\CalciumScoringMassFactorDevice(),
                'EnergyWeightingFactor' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWeightingFactor(),
                'CTAdditionalXRaySourceSequence' => new \PHPExiftool\Driver\Tag\DICOM\CTAdditionalXRaySourceSequence(),
                'ProjectionPixelCalibrationSequence' => new \PHPExiftool\Driver\Tag\DICOM\ProjectionPixelCalibrationSequence(),
                'DistanceSourceToIsocenter' => new \PHPExiftool\Driver\Tag\DICOM\DistanceSourceToIsocenter(),
                'DistanceObjectToTableTop' => new \PHPExiftool\Driver\Tag\DICOM\DistanceObjectToTableTop(),
                'ObjectPixelSpacingInCenterOfBeam' => new \PHPExiftool\Driver\Tag\DICOM\ObjectPixelSpacingInCenterOfBeam(),
                'PositionerPositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\PositionerPositionSequence(),
                'TablePositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\TablePositionSequence(),
                'CollimatorShapeSequence' => new \PHPExiftool\Driver\Tag\DICOM\CollimatorShapeSequence(),
                'XA-XRFFrameCharacteristicsSequence' => new \PHPExiftool\Driver\Tag\DICOM\XAXRFFrameCharacteristicsSequence(),
                'FrameAcquisitionSequence' => new \PHPExiftool\Driver\Tag\DICOM\FrameAcquisitionSequence(),
                'XRayReceptorType' => new \PHPExiftool\Driver\Tag\DICOM\XRayReceptorType(),
                'AcquisitionProtocolName' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionProtocolName(),
                'AcquisitionProtocolDescription' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionProtocolDescription(),
                'ContrastBolusIngredientOpaque' => new \PHPExiftool\Driver\Tag\DICOM\ContrastBolusIngredientOpaque(),
                'DistanceReceptorPlaneToDetHousing' => new \PHPExiftool\Driver\Tag\DICOM\DistanceReceptorPlaneToDetHousing(),
                'IntensifierActiveShape' => new \PHPExiftool\Driver\Tag\DICOM\IntensifierActiveShape(),
                'IntensifierActiveDimensions' => new \PHPExiftool\Driver\Tag\DICOM\IntensifierActiveDimensions(),
                'PhysicalDetectorSize' => new \PHPExiftool\Driver\Tag\DICOM\PhysicalDetectorSize(),
                'PositionOfIsocenterProjection' => new \PHPExiftool\Driver\Tag\DICOM\PositionOfIsocenterProjection(),
                'FieldOfViewSequence' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewSequence(),
                'FieldOfViewDescription' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewDescription(),
                'ExposureControlSensingRegionsSeq' => new \PHPExiftool\Driver\Tag\DICOM\ExposureControlSensingRegionsSeq(),
                'ExposureControlSensingRegionShape' => new \PHPExiftool\Driver\Tag\DICOM\ExposureControlSensingRegionShape(),
                'ExposureControlSensRegionLeftEdge' => new \PHPExiftool\Driver\Tag\DICOM\ExposureControlSensRegionLeftEdge(),
                'ExposureControlSensRegionRightEdge' => new \PHPExiftool\Driver\Tag\DICOM\ExposureControlSensRegionRightEdge(),
                'CenterOfCircExposControlSensRegion' => new \PHPExiftool\Driver\Tag\DICOM\CenterOfCircExposControlSensRegion(),
                'RadiusOfCircExposControlSensRegion' => new \PHPExiftool\Driver\Tag\DICOM\RadiusOfCircExposControlSensRegion(),
                'ColumnAngulationPatient' => new \PHPExiftool\Driver\Tag\DICOM\ColumnAngulationPatient(),
                'BeamAngle' => new \PHPExiftool\Driver\Tag\DICOM\BeamAngle(),
                'FrameDetectorParametersSequence' => new \PHPExiftool\Driver\Tag\DICOM\FrameDetectorParametersSequence(),
                'CalculatedAnatomyThickness' => new \PHPExiftool\Driver\Tag\DICOM\CalculatedAnatomyThickness(),
                'CalibrationSequence' => new \PHPExiftool\Driver\Tag\DICOM\CalibrationSequence(),
                'ObjectThicknessSequence' => new \PHPExiftool\Driver\Tag\DICOM\ObjectThicknessSequence(),
                'PlaneIdentification' => new \PHPExiftool\Driver\Tag\DICOM\PlaneIdentification(),
                'FieldOfViewDimensionsInFloat' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewDimensionsInFloat(),
                'IsocenterReferenceSystemSequence' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterReferenceSystemSequence(),
                'PositionerIsocenterPrimaryAngle' => new \PHPExiftool\Driver\Tag\DICOM\PositionerIsocenterPrimaryAngle(),
                'PositionerIsocenterSecondaryAngle' => new \PHPExiftool\Driver\Tag\DICOM\PositionerIsocenterSecondaryAngle(),
                'PositionerIsocenterDetRotAngle' => new \PHPExiftool\Driver\Tag\DICOM\PositionerIsocenterDetRotAngle(),
                'TableXPositionToIsocenter' => new \PHPExiftool\Driver\Tag\DICOM\TableXPositionToIsocenter(),
                'TableYPositionToIsocenter' => new \PHPExiftool\Driver\Tag\DICOM\TableYPositionToIsocenter(),
                'TableZPositionToIsocenter' => new \PHPExiftool\Driver\Tag\DICOM\TableZPositionToIsocenter(),
                'TableHorizontalRotationAngle' => new \PHPExiftool\Driver\Tag\DICOM\TableHorizontalRotationAngle(),
                'TableHeadTiltAngle' => new \PHPExiftool\Driver\Tag\DICOM\TableHeadTiltAngle(),
                'TableCradleTiltAngle' => new \PHPExiftool\Driver\Tag\DICOM\TableCradleTiltAngle(),
                'FrameDisplayShutterSequence' => new \PHPExiftool\Driver\Tag\DICOM\FrameDisplayShutterSequence(),
                'AcquiredImageAreaDoseProduct' => new \PHPExiftool\Driver\Tag\DICOM\AcquiredImageAreaDoseProduct(),
                'CArmPositionerTabletopRelationship' => new \PHPExiftool\Driver\Tag\DICOM\CArmPositionerTabletopRelationship(),
                'XRayGeometrySequence' => new \PHPExiftool\Driver\Tag\DICOM\XRayGeometrySequence(),
                'IrradiationEventIDSequence' => new \PHPExiftool\Driver\Tag\DICOM\IrradiationEventIDSequence(),
                'XRay3DFrameTypeSequence' => new \PHPExiftool\Driver\Tag\DICOM\XRay3DFrameTypeSequence(),
                'ContributingSourcesSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContributingSourcesSequence(),
                'XRay3DAcquisitionSequence' => new \PHPExiftool\Driver\Tag\DICOM\XRay3DAcquisitionSequence(),
                'PrimaryPositionerScanArc' => new \PHPExiftool\Driver\Tag\DICOM\PrimaryPositionerScanArc(),
                'SecondaryPositionerScanArc' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryPositionerScanArc(),
                'PrimaryPositionerScanStartAngle' => new \PHPExiftool\Driver\Tag\DICOM\PrimaryPositionerScanStartAngle(),
                'SecondaryPositionerScanStartAngle' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryPositionerScanStartAngle(),
                'PrimaryPositionerIncrement' => new \PHPExiftool\Driver\Tag\DICOM\PrimaryPositionerIncrement(),
                'SecondaryPositionerIncrement' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryPositionerIncrement(),
                'StartAcquisitionDateTime' => new \PHPExiftool\Driver\Tag\DICOM\StartAcquisitionDateTime(),
                'EndAcquisitionDateTime' => new \PHPExiftool\Driver\Tag\DICOM\EndAcquisitionDateTime(),
                'ApplicationName' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationName(),
                'ApplicationVersion' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationVersion(),
                'ApplicationManufacturer' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationManufacturer(),
                'AlgorithmType' => new \PHPExiftool\Driver\Tag\DICOM\AlgorithmType(),
                'AlgorithmDescription' => new \PHPExiftool\Driver\Tag\DICOM\AlgorithmDescription(),
                'XRay3DReconstructionSequence' => new \PHPExiftool\Driver\Tag\DICOM\XRay3DReconstructionSequence(),
                'ReconstructionDescription' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionDescription(),
                'PerProjectionAcquisitionSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerProjectionAcquisitionSequence(),
                'DiffusionBMatrixSequence' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionBMatrixSequence(),
                'DiffusionBValueXX' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionBValueXX(),
                'DiffusionBValueXY' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionBValueXY(),
                'DiffusionBValueXZ' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionBValueXZ(),
                'DiffusionBValueYY' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionBValueYY(),
                'DiffusionBValueYZ' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionBValueYZ(),
                'DiffusionBValueZZ' => new \PHPExiftool\Driver\Tag\DICOM\DiffusionBValueZZ(),
                'DecayCorrectionDateTime' => new \PHPExiftool\Driver\Tag\DICOM\DecayCorrectionDateTime(),
                'StartDensityThreshold' => new \PHPExiftool\Driver\Tag\DICOM\StartDensityThreshold(),
                'TerminationTimeThreshold' => new \PHPExiftool\Driver\Tag\DICOM\TerminationTimeThreshold(),
                'DetectorGeometry' => new \PHPExiftool\Driver\Tag\DICOM\DetectorGeometry(),
                'AxialDetectorDimension' => new \PHPExiftool\Driver\Tag\DICOM\AxialDetectorDimension(),
                'PETPositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\PETPositionSequence(),
                'NumberOfIterations' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfIterations(),
                'NumberOfSubsets' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfSubsets(),
                'PETFrameTypeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PETFrameTypeSequence(),
                'ReconstructionType' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionType(),
                'DecayCorrected' => new \PHPExiftool\Driver\Tag\DICOM\DecayCorrected(),
                'AttenuationCorrected' => new \PHPExiftool\Driver\Tag\DICOM\AttenuationCorrected(),
                'ScatterCorrected' => new \PHPExiftool\Driver\Tag\DICOM\ScatterCorrected(),
                'DeadTimeCorrected' => new \PHPExiftool\Driver\Tag\DICOM\DeadTimeCorrected(),
                'GantryMotionCorrected' => new \PHPExiftool\Driver\Tag\DICOM\GantryMotionCorrected(),
                'PatientMotionCorrected' => new \PHPExiftool\Driver\Tag\DICOM\PatientMotionCorrected(),
                'RandomsCorrected' => new \PHPExiftool\Driver\Tag\DICOM\RandomsCorrected(),
                'SensitivityCalibrated' => new \PHPExiftool\Driver\Tag\DICOM\SensitivityCalibrated(),
                'DepthsOfFocus' => new \PHPExiftool\Driver\Tag\DICOM\DepthsOfFocus(),
                'ExclusionStartDatetime' => new \PHPExiftool\Driver\Tag\DICOM\ExclusionStartDatetime(),
                'ExclusionDuration' => new \PHPExiftool\Driver\Tag\DICOM\ExclusionDuration(),
                'ImageDataTypeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ImageDataTypeSequence(),
                'DataType' => new \PHPExiftool\Driver\Tag\DICOM\DataType(),
                'AliasedDataType' => new \PHPExiftool\Driver\Tag\DICOM\AliasedDataType(),
                'ContributingEquipmentSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContributingEquipmentSequence(),
                'ContributionDateTime' => new \PHPExiftool\Driver\Tag\DICOM\ContributionDateTime(),
                'ContributionDescription' => new \PHPExiftool\Driver\Tag\DICOM\ContributionDescription(),
                'NumberOfCellsIInDetector' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfCellsIInDetector(),
                'CellNumberAtTheta' => new \PHPExiftool\Driver\Tag\DICOM\CellNumberAtTheta(),
                'CellSpacing' => new \PHPExiftool\Driver\Tag\DICOM\CellSpacing(),
                'HorizFrameOfRef' => new \PHPExiftool\Driver\Tag\DICOM\HorizFrameOfRef(),
                'SeriesContrast' => new \PHPExiftool\Driver\Tag\DICOM\SeriesContrast(),
                'LastPseq' => new \PHPExiftool\Driver\Tag\DICOM\LastPseq(),
                'StartNumberForBaseline' => new \PHPExiftool\Driver\Tag\DICOM\StartNumberForBaseline(),
                'EndNumberForBaseline' => new \PHPExiftool\Driver\Tag\DICOM\EndNumberForBaseline(),
                'StartNumberForEnhancedScans' => new \PHPExiftool\Driver\Tag\DICOM\StartNumberForEnhancedScans(),
                'EndNumberForEnhancedScans' => new \PHPExiftool\Driver\Tag\DICOM\EndNumberForEnhancedScans(),
                'SeriesPlane' => new \PHPExiftool\Driver\Tag\DICOM\SeriesPlane(),
                'FirstScanRas' => new \PHPExiftool\Driver\Tag\DICOM\FirstScanRas(),
                'FirstScanLocation' => new \PHPExiftool\Driver\Tag\DICOM\FirstScanLocation(),
                'LastScanRas' => new \PHPExiftool\Driver\Tag\DICOM\LastScanRas(),
                'LastScanLoc' => new \PHPExiftool\Driver\Tag\DICOM\LastScanLoc(),
                'DisplayFieldOfView' => new \PHPExiftool\Driver\Tag\DICOM\DisplayFieldOfView(),
                'MidScanTime' => new \PHPExiftool\Driver\Tag\DICOM\MidScanTime(),
                'MidScanFlag' => new \PHPExiftool\Driver\Tag\DICOM\MidScanFlag(),
                'DegreesOfAzimuth' => new \PHPExiftool\Driver\Tag\DICOM\DegreesOfAzimuth(),
                'GantryPeriod' => new \PHPExiftool\Driver\Tag\DICOM\GantryPeriod(),
                'XRayOnPosition' => new \PHPExiftool\Driver\Tag\DICOM\XRayOnPosition(),
                'XRayOffPosition' => new \PHPExiftool\Driver\Tag\DICOM\XRayOffPosition(),
                'NumberOfTriggers' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTriggers(),
                'AngleOfFirstView' => new \PHPExiftool\Driver\Tag\DICOM\AngleOfFirstView(),
                'TriggerFrequency' => new \PHPExiftool\Driver\Tag\DICOM\TriggerFrequency(),
                'ScanFOVType' => new \PHPExiftool\Driver\Tag\DICOM\ScanFOVType(),
                'StatReconFlag' => new \PHPExiftool\Driver\Tag\DICOM\StatReconFlag(),
                'ComputeType' => new \PHPExiftool\Driver\Tag\DICOM\ComputeType(),
                'SegmentNumber' => new \PHPExiftool\Driver\Tag\DICOM\SegmentNumber(),
                'TotalSegmentsRequested' => new \PHPExiftool\Driver\Tag\DICOM\TotalSegmentsRequested(),
                'InterscanDelay' => new \PHPExiftool\Driver\Tag\DICOM\InterscanDelay(),
                'ViewCompressionFactor' => new \PHPExiftool\Driver\Tag\DICOM\ViewCompressionFactor(),
                'TotalNoOfRefChannels' => new \PHPExiftool\Driver\Tag\DICOM\TotalNoOfRefChannels(),
                'DataSizeForScanData' => new \PHPExiftool\Driver\Tag\DICOM\DataSizeForScanData(),
                'ReconPostProcflag' => new \PHPExiftool\Driver\Tag\DICOM\ReconPostProcflag(),
                'CTWaterNumber' => new \PHPExiftool\Driver\Tag\DICOM\CTWaterNumber(),
                'CTBoneNumber' => new \PHPExiftool\Driver\Tag\DICOM\CTBoneNumber(),
                'NumberOfChannels' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfChannels(),
                'IncrementBetweenChannels' => new \PHPExiftool\Driver\Tag\DICOM\IncrementBetweenChannels(),
                'StartingView' => new \PHPExiftool\Driver\Tag\DICOM\StartingView(),
                'NumberOfViews' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfViews(),
                'IncrementBetweenViews' => new \PHPExiftool\Driver\Tag\DICOM\IncrementBetweenViews(),
                'DependantOnNoViewsProcessed' => new \PHPExiftool\Driver\Tag\DICOM\DependantOnNoViewsProcessed(),
                'FieldOfViewInDetectorCells' => new \PHPExiftool\Driver\Tag\DICOM\FieldOfViewInDetectorCells(),
                'ValueOfBackProjectionButton' => new \PHPExiftool\Driver\Tag\DICOM\ValueOfBackProjectionButton(),
                'SetIfFatqEstimatesWereUsed' => new \PHPExiftool\Driver\Tag\DICOM\SetIfFatqEstimatesWereUsed(),
                'ZChanAvgOverViews' => new \PHPExiftool\Driver\Tag\DICOM\ZChanAvgOverViews(),
                'AvgOfLeftRefChansOverViews' => new \PHPExiftool\Driver\Tag\DICOM\AvgOfLeftRefChansOverViews(),
                'MaxLeftChanOverViews' => new \PHPExiftool\Driver\Tag\DICOM\MaxLeftChanOverViews(),
                'AvgOfRightRefChansOverViews' => new \PHPExiftool\Driver\Tag\DICOM\AvgOfRightRefChansOverViews(),
                'MaxRightChanOverViews' => new \PHPExiftool\Driver\Tag\DICOM\MaxRightChanOverViews(),
                'SecondEcho' => new \PHPExiftool\Driver\Tag\DICOM\SecondEcho(),
                'NumberOfEchoes' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfEchoes(),
                'TableDelta' => new \PHPExiftool\Driver\Tag\DICOM\TableDelta(),
                'Contiguous' => new \PHPExiftool\Driver\Tag\DICOM\Contiguous(),
                'PeakSAR' => new \PHPExiftool\Driver\Tag\DICOM\PeakSAR(),
                'MonitorSAR' => new \PHPExiftool\Driver\Tag\DICOM\MonitorSAR(),
                'CardiacRepetitionTime' => new \PHPExiftool\Driver\Tag\DICOM\CardiacRepetitionTime(),
                'ImagesPerCardiacCycle' => new \PHPExiftool\Driver\Tag\DICOM\ImagesPerCardiacCycle(),
                'ActualReceiveGainAnalog' => new \PHPExiftool\Driver\Tag\DICOM\ActualReceiveGainAnalog(),
                'ActualReceiveGainDigital' => new \PHPExiftool\Driver\Tag\DICOM\ActualReceiveGainDigital(),
                'DelayAfterTrigger' => new \PHPExiftool\Driver\Tag\DICOM\DelayAfterTrigger(),
                'Swappf' => new \PHPExiftool\Driver\Tag\DICOM\Swappf(),
                'PauseInterval' => new \PHPExiftool\Driver\Tag\DICOM\PauseInterval(),
                'PulseTime' => new \PHPExiftool\Driver\Tag\DICOM\PulseTime(),
                'SliceOffsetOnFreqAxis' => new \PHPExiftool\Driver\Tag\DICOM\SliceOffsetOnFreqAxis(),
                'CenterFrequency' => new \PHPExiftool\Driver\Tag\DICOM\CenterFrequency(),
                'TransmitGain' => new \PHPExiftool\Driver\Tag\DICOM\TransmitGain(),
                'AnalogReceiverGain' => new \PHPExiftool\Driver\Tag\DICOM\AnalogReceiverGain(),
                'DigitalReceiverGain' => new \PHPExiftool\Driver\Tag\DICOM\DigitalReceiverGain(),
                'BitmapDefiningCVs' => new \PHPExiftool\Driver\Tag\DICOM\BitmapDefiningCVs(),
                'CenterFreqMethod' => new \PHPExiftool\Driver\Tag\DICOM\CenterFreqMethod(),
                'PulseSeqMode' => new \PHPExiftool\Driver\Tag\DICOM\PulseSeqMode(),
                'PulseSeqName' => new \PHPExiftool\Driver\Tag\DICOM\PulseSeqName(),
                'PulseSeqDate' => new \PHPExiftool\Driver\Tag\DICOM\PulseSeqDate(),
                'InternalPulseSeqName' => new \PHPExiftool\Driver\Tag\DICOM\InternalPulseSeqName(),
                'TransmittingCoil' => new \PHPExiftool\Driver\Tag\DICOM\TransmittingCoil(),
                'SurfaceCoilType' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceCoilType(),
                'ExtremityCoilFlag' => new \PHPExiftool\Driver\Tag\DICOM\ExtremityCoilFlag(),
                'RawDataRunNumber' => new \PHPExiftool\Driver\Tag\DICOM\RawDataRunNumber(),
                'CalibratedFieldStrength' => new \PHPExiftool\Driver\Tag\DICOM\CalibratedFieldStrength(),
                'SATFatWaterBone' => new \PHPExiftool\Driver\Tag\DICOM\SATFatWaterBone(),
                'ReceiveBandwidth' => new \PHPExiftool\Driver\Tag\DICOM\ReceiveBandwidth(),
                'UserData01' => new \PHPExiftool\Driver\Tag\DICOM\UserData01(),
                'UserData02' => new \PHPExiftool\Driver\Tag\DICOM\UserData02(),
                'UserData03' => new \PHPExiftool\Driver\Tag\DICOM\UserData03(),
                'UserData04' => new \PHPExiftool\Driver\Tag\DICOM\UserData04(),
                'UserData05' => new \PHPExiftool\Driver\Tag\DICOM\UserData05(),
                'UserData06' => new \PHPExiftool\Driver\Tag\DICOM\UserData06(),
                'UserData07' => new \PHPExiftool\Driver\Tag\DICOM\UserData07(),
                'UserData08' => new \PHPExiftool\Driver\Tag\DICOM\UserData08(),
                'UserData09' => new \PHPExiftool\Driver\Tag\DICOM\UserData09(),
                'UserData10' => new \PHPExiftool\Driver\Tag\DICOM\UserData10(),
                'UserData11' => new \PHPExiftool\Driver\Tag\DICOM\UserData11(),
                'UserData12' => new \PHPExiftool\Driver\Tag\DICOM\UserData12(),
                'UserData13' => new \PHPExiftool\Driver\Tag\DICOM\UserData13(),
                'UserData14' => new \PHPExiftool\Driver\Tag\DICOM\UserData14(),
                'UserData15' => new \PHPExiftool\Driver\Tag\DICOM\UserData15(),
                'UserData16' => new \PHPExiftool\Driver\Tag\DICOM\UserData16(),
                'UserData17' => new \PHPExiftool\Driver\Tag\DICOM\UserData17(),
                'UserData18' => new \PHPExiftool\Driver\Tag\DICOM\UserData18(),
                'UserData19' => new \PHPExiftool\Driver\Tag\DICOM\UserData19(),
                'UserData20' => new \PHPExiftool\Driver\Tag\DICOM\UserData20(),
                'UserData21' => new \PHPExiftool\Driver\Tag\DICOM\UserData21(),
                'UserData22' => new \PHPExiftool\Driver\Tag\DICOM\UserData22(),
                'UserData23' => new \PHPExiftool\Driver\Tag\DICOM\UserData23(),
                'ProjectionAngle' => new \PHPExiftool\Driver\Tag\DICOM\ProjectionAngle(),
                'SaturationPlanes' => new \PHPExiftool\Driver\Tag\DICOM\SaturationPlanes(),
                'SurfaceCoilIntensity' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceCoilIntensity(),
                'SATLocationR' => new \PHPExiftool\Driver\Tag\DICOM\SATLocationR(),
                'SATLocationL' => new \PHPExiftool\Driver\Tag\DICOM\SATLocationL(),
                'SATLocationA' => new \PHPExiftool\Driver\Tag\DICOM\SATLocationA(),
                'SATLocationP' => new \PHPExiftool\Driver\Tag\DICOM\SATLocationP(),
                'SATLocationH' => new \PHPExiftool\Driver\Tag\DICOM\SATLocationH(),
                'SATLocationF' => new \PHPExiftool\Driver\Tag\DICOM\SATLocationF(),
                'SATThicknessR-L' => new \PHPExiftool\Driver\Tag\DICOM\SATThicknessRL(),
                'SATThicknessA-P' => new \PHPExiftool\Driver\Tag\DICOM\SATThicknessAP(),
                'SATThicknessH-F' => new \PHPExiftool\Driver\Tag\DICOM\SATThicknessHF(),
                'PrescribedFlowAxis' => new \PHPExiftool\Driver\Tag\DICOM\PrescribedFlowAxis(),
                'VelocityEncoding' => new \PHPExiftool\Driver\Tag\DICOM\VelocityEncoding(),
                'ThicknessDisclaimer' => new \PHPExiftool\Driver\Tag\DICOM\ThicknessDisclaimer(),
                'PrescanType' => new \PHPExiftool\Driver\Tag\DICOM\PrescanType(),
                'PrescanStatus' => new \PHPExiftool\Driver\Tag\DICOM\PrescanStatus(),
                'RawDataType' => new \PHPExiftool\Driver\Tag\DICOM\RawDataType(),
                'ProjectionAlgorithm' => new \PHPExiftool\Driver\Tag\DICOM\ProjectionAlgorithm(),
                'FractionalEcho' => new \PHPExiftool\Driver\Tag\DICOM\FractionalEcho(),
                'PrepPulse' => new \PHPExiftool\Driver\Tag\DICOM\PrepPulse(),
                'CardiacPhases' => new \PHPExiftool\Driver\Tag\DICOM\CardiacPhases(),
                'VariableEchoflag' => new \PHPExiftool\Driver\Tag\DICOM\VariableEchoflag(),
                'ConcatenatedSAT' => new \PHPExiftool\Driver\Tag\DICOM\ConcatenatedSAT(),
                'ReferenceChannelUsed' => new \PHPExiftool\Driver\Tag\DICOM\ReferenceChannelUsed(),
                'BackProjectorCoefficient' => new \PHPExiftool\Driver\Tag\DICOM\BackProjectorCoefficient(),
                'PrimarySpeedCorrectionUsed' => new \PHPExiftool\Driver\Tag\DICOM\PrimarySpeedCorrectionUsed(),
                'OverrangeCorrectionUsed' => new \PHPExiftool\Driver\Tag\DICOM\OverrangeCorrectionUsed(),
                'DynamicZAlphaValue' => new \PHPExiftool\Driver\Tag\DICOM\DynamicZAlphaValue(),
                'UserData' => new \PHPExiftool\Driver\Tag\DICOM\UserData(),
                'VelocityEncodeScale' => new \PHPExiftool\Driver\Tag\DICOM\VelocityEncodeScale(),
                'FastPhases' => new \PHPExiftool\Driver\Tag\DICOM\FastPhases(),
                'TransmissionGain' => new \PHPExiftool\Driver\Tag\DICOM\TransmissionGain(),
                'RelationshipGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\RelationshipGroupLength(),
                'StudyInstanceUID' => new \PHPExiftool\Driver\Tag\DICOM\StudyInstanceUID(),
                'SeriesInstanceUID' => new \PHPExiftool\Driver\Tag\DICOM\SeriesInstanceUID(),
                'StudyID' => new \PHPExiftool\Driver\Tag\DICOM\StudyID(),
                'SeriesNumber' => new \PHPExiftool\Driver\Tag\DICOM\SeriesNumber(),
                'AcquisitionNumber' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionNumber(),
                'InstanceNumber' => new \PHPExiftool\Driver\Tag\DICOM\InstanceNumber(),
                'IsotopeNumber' => new \PHPExiftool\Driver\Tag\DICOM\IsotopeNumber(),
                'PhaseNumber' => new \PHPExiftool\Driver\Tag\DICOM\PhaseNumber(),
                'IntervalNumber' => new \PHPExiftool\Driver\Tag\DICOM\IntervalNumber(),
                'TimeSlotNumber' => new \PHPExiftool\Driver\Tag\DICOM\TimeSlotNumber(),
                'AngleNumber' => new \PHPExiftool\Driver\Tag\DICOM\AngleNumber(),
                'ItemNumber' => new \PHPExiftool\Driver\Tag\DICOM\ItemNumber(),
                'PatientOrientation' => new \PHPExiftool\Driver\Tag\DICOM\PatientOrientation(),
                'OverlayNumber' => new \PHPExiftool\Driver\Tag\DICOM\OverlayNumber(),
                'CurveNumber' => new \PHPExiftool\Driver\Tag\DICOM\CurveNumber(),
                'LookupTableNumber' => new \PHPExiftool\Driver\Tag\DICOM\LookupTableNumber(),
                'ImagePosition' => new \PHPExiftool\Driver\Tag\DICOM\ImagePosition(),
                'ImagePositionPatient' => new \PHPExiftool\Driver\Tag\DICOM\ImagePositionPatient(),
                'ImageOrientation' => new \PHPExiftool\Driver\Tag\DICOM\ImageOrientation(),
                'ImageOrientationPatient' => new \PHPExiftool\Driver\Tag\DICOM\ImageOrientationPatient(),
                'Location' => new \PHPExiftool\Driver\Tag\DICOM\Location(),
                'FrameOfReferenceUID' => new \PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceUID(),
                'Laterality' => new \PHPExiftool\Driver\Tag\DICOM\Laterality(),
                'ImageLaterality' => new \PHPExiftool\Driver\Tag\DICOM\ImageLaterality(),
                'ImageGeometryType' => new \PHPExiftool\Driver\Tag\DICOM\ImageGeometryType(),
                'MaskingImage' => new \PHPExiftool\Driver\Tag\DICOM\MaskingImage(),
                'TemporalPositionIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\TemporalPositionIdentifier(),
                'NumberOfTemporalPositions' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTemporalPositions(),
                'TemporalResolution' => new \PHPExiftool\Driver\Tag\DICOM\TemporalResolution(),
                'SynchronizationFrameOfReferenceUID' => new \PHPExiftool\Driver\Tag\DICOM\SynchronizationFrameOfReferenceUID(),
                'SeriesInStudy' => new \PHPExiftool\Driver\Tag\DICOM\SeriesInStudy(),
                'AcquisitionsInSeries' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionsInSeries(),
                'ImagesInAcquisition' => new \PHPExiftool\Driver\Tag\DICOM\ImagesInAcquisition(),
                'ImagesInSeries' => new \PHPExiftool\Driver\Tag\DICOM\ImagesInSeries(),
                'AcquisitionsInStudy' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionsInStudy(),
                'ImagesInStudy' => new \PHPExiftool\Driver\Tag\DICOM\ImagesInStudy(),
                'Reference' => new \PHPExiftool\Driver\Tag\DICOM\Reference(),
                'PositionReferenceIndicator' => new \PHPExiftool\Driver\Tag\DICOM\PositionReferenceIndicator(),
                'SliceLocation' => new \PHPExiftool\Driver\Tag\DICOM\SliceLocation(),
                'OtherStudyNumbers' => new \PHPExiftool\Driver\Tag\DICOM\OtherStudyNumbers(),
                'NumberOfPatientRelatedStudies' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPatientRelatedStudies(),
                'NumberOfPatientRelatedSeries' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPatientRelatedSeries(),
                'NumberOfPatientRelatedInstances' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPatientRelatedInstances(),
                'NumberOfStudyRelatedSeries' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfStudyRelatedSeries(),
                'NumberOfStudyRelatedInstances' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfStudyRelatedInstances(),
                'NumberOfSeriesRelatedInstances' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfSeriesRelatedInstances(),
                'SourceImageIDs' => new \PHPExiftool\Driver\Tag\DICOM\SourceImageIDs(),
                'ModifyingDeviceID' => new \PHPExiftool\Driver\Tag\DICOM\ModifyingDeviceID(),
                'ModifiedImageID' => new \PHPExiftool\Driver\Tag\DICOM\ModifiedImageID(),
                'ModifiedImageDate' => new \PHPExiftool\Driver\Tag\DICOM\ModifiedImageDate(),
                'ModifyingDeviceManufacturer' => new \PHPExiftool\Driver\Tag\DICOM\ModifyingDeviceManufacturer(),
                'ModifiedImageTime' => new \PHPExiftool\Driver\Tag\DICOM\ModifiedImageTime(),
                'ModifiedImageDescription' => new \PHPExiftool\Driver\Tag\DICOM\ModifiedImageDescription(),
                'ImageComments' => new \PHPExiftool\Driver\Tag\DICOM\ImageComments(),
                'OriginalImageIdentification' => new \PHPExiftool\Driver\Tag\DICOM\OriginalImageIdentification(),
                'OriginalImageIdentNomenclature' => new \PHPExiftool\Driver\Tag\DICOM\OriginalImageIdentNomenclature(),
                'StackID' => new \PHPExiftool\Driver\Tag\DICOM\StackID(),
                'InStackPositionNumber' => new \PHPExiftool\Driver\Tag\DICOM\InStackPositionNumber(),
                'FrameAnatomySequence' => new \PHPExiftool\Driver\Tag\DICOM\FrameAnatomySequence(),
                'FrameLaterality' => new \PHPExiftool\Driver\Tag\DICOM\FrameLaterality(),
                'FrameContentSequence' => new \PHPExiftool\Driver\Tag\DICOM\FrameContentSequence(),
                'PlanePositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\PlanePositionSequence(),
                'PlaneOrientationSequence' => new \PHPExiftool\Driver\Tag\DICOM\PlaneOrientationSequence(),
                'TemporalPositionIndex' => new \PHPExiftool\Driver\Tag\DICOM\TemporalPositionIndex(),
                'TriggerDelayTime' => new \PHPExiftool\Driver\Tag\DICOM\TriggerDelayTime(),
                'FrameAcquisitionNumber' => new \PHPExiftool\Driver\Tag\DICOM\FrameAcquisitionNumber(),
                'DimensionIndexValues' => new \PHPExiftool\Driver\Tag\DICOM\DimensionIndexValues(),
                'FrameComments' => new \PHPExiftool\Driver\Tag\DICOM\FrameComments(),
                'ConcatenationUID' => new \PHPExiftool\Driver\Tag\DICOM\ConcatenationUID(),
                'InConcatenationNumber' => new \PHPExiftool\Driver\Tag\DICOM\InConcatenationNumber(),
                'InConcatenationTotalNumber' => new \PHPExiftool\Driver\Tag\DICOM\InConcatenationTotalNumber(),
                'DimensionOrganizationUID' => new \PHPExiftool\Driver\Tag\DICOM\DimensionOrganizationUID(),
                'DimensionIndexPointer' => new \PHPExiftool\Driver\Tag\DICOM\DimensionIndexPointer(),
                'FunctionalGroupPointer' => new \PHPExiftool\Driver\Tag\DICOM\FunctionalGroupPointer(),
                'DimensionIndexPrivateCreator' => new \PHPExiftool\Driver\Tag\DICOM\DimensionIndexPrivateCreator(),
                'DimensionOrganizationSequence' => new \PHPExiftool\Driver\Tag\DICOM\DimensionOrganizationSequence(),
                'DimensionIndexSequence' => new \PHPExiftool\Driver\Tag\DICOM\DimensionIndexSequence(),
                'ConcatenationFrameOffsetNumber' => new \PHPExiftool\Driver\Tag\DICOM\ConcatenationFrameOffsetNumber(),
                'FunctionalGroupPrivateCreator' => new \PHPExiftool\Driver\Tag\DICOM\FunctionalGroupPrivateCreator(),
                'NominalPercentageOfCardiacPhase' => new \PHPExiftool\Driver\Tag\DICOM\NominalPercentageOfCardiacPhase(),
                'NominalPercentOfRespiratoryPhase' => new \PHPExiftool\Driver\Tag\DICOM\NominalPercentOfRespiratoryPhase(),
                'StartingRespiratoryAmplitude' => new \PHPExiftool\Driver\Tag\DICOM\StartingRespiratoryAmplitude(),
                'StartingRespiratoryPhase' => new \PHPExiftool\Driver\Tag\DICOM\StartingRespiratoryPhase(),
                'EndingRespiratoryAmplitude' => new \PHPExiftool\Driver\Tag\DICOM\EndingRespiratoryAmplitude(),
                'EndingRespiratoryPhase' => new \PHPExiftool\Driver\Tag\DICOM\EndingRespiratoryPhase(),
                'RespiratoryTriggerType' => new \PHPExiftool\Driver\Tag\DICOM\RespiratoryTriggerType(),
                'RRIntervalTimeNominal' => new \PHPExiftool\Driver\Tag\DICOM\RRIntervalTimeNominal(),
                'ActualCardiacTriggerDelayTime' => new \PHPExiftool\Driver\Tag\DICOM\ActualCardiacTriggerDelayTime(),
                'RespiratorySynchronizationSequence' => new \PHPExiftool\Driver\Tag\DICOM\RespiratorySynchronizationSequence(),
                'RespiratoryIntervalTime' => new \PHPExiftool\Driver\Tag\DICOM\RespiratoryIntervalTime(),
                'NominalRespiratoryTriggerDelayTime' => new \PHPExiftool\Driver\Tag\DICOM\NominalRespiratoryTriggerDelayTime(),
                'RespiratoryTriggerDelayThreshold' => new \PHPExiftool\Driver\Tag\DICOM\RespiratoryTriggerDelayThreshold(),
                'ActualRespiratoryTriggerDelayTime' => new \PHPExiftool\Driver\Tag\DICOM\ActualRespiratoryTriggerDelayTime(),
                'ImagePositionVolume' => new \PHPExiftool\Driver\Tag\DICOM\ImagePositionVolume(),
                'ImageOrientationVolume' => new \PHPExiftool\Driver\Tag\DICOM\ImageOrientationVolume(),
                'ApexPosition' => new \PHPExiftool\Driver\Tag\DICOM\ApexPosition(),
                'DimensionDescriptionLabel' => new \PHPExiftool\Driver\Tag\DICOM\DimensionDescriptionLabel(),
                'PatientOrientationInFrameSequence' => new \PHPExiftool\Driver\Tag\DICOM\PatientOrientationInFrameSequence(),
                'FrameLabel' => new \PHPExiftool\Driver\Tag\DICOM\FrameLabel(),
                'AcquisitionIndex' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionIndex(),
                'ContributingSOPInstancesRefSeq' => new \PHPExiftool\Driver\Tag\DICOM\ContributingSOPInstancesRefSeq(),
                'ReconstructionIndex' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionIndex(),
                'SeriesFromWhichPrescribed' => new \PHPExiftool\Driver\Tag\DICOM\SeriesFromWhichPrescribed(),
                'SeriesRecordChecksum' => new \PHPExiftool\Driver\Tag\DICOM\SeriesRecordChecksum(),
                'AcqreconRecordChecksum' => new \PHPExiftool\Driver\Tag\DICOM\AcqreconRecordChecksum(),
                'TableStartLocation' => new \PHPExiftool\Driver\Tag\DICOM\TableStartLocation(),
                'ImageFromWhichPrescribed' => new \PHPExiftool\Driver\Tag\DICOM\ImageFromWhichPrescribed(),
                'ScreenFormat' => new \PHPExiftool\Driver\Tag\DICOM\ScreenFormat(),
                'AnatomicalReferenceForScout' => new \PHPExiftool\Driver\Tag\DICOM\AnatomicalReferenceForScout(),
                'LocationsInAcquisition' => new \PHPExiftool\Driver\Tag\DICOM\LocationsInAcquisition(),
                'GraphicallyPrescribed' => new \PHPExiftool\Driver\Tag\DICOM\GraphicallyPrescribed(),
                'RotationFromSourceXRot' => new \PHPExiftool\Driver\Tag\DICOM\RotationFromSourceXRot(),
                'RotationFromSourceYRot' => new \PHPExiftool\Driver\Tag\DICOM\RotationFromSourceYRot(),
                'RotationFromSourceZRot' => new \PHPExiftool\Driver\Tag\DICOM\RotationFromSourceZRot(),
                'IntegerSlop' => new \PHPExiftool\Driver\Tag\DICOM\IntegerSlop(),
                'FloatSlop' => new \PHPExiftool\Driver\Tag\DICOM\FloatSlop(),
                'AutoWindowLevelAlpha' => new \PHPExiftool\Driver\Tag\DICOM\AutoWindowLevelAlpha(),
                'AutoWindowLevelBeta' => new \PHPExiftool\Driver\Tag\DICOM\AutoWindowLevelBeta(),
                'AutoWindowLevelWindow' => new \PHPExiftool\Driver\Tag\DICOM\AutoWindowLevelWindow(),
                'ToWindowLevelLevel' => new \PHPExiftool\Driver\Tag\DICOM\ToWindowLevelLevel(),
                'TubeFocalSpotPosition' => new \PHPExiftool\Driver\Tag\DICOM\TubeFocalSpotPosition(),
                'BiopsyPosition' => new \PHPExiftool\Driver\Tag\DICOM\BiopsyPosition(),
                'BiopsyTLocation' => new \PHPExiftool\Driver\Tag\DICOM\BiopsyTLocation(),
                'BiopsyRefLocation' => new \PHPExiftool\Driver\Tag\DICOM\BiopsyRefLocation(),
                'LightPathFilterPassThroughWavelen' => new \PHPExiftool\Driver\Tag\DICOM\LightPathFilterPassThroughWavelen(),
                'LightPathFilterPassBand' => new \PHPExiftool\Driver\Tag\DICOM\LightPathFilterPassBand(),
                'ImagePathFilterPassThroughWavelen' => new \PHPExiftool\Driver\Tag\DICOM\ImagePathFilterPassThroughWavelen(),
                'ImagePathFilterPassBand' => new \PHPExiftool\Driver\Tag\DICOM\ImagePathFilterPassBand(),
                'PatientEyeMovementCommanded' => new \PHPExiftool\Driver\Tag\DICOM\PatientEyeMovementCommanded(),
                'PatientEyeMovementCommandCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\PatientEyeMovementCommandCodeSeq(),
                'SphericalLensPower' => new \PHPExiftool\Driver\Tag\DICOM\SphericalLensPower(),
                'CylinderLensPower' => new \PHPExiftool\Driver\Tag\DICOM\CylinderLensPower(),
                'CylinderAxis' => new \PHPExiftool\Driver\Tag\DICOM\CylinderAxis(),
                'EmmetropicMagnification' => new \PHPExiftool\Driver\Tag\DICOM\EmmetropicMagnification(),
                'IntraOcularPressure' => new \PHPExiftool\Driver\Tag\DICOM\IntraOcularPressure(),
                'HorizontalFieldOfView' => new \PHPExiftool\Driver\Tag\DICOM\HorizontalFieldOfView(),
                'PupilDilated' => new \PHPExiftool\Driver\Tag\DICOM\PupilDilated(),
                'DegreeOfDilation' => new \PHPExiftool\Driver\Tag\DICOM\DegreeOfDilation(),
                'StereoBaselineAngle' => new \PHPExiftool\Driver\Tag\DICOM\StereoBaselineAngle(),
                'StereoBaselineDisplacement' => new \PHPExiftool\Driver\Tag\DICOM\StereoBaselineDisplacement(),
                'StereoHorizontalPixelOffset' => new \PHPExiftool\Driver\Tag\DICOM\StereoHorizontalPixelOffset(),
                'StereoVerticalPixelOffset' => new \PHPExiftool\Driver\Tag\DICOM\StereoVerticalPixelOffset(),
                'StereoRotation' => new \PHPExiftool\Driver\Tag\DICOM\StereoRotation(),
                'AcquisitionDeviceTypeCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionDeviceTypeCodeSequence(),
                'IlluminationTypeCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\IlluminationTypeCodeSequence(),
                'LightPathFilterTypeStackCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\LightPathFilterTypeStackCodeSeq(),
                'ImagePathFilterTypeStackCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\ImagePathFilterTypeStackCodeSeq(),
                'LensesCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\LensesCodeSequence(),
                'ChannelDescriptionCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ChannelDescriptionCodeSequence(),
                'RefractiveStateSequence' => new \PHPExiftool\Driver\Tag\DICOM\RefractiveStateSequence(),
                'MydriaticAgentCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\MydriaticAgentCodeSequence(),
                'RelativeImagePositionCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\RelativeImagePositionCodeSequence(),
                'StereoPairsSequence' => new \PHPExiftool\Driver\Tag\DICOM\StereoPairsSequence(),
                'LeftImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\LeftImageSequence(),
                'RightImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\RightImageSequence(),
                'AxialLengthOfTheEye' => new \PHPExiftool\Driver\Tag\DICOM\AxialLengthOfTheEye(),
                'OphthalmicFrameLocationSequence' => new \PHPExiftool\Driver\Tag\DICOM\OphthalmicFrameLocationSequence(),
                'ReferenceCoordinates' => new \PHPExiftool\Driver\Tag\DICOM\ReferenceCoordinates(),
                'DepthSpatialResolution' => new \PHPExiftool\Driver\Tag\DICOM\DepthSpatialResolution(),
                'MaximumDepthDistortion' => new \PHPExiftool\Driver\Tag\DICOM\MaximumDepthDistortion(),
                'AlongScanSpatialResolution' => new \PHPExiftool\Driver\Tag\DICOM\AlongScanSpatialResolution(),
                'MaximumAlongScanDistortion' => new \PHPExiftool\Driver\Tag\DICOM\MaximumAlongScanDistortion(),
                'OphthalmicImageOrientation' => new \PHPExiftool\Driver\Tag\DICOM\OphthalmicImageOrientation(),
                'DepthOfTransverseImage' => new \PHPExiftool\Driver\Tag\DICOM\DepthOfTransverseImage(),
                'MydriaticAgentConcUnitsSeq' => new \PHPExiftool\Driver\Tag\DICOM\MydriaticAgentConcUnitsSeq(),
                'AcrossScanSpatialResolution' => new \PHPExiftool\Driver\Tag\DICOM\AcrossScanSpatialResolution(),
                'MaximumAcrossScanDistortion' => new \PHPExiftool\Driver\Tag\DICOM\MaximumAcrossScanDistortion(),
                'MydriaticAgentConcentration' => new \PHPExiftool\Driver\Tag\DICOM\MydriaticAgentConcentration(),
                'IlluminationWaveLength' => new \PHPExiftool\Driver\Tag\DICOM\IlluminationWaveLength(),
                'IlluminationPower' => new \PHPExiftool\Driver\Tag\DICOM\IlluminationPower(),
                'IlluminationBandwidth' => new \PHPExiftool\Driver\Tag\DICOM\IlluminationBandwidth(),
                'MydriaticAgentSequence' => new \PHPExiftool\Driver\Tag\DICOM\MydriaticAgentSequence(),
                'NumberOfSeriesInStudy' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfSeriesInStudy(),
                'NumberOfUnarchivedSeries' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfUnarchivedSeries(),
                'ReferenceImageField' => new \PHPExiftool\Driver\Tag\DICOM\ReferenceImageField(),
                'SummaryImage' => new \PHPExiftool\Driver\Tag\DICOM\SummaryImage(),
                'StartTimeSecsInFirstAxial' => new \PHPExiftool\Driver\Tag\DICOM\StartTimeSecsInFirstAxial(),
                'NoofUpdatesToHeader' => new \PHPExiftool\Driver\Tag\DICOM\NoofUpdatesToHeader(),
                'IndicatesIfTheStudyHasCompleteInfo' => new \PHPExiftool\Driver\Tag\DICOM\IndicatesIfTheStudyHasCompleteInfo(),
                'LastPulseSequenceUsed' => new \PHPExiftool\Driver\Tag\DICOM\LastPulseSequenceUsed(),
                'LandmarkCounter' => new \PHPExiftool\Driver\Tag\DICOM\LandmarkCounter(),
                'NumberOfAcquisitions' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfAcquisitions(),
                'IndicatesNoofUpdatesToHeader' => new \PHPExiftool\Driver\Tag\DICOM\IndicatesNoofUpdatesToHeader(),
                'SeriesCompleteFlag' => new \PHPExiftool\Driver\Tag\DICOM\SeriesCompleteFlag(),
                'NumberOfImagesArchived' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfImagesArchived(),
                'LastImageNumberUsed' => new \PHPExiftool\Driver\Tag\DICOM\LastImageNumberUsed(),
                'PrimaryReceiverSuiteAndHost' => new \PHPExiftool\Driver\Tag\DICOM\PrimaryReceiverSuiteAndHost(),
                'ImageArchiveFlag' => new \PHPExiftool\Driver\Tag\DICOM\ImageArchiveFlag(),
                'ScoutType' => new \PHPExiftool\Driver\Tag\DICOM\ScoutType(),
                'VmaMamp' => new \PHPExiftool\Driver\Tag\DICOM\VmaMamp(),
                'VmaPhase' => new \PHPExiftool\Driver\Tag\DICOM\VmaPhase(),
                'VmaMod' => new \PHPExiftool\Driver\Tag\DICOM\VmaMod(),
                'VmaClip' => new \PHPExiftool\Driver\Tag\DICOM\VmaClip(),
                'SmartScanOnOffFlag' => new \PHPExiftool\Driver\Tag\DICOM\SmartScanOnOffFlag(),
                'ForeignImageRevision' => new \PHPExiftool\Driver\Tag\DICOM\ForeignImageRevision(),
                'ImagingMode' => new \PHPExiftool\Driver\Tag\DICOM\ImagingMode(),
                'PulseSequence' => new \PHPExiftool\Driver\Tag\DICOM\PulseSequence(),
                'ImagingOptions' => new \PHPExiftool\Driver\Tag\DICOM\ImagingOptions(),
                'PlaneType' => new \PHPExiftool\Driver\Tag\DICOM\PlaneType(),
                'ObliquePlane' => new \PHPExiftool\Driver\Tag\DICOM\ObliquePlane(),
                'RASLetterOfImageLocation' => new \PHPExiftool\Driver\Tag\DICOM\RASLetterOfImageLocation(),
                'ImageLocation' => new \PHPExiftool\Driver\Tag\DICOM\ImageLocation(),
                'CenterRCoordOfPlaneImage' => new \PHPExiftool\Driver\Tag\DICOM\CenterRCoordOfPlaneImage(),
                'CenterACoordOfPlaneImage' => new \PHPExiftool\Driver\Tag\DICOM\CenterACoordOfPlaneImage(),
                'CenterSCoordOfPlaneImage' => new \PHPExiftool\Driver\Tag\DICOM\CenterSCoordOfPlaneImage(),
                'NormalRCoord' => new \PHPExiftool\Driver\Tag\DICOM\NormalRCoord(),
                'NormalACoord' => new \PHPExiftool\Driver\Tag\DICOM\NormalACoord(),
                'NormalSCoord' => new \PHPExiftool\Driver\Tag\DICOM\NormalSCoord(),
                'RCoordOfTopRightCorner' => new \PHPExiftool\Driver\Tag\DICOM\RCoordOfTopRightCorner(),
                'ACoordOfTopRightCorner' => new \PHPExiftool\Driver\Tag\DICOM\ACoordOfTopRightCorner(),
                'SCoordOfTopRightCorner' => new \PHPExiftool\Driver\Tag\DICOM\SCoordOfTopRightCorner(),
                'RCoordOfBottomRightCorner' => new \PHPExiftool\Driver\Tag\DICOM\RCoordOfBottomRightCorner(),
                'ACoordOfBottomRightCorner' => new \PHPExiftool\Driver\Tag\DICOM\ACoordOfBottomRightCorner(),
                'SCoordOfBottomRightCorner' => new \PHPExiftool\Driver\Tag\DICOM\SCoordOfBottomRightCorner(),
                'TableEndLocation' => new \PHPExiftool\Driver\Tag\DICOM\TableEndLocation(),
                'RASLetterForSideOfImage' => new \PHPExiftool\Driver\Tag\DICOM\RASLetterForSideOfImage(),
                'RASLetterForAnteriorPosterior' => new \PHPExiftool\Driver\Tag\DICOM\RASLetterForAnteriorPosterior(),
                'RASLetterForScoutStartLoc' => new \PHPExiftool\Driver\Tag\DICOM\RASLetterForScoutStartLoc(),
                'RASLetterForScoutEndLoc' => new \PHPExiftool\Driver\Tag\DICOM\RASLetterForScoutEndLoc(),
                'ImageDimensionX' => new \PHPExiftool\Driver\Tag\DICOM\ImageDimensionX(),
                'ImageDimensionY' => new \PHPExiftool\Driver\Tag\DICOM\ImageDimensionY(),
                'NumberOfExcitations' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfExcitations(),
                'ImagePresentationGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\ImagePresentationGroupLength(),
                'SamplesPerPixel' => new \PHPExiftool\Driver\Tag\DICOM\SamplesPerPixel(),
                'SamplesPerPixelUsed' => new \PHPExiftool\Driver\Tag\DICOM\SamplesPerPixelUsed(),
                'PhotometricInterpretation' => new \PHPExiftool\Driver\Tag\DICOM\PhotometricInterpretation(),
                'ImageDimensions' => new \PHPExiftool\Driver\Tag\DICOM\ImageDimensions(),
                'PlanarConfiguration' => new \PHPExiftool\Driver\Tag\DICOM\PlanarConfiguration(),
                'NumberOfFrames' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfFrames(),
                'FrameIncrementPointer' => new \PHPExiftool\Driver\Tag\DICOM\FrameIncrementPointer(),
                'FrameDimensionPointer' => new \PHPExiftool\Driver\Tag\DICOM\FrameDimensionPointer(),
                'Rows' => new \PHPExiftool\Driver\Tag\DICOM\Rows(),
                'Columns' => new \PHPExiftool\Driver\Tag\DICOM\Columns(),
                'Planes' => new \PHPExiftool\Driver\Tag\DICOM\Planes(),
                'UltrasoundColorDataPresent' => new \PHPExiftool\Driver\Tag\DICOM\UltrasoundColorDataPresent(),
                'PixelSpacing' => new \PHPExiftool\Driver\Tag\DICOM\PixelSpacing(),
                'ZoomFactor' => new \PHPExiftool\Driver\Tag\DICOM\ZoomFactor(),
                'ZoomCenter' => new \PHPExiftool\Driver\Tag\DICOM\ZoomCenter(),
                'PixelAspectRatio' => new \PHPExiftool\Driver\Tag\DICOM\PixelAspectRatio(),
                'ImageFormat' => new \PHPExiftool\Driver\Tag\DICOM\ImageFormat(),
                'ManipulatedImage' => new \PHPExiftool\Driver\Tag\DICOM\ManipulatedImage(),
                'CorrectedImage' => new \PHPExiftool\Driver\Tag\DICOM\CorrectedImage(),
                'CompressionRecognitionCode' => new \PHPExiftool\Driver\Tag\DICOM\CompressionRecognitionCode(),
                'CompressionCode' => new \PHPExiftool\Driver\Tag\DICOM\CompressionCode(),
                'CompressionOriginator' => new \PHPExiftool\Driver\Tag\DICOM\CompressionOriginator(),
                'CompressionLabel' => new \PHPExiftool\Driver\Tag\DICOM\CompressionLabel(),
                'CompressionDescription' => new \PHPExiftool\Driver\Tag\DICOM\CompressionDescription(),
                'CompressionSequence' => new \PHPExiftool\Driver\Tag\DICOM\CompressionSequence(),
                'CompressionStepPointers' => new \PHPExiftool\Driver\Tag\DICOM\CompressionStepPointers(),
                'RepeatInterval' => new \PHPExiftool\Driver\Tag\DICOM\RepeatInterval(),
                'BitsGrouped' => new \PHPExiftool\Driver\Tag\DICOM\BitsGrouped(),
                'PerimeterTable' => new \PHPExiftool\Driver\Tag\DICOM\PerimeterTable(),
                'PerimeterValue' => new \PHPExiftool\Driver\Tag\DICOM\PerimeterValue(),
                'PredictorRows' => new \PHPExiftool\Driver\Tag\DICOM\PredictorRows(),
                'PredictorColumns' => new \PHPExiftool\Driver\Tag\DICOM\PredictorColumns(),
                'PredictorConstants' => new \PHPExiftool\Driver\Tag\DICOM\PredictorConstants(),
                'BlockedPixels' => new \PHPExiftool\Driver\Tag\DICOM\BlockedPixels(),
                'BlockRows' => new \PHPExiftool\Driver\Tag\DICOM\BlockRows(),
                'BlockColumns' => new \PHPExiftool\Driver\Tag\DICOM\BlockColumns(),
                'RowOverlap' => new \PHPExiftool\Driver\Tag\DICOM\RowOverlap(),
                'ColumnOverlap' => new \PHPExiftool\Driver\Tag\DICOM\ColumnOverlap(),
                'BitsAllocated' => new \PHPExiftool\Driver\Tag\DICOM\BitsAllocated(),
                'BitsStored' => new \PHPExiftool\Driver\Tag\DICOM\BitsStored(),
                'HighBit' => new \PHPExiftool\Driver\Tag\DICOM\HighBit(),
                'PixelRepresentation' => new \PHPExiftool\Driver\Tag\DICOM\PixelRepresentation(),
                'SmallestValidPixelValue' => new \PHPExiftool\Driver\Tag\DICOM\SmallestValidPixelValue(),
                'LargestValidPixelValue' => new \PHPExiftool\Driver\Tag\DICOM\LargestValidPixelValue(),
                'SmallestImagePixelValue' => new \PHPExiftool\Driver\Tag\DICOM\SmallestImagePixelValue(),
                'LargestImagePixelValue' => new \PHPExiftool\Driver\Tag\DICOM\LargestImagePixelValue(),
                'SmallestPixelValueInSeries' => new \PHPExiftool\Driver\Tag\DICOM\SmallestPixelValueInSeries(),
                'LargestPixelValueInSeries' => new \PHPExiftool\Driver\Tag\DICOM\LargestPixelValueInSeries(),
                'SmallestImagePixelValueInPlane' => new \PHPExiftool\Driver\Tag\DICOM\SmallestImagePixelValueInPlane(),
                'LargestImagePixelValueInPlane' => new \PHPExiftool\Driver\Tag\DICOM\LargestImagePixelValueInPlane(),
                'PixelPaddingValue' => new \PHPExiftool\Driver\Tag\DICOM\PixelPaddingValue(),
                'PixelPaddingRangeLimit' => new \PHPExiftool\Driver\Tag\DICOM\PixelPaddingRangeLimit(),
                'QualityControlImage' => new \PHPExiftool\Driver\Tag\DICOM\QualityControlImage(),
                'BurnedInAnnotation' => new \PHPExiftool\Driver\Tag\DICOM\BurnedInAnnotation(),
                'TransformLabel' => new \PHPExiftool\Driver\Tag\DICOM\TransformLabel(),
                'TransformVersionNumber' => new \PHPExiftool\Driver\Tag\DICOM\TransformVersionNumber(),
                'NumberOfTransformSteps' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTransformSteps(),
                'SequenceOfCompressedData' => new \PHPExiftool\Driver\Tag\DICOM\SequenceOfCompressedData(),
                'DetailsOfCoefficients' => new \PHPExiftool\Driver\Tag\DICOM\DetailsOfCoefficients(),
                'CoefficientCoding' => new \PHPExiftool\Driver\Tag\DICOM\CoefficientCoding(),
                'CoefficientCodingPointers' => new \PHPExiftool\Driver\Tag\DICOM\CoefficientCodingPointers(),
                'DCTLabel' => new \PHPExiftool\Driver\Tag\DICOM\DCTLabel(),
                'DataBlockDescription' => new \PHPExiftool\Driver\Tag\DICOM\DataBlockDescription(),
                'DataBlock' => new \PHPExiftool\Driver\Tag\DICOM\DataBlock(),
                'NormalizationFactorFormat' => new \PHPExiftool\Driver\Tag\DICOM\NormalizationFactorFormat(),
                'ZonalMapNumberFormat' => new \PHPExiftool\Driver\Tag\DICOM\ZonalMapNumberFormat(),
                'ZonalMapLocation' => new \PHPExiftool\Driver\Tag\DICOM\ZonalMapLocation(),
                'ZonalMapFormat' => new \PHPExiftool\Driver\Tag\DICOM\ZonalMapFormat(),
                'AdaptiveMapFormat' => new \PHPExiftool\Driver\Tag\DICOM\AdaptiveMapFormat(),
                'CodeNumberFormat' => new \PHPExiftool\Driver\Tag\DICOM\CodeNumberFormat(),
                'CodeLabel' => new \PHPExiftool\Driver\Tag\DICOM\CodeLabel(),
                'NumberOfTables' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTables(),
                'CodeTableLocation' => new \PHPExiftool\Driver\Tag\DICOM\CodeTableLocation(),
                'BitsForCodeWord' => new \PHPExiftool\Driver\Tag\DICOM\BitsForCodeWord(),
                'ImageDataLocation' => new \PHPExiftool\Driver\Tag\DICOM\ImageDataLocation(),
                'PixelSpacingCalibrationType' => new \PHPExiftool\Driver\Tag\DICOM\PixelSpacingCalibrationType(),
                'PixelSpacingCalibrationDescription' => new \PHPExiftool\Driver\Tag\DICOM\PixelSpacingCalibrationDescription(),
                'PixelIntensityRelationship' => new \PHPExiftool\Driver\Tag\DICOM\PixelIntensityRelationship(),
                'PixelIntensityRelationshipSign' => new \PHPExiftool\Driver\Tag\DICOM\PixelIntensityRelationshipSign(),
                'WindowCenter' => new \PHPExiftool\Driver\Tag\DICOM\WindowCenter(),
                'WindowWidth' => new \PHPExiftool\Driver\Tag\DICOM\WindowWidth(),
                'RescaleIntercept' => new \PHPExiftool\Driver\Tag\DICOM\RescaleIntercept(),
                'RescaleSlope' => new \PHPExiftool\Driver\Tag\DICOM\RescaleSlope(),
                'RescaleType' => new \PHPExiftool\Driver\Tag\DICOM\RescaleType(),
                'WindowCenterAndWidthExplanation' => new \PHPExiftool\Driver\Tag\DICOM\WindowCenterAndWidthExplanation(),
                'VOI_LUTFunction' => new \PHPExiftool\Driver\Tag\DICOM\VOILUTFunction(),
                'GrayScale' => new \PHPExiftool\Driver\Tag\DICOM\GrayScale(),
                'RecommendedViewingMode' => new \PHPExiftool\Driver\Tag\DICOM\RecommendedViewingMode(),
                'GrayLookupTableDescriptor' => new \PHPExiftool\Driver\Tag\DICOM\GrayLookupTableDescriptor(),
                'RedPaletteColorTableDescriptor' => new \PHPExiftool\Driver\Tag\DICOM\RedPaletteColorTableDescriptor(),
                'GreenPaletteColorTableDescriptor' => new \PHPExiftool\Driver\Tag\DICOM\GreenPaletteColorTableDescriptor(),
                'BluePaletteColorTableDescriptor' => new \PHPExiftool\Driver\Tag\DICOM\BluePaletteColorTableDescriptor(),
                'LargeRedPaletteColorTableDescr' => new \PHPExiftool\Driver\Tag\DICOM\LargeRedPaletteColorTableDescr(),
                'LargeGreenPaletteColorTableDescr' => new \PHPExiftool\Driver\Tag\DICOM\LargeGreenPaletteColorTableDescr(),
                'LargeBluePaletteColorTableDescr' => new \PHPExiftool\Driver\Tag\DICOM\LargeBluePaletteColorTableDescr(),
                'PaletteColorTableUID' => new \PHPExiftool\Driver\Tag\DICOM\PaletteColorTableUID(),
                'GrayLookupTableData' => new \PHPExiftool\Driver\Tag\DICOM\GrayLookupTableData(),
                'RedPaletteColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\RedPaletteColorTableData(),
                'GreenPaletteColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\GreenPaletteColorTableData(),
                'BluePaletteColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\BluePaletteColorTableData(),
                'LargeRedPaletteColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\LargeRedPaletteColorTableData(),
                'LargeGreenPaletteColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\LargeGreenPaletteColorTableData(),
                'LargeBluePaletteColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\LargeBluePaletteColorTableData(),
                'LargePaletteColorLookupTableUID' => new \PHPExiftool\Driver\Tag\DICOM\LargePaletteColorLookupTableUID(),
                'SegmentedRedColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\SegmentedRedColorTableData(),
                'SegmentedGreenColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\SegmentedGreenColorTableData(),
                'SegmentedBlueColorTableData' => new \PHPExiftool\Driver\Tag\DICOM\SegmentedBlueColorTableData(),
                'BreastImplantPresent' => new \PHPExiftool\Driver\Tag\DICOM\BreastImplantPresent(),
                'PartialView' => new \PHPExiftool\Driver\Tag\DICOM\PartialView(),
                'PartialViewDescription' => new \PHPExiftool\Driver\Tag\DICOM\PartialViewDescription(),
                'PartialViewCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PartialViewCodeSequence(),
                'SpatialLocationsPreserved' => new \PHPExiftool\Driver\Tag\DICOM\SpatialLocationsPreserved(),
                'DataPathAssignment' => new \PHPExiftool\Driver\Tag\DICOM\DataPathAssignment(),
                'BlendingLUT1Sequence' => new \PHPExiftool\Driver\Tag\DICOM\BlendingLUT1Sequence(),
                'BlendingWeightConstant' => new \PHPExiftool\Driver\Tag\DICOM\BlendingWeightConstant(),
                'BlendingLookupTableData' => new \PHPExiftool\Driver\Tag\DICOM\BlendingLookupTableData(),
                'BlendingLUT2Sequence' => new \PHPExiftool\Driver\Tag\DICOM\BlendingLUT2Sequence(),
                'DataPathID' => new \PHPExiftool\Driver\Tag\DICOM\DataPathID(),
                'RGBLUTTransferFunction' => new \PHPExiftool\Driver\Tag\DICOM\RGBLUTTransferFunction(),
                'AlphaLUTTransferFunction' => new \PHPExiftool\Driver\Tag\DICOM\AlphaLUTTransferFunction(),
                'ICCProfile' => new \PHPExiftool\Driver\Tag\DICOM\ICCProfile(),
                'LossyImageCompressionRatio' => new \PHPExiftool\Driver\Tag\DICOM\LossyImageCompressionRatio(),
                'LossyImageCompressionMethod' => new \PHPExiftool\Driver\Tag\DICOM\LossyImageCompressionMethod(),
                'ModalityLUTSequence' => new \PHPExiftool\Driver\Tag\DICOM\ModalityLUTSequence(),
                'LUTDescriptor' => new \PHPExiftool\Driver\Tag\DICOM\LUTDescriptor(),
                'LUTExplanation' => new \PHPExiftool\Driver\Tag\DICOM\LUTExplanation(),
                'ModalityLUTType' => new \PHPExiftool\Driver\Tag\DICOM\ModalityLUTType(),
                'LUTData' => new \PHPExiftool\Driver\Tag\DICOM\LUTData(),
                'VOILUTSequence' => new \PHPExiftool\Driver\Tag\DICOM\VOILUTSequence(),
                'SoftcopyVOILUTSequence' => new \PHPExiftool\Driver\Tag\DICOM\SoftcopyVOILUTSequence(),
                'ImagePresentationComments' => new \PHPExiftool\Driver\Tag\DICOM\ImagePresentationComments(),
                'BiPlaneAcquisitionSequence' => new \PHPExiftool\Driver\Tag\DICOM\BiPlaneAcquisitionSequence(),
                'RepresentativeFrameNumber' => new \PHPExiftool\Driver\Tag\DICOM\RepresentativeFrameNumber(),
                'FrameNumbersOfInterest' => new \PHPExiftool\Driver\Tag\DICOM\FrameNumbersOfInterest(),
                'FrameOfInterestDescription' => new \PHPExiftool\Driver\Tag\DICOM\FrameOfInterestDescription(),
                'FrameOfInterestType' => new \PHPExiftool\Driver\Tag\DICOM\FrameOfInterestType(),
                'MaskPointers' => new \PHPExiftool\Driver\Tag\DICOM\MaskPointers(),
                'RWavePointer' => new \PHPExiftool\Driver\Tag\DICOM\RWavePointer(),
                'MaskSubtractionSequence' => new \PHPExiftool\Driver\Tag\DICOM\MaskSubtractionSequence(),
                'MaskOperation' => new \PHPExiftool\Driver\Tag\DICOM\MaskOperation(),
                'ApplicableFrameRange' => new \PHPExiftool\Driver\Tag\DICOM\ApplicableFrameRange(),
                'MaskFrameNumbers' => new \PHPExiftool\Driver\Tag\DICOM\MaskFrameNumbers(),
                'ContrastFrameAveraging' => new \PHPExiftool\Driver\Tag\DICOM\ContrastFrameAveraging(),
                'MaskSubPixelShift' => new \PHPExiftool\Driver\Tag\DICOM\MaskSubPixelShift(),
                'TIDOffset' => new \PHPExiftool\Driver\Tag\DICOM\TIDOffset(),
                'MaskOperationExplanation' => new \PHPExiftool\Driver\Tag\DICOM\MaskOperationExplanation(),
                'PixelDataProviderURL' => new \PHPExiftool\Driver\Tag\DICOM\PixelDataProviderURL(),
                'DataPointRows' => new \PHPExiftool\Driver\Tag\DICOM\DataPointRows(),
                'DataPointColumns' => new \PHPExiftool\Driver\Tag\DICOM\DataPointColumns(),
                'SignalDomainColumns' => new \PHPExiftool\Driver\Tag\DICOM\SignalDomainColumns(),
                'LargestMonochromePixelValue' => new \PHPExiftool\Driver\Tag\DICOM\LargestMonochromePixelValue(),
                'DataRepresentation' => new \PHPExiftool\Driver\Tag\DICOM\DataRepresentation(),
                'PixelMeasuresSequence' => new \PHPExiftool\Driver\Tag\DICOM\PixelMeasuresSequence(),
                'FrameVOILUTSequence' => new \PHPExiftool\Driver\Tag\DICOM\FrameVOILUTSequence(),
                'PixelValueTransformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\PixelValueTransformationSequence(),
                'SignalDomainRows' => new \PHPExiftool\Driver\Tag\DICOM\SignalDomainRows(),
                'DisplayFilterPercentage' => new \PHPExiftool\Driver\Tag\DICOM\DisplayFilterPercentage(),
                'FramePixelShiftSequence' => new \PHPExiftool\Driver\Tag\DICOM\FramePixelShiftSequence(),
                'SubtractionItemID' => new \PHPExiftool\Driver\Tag\DICOM\SubtractionItemID(),
                'PixelIntensityRelationshipLUTSeq' => new \PHPExiftool\Driver\Tag\DICOM\PixelIntensityRelationshipLUTSeq(),
                'FramePixelDataPropertiesSequence' => new \PHPExiftool\Driver\Tag\DICOM\FramePixelDataPropertiesSequence(),
                'GeometricalProperties' => new \PHPExiftool\Driver\Tag\DICOM\GeometricalProperties(),
                'GeometricMaximumDistortion' => new \PHPExiftool\Driver\Tag\DICOM\GeometricMaximumDistortion(),
                'ImageProcessingApplied' => new \PHPExiftool\Driver\Tag\DICOM\ImageProcessingApplied(),
                'MaskSelectionMode' => new \PHPExiftool\Driver\Tag\DICOM\MaskSelectionMode(),
                'LUTFunction' => new \PHPExiftool\Driver\Tag\DICOM\LUTFunction(),
                'MaskVisibilityPercentage' => new \PHPExiftool\Driver\Tag\DICOM\MaskVisibilityPercentage(),
                'PixelShiftSequence' => new \PHPExiftool\Driver\Tag\DICOM\PixelShiftSequence(),
                'RegionPixelShiftSequence' => new \PHPExiftool\Driver\Tag\DICOM\RegionPixelShiftSequence(),
                'VerticesOfTheRegion' => new \PHPExiftool\Driver\Tag\DICOM\VerticesOfTheRegion(),
                'PixelShiftFrameRange' => new \PHPExiftool\Driver\Tag\DICOM\PixelShiftFrameRange(),
                'LUTFrameRange' => new \PHPExiftool\Driver\Tag\DICOM\LUTFrameRange(),
                'ImageToEquipmentMappingMatrix' => new \PHPExiftool\Driver\Tag\DICOM\ImageToEquipmentMappingMatrix(),
                'EquipmentCoordinateSystemID' => new \PHPExiftool\Driver\Tag\DICOM\EquipmentCoordinateSystemID(),
                'LowerRangeOfPixels1a' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1a(),
                'LowerRangeOfPixels1b' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1b(),
                'LowerRangeOfPixels1c' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1c(),
                'LowerRangeOfPixels1d' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1d(),
                'LowerRangeOfPixels1e' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1e(),
                'LowerRangeOfPixels1f' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1f(),
                'LowerRangeOfPixels1g' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1g(),
                'LowerRangeOfPixels1h' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1h(),
                'LowerRangeOfPixels1i' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1i(),
                'LowerRangeOfPixels2' => new \PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels2(),
                'UpperRangeOfPixels2' => new \PHPExiftool\Driver\Tag\DICOM\UpperRangeOfPixels2(),
                'LenOfTotHdrInBytes' => new \PHPExiftool\Driver\Tag\DICOM\LenOfTotHdrInBytes(),
                'VersionOfTheHdrStruct' => new \PHPExiftool\Driver\Tag\DICOM\VersionOfTheHdrStruct(),
                'AdvantageCompOverflow' => new \PHPExiftool\Driver\Tag\DICOM\AdvantageCompOverflow(),
                'AdvantageCompUnderflow' => new \PHPExiftool\Driver\Tag\DICOM\AdvantageCompUnderflow(),
                'StudyGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\StudyGroupLength(),
                'StudyStatusID' => new \PHPExiftool\Driver\Tag\DICOM\StudyStatusID(),
                'StudyPriorityID' => new \PHPExiftool\Driver\Tag\DICOM\StudyPriorityID(),
                'StudyIDIssuer' => new \PHPExiftool\Driver\Tag\DICOM\StudyIDIssuer(),
                'StudyVerifiedDate' => new \PHPExiftool\Driver\Tag\DICOM\StudyVerifiedDate(),
                'StudyVerifiedTime' => new \PHPExiftool\Driver\Tag\DICOM\StudyVerifiedTime(),
                'StudyReadDate' => new \PHPExiftool\Driver\Tag\DICOM\StudyReadDate(),
                'StudyReadTime' => new \PHPExiftool\Driver\Tag\DICOM\StudyReadTime(),
                'ScheduledStudyStartDate' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStudyStartDate(),
                'ScheduledStudyStartTime' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStudyStartTime(),
                'ScheduledStudyStopDate' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStudyStopDate(),
                'ScheduledStudyStopTime' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStudyStopTime(),
                'ScheduledStudyLocation' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStudyLocation(),
                'ScheduledStudyLocationAETitle' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStudyLocationAETitle(),
                'ReasonForStudy' => new \PHPExiftool\Driver\Tag\DICOM\ReasonForStudy(),
                'RequestingPhysicianIDSequence' => new \PHPExiftool\Driver\Tag\DICOM\RequestingPhysicianIDSequence(),
                'RequestingPhysician' => new \PHPExiftool\Driver\Tag\DICOM\RequestingPhysician(),
                'RequestingService' => new \PHPExiftool\Driver\Tag\DICOM\RequestingService(),
                'StudyArrivalDate' => new \PHPExiftool\Driver\Tag\DICOM\StudyArrivalDate(),
                'StudyArrivalTime' => new \PHPExiftool\Driver\Tag\DICOM\StudyArrivalTime(),
                'StudyCompletionDate' => new \PHPExiftool\Driver\Tag\DICOM\StudyCompletionDate(),
                'StudyCompletionTime' => new \PHPExiftool\Driver\Tag\DICOM\StudyCompletionTime(),
                'StudyComponentStatusID' => new \PHPExiftool\Driver\Tag\DICOM\StudyComponentStatusID(),
                'RequestedProcedureDescription' => new \PHPExiftool\Driver\Tag\DICOM\RequestedProcedureDescription(),
                'RequestedProcedureCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\RequestedProcedureCodeSequence(),
                'RequestedContrastAgent' => new \PHPExiftool\Driver\Tag\DICOM\RequestedContrastAgent(),
                'StudyComments' => new \PHPExiftool\Driver\Tag\DICOM\StudyComments(),
                'ReferencedPatientAliasSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedPatientAliasSequence(),
                'VisitStatusID' => new \PHPExiftool\Driver\Tag\DICOM\VisitStatusID(),
                'AdmissionID' => new \PHPExiftool\Driver\Tag\DICOM\AdmissionID(),
                'IssuerOfAdmissionID' => new \PHPExiftool\Driver\Tag\DICOM\IssuerOfAdmissionID(),
                'RouteOfAdmissions' => new \PHPExiftool\Driver\Tag\DICOM\RouteOfAdmissions(),
                'ScheduledAdmissionDate' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledAdmissionDate(),
                'ScheduledAdmissionTime' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledAdmissionTime(),
                'ScheduledDischargeDate' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledDischargeDate(),
                'ScheduledDischargeTime' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledDischargeTime(),
                'ScheduledPatientInstitResidence' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledPatientInstitResidence(),
                'AdmittingDate' => new \PHPExiftool\Driver\Tag\DICOM\AdmittingDate(),
                'AdmittingTime' => new \PHPExiftool\Driver\Tag\DICOM\AdmittingTime(),
                'DischargeDate' => new \PHPExiftool\Driver\Tag\DICOM\DischargeDate(),
                'DischargeTime' => new \PHPExiftool\Driver\Tag\DICOM\DischargeTime(),
                'DischargeDiagnosisDescription' => new \PHPExiftool\Driver\Tag\DICOM\DischargeDiagnosisDescription(),
                'DischargeDiagnosisCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\DischargeDiagnosisCodeSequence(),
                'SpecialNeeds' => new \PHPExiftool\Driver\Tag\DICOM\SpecialNeeds(),
                'ServiceEpisodeID' => new \PHPExiftool\Driver\Tag\DICOM\ServiceEpisodeID(),
                'IssuerOfServiceEpisodeID' => new \PHPExiftool\Driver\Tag\DICOM\IssuerOfServiceEpisodeID(),
                'ServiceEpisodeDescription' => new \PHPExiftool\Driver\Tag\DICOM\ServiceEpisodeDescription(),
                'PertinentDocumentsSequence' => new \PHPExiftool\Driver\Tag\DICOM\PertinentDocumentsSequence(),
                'CurrentPatientLocation' => new \PHPExiftool\Driver\Tag\DICOM\CurrentPatientLocation(),
                'PatientInstitutionResidence' => new \PHPExiftool\Driver\Tag\DICOM\PatientInstitutionResidence(),
                'PatientState' => new \PHPExiftool\Driver\Tag\DICOM\PatientState(),
                'PatientClinicalTrialParticipSeq' => new \PHPExiftool\Driver\Tag\DICOM\PatientClinicalTrialParticipSeq(),
                'VisitComments' => new \PHPExiftool\Driver\Tag\DICOM\VisitComments(),
                'WaveformOriginality' => new \PHPExiftool\Driver\Tag\DICOM\WaveformOriginality(),
                'NumberOfWaveformChannels' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfWaveformChannels(),
                'NumberOfWaveformSamples' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfWaveformSamples(),
                'SamplingFrequency' => new \PHPExiftool\Driver\Tag\DICOM\SamplingFrequency(),
                'MultiplexGroupLabel' => new \PHPExiftool\Driver\Tag\DICOM\MultiplexGroupLabel(),
                'ChannelDefinitionSequence' => new \PHPExiftool\Driver\Tag\DICOM\ChannelDefinitionSequence(),
                'WaveformChannelNumber' => new \PHPExiftool\Driver\Tag\DICOM\WaveformChannelNumber(),
                'ChannelLabel' => new \PHPExiftool\Driver\Tag\DICOM\ChannelLabel(),
                'ChannelStatus' => new \PHPExiftool\Driver\Tag\DICOM\ChannelStatus(),
                'ChannelSourceSequence' => new \PHPExiftool\Driver\Tag\DICOM\ChannelSourceSequence(),
                'ChannelSourceModifiersSequence' => new \PHPExiftool\Driver\Tag\DICOM\ChannelSourceModifiersSequence(),
                'SourceWaveformSequence' => new \PHPExiftool\Driver\Tag\DICOM\SourceWaveformSequence(),
                'ChannelDerivationDescription' => new \PHPExiftool\Driver\Tag\DICOM\ChannelDerivationDescription(),
                'ChannelSensitivity' => new \PHPExiftool\Driver\Tag\DICOM\ChannelSensitivity(),
                'ChannelSensitivityUnitsSequence' => new \PHPExiftool\Driver\Tag\DICOM\ChannelSensitivityUnitsSequence(),
                'ChannelSensitivityCorrectionFactor' => new \PHPExiftool\Driver\Tag\DICOM\ChannelSensitivityCorrectionFactor(),
                'ChannelBaseline' => new \PHPExiftool\Driver\Tag\DICOM\ChannelBaseline(),
                'ChannelTimeSkew' => new \PHPExiftool\Driver\Tag\DICOM\ChannelTimeSkew(),
                'ChannelSampleSkew' => new \PHPExiftool\Driver\Tag\DICOM\ChannelSampleSkew(),
                'ChannelOffset' => new \PHPExiftool\Driver\Tag\DICOM\ChannelOffset(),
                'WaveformBitsStored' => new \PHPExiftool\Driver\Tag\DICOM\WaveformBitsStored(),
                'FilterLowFrequency' => new \PHPExiftool\Driver\Tag\DICOM\FilterLowFrequency(),
                'FilterHighFrequency' => new \PHPExiftool\Driver\Tag\DICOM\FilterHighFrequency(),
                'NotchFilterFrequency' => new \PHPExiftool\Driver\Tag\DICOM\NotchFilterFrequency(),
                'NotchFilterBandwidth' => new \PHPExiftool\Driver\Tag\DICOM\NotchFilterBandwidth(),
                'WaveformDataDisplayScale' => new \PHPExiftool\Driver\Tag\DICOM\WaveformDataDisplayScale(),
                'WaveformDisplayBkgCIELabValue' => new \PHPExiftool\Driver\Tag\DICOM\WaveformDisplayBkgCIELabValue(),
                'WaveformPresentationGroupSequence' => new \PHPExiftool\Driver\Tag\DICOM\WaveformPresentationGroupSequence(),
                'PresentationGroupNumber' => new \PHPExiftool\Driver\Tag\DICOM\PresentationGroupNumber(),
                'ChannelDisplaySequence' => new \PHPExiftool\Driver\Tag\DICOM\ChannelDisplaySequence(),
                'ChannelRecommendDisplayCIELabValue' => new \PHPExiftool\Driver\Tag\DICOM\ChannelRecommendDisplayCIELabValue(),
                'ChannelPosition' => new \PHPExiftool\Driver\Tag\DICOM\ChannelPosition(),
                'DisplayShadingFlag' => new \PHPExiftool\Driver\Tag\DICOM\DisplayShadingFlag(),
                'FractionalChannelDisplayScale' => new \PHPExiftool\Driver\Tag\DICOM\FractionalChannelDisplayScale(),
                'AbsoluteChannelDisplayScale' => new \PHPExiftool\Driver\Tag\DICOM\AbsoluteChannelDisplayScale(),
                'MultiplexAudioChannelsDescrCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\MultiplexAudioChannelsDescrCodeSeq(),
                'ChannelIdentificationCode' => new \PHPExiftool\Driver\Tag\DICOM\ChannelIdentificationCode(),
                'ChannelMode' => new \PHPExiftool\Driver\Tag\DICOM\ChannelMode(),
                'ScheduledStationAETitle' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStationAETitle(),
                'ScheduledProcedureStepStartDate' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepStartDate(),
                'ScheduledProcedureStepStartTime' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepStartTime(),
                'ScheduledProcedureStepEndDate' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepEndDate(),
                'ScheduledProcedureStepEndTime' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepEndTime(),
                'ScheduledPerformingPhysiciansName' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledPerformingPhysiciansName(),
                'ScheduledProcedureStepDescription' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepDescription(),
                'ScheduledProtocolCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProtocolCodeSequence(),
                'ScheduledProcedureStepID' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepID(),
                'StageCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\StageCodeSequence(),
                'ScheduledPerformingPhysicianIDSeq' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledPerformingPhysicianIDSeq(),
                'ScheduledStationName' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStationName(),
                'ScheduledProcedureStepLocation' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepLocation(),
                'PreMedication' => new \PHPExiftool\Driver\Tag\DICOM\PreMedication(),
                'ScheduledProcedureStepStatus' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepStatus(),
                'LocalNamespaceEntityID' => new \PHPExiftool\Driver\Tag\DICOM\LocalNamespaceEntityID(),
                'UniversalEntityID' => new \PHPExiftool\Driver\Tag\DICOM\UniversalEntityID(),
                'UniversalEntityIDType' => new \PHPExiftool\Driver\Tag\DICOM\UniversalEntityIDType(),
                'IdentifierTypeCode' => new \PHPExiftool\Driver\Tag\DICOM\IdentifierTypeCode(),
                'AssigningFacilitySequence' => new \PHPExiftool\Driver\Tag\DICOM\AssigningFacilitySequence(),
                'ScheduledProcedureStepSequence' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepSequence(),
                'ReferencedNonImageCompositeSOPSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedNonImageCompositeSOPSeq(),
                'PerformedStationAETitle' => new \PHPExiftool\Driver\Tag\DICOM\PerformedStationAETitle(),
                'PerformedStationName' => new \PHPExiftool\Driver\Tag\DICOM\PerformedStationName(),
                'PerformedLocation' => new \PHPExiftool\Driver\Tag\DICOM\PerformedLocation(),
                'PerformedProcedureStepStartDate' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepStartDate(),
                'PerformedProcedureStepStartTime' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepStartTime(),
                'PerformedProcedureStepEndDate' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepEndDate(),
                'PerformedProcedureStepEndTime' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepEndTime(),
                'PerformedProcedureStepStatus' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepStatus(),
                'PerformedProcedureStepID' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepID(),
                'PerformedProcedureStepDescription' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepDescription(),
                'PerformedProcedureTypeDescription' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureTypeDescription(),
                'PerformedProtocolCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProtocolCodeSequence(),
                'PerformedProtocolType' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProtocolType(),
                'ScheduledStepAttributesSequence' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStepAttributesSequence(),
                'RequestAttributesSequence' => new \PHPExiftool\Driver\Tag\DICOM\RequestAttributesSequence(),
                'CommentsOnPerformedProcedureStep' => new \PHPExiftool\Driver\Tag\DICOM\CommentsOnPerformedProcedureStep(),
                'ProcStepDiscontinueReasonCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\ProcStepDiscontinueReasonCodeSeq(),
                'QuantitySequence' => new \PHPExiftool\Driver\Tag\DICOM\QuantitySequence(),
                'Quantity' => new \PHPExiftool\Driver\Tag\DICOM\Quantity(),
                'MeasuringUnitsSequence' => new \PHPExiftool\Driver\Tag\DICOM\MeasuringUnitsSequence(),
                'BillingItemSequence' => new \PHPExiftool\Driver\Tag\DICOM\BillingItemSequence(),
                'TotalTimeOfFluoroscopy' => new \PHPExiftool\Driver\Tag\DICOM\TotalTimeOfFluoroscopy(),
                'TotalNumberOfExposures' => new \PHPExiftool\Driver\Tag\DICOM\TotalNumberOfExposures(),
                'EntranceDose' => new \PHPExiftool\Driver\Tag\DICOM\EntranceDose(),
                'ExposedArea' => new \PHPExiftool\Driver\Tag\DICOM\ExposedArea(),
                'DistanceSourceToEntrance' => new \PHPExiftool\Driver\Tag\DICOM\DistanceSourceToEntrance(),
                'DistanceSourceToSupport' => new \PHPExiftool\Driver\Tag\DICOM\DistanceSourceToSupport(),
                'ExposureDoseSequence' => new \PHPExiftool\Driver\Tag\DICOM\ExposureDoseSequence(),
                'CommentsOnRadiationDose' => new \PHPExiftool\Driver\Tag\DICOM\CommentsOnRadiationDose(),
                'XRayOutput' => new \PHPExiftool\Driver\Tag\DICOM\XRayOutput(),
                'HalfValueLayer' => new \PHPExiftool\Driver\Tag\DICOM\HalfValueLayer(),
                'OrganDose' => new \PHPExiftool\Driver\Tag\DICOM\OrganDose(),
                'OrganExposed' => new \PHPExiftool\Driver\Tag\DICOM\OrganExposed(),
                'BillingProcedureStepSequence' => new \PHPExiftool\Driver\Tag\DICOM\BillingProcedureStepSequence(),
                'FilmConsumptionSequence' => new \PHPExiftool\Driver\Tag\DICOM\FilmConsumptionSequence(),
                'BillingSuppliesAndDevicesSequence' => new \PHPExiftool\Driver\Tag\DICOM\BillingSuppliesAndDevicesSequence(),
                'PerformedSeriesSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerformedSeriesSequence(),
                'CommentsOnScheduledProcedureStep' => new \PHPExiftool\Driver\Tag\DICOM\CommentsOnScheduledProcedureStep(),
                'ProtocolContextSequence' => new \PHPExiftool\Driver\Tag\DICOM\ProtocolContextSequence(),
                'ContentItemModifierSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContentItemModifierSequence(),
                'SpecimenAccessionNumber' => new \PHPExiftool\Driver\Tag\DICOM\SpecimenAccessionNumber(),
                'ContainerIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\ContainerIdentifier(),
                'ContainerDescription' => new \PHPExiftool\Driver\Tag\DICOM\ContainerDescription(),
                'SpecimenSequence' => new \PHPExiftool\Driver\Tag\DICOM\SpecimenSequence(),
                'SpecimenIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\SpecimenIdentifier(),
                'SpecimenDescriptionSequenceTrial' => new \PHPExiftool\Driver\Tag\DICOM\SpecimenDescriptionSequenceTrial(),
                'SpecimenDescriptionTrial' => new \PHPExiftool\Driver\Tag\DICOM\SpecimenDescriptionTrial(),
                'SpecimenUID' => new \PHPExiftool\Driver\Tag\DICOM\SpecimenUID(),
                'AcquisitionContextSequence' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionContextSequence(),
                'AcquisitionContextDescription' => new \PHPExiftool\Driver\Tag\DICOM\AcquisitionContextDescription(),
                'SpecimenTypeCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\SpecimenTypeCodeSequence(),
                'SpecimenShortDescription' => new \PHPExiftool\Driver\Tag\DICOM\SpecimenShortDescription(),
                'SlideIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\SlideIdentifier(),
                'ImageCenterPointCoordinatesSeq' => new \PHPExiftool\Driver\Tag\DICOM\ImageCenterPointCoordinatesSeq(),
                'XOffsetInSlideCoordinateSystem' => new \PHPExiftool\Driver\Tag\DICOM\XOffsetInSlideCoordinateSystem(),
                'YOffsetInSlideCoordinateSystem' => new \PHPExiftool\Driver\Tag\DICOM\YOffsetInSlideCoordinateSystem(),
                'ZOffsetInSlideCoordinateSystem' => new \PHPExiftool\Driver\Tag\DICOM\ZOffsetInSlideCoordinateSystem(),
                'PixelSpacingSequence' => new \PHPExiftool\Driver\Tag\DICOM\PixelSpacingSequence(),
                'CoordinateSystemAxisCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\CoordinateSystemAxisCodeSequence(),
                'MeasurementUnitsCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\MeasurementUnitsCodeSequence(),
                'VitalStainCodeSequenceTrial' => new \PHPExiftool\Driver\Tag\DICOM\VitalStainCodeSequenceTrial(),
                'RequestedProcedureID' => new \PHPExiftool\Driver\Tag\DICOM\RequestedProcedureID(),
                'ReasonForRequestedProcedure' => new \PHPExiftool\Driver\Tag\DICOM\ReasonForRequestedProcedure(),
                'RequestedProcedurePriority' => new \PHPExiftool\Driver\Tag\DICOM\RequestedProcedurePriority(),
                'PatientTransportArrangements' => new \PHPExiftool\Driver\Tag\DICOM\PatientTransportArrangements(),
                'RequestedProcedureLocation' => new \PHPExiftool\Driver\Tag\DICOM\RequestedProcedureLocation(),
                'PlacerOrderNumber-Procedure' => new \PHPExiftool\Driver\Tag\DICOM\PlacerOrderNumberProcedure(),
                'FillerOrderNumber-Procedure' => new \PHPExiftool\Driver\Tag\DICOM\FillerOrderNumberProcedure(),
                'ConfidentialityCode' => new \PHPExiftool\Driver\Tag\DICOM\ConfidentialityCode(),
                'ReportingPriority' => new \PHPExiftool\Driver\Tag\DICOM\ReportingPriority(),
                'ReasonForRequestedProcedureCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReasonForRequestedProcedureCodeSeq(),
                'NamesOfIntendedRecipientsOfResults' => new \PHPExiftool\Driver\Tag\DICOM\NamesOfIntendedRecipientsOfResults(),
                'IntendedRecipientsOfResultsIDSeq' => new \PHPExiftool\Driver\Tag\DICOM\IntendedRecipientsOfResultsIDSeq(),
                'PersonIdentificationCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PersonIdentificationCodeSequence(),
                'PersonAddress' => new \PHPExiftool\Driver\Tag\DICOM\PersonAddress(),
                'PersonTelephoneNumbers' => new \PHPExiftool\Driver\Tag\DICOM\PersonTelephoneNumbers(),
                'RequestedProcedureComments' => new \PHPExiftool\Driver\Tag\DICOM\RequestedProcedureComments(),
                'ReasonForImagingServiceRequest' => new \PHPExiftool\Driver\Tag\DICOM\ReasonForImagingServiceRequest(),
                'IssueDateOfImagingServiceRequest' => new \PHPExiftool\Driver\Tag\DICOM\IssueDateOfImagingServiceRequest(),
                'IssueTimeOfImagingServiceRequest' => new \PHPExiftool\Driver\Tag\DICOM\IssueTimeOfImagingServiceRequest(),
                'PlacerOrderNum-ImagingServiceReq' => new \PHPExiftool\Driver\Tag\DICOM\PlacerOrderNumImagingServiceReq(),
                'FillerOrderNum-ImagingServiceReq' => new \PHPExiftool\Driver\Tag\DICOM\FillerOrderNumImagingServiceReq(),
                'OrderEnteredBy' => new \PHPExiftool\Driver\Tag\DICOM\OrderEnteredBy(),
                'OrderEntererLocation' => new \PHPExiftool\Driver\Tag\DICOM\OrderEntererLocation(),
                'OrderCallbackPhoneNumber' => new \PHPExiftool\Driver\Tag\DICOM\OrderCallbackPhoneNumber(),
                'ImagingServiceRequestComments' => new \PHPExiftool\Driver\Tag\DICOM\ImagingServiceRequestComments(),
                'ConfidentialityOnPatientDataDescr' => new \PHPExiftool\Driver\Tag\DICOM\ConfidentialityOnPatientDataDescr(),
                'GenPurposeScheduledProcStepStatus' => new \PHPExiftool\Driver\Tag\DICOM\GenPurposeScheduledProcStepStatus(),
                'GenPurposePerformedProcStepStatus' => new \PHPExiftool\Driver\Tag\DICOM\GenPurposePerformedProcStepStatus(),
                'GenPurposeSchedProcStepPriority' => new \PHPExiftool\Driver\Tag\DICOM\GenPurposeSchedProcStepPriority(),
                'SchedProcessingApplicationsCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\SchedProcessingApplicationsCodeSeq(),
                'SchedProcedureStepStartDateAndTime' => new \PHPExiftool\Driver\Tag\DICOM\SchedProcedureStepStartDateAndTime(),
                'MultipleCopiesFlag' => new \PHPExiftool\Driver\Tag\DICOM\MultipleCopiesFlag(),
                'PerformedProcessingAppsCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcessingAppsCodeSeq(),
                'HumanPerformerCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\HumanPerformerCodeSequence(),
                'SchedProcStepModificationDateTime' => new \PHPExiftool\Driver\Tag\DICOM\SchedProcStepModificationDateTime(),
                'ExpectedCompletionDateAndTime' => new \PHPExiftool\Driver\Tag\DICOM\ExpectedCompletionDateAndTime(),
                'ResultingGenPurposePerfProcStepSeq' => new \PHPExiftool\Driver\Tag\DICOM\ResultingGenPurposePerfProcStepSeq(),
                'RefGenPurposeSchedProcStepSeq' => new \PHPExiftool\Driver\Tag\DICOM\RefGenPurposeSchedProcStepSeq(),
                'ScheduledWorkitemCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledWorkitemCodeSequence(),
                'PerformedWorkitemCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerformedWorkitemCodeSequence(),
                'InputAvailabilityFlag' => new \PHPExiftool\Driver\Tag\DICOM\InputAvailabilityFlag(),
                'InputInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\InputInformationSequence(),
                'RelevantInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\RelevantInformationSequence(),
                'RefGenPurSchedProcStepTransUID' => new \PHPExiftool\Driver\Tag\DICOM\RefGenPurSchedProcStepTransUID(),
                'ScheduledStationNameCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStationNameCodeSequence(),
                'ScheduledStationClassCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledStationClassCodeSequence(),
                'SchedStationGeographicLocCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\SchedStationGeographicLocCodeSeq(),
                'PerformedStationNameCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerformedStationNameCodeSequence(),
                'PerformedStationClassCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerformedStationClassCodeSequence(),
                'PerformedStationGeogLocCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\PerformedStationGeogLocCodeSeq(),
                'RequestedSubsequentWorkItemCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\RequestedSubsequentWorkItemCodeSeq(),
                'NonDICOMOutputCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\NonDICOMOutputCodeSequence(),
                'OutputInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\OutputInformationSequence(),
                'ScheduledHumanPerformersSequence' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledHumanPerformersSequence(),
                'ActualHumanPerformersSequence' => new \PHPExiftool\Driver\Tag\DICOM\ActualHumanPerformersSequence(),
                'HumanPerformersOrganization' => new \PHPExiftool\Driver\Tag\DICOM\HumanPerformersOrganization(),
                'HumanPerformerName' => new \PHPExiftool\Driver\Tag\DICOM\HumanPerformerName(),
                'RawDataHandling' => new \PHPExiftool\Driver\Tag\DICOM\RawDataHandling(),
                'EntranceDoseInMilliGy' => new \PHPExiftool\Driver\Tag\DICOM\EntranceDoseInMilliGy(),
                'RefImageRealWorldValueMappingSeq' => new \PHPExiftool\Driver\Tag\DICOM\RefImageRealWorldValueMappingSeq(),
                'RealWorldValueMappingSequence' => new \PHPExiftool\Driver\Tag\DICOM\RealWorldValueMappingSequence(),
                'PixelValueMappingCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PixelValueMappingCodeSequence(),
                'LUTLabel' => new \PHPExiftool\Driver\Tag\DICOM\LUTLabel(),
                'RealWorldValueLastValueMapped' => new \PHPExiftool\Driver\Tag\DICOM\RealWorldValueLastValueMapped(),
                'RealWorldValueLUTData' => new \PHPExiftool\Driver\Tag\DICOM\RealWorldValueLUTData(),
                'RealWorldValueFirstValueMapped' => new \PHPExiftool\Driver\Tag\DICOM\RealWorldValueFirstValueMapped(),
                'RealWorldValueIntercept' => new \PHPExiftool\Driver\Tag\DICOM\RealWorldValueIntercept(),
                'RealWorldValueSlope' => new \PHPExiftool\Driver\Tag\DICOM\RealWorldValueSlope(),
                'RelationshipType' => new \PHPExiftool\Driver\Tag\DICOM\RelationshipType(),
                'VerifyingOrganization' => new \PHPExiftool\Driver\Tag\DICOM\VerifyingOrganization(),
                'VerificationDateTime' => new \PHPExiftool\Driver\Tag\DICOM\VerificationDateTime(),
                'ObservationDateTime' => new \PHPExiftool\Driver\Tag\DICOM\ObservationDateTime(),
                'ValueType' => new \PHPExiftool\Driver\Tag\DICOM\ValueType(),
                'ConceptNameCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ConceptNameCodeSequence(),
                'ContinuityOfContent' => new \PHPExiftool\Driver\Tag\DICOM\ContinuityOfContent(),
                'VerifyingObserverSequence' => new \PHPExiftool\Driver\Tag\DICOM\VerifyingObserverSequence(),
                'VerifyingObserverName' => new \PHPExiftool\Driver\Tag\DICOM\VerifyingObserverName(),
                'AuthorObserverSequence' => new \PHPExiftool\Driver\Tag\DICOM\AuthorObserverSequence(),
                'ParticipantSequence' => new \PHPExiftool\Driver\Tag\DICOM\ParticipantSequence(),
                'CustodialOrganizationSequence' => new \PHPExiftool\Driver\Tag\DICOM\CustodialOrganizationSequence(),
                'ParticipationType' => new \PHPExiftool\Driver\Tag\DICOM\ParticipationType(),
                'ParticipationDateTime' => new \PHPExiftool\Driver\Tag\DICOM\ParticipationDateTime(),
                'ObserverType' => new \PHPExiftool\Driver\Tag\DICOM\ObserverType(),
                'VerifyingObserverIdentCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\VerifyingObserverIdentCodeSequence(),
                'EquivalentCDADocumentSequence' => new \PHPExiftool\Driver\Tag\DICOM\EquivalentCDADocumentSequence(),
                'ReferencedWaveformChannels' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedWaveformChannels(),
                'DateTime' => new \PHPExiftool\Driver\Tag\DICOM\DateTime(),
                'Date' => new \PHPExiftool\Driver\Tag\DICOM\Date(),
                'Time' => new \PHPExiftool\Driver\Tag\DICOM\Time(),
                'PersonName' => new \PHPExiftool\Driver\Tag\DICOM\PersonName(),
                'UID' => new \PHPExiftool\Driver\Tag\DICOM\UID(),
                'TemporalRangeType' => new \PHPExiftool\Driver\Tag\DICOM\TemporalRangeType(),
                'ReferencedSamplePositions' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSamplePositions(),
                'ReferencedFrameNumbers' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFrameNumbers(),
                'ReferencedTimeOffsets' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedTimeOffsets(),
                'ReferencedDateTime' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedDateTime(),
                'TextValue' => new \PHPExiftool\Driver\Tag\DICOM\TextValue(),
                'ConceptCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ConceptCodeSequence(),
                'PurposeOfReferenceCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PurposeOfReferenceCodeSequence(),
                'AnnotationGroupNumber' => new \PHPExiftool\Driver\Tag\DICOM\AnnotationGroupNumber(),
                'ModifierCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ModifierCodeSequence(),
                'MeasuredValueSequence' => new \PHPExiftool\Driver\Tag\DICOM\MeasuredValueSequence(),
                'NumericValueQualifierCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\NumericValueQualifierCodeSequence(),
                'NumericValue' => new \PHPExiftool\Driver\Tag\DICOM\NumericValue(),
                'AddressTrial' => new \PHPExiftool\Driver\Tag\DICOM\AddressTrial(),
                'TelephoneNumberTrial' => new \PHPExiftool\Driver\Tag\DICOM\TelephoneNumberTrial(),
                'PredecessorDocumentsSequence' => new \PHPExiftool\Driver\Tag\DICOM\PredecessorDocumentsSequence(),
                'ReferencedRequestSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedRequestSequence(),
                'PerformedProcedureCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcedureCodeSequence(),
                'CurrentRequestedProcEvidenceSeq' => new \PHPExiftool\Driver\Tag\DICOM\CurrentRequestedProcEvidenceSeq(),
                'PertinentOtherEvidenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\PertinentOtherEvidenceSequence(),
                'HL7StructuredDocumentRefSeq' => new \PHPExiftool\Driver\Tag\DICOM\HL7StructuredDocumentRefSeq(),
                'CompletionFlag' => new \PHPExiftool\Driver\Tag\DICOM\CompletionFlag(),
                'CompletionFlagDescription' => new \PHPExiftool\Driver\Tag\DICOM\CompletionFlagDescription(),
                'VerificationFlag' => new \PHPExiftool\Driver\Tag\DICOM\VerificationFlag(),
                'ArchiveRequested' => new \PHPExiftool\Driver\Tag\DICOM\ArchiveRequested(),
                'PreliminaryFlag' => new \PHPExiftool\Driver\Tag\DICOM\PreliminaryFlag(),
                'ContentTemplateSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContentTemplateSequence(),
                'IdenticalDocumentsSequence' => new \PHPExiftool\Driver\Tag\DICOM\IdenticalDocumentsSequence(),
                'ContentSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContentSequence(),
                'AnnotationSequence' => new \PHPExiftool\Driver\Tag\DICOM\AnnotationSequence(),
                'TemplateIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\TemplateIdentifier(),
                'TemplateVersion' => new \PHPExiftool\Driver\Tag\DICOM\TemplateVersion(),
                'TemplateLocalVersion' => new \PHPExiftool\Driver\Tag\DICOM\TemplateLocalVersion(),
                'TemplateExtensionFlag' => new \PHPExiftool\Driver\Tag\DICOM\TemplateExtensionFlag(),
                'TemplateExtensionOrganizationUID' => new \PHPExiftool\Driver\Tag\DICOM\TemplateExtensionOrganizationUID(),
                'TemplateExtensionCreatorUID' => new \PHPExiftool\Driver\Tag\DICOM\TemplateExtensionCreatorUID(),
                'ReferencedContentItemIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedContentItemIdentifier(),
                'HL7InstanceIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\HL7InstanceIdentifier(),
                'HL7DocumentEffectiveTime' => new \PHPExiftool\Driver\Tag\DICOM\HL7DocumentEffectiveTime(),
                'HL7DocumentTypeCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\HL7DocumentTypeCodeSequence(),
                'RetrieveURI' => new \PHPExiftool\Driver\Tag\DICOM\RetrieveURI(),
                'RetrieveLocationUID' => new \PHPExiftool\Driver\Tag\DICOM\RetrieveLocationUID(),
                'DocumentTitle' => new \PHPExiftool\Driver\Tag\DICOM\DocumentTitle(),
                'EncapsulatedDocument' => new \PHPExiftool\Driver\Tag\DICOM\EncapsulatedDocument(),
                'MIMETypeOfEncapsulatedDocument' => new \PHPExiftool\Driver\Tag\DICOM\MIMETypeOfEncapsulatedDocument(),
                'SourceInstanceSequence' => new \PHPExiftool\Driver\Tag\DICOM\SourceInstanceSequence(),
                'ListOfMIMETypes' => new \PHPExiftool\Driver\Tag\DICOM\ListOfMIMETypes(),
                'BitmapOfPrescanOptions' => new \PHPExiftool\Driver\Tag\DICOM\BitmapOfPrescanOptions(),
                'GradientOffsetInX' => new \PHPExiftool\Driver\Tag\DICOM\GradientOffsetInX(),
                'GradientOffsetInY' => new \PHPExiftool\Driver\Tag\DICOM\GradientOffsetInY(),
                'GradientOffsetInZ' => new \PHPExiftool\Driver\Tag\DICOM\GradientOffsetInZ(),
                'ImgIsOriginalOrUnoriginal' => new \PHPExiftool\Driver\Tag\DICOM\ImgIsOriginalOrUnoriginal(),
                'NumberOfEPIShots' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfEPIShots(),
                'ViewsPerSegment' => new \PHPExiftool\Driver\Tag\DICOM\ViewsPerSegment(),
                'RespiratoryRateBpm' => new \PHPExiftool\Driver\Tag\DICOM\RespiratoryRateBpm(),
                'RespiratoryTriggerPoint' => new \PHPExiftool\Driver\Tag\DICOM\RespiratoryTriggerPoint(),
                'TypeOfReceiverUsed' => new \PHPExiftool\Driver\Tag\DICOM\TypeOfReceiverUsed(),
                'PeakRateOfChangeOfGradientField' => new \PHPExiftool\Driver\Tag\DICOM\PeakRateOfChangeOfGradientField(),
                'LimitsInUnitsOfPercent' => new \PHPExiftool\Driver\Tag\DICOM\LimitsInUnitsOfPercent(),
                'PSDEstimatedLimit' => new \PHPExiftool\Driver\Tag\DICOM\PSDEstimatedLimit(),
                'PSDEstimatedLimitInTeslaPerSecond' => new \PHPExiftool\Driver\Tag\DICOM\PSDEstimatedLimitInTeslaPerSecond(),
                'Saravghead' => new \PHPExiftool\Driver\Tag\DICOM\Saravghead(),
                'WindowValue' => new \PHPExiftool\Driver\Tag\DICOM\WindowValue(),
                'TotalInputViews' => new \PHPExiftool\Driver\Tag\DICOM\TotalInputViews(),
                'X-RayChain' => new \PHPExiftool\Driver\Tag\DICOM\XRayChain(),
                'DeconKernelParameters' => new \PHPExiftool\Driver\Tag\DICOM\DeconKernelParameters(),
                'CalibrationParameters' => new \PHPExiftool\Driver\Tag\DICOM\CalibrationParameters(),
                'TotalOutputViews' => new \PHPExiftool\Driver\Tag\DICOM\TotalOutputViews(),
                'NumberOfOverranges' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfOverranges(),
                'IBHImageScaleFactors' => new \PHPExiftool\Driver\Tag\DICOM\IBHImageScaleFactors(),
                'BBHCoefficients' => new \PHPExiftool\Driver\Tag\DICOM\BBHCoefficients(),
                'NumberOfBBHChainsToBlend' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfBBHChainsToBlend(),
                'StartingChannelNumber' => new \PHPExiftool\Driver\Tag\DICOM\StartingChannelNumber(),
                'PpscanParameters' => new \PHPExiftool\Driver\Tag\DICOM\PpscanParameters(),
                'GEImageIntegrity' => new \PHPExiftool\Driver\Tag\DICOM\GEImageIntegrity(),
                'LevelValue' => new \PHPExiftool\Driver\Tag\DICOM\LevelValue(),
                'DeltaStartTime' => new \PHPExiftool\Driver\Tag\DICOM\DeltaStartTime(),
                'MaxOverrangesInAView' => new \PHPExiftool\Driver\Tag\DICOM\MaxOverrangesInAView(),
                'AvgOverrangesAllViews' => new \PHPExiftool\Driver\Tag\DICOM\AvgOverrangesAllViews(),
                'CorrectedAfterGlowTerms' => new \PHPExiftool\Driver\Tag\DICOM\CorrectedAfterGlowTerms(),
                'ReferenceChannels' => new \PHPExiftool\Driver\Tag\DICOM\ReferenceChannels(),
                'NoViewsRefChansBlocked' => new \PHPExiftool\Driver\Tag\DICOM\NoViewsRefChansBlocked(),
                'ScanPitchRatio' => new \PHPExiftool\Driver\Tag\DICOM\ScanPitchRatio(),
                'UniqueImageIden' => new \PHPExiftool\Driver\Tag\DICOM\UniqueImageIden(),
                'HistogramTables' => new \PHPExiftool\Driver\Tag\DICOM\HistogramTables(),
                'UserDefinedData' => new \PHPExiftool\Driver\Tag\DICOM\UserDefinedData(),
                'PrivateScanOptions' => new \PHPExiftool\Driver\Tag\DICOM\PrivateScanOptions(),
                'EffectiveEchoSpacing' => new \PHPExiftool\Driver\Tag\DICOM\EffectiveEchoSpacing(),
                'StringSlopField1' => new \PHPExiftool\Driver\Tag\DICOM\StringSlopField1(),
                'StringSlopField2' => new \PHPExiftool\Driver\Tag\DICOM\StringSlopField2(),
                'RACordOfTargetReconCenter' => new \PHPExiftool\Driver\Tag\DICOM\RACordOfTargetReconCenter(),
                'NegScanspacing' => new \PHPExiftool\Driver\Tag\DICOM\NegScanspacing(),
                'OffsetFrequency' => new \PHPExiftool\Driver\Tag\DICOM\OffsetFrequency(),
                'UserUsageTag' => new \PHPExiftool\Driver\Tag\DICOM\UserUsageTag(),
                'UserFillMapMSW' => new \PHPExiftool\Driver\Tag\DICOM\UserFillMapMSW(),
                'UserFillMapLSW' => new \PHPExiftool\Driver\Tag\DICOM\UserFillMapLSW(),
                'User25-48' => new \PHPExiftool\Driver\Tag\DICOM\User2548(),
                'SlopInt6-9' => new \PHPExiftool\Driver\Tag\DICOM\SlopInt69(),
                'TriggerOnPosition' => new \PHPExiftool\Driver\Tag\DICOM\TriggerOnPosition(),
                'DegreeOfRotation' => new \PHPExiftool\Driver\Tag\DICOM\DegreeOfRotation(),
                'DASTriggerSource' => new \PHPExiftool\Driver\Tag\DICOM\DASTriggerSource(),
                'DASFpaGain' => new \PHPExiftool\Driver\Tag\DICOM\DASFpaGain(),
                'DASOutputSource' => new \PHPExiftool\Driver\Tag\DICOM\DASOutputSource(),
                'DASAdInput' => new \PHPExiftool\Driver\Tag\DICOM\DASAdInput(),
                'DASCalMode' => new \PHPExiftool\Driver\Tag\DICOM\DASCalMode(),
                'DASCalFrequency' => new \PHPExiftool\Driver\Tag\DICOM\DASCalFrequency(),
                'DASRegXm' => new \PHPExiftool\Driver\Tag\DICOM\DASRegXm(),
                'DASAutoZero' => new \PHPExiftool\Driver\Tag\DICOM\DASAutoZero(),
                'StartingChannelOfView' => new \PHPExiftool\Driver\Tag\DICOM\StartingChannelOfView(),
                'DASXmPattern' => new \PHPExiftool\Driver\Tag\DICOM\DASXmPattern(),
                'TGGCTriggerMode' => new \PHPExiftool\Driver\Tag\DICOM\TGGCTriggerMode(),
                'StartScanToXrayOnDelay' => new \PHPExiftool\Driver\Tag\DICOM\StartScanToXrayOnDelay(),
                'DurationOfXrayOn' => new \PHPExiftool\Driver\Tag\DICOM\DurationOfXrayOn(),
                'SlopInt10-17' => new \PHPExiftool\Driver\Tag\DICOM\SlopInt1017(),
                'ScannerStudyEntityUID' => new \PHPExiftool\Driver\Tag\DICOM\ScannerStudyEntityUID(),
                'ScannerStudyID' => new \PHPExiftool\Driver\Tag\DICOM\ScannerStudyID(),
                'ScannerTableEntry' => new \PHPExiftool\Driver\Tag\DICOM\ScannerTableEntry(),
                'ProductPackageIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\ProductPackageIdentifier(),
                'SubstanceAdministrationApproval' => new \PHPExiftool\Driver\Tag\DICOM\SubstanceAdministrationApproval(),
                'ApprovalStatusFurtherDescription' => new \PHPExiftool\Driver\Tag\DICOM\ApprovalStatusFurtherDescription(),
                'ApprovalStatusDateTime' => new \PHPExiftool\Driver\Tag\DICOM\ApprovalStatusDateTime(),
                'ProductTypeCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ProductTypeCodeSequence(),
                'ProductName' => new \PHPExiftool\Driver\Tag\DICOM\ProductName(),
                'ProductDescription' => new \PHPExiftool\Driver\Tag\DICOM\ProductDescription(),
                'ProductLotIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\ProductLotIdentifier(),
                'ProductExpirationDateTime' => new \PHPExiftool\Driver\Tag\DICOM\ProductExpirationDateTime(),
                'SubstanceAdministrationDateTime' => new \PHPExiftool\Driver\Tag\DICOM\SubstanceAdministrationDateTime(),
                'SubstanceAdministrationNotes' => new \PHPExiftool\Driver\Tag\DICOM\SubstanceAdministrationNotes(),
                'SubstanceAdministrationDeviceID' => new \PHPExiftool\Driver\Tag\DICOM\SubstanceAdministrationDeviceID(),
                'ProductParameterSequence' => new \PHPExiftool\Driver\Tag\DICOM\ProductParameterSequence(),
                'SubstanceAdminParameterSeq' => new \PHPExiftool\Driver\Tag\DICOM\SubstanceAdminParameterSeq(),
                'NumberOfMacroRowsInDetector' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfMacroRowsInDetector(),
                'MacroWidthAtISOCenter' => new \PHPExiftool\Driver\Tag\DICOM\MacroWidthAtISOCenter(),
                'DASType' => new \PHPExiftool\Driver\Tag\DICOM\DASType(),
                'DASGain' => new \PHPExiftool\Driver\Tag\DICOM\DASGain(),
                'DASTemperature' => new \PHPExiftool\Driver\Tag\DICOM\DASTemperature(),
                'TableDirectionInOrOut' => new \PHPExiftool\Driver\Tag\DICOM\TableDirectionInOrOut(),
                'ZSmoothingFactor' => new \PHPExiftool\Driver\Tag\DICOM\ZSmoothingFactor(),
                'ViewWeightingMode' => new \PHPExiftool\Driver\Tag\DICOM\ViewWeightingMode(),
                'SigmaRowNumberWhichRowsWereUsed' => new \PHPExiftool\Driver\Tag\DICOM\SigmaRowNumberWhichRowsWereUsed(),
                'MinimumDasValueFoundInTheScanData' => new \PHPExiftool\Driver\Tag\DICOM\MinimumDasValueFoundInTheScanData(),
                'MaximumOffsetShiftValueUsed' => new \PHPExiftool\Driver\Tag\DICOM\MaximumOffsetShiftValueUsed(),
                'NumberOfViewsShifted' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfViewsShifted(),
                'ZTrackingFlag' => new \PHPExiftool\Driver\Tag\DICOM\ZTrackingFlag(),
                'MeanZError' => new \PHPExiftool\Driver\Tag\DICOM\MeanZError(),
                'ZTrackingMaximumError' => new \PHPExiftool\Driver\Tag\DICOM\ZTrackingMaximumError(),
                'StartingViewForRow2a' => new \PHPExiftool\Driver\Tag\DICOM\StartingViewForRow2a(),
                'NumberOfViewsInRow2a' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInRow2a(),
                'StartingViewForRow1a' => new \PHPExiftool\Driver\Tag\DICOM\StartingViewForRow1a(),
                'SigmaMode' => new \PHPExiftool\Driver\Tag\DICOM\SigmaMode(),
                'NumberOfViewsInRow1a' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInRow1a(),
                'StartingViewForRow2b' => new \PHPExiftool\Driver\Tag\DICOM\StartingViewForRow2b(),
                'NumberOfViewsInRow2b' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInRow2b(),
                'StartingViewForRow1b' => new \PHPExiftool\Driver\Tag\DICOM\StartingViewForRow1b(),
                'NumberOfViewsInRow1b' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInRow1b(),
                'AirFilterCalibrationDate' => new \PHPExiftool\Driver\Tag\DICOM\AirFilterCalibrationDate(),
                'AirFilterCalibrationTime' => new \PHPExiftool\Driver\Tag\DICOM\AirFilterCalibrationTime(),
                'PhantomCalibrationDate' => new \PHPExiftool\Driver\Tag\DICOM\PhantomCalibrationDate(),
                'PhantomCalibrationTime' => new \PHPExiftool\Driver\Tag\DICOM\PhantomCalibrationTime(),
                'ZSlopeCalibrationDate' => new \PHPExiftool\Driver\Tag\DICOM\ZSlopeCalibrationDate(),
                'ZSlopeCalibrationTime' => new \PHPExiftool\Driver\Tag\DICOM\ZSlopeCalibrationTime(),
                'CrosstalkCalibrationDate' => new \PHPExiftool\Driver\Tag\DICOM\CrosstalkCalibrationDate(),
                'CrosstalkCalibrationTime' => new \PHPExiftool\Driver\Tag\DICOM\CrosstalkCalibrationTime(),
                'IterboneOptionFlag' => new \PHPExiftool\Driver\Tag\DICOM\IterboneOptionFlag(),
                'PeristalticFlagOption' => new \PHPExiftool\Driver\Tag\DICOM\PeristalticFlagOption(),
                'LensDescription' => new \PHPExiftool\Driver\Tag\DICOM\LensDescription(),
                'RightLensSequence' => new \PHPExiftool\Driver\Tag\DICOM\RightLensSequence(),
                'LeftLensSequence' => new \PHPExiftool\Driver\Tag\DICOM\LeftLensSequence(),
                'CylinderSequence' => new \PHPExiftool\Driver\Tag\DICOM\CylinderSequence(),
                'PrismSequence' => new \PHPExiftool\Driver\Tag\DICOM\PrismSequence(),
                'HorizontalPrismPower' => new \PHPExiftool\Driver\Tag\DICOM\HorizontalPrismPower(),
                'HorizontalPrismBase' => new \PHPExiftool\Driver\Tag\DICOM\HorizontalPrismBase(),
                'VerticalPrismPower' => new \PHPExiftool\Driver\Tag\DICOM\VerticalPrismPower(),
                'VerticalPrismBase' => new \PHPExiftool\Driver\Tag\DICOM\VerticalPrismBase(),
                'LensSegmentType' => new \PHPExiftool\Driver\Tag\DICOM\LensSegmentType(),
                'OpticalTransmittance' => new \PHPExiftool\Driver\Tag\DICOM\OpticalTransmittance(),
                'ChannelWidth' => new \PHPExiftool\Driver\Tag\DICOM\ChannelWidth(),
                'PupilSize' => new \PHPExiftool\Driver\Tag\DICOM\PupilSize(),
                'CornealSize' => new \PHPExiftool\Driver\Tag\DICOM\CornealSize(),
                'DistancePupillaryDistance' => new \PHPExiftool\Driver\Tag\DICOM\DistancePupillaryDistance(),
                'NearPupillaryDistance' => new \PHPExiftool\Driver\Tag\DICOM\NearPupillaryDistance(),
                'OtherPupillaryDistance' => new \PHPExiftool\Driver\Tag\DICOM\OtherPupillaryDistance(),
                'RadiusOfCurvature' => new \PHPExiftool\Driver\Tag\DICOM\RadiusOfCurvature(),
                'KeratometricPower' => new \PHPExiftool\Driver\Tag\DICOM\KeratometricPower(),
                'KeratometricAxis' => new \PHPExiftool\Driver\Tag\DICOM\KeratometricAxis(),
                'BackgroundColor' => new \PHPExiftool\Driver\Tag\DICOM\BackgroundColor(),
                'Optotype' => new \PHPExiftool\Driver\Tag\DICOM\Optotype(),
                'OptotypePresentation' => new \PHPExiftool\Driver\Tag\DICOM\OptotypePresentation(),
                'AddNearSequence' => new \PHPExiftool\Driver\Tag\DICOM\AddNearSequence(),
                'AddIntermediateSequence' => new \PHPExiftool\Driver\Tag\DICOM\AddIntermediateSequence(),
                'AddOtherSequence' => new \PHPExiftool\Driver\Tag\DICOM\AddOtherSequence(),
                'AddPower' => new \PHPExiftool\Driver\Tag\DICOM\AddPower(),
                'ViewingDistance' => new \PHPExiftool\Driver\Tag\DICOM\ViewingDistance(),
                'ViewingDistanceType' => new \PHPExiftool\Driver\Tag\DICOM\ViewingDistanceType(),
                'VisualAcuityModifiers' => new \PHPExiftool\Driver\Tag\DICOM\VisualAcuityModifiers(),
                'DecimalVisualAcuity' => new \PHPExiftool\Driver\Tag\DICOM\DecimalVisualAcuity(),
                'OptotypeDetailedDefinition' => new \PHPExiftool\Driver\Tag\DICOM\OptotypeDetailedDefinition(),
                'SpherePower' => new \PHPExiftool\Driver\Tag\DICOM\SpherePower(),
                'CylinderPower' => new \PHPExiftool\Driver\Tag\DICOM\CylinderPower(),
                'CalibrationImage' => new \PHPExiftool\Driver\Tag\DICOM\CalibrationImage(),
                'DeviceSequence' => new \PHPExiftool\Driver\Tag\DICOM\DeviceSequence(),
                'DeviceLength' => new \PHPExiftool\Driver\Tag\DICOM\DeviceLength(),
                'ContainerComponentWidth' => new \PHPExiftool\Driver\Tag\DICOM\ContainerComponentWidth(),
                'DeviceDiameter' => new \PHPExiftool\Driver\Tag\DICOM\DeviceDiameter(),
                'DeviceDiameterUnits' => new \PHPExiftool\Driver\Tag\DICOM\DeviceDiameterUnits(),
                'DeviceVolume' => new \PHPExiftool\Driver\Tag\DICOM\DeviceVolume(),
                'InterMarkerDistance' => new \PHPExiftool\Driver\Tag\DICOM\InterMarkerDistance(),
                'ContainerComponentID' => new \PHPExiftool\Driver\Tag\DICOM\ContainerComponentID(),
                'DeviceDescription' => new \PHPExiftool\Driver\Tag\DICOM\DeviceDescription(),
                'EnergyWindowVector' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowVector(),
                'NumberOfEnergyWindows' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfEnergyWindows(),
                'EnergyWindowInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowInformationSequence(),
                'EnergyWindowRangeSequence' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowRangeSequence(),
                'EnergyWindowLowerLimit' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowLowerLimit(),
                'EnergyWindowUpperLimit' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowUpperLimit(),
                'RadiopharmaceuticalInformationSeq' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalInformationSeq(),
                'ResidualSyringeCounts' => new \PHPExiftool\Driver\Tag\DICOM\ResidualSyringeCounts(),
                'EnergyWindowName' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowName(),
                'DetectorVector' => new \PHPExiftool\Driver\Tag\DICOM\DetectorVector(),
                'NumberOfDetectors' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfDetectors(),
                'DetectorInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\DetectorInformationSequence(),
                'PhaseVector' => new \PHPExiftool\Driver\Tag\DICOM\PhaseVector(),
                'NumberOfPhases' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPhases(),
                'PhaseInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\PhaseInformationSequence(),
                'NumberOfFramesInPhase' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfFramesInPhase(),
                'PhaseDelay' => new \PHPExiftool\Driver\Tag\DICOM\PhaseDelay(),
                'PauseBetweenFrames' => new \PHPExiftool\Driver\Tag\DICOM\PauseBetweenFrames(),
                'PhaseDescription' => new \PHPExiftool\Driver\Tag\DICOM\PhaseDescription(),
                'RotationVector' => new \PHPExiftool\Driver\Tag\DICOM\RotationVector(),
                'NumberOfRotations' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfRotations(),
                'RotationInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\RotationInformationSequence(),
                'NumberOfFramesInRotation' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfFramesInRotation(),
                'RRIntervalVector' => new \PHPExiftool\Driver\Tag\DICOM\RRIntervalVector(),
                'NumberOfRRIntervals' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfRRIntervals(),
                'GatedInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\GatedInformationSequence(),
                'DataInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\DataInformationSequence(),
                'TimeSlotVector' => new \PHPExiftool\Driver\Tag\DICOM\TimeSlotVector(),
                'NumberOfTimeSlots' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTimeSlots(),
                'TimeSlotInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\TimeSlotInformationSequence(),
                'TimeSlotTime' => new \PHPExiftool\Driver\Tag\DICOM\TimeSlotTime(),
                'SliceVector' => new \PHPExiftool\Driver\Tag\DICOM\SliceVector(),
                'NumberOfSlices' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfSlices(),
                'AngularViewVector' => new \PHPExiftool\Driver\Tag\DICOM\AngularViewVector(),
                'TimeSliceVector' => new \PHPExiftool\Driver\Tag\DICOM\TimeSliceVector(),
                'NumberOfTimeSlices' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTimeSlices(),
                'StartAngle' => new \PHPExiftool\Driver\Tag\DICOM\StartAngle(),
                'TypeOfDetectorMotion' => new \PHPExiftool\Driver\Tag\DICOM\TypeOfDetectorMotion(),
                'TriggerVector' => new \PHPExiftool\Driver\Tag\DICOM\TriggerVector(),
                'NumberOfTriggersInPhase' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfTriggersInPhase(),
                'ViewCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ViewCodeSequence(),
                'ViewModifierCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ViewModifierCodeSequence(),
                'RadionuclideCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\RadionuclideCodeSequence(),
                'AdministrationRouteCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\AdministrationRouteCodeSequence(),
                'RadiopharmaceuticalCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalCodeSequence(),
                'CalibrationDataSequence' => new \PHPExiftool\Driver\Tag\DICOM\CalibrationDataSequence(),
                'EnergyWindowNumber' => new \PHPExiftool\Driver\Tag\DICOM\EnergyWindowNumber(),
                'ImageID' => new \PHPExiftool\Driver\Tag\DICOM\ImageID(),
                'PatientOrientationCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\PatientOrientationCodeSequence(),
                'PatientOrientationModifierCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\PatientOrientationModifierCodeSeq(),
                'PatientGantryRelationshipCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\PatientGantryRelationshipCodeSeq(),
                'SliceProgressionDirection' => new \PHPExiftool\Driver\Tag\DICOM\SliceProgressionDirection(),
                'SeriesType' => new \PHPExiftool\Driver\Tag\DICOM\SeriesType(),
                'Units' => new \PHPExiftool\Driver\Tag\DICOM\Units(),
                'CountsSource' => new \PHPExiftool\Driver\Tag\DICOM\CountsSource(),
                'ReprojectionMethod' => new \PHPExiftool\Driver\Tag\DICOM\ReprojectionMethod(),
                'RandomsCorrectionMethod' => new \PHPExiftool\Driver\Tag\DICOM\RandomsCorrectionMethod(),
                'AttenuationCorrectionMethod' => new \PHPExiftool\Driver\Tag\DICOM\AttenuationCorrectionMethod(),
                'DecayCorrection' => new \PHPExiftool\Driver\Tag\DICOM\DecayCorrection(),
                'ReconstructionMethod' => new \PHPExiftool\Driver\Tag\DICOM\ReconstructionMethod(),
                'DetectorLinesOfResponseUsed' => new \PHPExiftool\Driver\Tag\DICOM\DetectorLinesOfResponseUsed(),
                'ScatterCorrectionMethod' => new \PHPExiftool\Driver\Tag\DICOM\ScatterCorrectionMethod(),
                'AxialAcceptance' => new \PHPExiftool\Driver\Tag\DICOM\AxialAcceptance(),
                'AxialMash' => new \PHPExiftool\Driver\Tag\DICOM\AxialMash(),
                'TransverseMash' => new \PHPExiftool\Driver\Tag\DICOM\TransverseMash(),
                'DetectorElementSize' => new \PHPExiftool\Driver\Tag\DICOM\DetectorElementSize(),
                'CoincidenceWindowWidth' => new \PHPExiftool\Driver\Tag\DICOM\CoincidenceWindowWidth(),
                'SecondaryCountsType' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryCountsType(),
                'FrameReferenceTime' => new \PHPExiftool\Driver\Tag\DICOM\FrameReferenceTime(),
                'PrimaryCountsAccumulated' => new \PHPExiftool\Driver\Tag\DICOM\PrimaryCountsAccumulated(),
                'SecondaryCountsAccumulated' => new \PHPExiftool\Driver\Tag\DICOM\SecondaryCountsAccumulated(),
                'SliceSensitivityFactor' => new \PHPExiftool\Driver\Tag\DICOM\SliceSensitivityFactor(),
                'DecayFactor' => new \PHPExiftool\Driver\Tag\DICOM\DecayFactor(),
                'DoseCalibrationFactor' => new \PHPExiftool\Driver\Tag\DICOM\DoseCalibrationFactor(),
                'ScatterFractionFactor' => new \PHPExiftool\Driver\Tag\DICOM\ScatterFractionFactor(),
                'DeadTimeFactor' => new \PHPExiftool\Driver\Tag\DICOM\DeadTimeFactor(),
                'ImageIndex' => new \PHPExiftool\Driver\Tag\DICOM\ImageIndex(),
                'CountsIncluded' => new \PHPExiftool\Driver\Tag\DICOM\CountsIncluded(),
                'DeadTimeCorrectionFlag' => new \PHPExiftool\Driver\Tag\DICOM\DeadTimeCorrectionFlag(),
                'HistogramSequence' => new \PHPExiftool\Driver\Tag\DICOM\HistogramSequence(),
                'HistogramNumberOfBins' => new \PHPExiftool\Driver\Tag\DICOM\HistogramNumberOfBins(),
                'HistogramFirstBinValue' => new \PHPExiftool\Driver\Tag\DICOM\HistogramFirstBinValue(),
                'HistogramLastBinValue' => new \PHPExiftool\Driver\Tag\DICOM\HistogramLastBinValue(),
                'HistogramBinWidth' => new \PHPExiftool\Driver\Tag\DICOM\HistogramBinWidth(),
                'HistogramExplanation' => new \PHPExiftool\Driver\Tag\DICOM\HistogramExplanation(),
                'HistogramData' => new \PHPExiftool\Driver\Tag\DICOM\HistogramData(),
                'SegmentationType' => new \PHPExiftool\Driver\Tag\DICOM\SegmentationType(),
                'SegmentSequence' => new \PHPExiftool\Driver\Tag\DICOM\SegmentSequence(),
                'SegmentedPropertyCategoryCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\SegmentedPropertyCategoryCodeSeq(),
                'SegmentLabel' => new \PHPExiftool\Driver\Tag\DICOM\SegmentLabel(),
                'SegmentDescription' => new \PHPExiftool\Driver\Tag\DICOM\SegmentDescription(),
                'SegmentAlgorithmType' => new \PHPExiftool\Driver\Tag\DICOM\SegmentAlgorithmType(),
                'SegmentAlgorithmName' => new \PHPExiftool\Driver\Tag\DICOM\SegmentAlgorithmName(),
                'SegmentIdentificationSequence' => new \PHPExiftool\Driver\Tag\DICOM\SegmentIdentificationSequence(),
                'ReferencedSegmentNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSegmentNumber(),
                'RecommendedDisplayGrayscaleValue' => new \PHPExiftool\Driver\Tag\DICOM\RecommendedDisplayGrayscaleValue(),
                'RecommendedDisplayCIELabValue' => new \PHPExiftool\Driver\Tag\DICOM\RecommendedDisplayCIELabValue(),
                'MaximumFractionalValue' => new \PHPExiftool\Driver\Tag\DICOM\MaximumFractionalValue(),
                'SegmentedPropertyTypeCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\SegmentedPropertyTypeCodeSequence(),
                'SegmentationFractionalType' => new \PHPExiftool\Driver\Tag\DICOM\SegmentationFractionalType(),
                'DeformableRegistrationSequence' => new \PHPExiftool\Driver\Tag\DICOM\DeformableRegistrationSequence(),
                'SourceFrameOfReferenceUID' => new \PHPExiftool\Driver\Tag\DICOM\SourceFrameOfReferenceUID(),
                'DeformableRegistrationGridSequence' => new \PHPExiftool\Driver\Tag\DICOM\DeformableRegistrationGridSequence(),
                'GridDimensions' => new \PHPExiftool\Driver\Tag\DICOM\GridDimensions(),
                'GridResolution' => new \PHPExiftool\Driver\Tag\DICOM\GridResolution(),
                'VectorGridData' => new \PHPExiftool\Driver\Tag\DICOM\VectorGridData(),
                'PreDeformationMatrixRegistSeq' => new \PHPExiftool\Driver\Tag\DICOM\PreDeformationMatrixRegistSeq(),
                'PostDeformationMatrixRegistSeq' => new \PHPExiftool\Driver\Tag\DICOM\PostDeformationMatrixRegistSeq(),
                'NumberOfSurfaces' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfSurfaces(),
                'SurfaceSequence' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceSequence(),
                'SurfaceNumber' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceNumber(),
                'SurfaceComments' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceComments(),
                'SurfaceProcessing' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceProcessing(),
                'SurfaceProcessingRatio' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceProcessingRatio(),
                'FiniteVolume' => new \PHPExiftool\Driver\Tag\DICOM\FiniteVolume(),
                'Manifold' => new \PHPExiftool\Driver\Tag\DICOM\Manifold(),
                'SurfacePointsSequence' => new \PHPExiftool\Driver\Tag\DICOM\SurfacePointsSequence(),
                'NumberOfSurfacePoints' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfSurfacePoints(),
                'PointCoordinatesData' => new \PHPExiftool\Driver\Tag\DICOM\PointCoordinatesData(),
                'PointPositionAccuracy' => new \PHPExiftool\Driver\Tag\DICOM\PointPositionAccuracy(),
                'MeanPointDistance' => new \PHPExiftool\Driver\Tag\DICOM\MeanPointDistance(),
                'MaximumPointDistance' => new \PHPExiftool\Driver\Tag\DICOM\MaximumPointDistance(),
                'AxisOfRotation' => new \PHPExiftool\Driver\Tag\DICOM\AxisOfRotation(),
                'CenterOfRotation' => new \PHPExiftool\Driver\Tag\DICOM\CenterOfRotation(),
                'NumberOfVectors' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfVectors(),
                'VectorDimensionality' => new \PHPExiftool\Driver\Tag\DICOM\VectorDimensionality(),
                'VectorAccuracy' => new \PHPExiftool\Driver\Tag\DICOM\VectorAccuracy(),
                'VectorCoordinateData' => new \PHPExiftool\Driver\Tag\DICOM\VectorCoordinateData(),
                'TrianglePointIndexList' => new \PHPExiftool\Driver\Tag\DICOM\TrianglePointIndexList(),
                'EdgePointIndexList' => new \PHPExiftool\Driver\Tag\DICOM\EdgePointIndexList(),
                'VertexPointIndexList' => new \PHPExiftool\Driver\Tag\DICOM\VertexPointIndexList(),
                'TriangleStripSequence' => new \PHPExiftool\Driver\Tag\DICOM\TriangleStripSequence(),
                'TriangleFanSequence' => new \PHPExiftool\Driver\Tag\DICOM\TriangleFanSequence(),
                'LineSequence' => new \PHPExiftool\Driver\Tag\DICOM\LineSequence(),
                'PrimitivePointIndexList' => new \PHPExiftool\Driver\Tag\DICOM\PrimitivePointIndexList(),
                'SurfaceCount' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceCount(),
                'AlgorithmFamilyCodeSequ' => new \PHPExiftool\Driver\Tag\DICOM\AlgorithmFamilyCodeSequ(),
                'AlgorithmVersion' => new \PHPExiftool\Driver\Tag\DICOM\AlgorithmVersion(),
                'AlgorithmParameters' => new \PHPExiftool\Driver\Tag\DICOM\AlgorithmParameters(),
                'FacetSequence' => new \PHPExiftool\Driver\Tag\DICOM\FacetSequence(),
                'AlgorithmName' => new \PHPExiftool\Driver\Tag\DICOM\AlgorithmName(),
                'GraphicAnnotationSequence' => new \PHPExiftool\Driver\Tag\DICOM\GraphicAnnotationSequence(),
                'GraphicLayer' => new \PHPExiftool\Driver\Tag\DICOM\GraphicLayer(),
                'BoundingBoxAnnotationUnits' => new \PHPExiftool\Driver\Tag\DICOM\BoundingBoxAnnotationUnits(),
                'AnchorPointAnnotationUnits' => new \PHPExiftool\Driver\Tag\DICOM\AnchorPointAnnotationUnits(),
                'GraphicAnnotationUnits' => new \PHPExiftool\Driver\Tag\DICOM\GraphicAnnotationUnits(),
                'UnformattedTextValue' => new \PHPExiftool\Driver\Tag\DICOM\UnformattedTextValue(),
                'TextObjectSequence' => new \PHPExiftool\Driver\Tag\DICOM\TextObjectSequence(),
                'GraphicObjectSequence' => new \PHPExiftool\Driver\Tag\DICOM\GraphicObjectSequence(),
                'BoundingBoxTopLeftHandCorner' => new \PHPExiftool\Driver\Tag\DICOM\BoundingBoxTopLeftHandCorner(),
                'BoundingBoxBottomRightHandCorner' => new \PHPExiftool\Driver\Tag\DICOM\BoundingBoxBottomRightHandCorner(),
                'BoundingBoxTextHorizJustification' => new \PHPExiftool\Driver\Tag\DICOM\BoundingBoxTextHorizJustification(),
                'AnchorPoint' => new \PHPExiftool\Driver\Tag\DICOM\AnchorPoint(),
                'AnchorPointVisibility' => new \PHPExiftool\Driver\Tag\DICOM\AnchorPointVisibility(),
                'GraphicDimensions' => new \PHPExiftool\Driver\Tag\DICOM\GraphicDimensions(),
                'NumberOfGraphicPoints' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfGraphicPoints(),
                'GraphicData' => new \PHPExiftool\Driver\Tag\DICOM\GraphicData(),
                'GraphicType' => new \PHPExiftool\Driver\Tag\DICOM\GraphicType(),
                'GraphicFilled' => new \PHPExiftool\Driver\Tag\DICOM\GraphicFilled(),
                'ImageRotationRetired' => new \PHPExiftool\Driver\Tag\DICOM\ImageRotationRetired(),
                'ImageHorizontalFlip' => new \PHPExiftool\Driver\Tag\DICOM\ImageHorizontalFlip(),
                'ImageRotation' => new \PHPExiftool\Driver\Tag\DICOM\ImageRotation(),
                'DisplayedAreaTopLeftTrial' => new \PHPExiftool\Driver\Tag\DICOM\DisplayedAreaTopLeftTrial(),
                'DisplayedAreaBottomRightTrial' => new \PHPExiftool\Driver\Tag\DICOM\DisplayedAreaBottomRightTrial(),
                'DisplayedAreaTopLeft' => new \PHPExiftool\Driver\Tag\DICOM\DisplayedAreaTopLeft(),
                'DisplayedAreaBottomRight' => new \PHPExiftool\Driver\Tag\DICOM\DisplayedAreaBottomRight(),
                'DisplayedAreaSelectionSequence' => new \PHPExiftool\Driver\Tag\DICOM\DisplayedAreaSelectionSequence(),
                'GraphicLayerSequence' => new \PHPExiftool\Driver\Tag\DICOM\GraphicLayerSequence(),
                'GraphicLayerOrder' => new \PHPExiftool\Driver\Tag\DICOM\GraphicLayerOrder(),
                'GraphicLayerRecDisplayGraysclValue' => new \PHPExiftool\Driver\Tag\DICOM\GraphicLayerRecDisplayGraysclValue(),
                'GraphicLayerRecDisplayRGBValue' => new \PHPExiftool\Driver\Tag\DICOM\GraphicLayerRecDisplayRGBValue(),
                'GraphicLayerDescription' => new \PHPExiftool\Driver\Tag\DICOM\GraphicLayerDescription(),
                'ContentLabel' => new \PHPExiftool\Driver\Tag\DICOM\ContentLabel(),
                'ContentDescription' => new \PHPExiftool\Driver\Tag\DICOM\ContentDescription(),
                'PresentationCreationDate' => new \PHPExiftool\Driver\Tag\DICOM\PresentationCreationDate(),
                'PresentationCreationTime' => new \PHPExiftool\Driver\Tag\DICOM\PresentationCreationTime(),
                'ContentCreatorName' => new \PHPExiftool\Driver\Tag\DICOM\ContentCreatorName(),
                'ContentCreatorIDCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContentCreatorIDCodeSequence(),
                'PresentationSizeMode' => new \PHPExiftool\Driver\Tag\DICOM\PresentationSizeMode(),
                'PresentationPixelSpacing' => new \PHPExiftool\Driver\Tag\DICOM\PresentationPixelSpacing(),
                'PresentationPixelAspectRatio' => new \PHPExiftool\Driver\Tag\DICOM\PresentationPixelAspectRatio(),
                'PresentationPixelMagRatio' => new \PHPExiftool\Driver\Tag\DICOM\PresentationPixelMagRatio(),
                'ShapeType' => new \PHPExiftool\Driver\Tag\DICOM\ShapeType(),
                'RegistrationSequence' => new \PHPExiftool\Driver\Tag\DICOM\RegistrationSequence(),
                'MatrixRegistrationSequence' => new \PHPExiftool\Driver\Tag\DICOM\MatrixRegistrationSequence(),
                'MatrixSequence' => new \PHPExiftool\Driver\Tag\DICOM\MatrixSequence(),
                'FrameOfRefTransformationMatrixType' => new \PHPExiftool\Driver\Tag\DICOM\FrameOfRefTransformationMatrixType(),
                'RegistrationTypeCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\RegistrationTypeCodeSequence(),
                'FiducialDescription' => new \PHPExiftool\Driver\Tag\DICOM\FiducialDescription(),
                'FiducialIdentifier' => new \PHPExiftool\Driver\Tag\DICOM\FiducialIdentifier(),
                'FiducialIdentifierCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\FiducialIdentifierCodeSequence(),
                'ContourUncertaintyRadius' => new \PHPExiftool\Driver\Tag\DICOM\ContourUncertaintyRadius(),
                'UsedFiducialsSequence' => new \PHPExiftool\Driver\Tag\DICOM\UsedFiducialsSequence(),
                'GraphicCoordinatesDataSequence' => new \PHPExiftool\Driver\Tag\DICOM\GraphicCoordinatesDataSequence(),
                'FiducialUID' => new \PHPExiftool\Driver\Tag\DICOM\FiducialUID(),
                'FiducialSetSequence' => new \PHPExiftool\Driver\Tag\DICOM\FiducialSetSequence(),
                'FiducialSequence' => new \PHPExiftool\Driver\Tag\DICOM\FiducialSequence(),
                'GraphicLayerRecomDisplayCIELabVal' => new \PHPExiftool\Driver\Tag\DICOM\GraphicLayerRecomDisplayCIELabVal(),
                'BlendingSequence' => new \PHPExiftool\Driver\Tag\DICOM\BlendingSequence(),
                'RelativeOpacity' => new \PHPExiftool\Driver\Tag\DICOM\RelativeOpacity(),
                'ReferencedSpatialRegistrationSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSpatialRegistrationSeq(),
                'BlendingPosition' => new \PHPExiftool\Driver\Tag\DICOM\BlendingPosition(),
                'HangingProtocolName' => new \PHPExiftool\Driver\Tag\DICOM\HangingProtocolName(),
                'HangingProtocolDescription' => new \PHPExiftool\Driver\Tag\DICOM\HangingProtocolDescription(),
                'HangingProtocolLevel' => new \PHPExiftool\Driver\Tag\DICOM\HangingProtocolLevel(),
                'HangingProtocolCreator' => new \PHPExiftool\Driver\Tag\DICOM\HangingProtocolCreator(),
                'HangingProtocolCreationDateTime' => new \PHPExiftool\Driver\Tag\DICOM\HangingProtocolCreationDateTime(),
                'HangingProtocolDefinitionSequence' => new \PHPExiftool\Driver\Tag\DICOM\HangingProtocolDefinitionSequence(),
                'HangingProtocolUserIDCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\HangingProtocolUserIDCodeSequence(),
                'HangingProtocolUserGroupName' => new \PHPExiftool\Driver\Tag\DICOM\HangingProtocolUserGroupName(),
                'SourceHangingProtocolSequence' => new \PHPExiftool\Driver\Tag\DICOM\SourceHangingProtocolSequence(),
                'NumberOfPriorsReferenced' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPriorsReferenced(),
                'ImageSetsSequence' => new \PHPExiftool\Driver\Tag\DICOM\ImageSetsSequence(),
                'ImageSetSelectorSequence' => new \PHPExiftool\Driver\Tag\DICOM\ImageSetSelectorSequence(),
                'ImageSetSelectorUsageFlag' => new \PHPExiftool\Driver\Tag\DICOM\ImageSetSelectorUsageFlag(),
                'SelectorAttribute' => new \PHPExiftool\Driver\Tag\DICOM\SelectorAttribute(),
                'SelectorValueNumber' => new \PHPExiftool\Driver\Tag\DICOM\SelectorValueNumber(),
                'TimeBasedImageSetsSequence' => new \PHPExiftool\Driver\Tag\DICOM\TimeBasedImageSetsSequence(),
                'ImageSetNumber' => new \PHPExiftool\Driver\Tag\DICOM\ImageSetNumber(),
                'ImageSetSelectorCategory' => new \PHPExiftool\Driver\Tag\DICOM\ImageSetSelectorCategory(),
                'RelativeTime' => new \PHPExiftool\Driver\Tag\DICOM\RelativeTime(),
                'RelativeTimeUnits' => new \PHPExiftool\Driver\Tag\DICOM\RelativeTimeUnits(),
                'AbstractPriorValue' => new \PHPExiftool\Driver\Tag\DICOM\AbstractPriorValue(),
                'AbstractPriorCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\AbstractPriorCodeSequence(),
                'ImageSetLabel' => new \PHPExiftool\Driver\Tag\DICOM\ImageSetLabel(),
                'SelectorAttributeVR' => new \PHPExiftool\Driver\Tag\DICOM\SelectorAttributeVR(),
                'SelectorSequencePointer' => new \PHPExiftool\Driver\Tag\DICOM\SelectorSequencePointer(),
                'SelectorSeqPointerPrivateCreator' => new \PHPExiftool\Driver\Tag\DICOM\SelectorSeqPointerPrivateCreator(),
                'SelectorAttributePrivateCreator' => new \PHPExiftool\Driver\Tag\DICOM\SelectorAttributePrivateCreator(),
                'SelectorATValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorATValue(),
                'SelectorCSValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorCSValue(),
                'SelectorISValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorISValue(),
                'SelectorLOValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorLOValue(),
                'SelectorLTValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorLTValue(),
                'SelectorPNValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorPNValue(),
                'SelectorSHValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorSHValue(),
                'SelectorSTValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorSTValue(),
                'SelectorUTValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorUTValue(),
                'SelectorDSValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorDSValue(),
                'SelectorFDValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorFDValue(),
                'SelectorFLValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorFLValue(),
                'SelectorULValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorULValue(),
                'SelectorUSValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorUSValue(),
                'SelectorSLValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorSLValue(),
                'SelectorSSValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorSSValue(),
                'SelectorCodeSequenceValue' => new \PHPExiftool\Driver\Tag\DICOM\SelectorCodeSequenceValue(),
                'NumberOfScreens' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfScreens(),
                'NominalScreenDefinitionSequence' => new \PHPExiftool\Driver\Tag\DICOM\NominalScreenDefinitionSequence(),
                'NumberOfVerticalPixels' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfVerticalPixels(),
                'NumberOfHorizontalPixels' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfHorizontalPixels(),
                'DisplayEnvironmentSpatialPosition' => new \PHPExiftool\Driver\Tag\DICOM\DisplayEnvironmentSpatialPosition(),
                'ScreenMinimumGrayscaleBitDepth' => new \PHPExiftool\Driver\Tag\DICOM\ScreenMinimumGrayscaleBitDepth(),
                'ScreenMinimumColorBitDepth' => new \PHPExiftool\Driver\Tag\DICOM\ScreenMinimumColorBitDepth(),
                'ApplicationMaximumRepaintTime' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationMaximumRepaintTime(),
                'DisplaySetsSequence' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetsSequence(),
                'DisplaySetNumber' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetNumber(),
                'DisplaySetLabel' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetLabel(),
                'DisplaySetPresentationGroup' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetPresentationGroup(),
                'DisplaySetPresentationGroupDescr' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetPresentationGroupDescr(),
                'PartialDataDisplayHandling' => new \PHPExiftool\Driver\Tag\DICOM\PartialDataDisplayHandling(),
                'SynchronizedScrollingSequence' => new \PHPExiftool\Driver\Tag\DICOM\SynchronizedScrollingSequence(),
                'DisplaySetScrollingGroup' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetScrollingGroup(),
                'NavigationIndicatorSequence' => new \PHPExiftool\Driver\Tag\DICOM\NavigationIndicatorSequence(),
                'NavigationDisplaySet' => new \PHPExiftool\Driver\Tag\DICOM\NavigationDisplaySet(),
                'ReferenceDisplaySets' => new \PHPExiftool\Driver\Tag\DICOM\ReferenceDisplaySets(),
                'ImageBoxesSequence' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxesSequence(),
                'ImageBoxNumber' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxNumber(),
                'ImageBoxLayoutType' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxLayoutType(),
                'ImageBoxTileHorizontalDimension' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxTileHorizontalDimension(),
                'ImageBoxTileVerticalDimension' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxTileVerticalDimension(),
                'ImageBoxScrollDirection' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxScrollDirection(),
                'ImageBoxSmallScrollType' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxSmallScrollType(),
                'ImageBoxSmallScrollAmount' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxSmallScrollAmount(),
                'ImageBoxLargeScrollType' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxLargeScrollType(),
                'ImageBoxLargeScrollAmount' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxLargeScrollAmount(),
                'ImageBoxOverlapPriority' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxOverlapPriority(),
                'CineRelativeToRealTime' => new \PHPExiftool\Driver\Tag\DICOM\CineRelativeToRealTime(),
                'FilterOperationsSequence' => new \PHPExiftool\Driver\Tag\DICOM\FilterOperationsSequence(),
                'FilterByCategory' => new \PHPExiftool\Driver\Tag\DICOM\FilterByCategory(),
                'FilterByAttributePresence' => new \PHPExiftool\Driver\Tag\DICOM\FilterByAttributePresence(),
                'FilterByOperator' => new \PHPExiftool\Driver\Tag\DICOM\FilterByOperator(),
                'SynchronizedImageBoxList' => new \PHPExiftool\Driver\Tag\DICOM\SynchronizedImageBoxList(),
                'TypeOfSynchronization' => new \PHPExiftool\Driver\Tag\DICOM\TypeOfSynchronization(),
                'BlendingOperationType' => new \PHPExiftool\Driver\Tag\DICOM\BlendingOperationType(),
                'ReformattingOperationType' => new \PHPExiftool\Driver\Tag\DICOM\ReformattingOperationType(),
                'ReformattingThickness' => new \PHPExiftool\Driver\Tag\DICOM\ReformattingThickness(),
                'ReformattingInterval' => new \PHPExiftool\Driver\Tag\DICOM\ReformattingInterval(),
                'ReformattingOpInitialViewDir' => new \PHPExiftool\Driver\Tag\DICOM\ReformattingOpInitialViewDir(),
                'RenderingType3D' => new \PHPExiftool\Driver\Tag\DICOM\RenderingType3D(),
                'SortingOperationsSequence' => new \PHPExiftool\Driver\Tag\DICOM\SortingOperationsSequence(),
                'SortByCategory' => new \PHPExiftool\Driver\Tag\DICOM\SortByCategory(),
                'SortingDirection' => new \PHPExiftool\Driver\Tag\DICOM\SortingDirection(),
                'DisplaySetPatientOrientation' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetPatientOrientation(),
                'VOIType' => new \PHPExiftool\Driver\Tag\DICOM\VOIType(),
                'PseudoColorType' => new \PHPExiftool\Driver\Tag\DICOM\PseudoColorType(),
                'ShowGrayscaleInverted' => new \PHPExiftool\Driver\Tag\DICOM\ShowGrayscaleInverted(),
                'ShowImageTrueSizeFlag' => new \PHPExiftool\Driver\Tag\DICOM\ShowImageTrueSizeFlag(),
                'ShowGraphicAnnotationFlag' => new \PHPExiftool\Driver\Tag\DICOM\ShowGraphicAnnotationFlag(),
                'ShowPatientDemographicsFlag' => new \PHPExiftool\Driver\Tag\DICOM\ShowPatientDemographicsFlag(),
                'ShowAcquisitionTechniquesFlag' => new \PHPExiftool\Driver\Tag\DICOM\ShowAcquisitionTechniquesFlag(),
                'DisplaySetHorizontalJustification' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetHorizontalJustification(),
                'DisplaySetVerticalJustification' => new \PHPExiftool\Driver\Tag\DICOM\DisplaySetVerticalJustification(),
                'UnifiedProcedureStepState' => new \PHPExiftool\Driver\Tag\DICOM\UnifiedProcedureStepState(),
                'UPSProgressInformationSequence' => new \PHPExiftool\Driver\Tag\DICOM\UPSProgressInformationSequence(),
                'UnifiedProcedureStepProgress' => new \PHPExiftool\Driver\Tag\DICOM\UnifiedProcedureStepProgress(),
                'UnifiedProcedureStepProgressDescr' => new \PHPExiftool\Driver\Tag\DICOM\UnifiedProcedureStepProgressDescr(),
                'UnifiedProcedureStepComURISeq' => new \PHPExiftool\Driver\Tag\DICOM\UnifiedProcedureStepComURISeq(),
                'ContactURI' => new \PHPExiftool\Driver\Tag\DICOM\ContactURI(),
                'ContactDisplayName' => new \PHPExiftool\Driver\Tag\DICOM\ContactDisplayName(),
                'BeamTaskSequence' => new \PHPExiftool\Driver\Tag\DICOM\BeamTaskSequence(),
                'BeamTaskType' => new \PHPExiftool\Driver\Tag\DICOM\BeamTaskType(),
                'BeamOrderIndex' => new \PHPExiftool\Driver\Tag\DICOM\BeamOrderIndex(),
                'DeliveryVerificationImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\DeliveryVerificationImageSequence(),
                'VerificationImageTiming' => new \PHPExiftool\Driver\Tag\DICOM\VerificationImageTiming(),
                'DoubleExposureFlag' => new \PHPExiftool\Driver\Tag\DICOM\DoubleExposureFlag(),
                'DoubleExposureOrdering' => new \PHPExiftool\Driver\Tag\DICOM\DoubleExposureOrdering(),
                'DoubleExposureMeterset' => new \PHPExiftool\Driver\Tag\DICOM\DoubleExposureMeterset(),
                'DoubleExposureFieldDelta' => new \PHPExiftool\Driver\Tag\DICOM\DoubleExposureFieldDelta(),
                'RelatedReferenceRTImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\RelatedReferenceRTImageSequence(),
                'GeneralMachineVerificationSequence' => new \PHPExiftool\Driver\Tag\DICOM\GeneralMachineVerificationSequence(),
                'ConventionalMachineVerificationSeq' => new \PHPExiftool\Driver\Tag\DICOM\ConventionalMachineVerificationSeq(),
                'IonMachineVerificationSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonMachineVerificationSequence(),
                'FailedAttributesSequence' => new \PHPExiftool\Driver\Tag\DICOM\FailedAttributesSequence(),
                'OverriddenAttributesSequence' => new \PHPExiftool\Driver\Tag\DICOM\OverriddenAttributesSequence(),
                'ConventionalControlPointVerifySeq' => new \PHPExiftool\Driver\Tag\DICOM\ConventionalControlPointVerifySeq(),
                'IonControlPointVerificationSeq' => new \PHPExiftool\Driver\Tag\DICOM\IonControlPointVerificationSeq(),
                'AttributeOccurrenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\AttributeOccurrenceSequence(),
                'AttributeOccurrencePointer' => new \PHPExiftool\Driver\Tag\DICOM\AttributeOccurrencePointer(),
                'AttributeItemSelector' => new \PHPExiftool\Driver\Tag\DICOM\AttributeItemSelector(),
                'AttributeOccurrencePrivateCreator' => new \PHPExiftool\Driver\Tag\DICOM\AttributeOccurrencePrivateCreator(),
                'ScheduledProcedureStepPriority' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepPriority(),
                'WorklistLabel' => new \PHPExiftool\Driver\Tag\DICOM\WorklistLabel(),
                'ProcedureStepLabel' => new \PHPExiftool\Driver\Tag\DICOM\ProcedureStepLabel(),
                'ScheduledProcessingParametersSeq' => new \PHPExiftool\Driver\Tag\DICOM\ScheduledProcessingParametersSeq(),
                'PerformedProcessingParametersSeq' => new \PHPExiftool\Driver\Tag\DICOM\PerformedProcessingParametersSeq(),
                'UPSPerformedProcedureSequence' => new \PHPExiftool\Driver\Tag\DICOM\UPSPerformedProcedureSequence(),
                'RelatedProcedureStepSequence' => new \PHPExiftool\Driver\Tag\DICOM\RelatedProcedureStepSequence(),
                'ProcedureStepRelationshipType' => new \PHPExiftool\Driver\Tag\DICOM\ProcedureStepRelationshipType(),
                'DeletionLock' => new \PHPExiftool\Driver\Tag\DICOM\DeletionLock(),
                'ReceivingAE' => new \PHPExiftool\Driver\Tag\DICOM\ReceivingAE(),
                'RequestingAE' => new \PHPExiftool\Driver\Tag\DICOM\RequestingAE(),
                'ReasonForCancellation' => new \PHPExiftool\Driver\Tag\DICOM\ReasonForCancellation(),
                'SCPStatus' => new \PHPExiftool\Driver\Tag\DICOM\SCPStatus(),
                'SubscriptionListStatus' => new \PHPExiftool\Driver\Tag\DICOM\SubscriptionListStatus(),
                'UPSListStatus' => new \PHPExiftool\Driver\Tag\DICOM\UPSListStatus(),
                'StorageMediaFileSetID' => new \PHPExiftool\Driver\Tag\DICOM\StorageMediaFileSetID(),
                'StorageMediaFileSetUID' => new \PHPExiftool\Driver\Tag\DICOM\StorageMediaFileSetUID(),
                'IconImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\IconImageSequence(),
                'TopicTitle' => new \PHPExiftool\Driver\Tag\DICOM\TopicTitle(),
                'TopicSubject' => new \PHPExiftool\Driver\Tag\DICOM\TopicSubject(),
                'TopicAuthor' => new \PHPExiftool\Driver\Tag\DICOM\TopicAuthor(),
                'TopicKeywords' => new \PHPExiftool\Driver\Tag\DICOM\TopicKeywords(),
                'SOPInstanceStatus' => new \PHPExiftool\Driver\Tag\DICOM\SOPInstanceStatus(),
                'SOPAuthorizationDateAndTime' => new \PHPExiftool\Driver\Tag\DICOM\SOPAuthorizationDateAndTime(),
                'SOPAuthorizationComment' => new \PHPExiftool\Driver\Tag\DICOM\SOPAuthorizationComment(),
                'AuthorizationEquipmentCertNumber' => new \PHPExiftool\Driver\Tag\DICOM\AuthorizationEquipmentCertNumber(),
                'MACIDNumber' => new \PHPExiftool\Driver\Tag\DICOM\MACIDNumber(),
                'MACCalculationTransferSyntaxUID' => new \PHPExiftool\Driver\Tag\DICOM\MACCalculationTransferSyntaxUID(),
                'MACAlgorithm' => new \PHPExiftool\Driver\Tag\DICOM\MACAlgorithm(),
                'DataElementsSigned' => new \PHPExiftool\Driver\Tag\DICOM\DataElementsSigned(),
                'DigitalSignatureUID' => new \PHPExiftool\Driver\Tag\DICOM\DigitalSignatureUID(),
                'DigitalSignatureDateTime' => new \PHPExiftool\Driver\Tag\DICOM\DigitalSignatureDateTime(),
                'CertificateType' => new \PHPExiftool\Driver\Tag\DICOM\CertificateType(),
                'CertificateOfSigner' => new \PHPExiftool\Driver\Tag\DICOM\CertificateOfSigner(),
                'Signature' => new \PHPExiftool\Driver\Tag\DICOM\Signature(),
                'CertifiedTimestampType' => new \PHPExiftool\Driver\Tag\DICOM\CertifiedTimestampType(),
                'CertifiedTimestamp' => new \PHPExiftool\Driver\Tag\DICOM\CertifiedTimestamp(),
                'DigitalSignaturePurposeCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\DigitalSignaturePurposeCodeSeq(),
                'ReferencedDigitalSignatureSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedDigitalSignatureSeq(),
                'ReferencedSOPInstanceMACSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSOPInstanceMACSeq(),
                'MAC' => new \PHPExiftool\Driver\Tag\DICOM\MAC(),
                'EncryptedAttributesSequence' => new \PHPExiftool\Driver\Tag\DICOM\EncryptedAttributesSequence(),
                'EncryptedContentTransferSyntaxUID' => new \PHPExiftool\Driver\Tag\DICOM\EncryptedContentTransferSyntaxUID(),
                'EncryptedContent' => new \PHPExiftool\Driver\Tag\DICOM\EncryptedContent(),
                'ModifiedAttributesSequence' => new \PHPExiftool\Driver\Tag\DICOM\ModifiedAttributesSequence(),
                'OriginalAttributesSequence' => new \PHPExiftool\Driver\Tag\DICOM\OriginalAttributesSequence(),
                'AttributeModificationDateTime' => new \PHPExiftool\Driver\Tag\DICOM\AttributeModificationDateTime(),
                'ModifyingSystem' => new \PHPExiftool\Driver\Tag\DICOM\ModifyingSystem(),
                'SourceOfPreviousValues' => new \PHPExiftool\Driver\Tag\DICOM\SourceOfPreviousValues(),
                'ReasonForTheAttributeModification' => new \PHPExiftool\Driver\Tag\DICOM\ReasonForTheAttributeModification(),
                'EscapeTriplet' => new \PHPExiftool\Driver\Tag\DICOM\EscapeTriplet(),
                'RunLengthTriplet' => new \PHPExiftool\Driver\Tag\DICOM\RunLengthTriplet(),
                'HuffmanTableSize' => new \PHPExiftool\Driver\Tag\DICOM\HuffmanTableSize(),
                'HuffmanTableTriplet' => new \PHPExiftool\Driver\Tag\DICOM\HuffmanTableTriplet(),
                'ShiftTableSize' => new \PHPExiftool\Driver\Tag\DICOM\ShiftTableSize(),
                'ShiftTableTriplet' => new \PHPExiftool\Driver\Tag\DICOM\ShiftTableTriplet(),
                'ZonalMap' => new \PHPExiftool\Driver\Tag\DICOM\ZonalMap(),
                'NumberOfCopies' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfCopies(),
                'PrinterConfigurationSequence' => new \PHPExiftool\Driver\Tag\DICOM\PrinterConfigurationSequence(),
                'PrintPriority' => new \PHPExiftool\Driver\Tag\DICOM\PrintPriority(),
                'MediumType' => new \PHPExiftool\Driver\Tag\DICOM\MediumType(),
                'FilmDestination' => new \PHPExiftool\Driver\Tag\DICOM\FilmDestination(),
                'FilmSessionLabel' => new \PHPExiftool\Driver\Tag\DICOM\FilmSessionLabel(),
                'MemoryAllocation' => new \PHPExiftool\Driver\Tag\DICOM\MemoryAllocation(),
                'MaximumMemoryAllocation' => new \PHPExiftool\Driver\Tag\DICOM\MaximumMemoryAllocation(),
                'ColorImagePrintingFlag' => new \PHPExiftool\Driver\Tag\DICOM\ColorImagePrintingFlag(),
                'CollationFlag' => new \PHPExiftool\Driver\Tag\DICOM\CollationFlag(),
                'AnnotationFlag' => new \PHPExiftool\Driver\Tag\DICOM\AnnotationFlag(),
                'ImageOverlayFlag' => new \PHPExiftool\Driver\Tag\DICOM\ImageOverlayFlag(),
                'PresentationLUTFlag' => new \PHPExiftool\Driver\Tag\DICOM\PresentationLUTFlag(),
                'ImageBoxPresentationLUTFlag' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxPresentationLUTFlag(),
                'MemoryBitDepth' => new \PHPExiftool\Driver\Tag\DICOM\MemoryBitDepth(),
                'PrintingBitDepth' => new \PHPExiftool\Driver\Tag\DICOM\PrintingBitDepth(),
                'MediaInstalledSequence' => new \PHPExiftool\Driver\Tag\DICOM\MediaInstalledSequence(),
                'OtherMediaAvailableSequence' => new \PHPExiftool\Driver\Tag\DICOM\OtherMediaAvailableSequence(),
                'SupportedImageDisplayFormatSeq' => new \PHPExiftool\Driver\Tag\DICOM\SupportedImageDisplayFormatSeq(),
                'ReferencedFilmBoxSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFilmBoxSequence(),
                'ReferencedStoredPrintSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedStoredPrintSequence(),
                'ImageDisplayFormat' => new \PHPExiftool\Driver\Tag\DICOM\ImageDisplayFormat(),
                'AnnotationDisplayFormatID' => new \PHPExiftool\Driver\Tag\DICOM\AnnotationDisplayFormatID(),
                'FilmOrientation' => new \PHPExiftool\Driver\Tag\DICOM\FilmOrientation(),
                'FilmSizeID' => new \PHPExiftool\Driver\Tag\DICOM\FilmSizeID(),
                'PrinterResolutionID' => new \PHPExiftool\Driver\Tag\DICOM\PrinterResolutionID(),
                'DefaultPrinterResolutionID' => new \PHPExiftool\Driver\Tag\DICOM\DefaultPrinterResolutionID(),
                'MagnificationType' => new \PHPExiftool\Driver\Tag\DICOM\MagnificationType(),
                'SmoothingType' => new \PHPExiftool\Driver\Tag\DICOM\SmoothingType(),
                'DefaultMagnificationType' => new \PHPExiftool\Driver\Tag\DICOM\DefaultMagnificationType(),
                'OtherMagnificationTypesAvailable' => new \PHPExiftool\Driver\Tag\DICOM\OtherMagnificationTypesAvailable(),
                'DefaultSmoothingType' => new \PHPExiftool\Driver\Tag\DICOM\DefaultSmoothingType(),
                'OtherSmoothingTypesAvailable' => new \PHPExiftool\Driver\Tag\DICOM\OtherSmoothingTypesAvailable(),
                'BorderDensity' => new \PHPExiftool\Driver\Tag\DICOM\BorderDensity(),
                'EmptyImageDensity' => new \PHPExiftool\Driver\Tag\DICOM\EmptyImageDensity(),
                'MinDensity' => new \PHPExiftool\Driver\Tag\DICOM\MinDensity(),
                'MaxDensity' => new \PHPExiftool\Driver\Tag\DICOM\MaxDensity(),
                'Trim' => new \PHPExiftool\Driver\Tag\DICOM\Trim(),
                'ConfigurationInformation' => new \PHPExiftool\Driver\Tag\DICOM\ConfigurationInformation(),
                'ConfigurationInformationDescr' => new \PHPExiftool\Driver\Tag\DICOM\ConfigurationInformationDescr(),
                'MaximumCollatedFilms' => new \PHPExiftool\Driver\Tag\DICOM\MaximumCollatedFilms(),
                'Illumination' => new \PHPExiftool\Driver\Tag\DICOM\Illumination(),
                'ReflectedAmbientLight' => new \PHPExiftool\Driver\Tag\DICOM\ReflectedAmbientLight(),
                'PrinterPixelSpacing' => new \PHPExiftool\Driver\Tag\DICOM\PrinterPixelSpacing(),
                'ReferencedFilmSessionSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFilmSessionSequence(),
                'ReferencedImageBoxSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedImageBoxSequence(),
                'ReferencedBasicAnnotationBoxSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedBasicAnnotationBoxSeq(),
                'ImageBoxPosition' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxPosition(),
                'Polarity' => new \PHPExiftool\Driver\Tag\DICOM\Polarity(),
                'RequestedImageSize' => new \PHPExiftool\Driver\Tag\DICOM\RequestedImageSize(),
                'RequestedDecimate-CropBehavior' => new \PHPExiftool\Driver\Tag\DICOM\RequestedDecimateCropBehavior(),
                'RequestedResolutionID' => new \PHPExiftool\Driver\Tag\DICOM\RequestedResolutionID(),
                'RequestedImageSizeFlag' => new \PHPExiftool\Driver\Tag\DICOM\RequestedImageSizeFlag(),
                'DecimateCropResult' => new \PHPExiftool\Driver\Tag\DICOM\DecimateCropResult(),
                'BasicGrayscaleImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\BasicGrayscaleImageSequence(),
                'BasicColorImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\BasicColorImageSequence(),
                'ReferencedImageOverlayBoxSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedImageOverlayBoxSequence(),
                'ReferencedVOILUTBoxSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedVOILUTBoxSequence(),
                'AnnotationPosition' => new \PHPExiftool\Driver\Tag\DICOM\AnnotationPosition(),
                'TextString' => new \PHPExiftool\Driver\Tag\DICOM\TextString(),
                'ReferencedOverlayPlaneSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedOverlayPlaneSequence(),
                'ReferencedOverlayPlaneGroups' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedOverlayPlaneGroups(),
                'OverlayPixelDataSequence' => new \PHPExiftool\Driver\Tag\DICOM\OverlayPixelDataSequence(),
                'OverlayMagnificationType' => new \PHPExiftool\Driver\Tag\DICOM\OverlayMagnificationType(),
                'OverlaySmoothingType' => new \PHPExiftool\Driver\Tag\DICOM\OverlaySmoothingType(),
                'OverlayOrImageMagnification' => new \PHPExiftool\Driver\Tag\DICOM\OverlayOrImageMagnification(),
                'MagnifyToNumberOfColumns' => new \PHPExiftool\Driver\Tag\DICOM\MagnifyToNumberOfColumns(),
                'OverlayForegroundDensity' => new \PHPExiftool\Driver\Tag\DICOM\OverlayForegroundDensity(),
                'OverlayBackgroundDensity' => new \PHPExiftool\Driver\Tag\DICOM\OverlayBackgroundDensity(),
                'OverlayMode' => new \PHPExiftool\Driver\Tag\DICOM\OverlayMode(),
                'ThresholdDensity' => new \PHPExiftool\Driver\Tag\DICOM\ThresholdDensity(),
                'PresentationLUTSequence' => new \PHPExiftool\Driver\Tag\DICOM\PresentationLUTSequence(),
                'PresentationLUTShape' => new \PHPExiftool\Driver\Tag\DICOM\PresentationLUTShape(),
                'ReferencedPresentationLUTSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedPresentationLUTSequence(),
                'PrintJobID' => new \PHPExiftool\Driver\Tag\DICOM\PrintJobID(),
                'ExecutionStatus' => new \PHPExiftool\Driver\Tag\DICOM\ExecutionStatus(),
                'ExecutionStatusInfo' => new \PHPExiftool\Driver\Tag\DICOM\ExecutionStatusInfo(),
                'CreationDate' => new \PHPExiftool\Driver\Tag\DICOM\CreationDate(),
                'CreationTime' => new \PHPExiftool\Driver\Tag\DICOM\CreationTime(),
                'Originator' => new \PHPExiftool\Driver\Tag\DICOM\Originator(),
                'DestinationAE' => new \PHPExiftool\Driver\Tag\DICOM\DestinationAE(),
                'OwnerID' => new \PHPExiftool\Driver\Tag\DICOM\OwnerID(),
                'NumberOfFilms' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfFilms(),
                'ReferencedPrintJobSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedPrintJobSequence(),
                'PrinterStatus' => new \PHPExiftool\Driver\Tag\DICOM\PrinterStatus(),
                'PrinterStatusInfo' => new \PHPExiftool\Driver\Tag\DICOM\PrinterStatusInfo(),
                'PrinterName' => new \PHPExiftool\Driver\Tag\DICOM\PrinterName(),
                'PrintQueueID' => new \PHPExiftool\Driver\Tag\DICOM\PrintQueueID(),
                'QueueStatus' => new \PHPExiftool\Driver\Tag\DICOM\QueueStatus(),
                'PrintJobDescriptionSequence' => new \PHPExiftool\Driver\Tag\DICOM\PrintJobDescriptionSequence(),
                'PrintManagementCapabilitiesSeq' => new \PHPExiftool\Driver\Tag\DICOM\PrintManagementCapabilitiesSeq(),
                'PrinterCharacteristicsSequence' => new \PHPExiftool\Driver\Tag\DICOM\PrinterCharacteristicsSequence(),
                'FilmBoxContentSequence' => new \PHPExiftool\Driver\Tag\DICOM\FilmBoxContentSequence(),
                'ImageBoxContentSequence' => new \PHPExiftool\Driver\Tag\DICOM\ImageBoxContentSequence(),
                'AnnotationContentSequence' => new \PHPExiftool\Driver\Tag\DICOM\AnnotationContentSequence(),
                'ImageOverlayBoxContentSequence' => new \PHPExiftool\Driver\Tag\DICOM\ImageOverlayBoxContentSequence(),
                'PresentationLUTContentSequence' => new \PHPExiftool\Driver\Tag\DICOM\PresentationLUTContentSequence(),
                'ProposedStudySequence' => new \PHPExiftool\Driver\Tag\DICOM\ProposedStudySequence(),
                'OriginalImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\OriginalImageSequence(),
                'LabelFromInfoExtractedFromInstance' => new \PHPExiftool\Driver\Tag\DICOM\LabelFromInfoExtractedFromInstance(),
                'LabelText' => new \PHPExiftool\Driver\Tag\DICOM\LabelText(),
                'LabelStyleSelection' => new \PHPExiftool\Driver\Tag\DICOM\LabelStyleSelection(),
                'MediaDisposition' => new \PHPExiftool\Driver\Tag\DICOM\MediaDisposition(),
                'BarcodeValue' => new \PHPExiftool\Driver\Tag\DICOM\BarcodeValue(),
                'BarcodeSymbology' => new \PHPExiftool\Driver\Tag\DICOM\BarcodeSymbology(),
                'AllowMediaSplitting' => new \PHPExiftool\Driver\Tag\DICOM\AllowMediaSplitting(),
                'IncludeNonDICOMObjects' => new \PHPExiftool\Driver\Tag\DICOM\IncludeNonDICOMObjects(),
                'IncludeDisplayApplication' => new \PHPExiftool\Driver\Tag\DICOM\IncludeDisplayApplication(),
                'SaveCompInstancesAfterMediaCreate' => new \PHPExiftool\Driver\Tag\DICOM\SaveCompInstancesAfterMediaCreate(),
                'TotalNumberMediaPiecesCreated' => new \PHPExiftool\Driver\Tag\DICOM\TotalNumberMediaPiecesCreated(),
                'RequestedMediaApplicationProfile' => new \PHPExiftool\Driver\Tag\DICOM\RequestedMediaApplicationProfile(),
                'ReferencedStorageMediaSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedStorageMediaSequence(),
                'FailureAttributes' => new \PHPExiftool\Driver\Tag\DICOM\FailureAttributes(),
                'AllowLossyCompression' => new \PHPExiftool\Driver\Tag\DICOM\AllowLossyCompression(),
                'RequestPriority' => new \PHPExiftool\Driver\Tag\DICOM\RequestPriority(),
                'RTImageLabel' => new \PHPExiftool\Driver\Tag\DICOM\RTImageLabel(),
                'RTImageName' => new \PHPExiftool\Driver\Tag\DICOM\RTImageName(),
                'RTImageDescription' => new \PHPExiftool\Driver\Tag\DICOM\RTImageDescription(),
                'ReportedValuesOrigin' => new \PHPExiftool\Driver\Tag\DICOM\ReportedValuesOrigin(),
                'RTImagePlane' => new \PHPExiftool\Driver\Tag\DICOM\RTImagePlane(),
                'XRayImageReceptorTranslation' => new \PHPExiftool\Driver\Tag\DICOM\XRayImageReceptorTranslation(),
                'XRayImageReceptorAngle' => new \PHPExiftool\Driver\Tag\DICOM\XRayImageReceptorAngle(),
                'RTImageOrientation' => new \PHPExiftool\Driver\Tag\DICOM\RTImageOrientation(),
                'ImagePlanePixelSpacing' => new \PHPExiftool\Driver\Tag\DICOM\ImagePlanePixelSpacing(),
                'RTImagePosition' => new \PHPExiftool\Driver\Tag\DICOM\RTImagePosition(),
                'RadiationMachineName' => new \PHPExiftool\Driver\Tag\DICOM\RadiationMachineName(),
                'RadiationMachineSAD' => new \PHPExiftool\Driver\Tag\DICOM\RadiationMachineSAD(),
                'RadiationMachineSSD' => new \PHPExiftool\Driver\Tag\DICOM\RadiationMachineSSD(),
                'RTImageSID' => new \PHPExiftool\Driver\Tag\DICOM\RTImageSID(),
                'SourceToReferenceObjectDistance' => new \PHPExiftool\Driver\Tag\DICOM\SourceToReferenceObjectDistance(),
                'FractionNumber' => new \PHPExiftool\Driver\Tag\DICOM\FractionNumber(),
                'ExposureSequence' => new \PHPExiftool\Driver\Tag\DICOM\ExposureSequence(),
                'MetersetExposure' => new \PHPExiftool\Driver\Tag\DICOM\MetersetExposure(),
                'DiaphragmPosition' => new \PHPExiftool\Driver\Tag\DICOM\DiaphragmPosition(),
                'FluenceMapSequence' => new \PHPExiftool\Driver\Tag\DICOM\FluenceMapSequence(),
                'FluenceDataSource' => new \PHPExiftool\Driver\Tag\DICOM\FluenceDataSource(),
                'FluenceDataScale' => new \PHPExiftool\Driver\Tag\DICOM\FluenceDataScale(),
                'FluenceMode' => new \PHPExiftool\Driver\Tag\DICOM\FluenceMode(),
                'FluenceModeID' => new \PHPExiftool\Driver\Tag\DICOM\FluenceModeID(),
                'DVHType' => new \PHPExiftool\Driver\Tag\DICOM\DVHType(),
                'DoseUnits' => new \PHPExiftool\Driver\Tag\DICOM\DoseUnits(),
                'DoseType' => new \PHPExiftool\Driver\Tag\DICOM\DoseType(),
                'DoseComment' => new \PHPExiftool\Driver\Tag\DICOM\DoseComment(),
                'NormalizationPoint' => new \PHPExiftool\Driver\Tag\DICOM\NormalizationPoint(),
                'DoseSummationType' => new \PHPExiftool\Driver\Tag\DICOM\DoseSummationType(),
                'GridFrameOffsetVector' => new \PHPExiftool\Driver\Tag\DICOM\GridFrameOffsetVector(),
                'DoseGridScaling' => new \PHPExiftool\Driver\Tag\DICOM\DoseGridScaling(),
                'RTDoseROISequence' => new \PHPExiftool\Driver\Tag\DICOM\RTDoseROISequence(),
                'DoseValue' => new \PHPExiftool\Driver\Tag\DICOM\DoseValue(),
                'TissueHeterogeneityCorrection' => new \PHPExiftool\Driver\Tag\DICOM\TissueHeterogeneityCorrection(),
                'DVHNormalizationPoint' => new \PHPExiftool\Driver\Tag\DICOM\DVHNormalizationPoint(),
                'DVHNormalizationDoseValue' => new \PHPExiftool\Driver\Tag\DICOM\DVHNormalizationDoseValue(),
                'DVHSequence' => new \PHPExiftool\Driver\Tag\DICOM\DVHSequence(),
                'DVHDoseScaling' => new \PHPExiftool\Driver\Tag\DICOM\DVHDoseScaling(),
                'DVHVolumeUnits' => new \PHPExiftool\Driver\Tag\DICOM\DVHVolumeUnits(),
                'DVHNumberOfBins' => new \PHPExiftool\Driver\Tag\DICOM\DVHNumberOfBins(),
                'DVHData' => new \PHPExiftool\Driver\Tag\DICOM\DVHData(),
                'DVHReferencedROISequence' => new \PHPExiftool\Driver\Tag\DICOM\DVHReferencedROISequence(),
                'DVHROIContributionType' => new \PHPExiftool\Driver\Tag\DICOM\DVHROIContributionType(),
                'DVHMinimumDose' => new \PHPExiftool\Driver\Tag\DICOM\DVHMinimumDose(),
                'DVHMaximumDose' => new \PHPExiftool\Driver\Tag\DICOM\DVHMaximumDose(),
                'DVHMeanDose' => new \PHPExiftool\Driver\Tag\DICOM\DVHMeanDose(),
                'StructureSetLabel' => new \PHPExiftool\Driver\Tag\DICOM\StructureSetLabel(),
                'StructureSetName' => new \PHPExiftool\Driver\Tag\DICOM\StructureSetName(),
                'StructureSetDescription' => new \PHPExiftool\Driver\Tag\DICOM\StructureSetDescription(),
                'StructureSetDate' => new \PHPExiftool\Driver\Tag\DICOM\StructureSetDate(),
                'StructureSetTime' => new \PHPExiftool\Driver\Tag\DICOM\StructureSetTime(),
                'ReferencedFrameOfReferenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFrameOfReferenceSequence(),
                'RTReferencedStudySequence' => new \PHPExiftool\Driver\Tag\DICOM\RTReferencedStudySequence(),
                'RTReferencedSeriesSequence' => new \PHPExiftool\Driver\Tag\DICOM\RTReferencedSeriesSequence(),
                'ContourImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContourImageSequence(),
                'StructureSetROISequence' => new \PHPExiftool\Driver\Tag\DICOM\StructureSetROISequence(),
                'ROINumber' => new \PHPExiftool\Driver\Tag\DICOM\ROINumber(),
                'ReferencedFrameOfReferenceUID' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFrameOfReferenceUID(),
                'ROIName' => new \PHPExiftool\Driver\Tag\DICOM\ROIName(),
                'ROIDescription' => new \PHPExiftool\Driver\Tag\DICOM\ROIDescription(),
                'ROIDisplayColor' => new \PHPExiftool\Driver\Tag\DICOM\ROIDisplayColor(),
                'ROIVolume' => new \PHPExiftool\Driver\Tag\DICOM\ROIVolume(),
                'RTRelatedROISequence' => new \PHPExiftool\Driver\Tag\DICOM\RTRelatedROISequence(),
                'RTROIRelationship' => new \PHPExiftool\Driver\Tag\DICOM\RTROIRelationship(),
                'ROIGenerationAlgorithm' => new \PHPExiftool\Driver\Tag\DICOM\ROIGenerationAlgorithm(),
                'ROIGenerationDescription' => new \PHPExiftool\Driver\Tag\DICOM\ROIGenerationDescription(),
                'ROIContourSequence' => new \PHPExiftool\Driver\Tag\DICOM\ROIContourSequence(),
                'ContourSequence' => new \PHPExiftool\Driver\Tag\DICOM\ContourSequence(),
                'ContourGeometricType' => new \PHPExiftool\Driver\Tag\DICOM\ContourGeometricType(),
                'ContourSlabThickness' => new \PHPExiftool\Driver\Tag\DICOM\ContourSlabThickness(),
                'ContourOffsetVector' => new \PHPExiftool\Driver\Tag\DICOM\ContourOffsetVector(),
                'NumberOfContourPoints' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfContourPoints(),
                'ContourNumber' => new \PHPExiftool\Driver\Tag\DICOM\ContourNumber(),
                'AttachedContours' => new \PHPExiftool\Driver\Tag\DICOM\AttachedContours(),
                'ContourData' => new \PHPExiftool\Driver\Tag\DICOM\ContourData(),
                'RTROIObservationsSequence' => new \PHPExiftool\Driver\Tag\DICOM\RTROIObservationsSequence(),
                'ObservationNumber' => new \PHPExiftool\Driver\Tag\DICOM\ObservationNumber(),
                'ReferencedROINumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedROINumber(),
                'ROIObservationLabel' => new \PHPExiftool\Driver\Tag\DICOM\ROIObservationLabel(),
                'RTROIIdentificationCodeSequence' => new \PHPExiftool\Driver\Tag\DICOM\RTROIIdentificationCodeSequence(),
                'ROIObservationDescription' => new \PHPExiftool\Driver\Tag\DICOM\ROIObservationDescription(),
                'RelatedRTROIObservationsSequence' => new \PHPExiftool\Driver\Tag\DICOM\RelatedRTROIObservationsSequence(),
                'RTROIInterpretedType' => new \PHPExiftool\Driver\Tag\DICOM\RTROIInterpretedType(),
                'ROIInterpreter' => new \PHPExiftool\Driver\Tag\DICOM\ROIInterpreter(),
                'ROIPhysicalPropertiesSequence' => new \PHPExiftool\Driver\Tag\DICOM\ROIPhysicalPropertiesSequence(),
                'ROIPhysicalProperty' => new \PHPExiftool\Driver\Tag\DICOM\ROIPhysicalProperty(),
                'ROIPhysicalPropertyValue' => new \PHPExiftool\Driver\Tag\DICOM\ROIPhysicalPropertyValue(),
                'ROIElementalCompositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\ROIElementalCompositionSequence(),
                'ROIElementalCompAtomicNumber' => new \PHPExiftool\Driver\Tag\DICOM\ROIElementalCompAtomicNumber(),
                'ROIElementalCompAtomicMassFraction' => new \PHPExiftool\Driver\Tag\DICOM\ROIElementalCompAtomicMassFraction(),
                'FrameOfReferenceRelationshipSeq' => new \PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceRelationshipSeq(),
                'RelatedFrameOfReferenceUID' => new \PHPExiftool\Driver\Tag\DICOM\RelatedFrameOfReferenceUID(),
                'FrameOfReferenceTransformType' => new \PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceTransformType(),
                'FrameOfReferenceTransformMatrix' => new \PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceTransformMatrix(),
                'FrameOfReferenceTransformComment' => new \PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceTransformComment(),
                'MeasuredDoseReferenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\MeasuredDoseReferenceSequence(),
                'MeasuredDoseDescription' => new \PHPExiftool\Driver\Tag\DICOM\MeasuredDoseDescription(),
                'MeasuredDoseType' => new \PHPExiftool\Driver\Tag\DICOM\MeasuredDoseType(),
                'MeasuredDoseValue' => new \PHPExiftool\Driver\Tag\DICOM\MeasuredDoseValue(),
                'TreatmentSessionBeamSequence' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentSessionBeamSequence(),
                'TreatmentSessionIonBeamSequence' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentSessionIonBeamSequence(),
                'CurrentFractionNumber' => new \PHPExiftool\Driver\Tag\DICOM\CurrentFractionNumber(),
                'TreatmentControlPointDate' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentControlPointDate(),
                'TreatmentControlPointTime' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentControlPointTime(),
                'TreatmentTerminationStatus' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentTerminationStatus(),
                'TreatmentTerminationCode' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentTerminationCode(),
                'TreatmentVerificationStatus' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentVerificationStatus(),
                'ReferencedTreatmentRecordSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedTreatmentRecordSequence(),
                'SpecifiedPrimaryMeterset' => new \PHPExiftool\Driver\Tag\DICOM\SpecifiedPrimaryMeterset(),
                'SpecifiedSecondaryMeterset' => new \PHPExiftool\Driver\Tag\DICOM\SpecifiedSecondaryMeterset(),
                'DeliveredPrimaryMeterset' => new \PHPExiftool\Driver\Tag\DICOM\DeliveredPrimaryMeterset(),
                'DeliveredSecondaryMeterset' => new \PHPExiftool\Driver\Tag\DICOM\DeliveredSecondaryMeterset(),
                'SpecifiedTreatmentTime' => new \PHPExiftool\Driver\Tag\DICOM\SpecifiedTreatmentTime(),
                'DeliveredTreatmentTime' => new \PHPExiftool\Driver\Tag\DICOM\DeliveredTreatmentTime(),
                'ControlPointDeliverySequence' => new \PHPExiftool\Driver\Tag\DICOM\ControlPointDeliverySequence(),
                'IonControlPointDeliverySequence' => new \PHPExiftool\Driver\Tag\DICOM\IonControlPointDeliverySequence(),
                'SpecifiedMeterset' => new \PHPExiftool\Driver\Tag\DICOM\SpecifiedMeterset(),
                'DeliveredMeterset' => new \PHPExiftool\Driver\Tag\DICOM\DeliveredMeterset(),
                'MetersetRateSet' => new \PHPExiftool\Driver\Tag\DICOM\MetersetRateSet(),
                'MetersetRateDelivered' => new \PHPExiftool\Driver\Tag\DICOM\MetersetRateDelivered(),
                'ScanSpotMetersetsDelivered' => new \PHPExiftool\Driver\Tag\DICOM\ScanSpotMetersetsDelivered(),
                'DoseRateDelivered' => new \PHPExiftool\Driver\Tag\DICOM\DoseRateDelivered(),
                'TreatmentSummaryCalcDoseRefSeq' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentSummaryCalcDoseRefSeq(),
                'CumulativeDoseToDoseReference' => new \PHPExiftool\Driver\Tag\DICOM\CumulativeDoseToDoseReference(),
                'FirstTreatmentDate' => new \PHPExiftool\Driver\Tag\DICOM\FirstTreatmentDate(),
                'MostRecentTreatmentDate' => new \PHPExiftool\Driver\Tag\DICOM\MostRecentTreatmentDate(),
                'NumberOfFractionsDelivered' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfFractionsDelivered(),
                'OverrideSequence' => new \PHPExiftool\Driver\Tag\DICOM\OverrideSequence(),
                'ParameterSequencePointer' => new \PHPExiftool\Driver\Tag\DICOM\ParameterSequencePointer(),
                'OverrideParameterPointer' => new \PHPExiftool\Driver\Tag\DICOM\OverrideParameterPointer(),
                'ParameterItemIndex' => new \PHPExiftool\Driver\Tag\DICOM\ParameterItemIndex(),
                'MeasuredDoseReferenceNumber' => new \PHPExiftool\Driver\Tag\DICOM\MeasuredDoseReferenceNumber(),
                'ParameterPointer' => new \PHPExiftool\Driver\Tag\DICOM\ParameterPointer(),
                'OverrideReason' => new \PHPExiftool\Driver\Tag\DICOM\OverrideReason(),
                'CorrectedParameterSequence' => new \PHPExiftool\Driver\Tag\DICOM\CorrectedParameterSequence(),
                'CorrectionValue' => new \PHPExiftool\Driver\Tag\DICOM\CorrectionValue(),
                'CalculatedDoseReferenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\CalculatedDoseReferenceSequence(),
                'CalculatedDoseReferenceNumber' => new \PHPExiftool\Driver\Tag\DICOM\CalculatedDoseReferenceNumber(),
                'CalculatedDoseReferenceDescription' => new \PHPExiftool\Driver\Tag\DICOM\CalculatedDoseReferenceDescription(),
                'CalculatedDoseReferenceDoseValue' => new \PHPExiftool\Driver\Tag\DICOM\CalculatedDoseReferenceDoseValue(),
                'StartMeterset' => new \PHPExiftool\Driver\Tag\DICOM\StartMeterset(),
                'EndMeterset' => new \PHPExiftool\Driver\Tag\DICOM\EndMeterset(),
                'ReferencedMeasuredDoseReferenceSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedMeasuredDoseReferenceSeq(),
                'ReferencedMeasuredDoseReferenceNum' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedMeasuredDoseReferenceNum(),
                'ReferencedCalculatedDoseRefSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedCalculatedDoseRefSeq(),
                'ReferencedCalculatedDoseRefNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedCalculatedDoseRefNumber(),
                'BeamLimitingDeviceLeafPairsSeq' => new \PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceLeafPairsSeq(),
                'RecordedWedgeSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedWedgeSequence(),
                'RecordedCompensatorSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedCompensatorSequence(),
                'RecordedBlockSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedBlockSequence(),
                'TreatmentSummaryMeasuredDoseRefSeq' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentSummaryMeasuredDoseRefSeq(),
                'RecordedSnoutSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedSnoutSequence(),
                'RecordedRangeShifterSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedRangeShifterSequence(),
                'RecordedLateralSpreadingDeviceSeq' => new \PHPExiftool\Driver\Tag\DICOM\RecordedLateralSpreadingDeviceSeq(),
                'RecordedRangeModulatorSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedRangeModulatorSequence(),
                'RecordedSourceSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedSourceSequence(),
                'SourceSerialNumber' => new \PHPExiftool\Driver\Tag\DICOM\SourceSerialNumber(),
                'TreatmentSessionAppSetupSeq' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentSessionAppSetupSeq(),
                'ApplicationSetupCheck' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationSetupCheck(),
                'RecordedBrachyAccessoryDeviceSeq' => new \PHPExiftool\Driver\Tag\DICOM\RecordedBrachyAccessoryDeviceSeq(),
                'ReferencedBrachyAccessoryDeviceNum' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedBrachyAccessoryDeviceNum(),
                'RecordedChannelSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedChannelSequence(),
                'SpecifiedChannelTotalTime' => new \PHPExiftool\Driver\Tag\DICOM\SpecifiedChannelTotalTime(),
                'DeliveredChannelTotalTime' => new \PHPExiftool\Driver\Tag\DICOM\DeliveredChannelTotalTime(),
                'SpecifiedNumberOfPulses' => new \PHPExiftool\Driver\Tag\DICOM\SpecifiedNumberOfPulses(),
                'DeliveredNumberOfPulses' => new \PHPExiftool\Driver\Tag\DICOM\DeliveredNumberOfPulses(),
                'SpecifiedPulseRepetitionInterval' => new \PHPExiftool\Driver\Tag\DICOM\SpecifiedPulseRepetitionInterval(),
                'DeliveredPulseRepetitionInterval' => new \PHPExiftool\Driver\Tag\DICOM\DeliveredPulseRepetitionInterval(),
                'RecordedSourceApplicatorSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedSourceApplicatorSequence(),
                'ReferencedSourceApplicatorNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSourceApplicatorNumber(),
                'RecordedChannelShieldSequence' => new \PHPExiftool\Driver\Tag\DICOM\RecordedChannelShieldSequence(),
                'ReferencedChannelShieldNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedChannelShieldNumber(),
                'BrachyControlPointDeliveredSeq' => new \PHPExiftool\Driver\Tag\DICOM\BrachyControlPointDeliveredSeq(),
                'SafePositionExitDate' => new \PHPExiftool\Driver\Tag\DICOM\SafePositionExitDate(),
                'SafePositionExitTime' => new \PHPExiftool\Driver\Tag\DICOM\SafePositionExitTime(),
                'SafePositionReturnDate' => new \PHPExiftool\Driver\Tag\DICOM\SafePositionReturnDate(),
                'SafePositionReturnTime' => new \PHPExiftool\Driver\Tag\DICOM\SafePositionReturnTime(),
                'CurrentTreatmentStatus' => new \PHPExiftool\Driver\Tag\DICOM\CurrentTreatmentStatus(),
                'TreatmentStatusComment' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentStatusComment(),
                'FractionGroupSummarySequence' => new \PHPExiftool\Driver\Tag\DICOM\FractionGroupSummarySequence(),
                'ReferencedFractionNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFractionNumber(),
                'FractionGroupType' => new \PHPExiftool\Driver\Tag\DICOM\FractionGroupType(),
                'BeamStopperPosition' => new \PHPExiftool\Driver\Tag\DICOM\BeamStopperPosition(),
                'FractionStatusSummarySequence' => new \PHPExiftool\Driver\Tag\DICOM\FractionStatusSummarySequence(),
                'TreatmentDate' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentDate(),
                'TreatmentTime' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentTime(),
                'RTPlanLabel' => new \PHPExiftool\Driver\Tag\DICOM\RTPlanLabel(),
                'RTPlanName' => new \PHPExiftool\Driver\Tag\DICOM\RTPlanName(),
                'RTPlanDescription' => new \PHPExiftool\Driver\Tag\DICOM\RTPlanDescription(),
                'RTPlanDate' => new \PHPExiftool\Driver\Tag\DICOM\RTPlanDate(),
                'RTPlanTime' => new \PHPExiftool\Driver\Tag\DICOM\RTPlanTime(),
                'TreatmentProtocols' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentProtocols(),
                'PlanIntent' => new \PHPExiftool\Driver\Tag\DICOM\PlanIntent(),
                'TreatmentSites' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentSites(),
                'RTPlanGeometry' => new \PHPExiftool\Driver\Tag\DICOM\RTPlanGeometry(),
                'PrescriptionDescription' => new \PHPExiftool\Driver\Tag\DICOM\PrescriptionDescription(),
                'DoseReferenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\DoseReferenceSequence(),
                'DoseReferenceNumber' => new \PHPExiftool\Driver\Tag\DICOM\DoseReferenceNumber(),
                'DoseReferenceUID' => new \PHPExiftool\Driver\Tag\DICOM\DoseReferenceUID(),
                'DoseReferenceStructureType' => new \PHPExiftool\Driver\Tag\DICOM\DoseReferenceStructureType(),
                'NominalBeamEnergyUnit' => new \PHPExiftool\Driver\Tag\DICOM\NominalBeamEnergyUnit(),
                'DoseReferenceDescription' => new \PHPExiftool\Driver\Tag\DICOM\DoseReferenceDescription(),
                'DoseReferencePointCoordinates' => new \PHPExiftool\Driver\Tag\DICOM\DoseReferencePointCoordinates(),
                'NominalPriorDose' => new \PHPExiftool\Driver\Tag\DICOM\NominalPriorDose(),
                'DoseReferenceType' => new \PHPExiftool\Driver\Tag\DICOM\DoseReferenceType(),
                'ConstraintWeight' => new \PHPExiftool\Driver\Tag\DICOM\ConstraintWeight(),
                'DeliveryWarningDose' => new \PHPExiftool\Driver\Tag\DICOM\DeliveryWarningDose(),
                'DeliveryMaximumDose' => new \PHPExiftool\Driver\Tag\DICOM\DeliveryMaximumDose(),
                'TargetMinimumDose' => new \PHPExiftool\Driver\Tag\DICOM\TargetMinimumDose(),
                'TargetPrescriptionDose' => new \PHPExiftool\Driver\Tag\DICOM\TargetPrescriptionDose(),
                'TargetMaximumDose' => new \PHPExiftool\Driver\Tag\DICOM\TargetMaximumDose(),
                'TargetUnderdoseVolumeFraction' => new \PHPExiftool\Driver\Tag\DICOM\TargetUnderdoseVolumeFraction(),
                'OrganAtRiskFullVolumeDose' => new \PHPExiftool\Driver\Tag\DICOM\OrganAtRiskFullVolumeDose(),
                'OrganAtRiskLimitDose' => new \PHPExiftool\Driver\Tag\DICOM\OrganAtRiskLimitDose(),
                'OrganAtRiskMaximumDose' => new \PHPExiftool\Driver\Tag\DICOM\OrganAtRiskMaximumDose(),
                'OrganAtRiskOverdoseVolumeFraction' => new \PHPExiftool\Driver\Tag\DICOM\OrganAtRiskOverdoseVolumeFraction(),
                'ToleranceTableSequence' => new \PHPExiftool\Driver\Tag\DICOM\ToleranceTableSequence(),
                'ToleranceTableNumber' => new \PHPExiftool\Driver\Tag\DICOM\ToleranceTableNumber(),
                'ToleranceTableLabel' => new \PHPExiftool\Driver\Tag\DICOM\ToleranceTableLabel(),
                'GantryAngleTolerance' => new \PHPExiftool\Driver\Tag\DICOM\GantryAngleTolerance(),
                'BeamLimitingDeviceAngleTolerance' => new \PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceAngleTolerance(),
                'BeamLimitingDeviceToleranceSeq' => new \PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceToleranceSeq(),
                'BeamLimitingDevicePositionTol' => new \PHPExiftool\Driver\Tag\DICOM\BeamLimitingDevicePositionTol(),
                'SnoutPositionTolerance' => new \PHPExiftool\Driver\Tag\DICOM\SnoutPositionTolerance(),
                'PatientSupportAngleTolerance' => new \PHPExiftool\Driver\Tag\DICOM\PatientSupportAngleTolerance(),
                'TableTopEccentricAngleTolerance' => new \PHPExiftool\Driver\Tag\DICOM\TableTopEccentricAngleTolerance(),
                'TableTopPitchAngleTolerance' => new \PHPExiftool\Driver\Tag\DICOM\TableTopPitchAngleTolerance(),
                'TableTopRollAngleTolerance' => new \PHPExiftool\Driver\Tag\DICOM\TableTopRollAngleTolerance(),
                'TableTopVerticalPositionTolerance' => new \PHPExiftool\Driver\Tag\DICOM\TableTopVerticalPositionTolerance(),
                'TableTopLongitudinalPositionTol' => new \PHPExiftool\Driver\Tag\DICOM\TableTopLongitudinalPositionTol(),
                'TableTopLateralPositionTolerance' => new \PHPExiftool\Driver\Tag\DICOM\TableTopLateralPositionTolerance(),
                'RTPlanRelationship' => new \PHPExiftool\Driver\Tag\DICOM\RTPlanRelationship(),
                'FractionGroupSequence' => new \PHPExiftool\Driver\Tag\DICOM\FractionGroupSequence(),
                'FractionGroupNumber' => new \PHPExiftool\Driver\Tag\DICOM\FractionGroupNumber(),
                'FractionGroupDescription' => new \PHPExiftool\Driver\Tag\DICOM\FractionGroupDescription(),
                'NumberOfFractionsPlanned' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfFractionsPlanned(),
                'NumberFractionPatternDigitsPerDay' => new \PHPExiftool\Driver\Tag\DICOM\NumberFractionPatternDigitsPerDay(),
                'RepeatFractionCycleLength' => new \PHPExiftool\Driver\Tag\DICOM\RepeatFractionCycleLength(),
                'FractionPattern' => new \PHPExiftool\Driver\Tag\DICOM\FractionPattern(),
                'NumberOfBeams' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfBeams(),
                'BeamDoseSpecificationPoint' => new \PHPExiftool\Driver\Tag\DICOM\BeamDoseSpecificationPoint(),
                'BeamDose' => new \PHPExiftool\Driver\Tag\DICOM\BeamDose(),
                'BeamMeterset' => new \PHPExiftool\Driver\Tag\DICOM\BeamMeterset(),
                'BeamDosePointDepth' => new \PHPExiftool\Driver\Tag\DICOM\BeamDosePointDepth(),
                'BeamDosePointEquivalentDepth' => new \PHPExiftool\Driver\Tag\DICOM\BeamDosePointEquivalentDepth(),
                'BeamDosePointSSD' => new \PHPExiftool\Driver\Tag\DICOM\BeamDosePointSSD(),
                'NumberOfBrachyApplicationSetups' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfBrachyApplicationSetups(),
                'BrachyAppSetupDoseSpecPoint' => new \PHPExiftool\Driver\Tag\DICOM\BrachyAppSetupDoseSpecPoint(),
                'BrachyApplicationSetupDose' => new \PHPExiftool\Driver\Tag\DICOM\BrachyApplicationSetupDose(),
                'BeamSequence' => new \PHPExiftool\Driver\Tag\DICOM\BeamSequence(),
                'TreatmentMachineName' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentMachineName(),
                'PrimaryDosimeterUnit' => new \PHPExiftool\Driver\Tag\DICOM\PrimaryDosimeterUnit(),
                'SourceAxisDistance' => new \PHPExiftool\Driver\Tag\DICOM\SourceAxisDistance(),
                'BeamLimitingDeviceSequence' => new \PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceSequence(),
                'RTBeamLimitingDeviceType' => new \PHPExiftool\Driver\Tag\DICOM\RTBeamLimitingDeviceType(),
                'SourceToBeamLimitingDeviceDistance' => new \PHPExiftool\Driver\Tag\DICOM\SourceToBeamLimitingDeviceDistance(),
                'IsocenterToBeamLimitingDeviceDist' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterToBeamLimitingDeviceDist(),
                'NumberOfLeafJawPairs' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfLeafJawPairs(),
                'LeafPositionBoundaries' => new \PHPExiftool\Driver\Tag\DICOM\LeafPositionBoundaries(),
                'BeamNumber' => new \PHPExiftool\Driver\Tag\DICOM\BeamNumber(),
                'BeamName' => new \PHPExiftool\Driver\Tag\DICOM\BeamName(),
                'BeamDescription' => new \PHPExiftool\Driver\Tag\DICOM\BeamDescription(),
                'BeamType' => new \PHPExiftool\Driver\Tag\DICOM\BeamType(),
                'RadiationType' => new \PHPExiftool\Driver\Tag\DICOM\RadiationType(),
                'HighDoseTechniqueType' => new \PHPExiftool\Driver\Tag\DICOM\HighDoseTechniqueType(),
                'ReferenceImageNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferenceImageNumber(),
                'PlannedVerificationImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\PlannedVerificationImageSequence(),
                'ImagingDeviceSpecificAcqParams' => new \PHPExiftool\Driver\Tag\DICOM\ImagingDeviceSpecificAcqParams(),
                'TreatmentDeliveryType' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentDeliveryType(),
                'NumberOfWedges' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfWedges(),
                'WedgeSequence' => new \PHPExiftool\Driver\Tag\DICOM\WedgeSequence(),
                'WedgeNumber' => new \PHPExiftool\Driver\Tag\DICOM\WedgeNumber(),
                'WedgeType' => new \PHPExiftool\Driver\Tag\DICOM\WedgeType(),
                'WedgeID' => new \PHPExiftool\Driver\Tag\DICOM\WedgeID(),
                'WedgeAngle' => new \PHPExiftool\Driver\Tag\DICOM\WedgeAngle(),
                'WedgeFactor' => new \PHPExiftool\Driver\Tag\DICOM\WedgeFactor(),
                'TotalWedgeTrayWaterEquivThickness' => new \PHPExiftool\Driver\Tag\DICOM\TotalWedgeTrayWaterEquivThickness(),
                'WedgeOrientation' => new \PHPExiftool\Driver\Tag\DICOM\WedgeOrientation(),
                'IsocenterToWedgeTrayDistance' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterToWedgeTrayDistance(),
                'SourceToWedgeTrayDistance' => new \PHPExiftool\Driver\Tag\DICOM\SourceToWedgeTrayDistance(),
                'WedgeThinEdgePosition' => new \PHPExiftool\Driver\Tag\DICOM\WedgeThinEdgePosition(),
                'BolusID' => new \PHPExiftool\Driver\Tag\DICOM\BolusID(),
                'BolusDescription' => new \PHPExiftool\Driver\Tag\DICOM\BolusDescription(),
                'NumberOfCompensators' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfCompensators(),
                'MaterialID' => new \PHPExiftool\Driver\Tag\DICOM\MaterialID(),
                'TotalCompensatorTrayFactor' => new \PHPExiftool\Driver\Tag\DICOM\TotalCompensatorTrayFactor(),
                'CompensatorSequence' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorSequence(),
                'CompensatorNumber' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorNumber(),
                'CompensatorID' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorID(),
                'SourceToCompensatorTrayDistance' => new \PHPExiftool\Driver\Tag\DICOM\SourceToCompensatorTrayDistance(),
                'CompensatorRows' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorRows(),
                'CompensatorColumns' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorColumns(),
                'CompensatorPixelSpacing' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorPixelSpacing(),
                'CompensatorPosition' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorPosition(),
                'CompensatorTransmissionData' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorTransmissionData(),
                'CompensatorThicknessData' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorThicknessData(),
                'NumberOfBoli' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfBoli(),
                'CompensatorType' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorType(),
                'NumberOfBlocks' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfBlocks(),
                'TotalBlockTrayFactor' => new \PHPExiftool\Driver\Tag\DICOM\TotalBlockTrayFactor(),
                'TotalBlockTrayWaterEquivThickness' => new \PHPExiftool\Driver\Tag\DICOM\TotalBlockTrayWaterEquivThickness(),
                'BlockSequence' => new \PHPExiftool\Driver\Tag\DICOM\BlockSequence(),
                'BlockTrayID' => new \PHPExiftool\Driver\Tag\DICOM\BlockTrayID(),
                'SourceToBlockTrayDistance' => new \PHPExiftool\Driver\Tag\DICOM\SourceToBlockTrayDistance(),
                'IsocenterToBlockTrayDistance' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterToBlockTrayDistance(),
                'BlockType' => new \PHPExiftool\Driver\Tag\DICOM\BlockType(),
                'AccessoryCode' => new \PHPExiftool\Driver\Tag\DICOM\AccessoryCode(),
                'BlockDivergence' => new \PHPExiftool\Driver\Tag\DICOM\BlockDivergence(),
                'BlockMountingPosition' => new \PHPExiftool\Driver\Tag\DICOM\BlockMountingPosition(),
                'BlockNumber' => new \PHPExiftool\Driver\Tag\DICOM\BlockNumber(),
                'BlockName' => new \PHPExiftool\Driver\Tag\DICOM\BlockName(),
                'BlockThickness' => new \PHPExiftool\Driver\Tag\DICOM\BlockThickness(),
                'BlockTransmission' => new \PHPExiftool\Driver\Tag\DICOM\BlockTransmission(),
                'BlockNumberOfPoints' => new \PHPExiftool\Driver\Tag\DICOM\BlockNumberOfPoints(),
                'BlockData' => new \PHPExiftool\Driver\Tag\DICOM\BlockData(),
                'ApplicatorSequence' => new \PHPExiftool\Driver\Tag\DICOM\ApplicatorSequence(),
                'ApplicatorID' => new \PHPExiftool\Driver\Tag\DICOM\ApplicatorID(),
                'ApplicatorType' => new \PHPExiftool\Driver\Tag\DICOM\ApplicatorType(),
                'ApplicatorDescription' => new \PHPExiftool\Driver\Tag\DICOM\ApplicatorDescription(),
                'CumulativeDoseReferenceCoefficient' => new \PHPExiftool\Driver\Tag\DICOM\CumulativeDoseReferenceCoefficient(),
                'FinalCumulativeMetersetWeight' => new \PHPExiftool\Driver\Tag\DICOM\FinalCumulativeMetersetWeight(),
                'NumberOfControlPoints' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfControlPoints(),
                'ControlPointSequence' => new \PHPExiftool\Driver\Tag\DICOM\ControlPointSequence(),
                'ControlPointIndex' => new \PHPExiftool\Driver\Tag\DICOM\ControlPointIndex(),
                'NominalBeamEnergy' => new \PHPExiftool\Driver\Tag\DICOM\NominalBeamEnergy(),
                'DoseRateSet' => new \PHPExiftool\Driver\Tag\DICOM\DoseRateSet(),
                'WedgePositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\WedgePositionSequence(),
                'WedgePosition' => new \PHPExiftool\Driver\Tag\DICOM\WedgePosition(),
                'BeamLimitingDevicePositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\BeamLimitingDevicePositionSequence(),
                'LeafJawPositions' => new \PHPExiftool\Driver\Tag\DICOM\LeafJawPositions(),
                'GantryAngle' => new \PHPExiftool\Driver\Tag\DICOM\GantryAngle(),
                'GantryRotationDirection' => new \PHPExiftool\Driver\Tag\DICOM\GantryRotationDirection(),
                'BeamLimitingDeviceAngle' => new \PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceAngle(),
                'BeamLimitingDeviceRotateDirection' => new \PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceRotateDirection(),
                'PatientSupportAngle' => new \PHPExiftool\Driver\Tag\DICOM\PatientSupportAngle(),
                'PatientSupportRotationDirection' => new \PHPExiftool\Driver\Tag\DICOM\PatientSupportRotationDirection(),
                'TableTopEccentricAxisDistance' => new \PHPExiftool\Driver\Tag\DICOM\TableTopEccentricAxisDistance(),
                'TableTopEccentricAngle' => new \PHPExiftool\Driver\Tag\DICOM\TableTopEccentricAngle(),
                'TableTopEccentricRotateDirection' => new \PHPExiftool\Driver\Tag\DICOM\TableTopEccentricRotateDirection(),
                'TableTopVerticalPosition' => new \PHPExiftool\Driver\Tag\DICOM\TableTopVerticalPosition(),
                'TableTopLongitudinalPosition' => new \PHPExiftool\Driver\Tag\DICOM\TableTopLongitudinalPosition(),
                'TableTopLateralPosition' => new \PHPExiftool\Driver\Tag\DICOM\TableTopLateralPosition(),
                'IsocenterPosition' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterPosition(),
                'SurfaceEntryPoint' => new \PHPExiftool\Driver\Tag\DICOM\SurfaceEntryPoint(),
                'SourceToSurfaceDistance' => new \PHPExiftool\Driver\Tag\DICOM\SourceToSurfaceDistance(),
                'CumulativeMetersetWeight' => new \PHPExiftool\Driver\Tag\DICOM\CumulativeMetersetWeight(),
                'TableTopPitchAngle' => new \PHPExiftool\Driver\Tag\DICOM\TableTopPitchAngle(),
                'TableTopPitchRotationDirection' => new \PHPExiftool\Driver\Tag\DICOM\TableTopPitchRotationDirection(),
                'TableTopRollAngle' => new \PHPExiftool\Driver\Tag\DICOM\TableTopRollAngle(),
                'TableTopRollRotationDirection' => new \PHPExiftool\Driver\Tag\DICOM\TableTopRollRotationDirection(),
                'HeadFixationAngle' => new \PHPExiftool\Driver\Tag\DICOM\HeadFixationAngle(),
                'GantryPitchAngle' => new \PHPExiftool\Driver\Tag\DICOM\GantryPitchAngle(),
                'GantryPitchRotationDirection' => new \PHPExiftool\Driver\Tag\DICOM\GantryPitchRotationDirection(),
                'GantryPitchAngleTolerance' => new \PHPExiftool\Driver\Tag\DICOM\GantryPitchAngleTolerance(),
                'PatientSetupSequence' => new \PHPExiftool\Driver\Tag\DICOM\PatientSetupSequence(),
                'PatientSetupNumber' => new \PHPExiftool\Driver\Tag\DICOM\PatientSetupNumber(),
                'PatientSetupLabel' => new \PHPExiftool\Driver\Tag\DICOM\PatientSetupLabel(),
                'PatientAdditionalPosition' => new \PHPExiftool\Driver\Tag\DICOM\PatientAdditionalPosition(),
                'FixationDeviceSequence' => new \PHPExiftool\Driver\Tag\DICOM\FixationDeviceSequence(),
                'FixationDeviceType' => new \PHPExiftool\Driver\Tag\DICOM\FixationDeviceType(),
                'FixationDeviceLabel' => new \PHPExiftool\Driver\Tag\DICOM\FixationDeviceLabel(),
                'FixationDeviceDescription' => new \PHPExiftool\Driver\Tag\DICOM\FixationDeviceDescription(),
                'FixationDevicePosition' => new \PHPExiftool\Driver\Tag\DICOM\FixationDevicePosition(),
                'FixationDevicePitchAngle' => new \PHPExiftool\Driver\Tag\DICOM\FixationDevicePitchAngle(),
                'FixationDeviceRollAngle' => new \PHPExiftool\Driver\Tag\DICOM\FixationDeviceRollAngle(),
                'ShieldingDeviceSequence' => new \PHPExiftool\Driver\Tag\DICOM\ShieldingDeviceSequence(),
                'ShieldingDeviceType' => new \PHPExiftool\Driver\Tag\DICOM\ShieldingDeviceType(),
                'ShieldingDeviceLabel' => new \PHPExiftool\Driver\Tag\DICOM\ShieldingDeviceLabel(),
                'ShieldingDeviceDescription' => new \PHPExiftool\Driver\Tag\DICOM\ShieldingDeviceDescription(),
                'ShieldingDevicePosition' => new \PHPExiftool\Driver\Tag\DICOM\ShieldingDevicePosition(),
                'SetupTechnique' => new \PHPExiftool\Driver\Tag\DICOM\SetupTechnique(),
                'SetupTechniqueDescription' => new \PHPExiftool\Driver\Tag\DICOM\SetupTechniqueDescription(),
                'SetupDeviceSequence' => new \PHPExiftool\Driver\Tag\DICOM\SetupDeviceSequence(),
                'SetupDeviceType' => new \PHPExiftool\Driver\Tag\DICOM\SetupDeviceType(),
                'SetupDeviceLabel' => new \PHPExiftool\Driver\Tag\DICOM\SetupDeviceLabel(),
                'SetupDeviceDescription' => new \PHPExiftool\Driver\Tag\DICOM\SetupDeviceDescription(),
                'SetupDeviceParameter' => new \PHPExiftool\Driver\Tag\DICOM\SetupDeviceParameter(),
                'SetupReferenceDescription' => new \PHPExiftool\Driver\Tag\DICOM\SetupReferenceDescription(),
                'TableTopVerticalSetupDisplacement' => new \PHPExiftool\Driver\Tag\DICOM\TableTopVerticalSetupDisplacement(),
                'TableTopLongitudinalSetupDisplace' => new \PHPExiftool\Driver\Tag\DICOM\TableTopLongitudinalSetupDisplace(),
                'TableTopLateralSetupDisplacement' => new \PHPExiftool\Driver\Tag\DICOM\TableTopLateralSetupDisplacement(),
                'BrachyTreatmentTechnique' => new \PHPExiftool\Driver\Tag\DICOM\BrachyTreatmentTechnique(),
                'BrachyTreatmentType' => new \PHPExiftool\Driver\Tag\DICOM\BrachyTreatmentType(),
                'TreatmentMachineSequence' => new \PHPExiftool\Driver\Tag\DICOM\TreatmentMachineSequence(),
                'SourceSequence' => new \PHPExiftool\Driver\Tag\DICOM\SourceSequence(),
                'SourceNumber' => new \PHPExiftool\Driver\Tag\DICOM\SourceNumber(),
                'SourceType' => new \PHPExiftool\Driver\Tag\DICOM\SourceType(),
                'SourceManufacturer' => new \PHPExiftool\Driver\Tag\DICOM\SourceManufacturer(),
                'ActiveSourceDiameter' => new \PHPExiftool\Driver\Tag\DICOM\ActiveSourceDiameter(),
                'ActiveSourceLength' => new \PHPExiftool\Driver\Tag\DICOM\ActiveSourceLength(),
                'SourceEncapsulationNomThickness' => new \PHPExiftool\Driver\Tag\DICOM\SourceEncapsulationNomThickness(),
                'SourceEncapsulationNomTransmission' => new \PHPExiftool\Driver\Tag\DICOM\SourceEncapsulationNomTransmission(),
                'SourceIsotopeName' => new \PHPExiftool\Driver\Tag\DICOM\SourceIsotopeName(),
                'SourceIsotopeHalfLife' => new \PHPExiftool\Driver\Tag\DICOM\SourceIsotopeHalfLife(),
                'SourceStrengthUnits' => new \PHPExiftool\Driver\Tag\DICOM\SourceStrengthUnits(),
                'ReferenceAirKermaRate' => new \PHPExiftool\Driver\Tag\DICOM\ReferenceAirKermaRate(),
                'SourceStrength' => new \PHPExiftool\Driver\Tag\DICOM\SourceStrength(),
                'SourceStrengthReferenceDate' => new \PHPExiftool\Driver\Tag\DICOM\SourceStrengthReferenceDate(),
                'SourceStrengthReferenceTime' => new \PHPExiftool\Driver\Tag\DICOM\SourceStrengthReferenceTime(),
                'ApplicationSetupSequence' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationSetupSequence(),
                'ApplicationSetupType' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationSetupType(),
                'ApplicationSetupNumber' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationSetupNumber(),
                'ApplicationSetupName' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationSetupName(),
                'ApplicationSetupManufacturer' => new \PHPExiftool\Driver\Tag\DICOM\ApplicationSetupManufacturer(),
                'TemplateNumber' => new \PHPExiftool\Driver\Tag\DICOM\TemplateNumber(),
                'TemplateType' => new \PHPExiftool\Driver\Tag\DICOM\TemplateType(),
                'TemplateName' => new \PHPExiftool\Driver\Tag\DICOM\TemplateName(),
                'TotalReferenceAirKerma' => new \PHPExiftool\Driver\Tag\DICOM\TotalReferenceAirKerma(),
                'BrachyAccessoryDeviceSequence' => new \PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceSequence(),
                'BrachyAccessoryDeviceNumber' => new \PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceNumber(),
                'BrachyAccessoryDeviceID' => new \PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceID(),
                'BrachyAccessoryDeviceType' => new \PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceType(),
                'BrachyAccessoryDeviceName' => new \PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceName(),
                'BrachyAccessoryDeviceNomThickness' => new \PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceNomThickness(),
                'BrachyAccessoryDevNomTransmission' => new \PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDevNomTransmission(),
                'ChannelSequence' => new \PHPExiftool\Driver\Tag\DICOM\ChannelSequence(),
                'ChannelNumber' => new \PHPExiftool\Driver\Tag\DICOM\ChannelNumber(),
                'ChannelLength' => new \PHPExiftool\Driver\Tag\DICOM\ChannelLength(),
                'ChannelTotalTime' => new \PHPExiftool\Driver\Tag\DICOM\ChannelTotalTime(),
                'SourceMovementType' => new \PHPExiftool\Driver\Tag\DICOM\SourceMovementType(),
                'NumberOfPulses' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPulses(),
                'PulseRepetitionInterval' => new \PHPExiftool\Driver\Tag\DICOM\PulseRepetitionInterval(),
                'SourceApplicatorNumber' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorNumber(),
                'SourceApplicatorID' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorID(),
                'SourceApplicatorType' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorType(),
                'SourceApplicatorName' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorName(),
                'SourceApplicatorLength' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorLength(),
                'SourceApplicatorManufacturer' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorManufacturer(),
                'SourceApplicatorWallNomThickness' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorWallNomThickness(),
                'SourceApplicatorWallNomTrans' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorWallNomTrans(),
                'SourceApplicatorStepSize' => new \PHPExiftool\Driver\Tag\DICOM\SourceApplicatorStepSize(),
                'TransferTubeNumber' => new \PHPExiftool\Driver\Tag\DICOM\TransferTubeNumber(),
                'TransferTubeLength' => new \PHPExiftool\Driver\Tag\DICOM\TransferTubeLength(),
                'ChannelShieldSequence' => new \PHPExiftool\Driver\Tag\DICOM\ChannelShieldSequence(),
                'ChannelShieldNumber' => new \PHPExiftool\Driver\Tag\DICOM\ChannelShieldNumber(),
                'ChannelShieldID' => new \PHPExiftool\Driver\Tag\DICOM\ChannelShieldID(),
                'ChannelShieldName' => new \PHPExiftool\Driver\Tag\DICOM\ChannelShieldName(),
                'ChannelShieldNominalThickness' => new \PHPExiftool\Driver\Tag\DICOM\ChannelShieldNominalThickness(),
                'ChannelShieldNominalTransmission' => new \PHPExiftool\Driver\Tag\DICOM\ChannelShieldNominalTransmission(),
                'FinalCumulativeTimeWeight' => new \PHPExiftool\Driver\Tag\DICOM\FinalCumulativeTimeWeight(),
                'BrachyControlPointSequence' => new \PHPExiftool\Driver\Tag\DICOM\BrachyControlPointSequence(),
                'ControlPointRelativePosition' => new \PHPExiftool\Driver\Tag\DICOM\ControlPointRelativePosition(),
                'ControlPoint3DPosition' => new \PHPExiftool\Driver\Tag\DICOM\ControlPoint3DPosition(),
                'CumulativeTimeWeight' => new \PHPExiftool\Driver\Tag\DICOM\CumulativeTimeWeight(),
                'CompensatorDivergence' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorDivergence(),
                'CompensatorMountingPosition' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorMountingPosition(),
                'SourceToCompensatorDistance' => new \PHPExiftool\Driver\Tag\DICOM\SourceToCompensatorDistance(),
                'TotalCompTrayWaterEquivThickness' => new \PHPExiftool\Driver\Tag\DICOM\TotalCompTrayWaterEquivThickness(),
                'IsocenterToCompensatorTrayDistance' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterToCompensatorTrayDistance(),
                'CompensatorColumnOffset' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorColumnOffset(),
                'IsocenterToCompensatorDistances' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterToCompensatorDistances(),
                'CompensatorRelStoppingPowerRatio' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorRelStoppingPowerRatio(),
                'CompensatorMillingToolDiameter' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorMillingToolDiameter(),
                'IonRangeCompensatorSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonRangeCompensatorSequence(),
                'CompensatorDescription' => new \PHPExiftool\Driver\Tag\DICOM\CompensatorDescription(),
                'RadiationMassNumber' => new \PHPExiftool\Driver\Tag\DICOM\RadiationMassNumber(),
                'RadiationAtomicNumber' => new \PHPExiftool\Driver\Tag\DICOM\RadiationAtomicNumber(),
                'RadiationChargeState' => new \PHPExiftool\Driver\Tag\DICOM\RadiationChargeState(),
                'ScanMode' => new \PHPExiftool\Driver\Tag\DICOM\ScanMode(),
                'VirtualSourceAxisDistances' => new \PHPExiftool\Driver\Tag\DICOM\VirtualSourceAxisDistances(),
                'SnoutSequence' => new \PHPExiftool\Driver\Tag\DICOM\SnoutSequence(),
                'SnoutPosition' => new \PHPExiftool\Driver\Tag\DICOM\SnoutPosition(),
                'SnoutID' => new \PHPExiftool\Driver\Tag\DICOM\SnoutID(),
                'NumberOfRangeShifters' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfRangeShifters(),
                'RangeShifterSequence' => new \PHPExiftool\Driver\Tag\DICOM\RangeShifterSequence(),
                'RangeShifterNumber' => new \PHPExiftool\Driver\Tag\DICOM\RangeShifterNumber(),
                'RangeShifterID' => new \PHPExiftool\Driver\Tag\DICOM\RangeShifterID(),
                'RangeShifterType' => new \PHPExiftool\Driver\Tag\DICOM\RangeShifterType(),
                'RangeShifterDescription' => new \PHPExiftool\Driver\Tag\DICOM\RangeShifterDescription(),
                'NumberOfLateralSpreadingDevices' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfLateralSpreadingDevices(),
                'LateralSpreadingDeviceSequence' => new \PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceSequence(),
                'LateralSpreadingDeviceNumber' => new \PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceNumber(),
                'LateralSpreadingDeviceID' => new \PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceID(),
                'LateralSpreadingDeviceType' => new \PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceType(),
                'LateralSpreadingDeviceDescription' => new \PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceDescription(),
                'LateralSpreadingDevWaterEquivThick' => new \PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDevWaterEquivThick(),
                'NumberOfRangeModulators' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfRangeModulators(),
                'RangeModulatorSequence' => new \PHPExiftool\Driver\Tag\DICOM\RangeModulatorSequence(),
                'RangeModulatorNumber' => new \PHPExiftool\Driver\Tag\DICOM\RangeModulatorNumber(),
                'RangeModulatorID' => new \PHPExiftool\Driver\Tag\DICOM\RangeModulatorID(),
                'RangeModulatorType' => new \PHPExiftool\Driver\Tag\DICOM\RangeModulatorType(),
                'RangeModulatorDescription' => new \PHPExiftool\Driver\Tag\DICOM\RangeModulatorDescription(),
                'BeamCurrentModulationID' => new \PHPExiftool\Driver\Tag\DICOM\BeamCurrentModulationID(),
                'PatientSupportType' => new \PHPExiftool\Driver\Tag\DICOM\PatientSupportType(),
                'PatientSupportID' => new \PHPExiftool\Driver\Tag\DICOM\PatientSupportID(),
                'PatientSupportAccessoryCode' => new \PHPExiftool\Driver\Tag\DICOM\PatientSupportAccessoryCode(),
                'FixationLightAzimuthalAngle' => new \PHPExiftool\Driver\Tag\DICOM\FixationLightAzimuthalAngle(),
                'FixationLightPolarAngle' => new \PHPExiftool\Driver\Tag\DICOM\FixationLightPolarAngle(),
                'MetersetRate' => new \PHPExiftool\Driver\Tag\DICOM\MetersetRate(),
                'RangeShifterSettingsSequence' => new \PHPExiftool\Driver\Tag\DICOM\RangeShifterSettingsSequence(),
                'RangeShifterSetting' => new \PHPExiftool\Driver\Tag\DICOM\RangeShifterSetting(),
                'IsocenterToRangeShifterDistance' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterToRangeShifterDistance(),
                'RangeShifterWaterEquivThickness' => new \PHPExiftool\Driver\Tag\DICOM\RangeShifterWaterEquivThickness(),
                'LateralSpreadingDeviceSettingsSeq' => new \PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceSettingsSeq(),
                'LateralSpreadingDeviceSetting' => new \PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceSetting(),
                'IsocenterToLateralSpreadingDevDist' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterToLateralSpreadingDevDist(),
                'RangeModulatorSettingsSequence' => new \PHPExiftool\Driver\Tag\DICOM\RangeModulatorSettingsSequence(),
                'RangeModulatorGatingStartValue' => new \PHPExiftool\Driver\Tag\DICOM\RangeModulatorGatingStartValue(),
                'RangeModulatorGatingStopValue' => new \PHPExiftool\Driver\Tag\DICOM\RangeModulatorGatingStopValue(),
                'IsocenterToRangeModulatorDistance' => new \PHPExiftool\Driver\Tag\DICOM\IsocenterToRangeModulatorDistance(),
                'ScanSpotTuneID' => new \PHPExiftool\Driver\Tag\DICOM\ScanSpotTuneID(),
                'NumberOfScanSpotPositions' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfScanSpotPositions(),
                'ScanSpotPositionMap' => new \PHPExiftool\Driver\Tag\DICOM\ScanSpotPositionMap(),
                'ScanSpotMetersetWeights' => new \PHPExiftool\Driver\Tag\DICOM\ScanSpotMetersetWeights(),
                'ScanningSpotSize' => new \PHPExiftool\Driver\Tag\DICOM\ScanningSpotSize(),
                'NumberOfPaintings' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPaintings(),
                'IonToleranceTableSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonToleranceTableSequence(),
                'IonBeamSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonBeamSequence(),
                'IonBeamLimitingDeviceSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonBeamLimitingDeviceSequence(),
                'IonBlockSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonBlockSequence(),
                'IonControlPointSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonControlPointSequence(),
                'IonWedgeSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonWedgeSequence(),
                'IonWedgePositionSequence' => new \PHPExiftool\Driver\Tag\DICOM\IonWedgePositionSequence(),
                'ReferencedSetupImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSetupImageSequence(),
                'SetupImageComment' => new \PHPExiftool\Driver\Tag\DICOM\SetupImageComment(),
                'MotionSynchronizationSequence' => new \PHPExiftool\Driver\Tag\DICOM\MotionSynchronizationSequence(),
                'ControlPointOrientation' => new \PHPExiftool\Driver\Tag\DICOM\ControlPointOrientation(),
                'GeneralAccessorySequence' => new \PHPExiftool\Driver\Tag\DICOM\GeneralAccessorySequence(),
                'GeneralAccessoryID' => new \PHPExiftool\Driver\Tag\DICOM\GeneralAccessoryID(),
                'GeneralAccessoryDescription' => new \PHPExiftool\Driver\Tag\DICOM\GeneralAccessoryDescription(),
                'GeneralAccessoryType' => new \PHPExiftool\Driver\Tag\DICOM\GeneralAccessoryType(),
                'GeneralAccessoryNumber' => new \PHPExiftool\Driver\Tag\DICOM\GeneralAccessoryNumber(),
                'ReferencedRTPlanSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedRTPlanSequence(),
                'ReferencedBeamSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedBeamSequence(),
                'ReferencedBeamNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedBeamNumber(),
                'ReferencedReferenceImageNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedReferenceImageNumber(),
                'StartCumulativeMetersetWeight' => new \PHPExiftool\Driver\Tag\DICOM\StartCumulativeMetersetWeight(),
                'EndCumulativeMetersetWeight' => new \PHPExiftool\Driver\Tag\DICOM\EndCumulativeMetersetWeight(),
                'ReferencedBrachyAppSetupSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedBrachyAppSetupSeq(),
                'ReferencedBrachyAppSetupNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedBrachyAppSetupNumber(),
                'ReferencedSourceNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedSourceNumber(),
                'ReferencedFractionGroupSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFractionGroupSequence(),
                'ReferencedFractionGroupNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedFractionGroupNumber(),
                'ReferencedVerificationImageSeq' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedVerificationImageSeq(),
                'ReferencedReferenceImageSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedReferenceImageSequence(),
                'ReferencedDoseReferenceSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedDoseReferenceSequence(),
                'ReferencedDoseReferenceNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedDoseReferenceNumber(),
                'BrachyReferencedDoseReferenceSeq' => new \PHPExiftool\Driver\Tag\DICOM\BrachyReferencedDoseReferenceSeq(),
                'ReferencedStructureSetSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedStructureSetSequence(),
                'ReferencedPatientSetupNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedPatientSetupNumber(),
                'ReferencedDoseSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedDoseSequence(),
                'ReferencedToleranceTableNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedToleranceTableNumber(),
                'ReferencedBolusSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedBolusSequence(),
                'ReferencedWedgeNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedWedgeNumber(),
                'ReferencedCompensatorNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedCompensatorNumber(),
                'ReferencedBlockNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedBlockNumber(),
                'ReferencedControlPointIndex' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedControlPointIndex(),
                'ReferencedControlPointSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedControlPointSequence(),
                'ReferencedStartControlPointIndex' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedStartControlPointIndex(),
                'ReferencedStopControlPointIndex' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedStopControlPointIndex(),
                'ReferencedRangeShifterNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedRangeShifterNumber(),
                'ReferencedLateralSpreadingDevNum' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedLateralSpreadingDevNum(),
                'ReferencedRangeModulatorNumber' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedRangeModulatorNumber(),
                'ApprovalStatus' => new \PHPExiftool\Driver\Tag\DICOM\ApprovalStatus(),
                'ReviewDate' => new \PHPExiftool\Driver\Tag\DICOM\ReviewDate(),
                'ReviewTime' => new \PHPExiftool\Driver\Tag\DICOM\ReviewTime(),
                'ReviewerName' => new \PHPExiftool\Driver\Tag\DICOM\ReviewerName(),
                'TextGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\TextGroupLength(),
                'Arbitrary' => new \PHPExiftool\Driver\Tag\DICOM\Arbitrary(),
                'TextComments' => new \PHPExiftool\Driver\Tag\DICOM\TextComments(),
                'ResultsID' => new \PHPExiftool\Driver\Tag\DICOM\ResultsID(),
                'ResultsIDIssuer' => new \PHPExiftool\Driver\Tag\DICOM\ResultsIDIssuer(),
                'ReferencedInterpretationSequence' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedInterpretationSequence(),
                'InterpretationRecordedDate' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationRecordedDate(),
                'InterpretationRecordedTime' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationRecordedTime(),
                'InterpretationRecorder' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationRecorder(),
                'ReferenceToRecordedSound' => new \PHPExiftool\Driver\Tag\DICOM\ReferenceToRecordedSound(),
                'InterpretationTranscriptionDate' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationTranscriptionDate(),
                'InterpretationTranscriptionTime' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationTranscriptionTime(),
                'InterpretationTranscriber' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationTranscriber(),
                'InterpretationText' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationText(),
                'InterpretationAuthor' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationAuthor(),
                'InterpretationApproverSequence' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationApproverSequence(),
                'InterpretationApprovalDate' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationApprovalDate(),
                'InterpretationApprovalTime' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationApprovalTime(),
                'PhysicianApprovingInterpretation' => new \PHPExiftool\Driver\Tag\DICOM\PhysicianApprovingInterpretation(),
                'InterpretationDiagnosisDescription' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationDiagnosisDescription(),
                'InterpretationDiagnosisCodeSeq' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationDiagnosisCodeSeq(),
                'ResultsDistributionListSequence' => new \PHPExiftool\Driver\Tag\DICOM\ResultsDistributionListSequence(),
                'DistributionName' => new \PHPExiftool\Driver\Tag\DICOM\DistributionName(),
                'DistributionAddress' => new \PHPExiftool\Driver\Tag\DICOM\DistributionAddress(),
                'InterpretationID' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationID(),
                'InterpretationIDIssuer' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationIDIssuer(),
                'InterpretationTypeID' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationTypeID(),
                'InterpretationStatusID' => new \PHPExiftool\Driver\Tag\DICOM\InterpretationStatusID(),
                'Impressions' => new \PHPExiftool\Driver\Tag\DICOM\Impressions(),
                'ResultsComments' => new \PHPExiftool\Driver\Tag\DICOM\ResultsComments(),
                'MACParametersSequence' => new \PHPExiftool\Driver\Tag\DICOM\MACParametersSequence(),
                'CurveDimensions' => new \PHPExiftool\Driver\Tag\DICOM\CurveDimensions(),
                'NumberOfPoints' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfPoints(),
                'TypeOfData' => new \PHPExiftool\Driver\Tag\DICOM\TypeOfData(),
                'CurveDescription' => new \PHPExiftool\Driver\Tag\DICOM\CurveDescription(),
                'AxisUnits' => new \PHPExiftool\Driver\Tag\DICOM\AxisUnits(),
                'AxisLabels' => new \PHPExiftool\Driver\Tag\DICOM\AxisLabels(),
                'DataValueRepresentation' => new \PHPExiftool\Driver\Tag\DICOM\DataValueRepresentation(),
                'MinimumCoordinateValue' => new \PHPExiftool\Driver\Tag\DICOM\MinimumCoordinateValue(),
                'MaximumCoordinateValue' => new \PHPExiftool\Driver\Tag\DICOM\MaximumCoordinateValue(),
                'CurveRange' => new \PHPExiftool\Driver\Tag\DICOM\CurveRange(),
                'CurveDataDescriptor' => new \PHPExiftool\Driver\Tag\DICOM\CurveDataDescriptor(),
                'CoordinateStartValue' => new \PHPExiftool\Driver\Tag\DICOM\CoordinateStartValue(),
                'CoordinateStepValue' => new \PHPExiftool\Driver\Tag\DICOM\CoordinateStepValue(),
                'CurveActivationLayer' => new \PHPExiftool\Driver\Tag\DICOM\CurveActivationLayer(),
                'AudioType' => new \PHPExiftool\Driver\Tag\DICOM\AudioType(),
                'AudioSampleFormat' => new \PHPExiftool\Driver\Tag\DICOM\AudioSampleFormat(),
                'NumberOfSamples' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfSamples(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\DICOM\SampleRate(),
                'TotalTime' => new \PHPExiftool\Driver\Tag\DICOM\TotalTime(),
                'AudioSampleData' => new \PHPExiftool\Driver\Tag\DICOM\AudioSampleData(),
                'AudioComments' => new \PHPExiftool\Driver\Tag\DICOM\AudioComments(),
                'CurveLabel' => new \PHPExiftool\Driver\Tag\DICOM\CurveLabel(),
                'ReferencedOverlayGroup' => new \PHPExiftool\Driver\Tag\DICOM\ReferencedOverlayGroup(),
                'CurveData' => new \PHPExiftool\Driver\Tag\DICOM\CurveData(),
                'SharedFunctionalGroupsSequence' => new \PHPExiftool\Driver\Tag\DICOM\SharedFunctionalGroupsSequence(),
                'PerFrameFunctionalGroupsSequence' => new \PHPExiftool\Driver\Tag\DICOM\PerFrameFunctionalGroupsSequence(),
                'WaveformSequence' => new \PHPExiftool\Driver\Tag\DICOM\WaveformSequence(),
                'ChannelMinimumValue' => new \PHPExiftool\Driver\Tag\DICOM\ChannelMinimumValue(),
                'ChannelMaximumValue' => new \PHPExiftool\Driver\Tag\DICOM\ChannelMaximumValue(),
                'WaveformBitsAllocated' => new \PHPExiftool\Driver\Tag\DICOM\WaveformBitsAllocated(),
                'WaveformSampleInterpretation' => new \PHPExiftool\Driver\Tag\DICOM\WaveformSampleInterpretation(),
                'WaveformPaddingValue' => new \PHPExiftool\Driver\Tag\DICOM\WaveformPaddingValue(),
                'WaveformData' => new \PHPExiftool\Driver\Tag\DICOM\WaveformData(),
                'FirstOrderPhaseCorrectionAngle' => new \PHPExiftool\Driver\Tag\DICOM\FirstOrderPhaseCorrectionAngle(),
                'SpectroscopyData' => new \PHPExiftool\Driver\Tag\DICOM\SpectroscopyData(),
                'OverlayGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\OverlayGroupLength(),
                'OverlayRows' => new \PHPExiftool\Driver\Tag\DICOM\OverlayRows(),
                'OverlayColumns' => new \PHPExiftool\Driver\Tag\DICOM\OverlayColumns(),
                'OverlayPlanes' => new \PHPExiftool\Driver\Tag\DICOM\OverlayPlanes(),
                'NumberOfFramesInOverlay' => new \PHPExiftool\Driver\Tag\DICOM\NumberOfFramesInOverlay(),
                'OverlayDescription' => new \PHPExiftool\Driver\Tag\DICOM\OverlayDescription(),
                'OverlayType' => new \PHPExiftool\Driver\Tag\DICOM\OverlayType(),
                'OverlaySubtype' => new \PHPExiftool\Driver\Tag\DICOM\OverlaySubtype(),
                'OverlayOrigin' => new \PHPExiftool\Driver\Tag\DICOM\OverlayOrigin(),
                'ImageFrameOrigin' => new \PHPExiftool\Driver\Tag\DICOM\ImageFrameOrigin(),
                'OverlayPlaneOrigin' => new \PHPExiftool\Driver\Tag\DICOM\OverlayPlaneOrigin(),
                'OverlayCompressionCode' => new \PHPExiftool\Driver\Tag\DICOM\OverlayCompressionCode(),
                'OverlayCompressionOriginator' => new \PHPExiftool\Driver\Tag\DICOM\OverlayCompressionOriginator(),
                'OverlayCompressionLabel' => new \PHPExiftool\Driver\Tag\DICOM\OverlayCompressionLabel(),
                'OverlayCompressionDescription' => new \PHPExiftool\Driver\Tag\DICOM\OverlayCompressionDescription(),
                'OverlayCompressionStepPointers' => new \PHPExiftool\Driver\Tag\DICOM\OverlayCompressionStepPointers(),
                'OverlayRepeatInterval' => new \PHPExiftool\Driver\Tag\DICOM\OverlayRepeatInterval(),
                'OverlayBitsGrouped' => new \PHPExiftool\Driver\Tag\DICOM\OverlayBitsGrouped(),
                'OverlayBitsAllocated' => new \PHPExiftool\Driver\Tag\DICOM\OverlayBitsAllocated(),
                'OverlayBitPosition' => new \PHPExiftool\Driver\Tag\DICOM\OverlayBitPosition(),
                'OverlayFormat' => new \PHPExiftool\Driver\Tag\DICOM\OverlayFormat(),
                'OverlayLocation' => new \PHPExiftool\Driver\Tag\DICOM\OverlayLocation(),
                'OverlayCodeLabel' => new \PHPExiftool\Driver\Tag\DICOM\OverlayCodeLabel(),
                'OverlayNumberOfTables' => new \PHPExiftool\Driver\Tag\DICOM\OverlayNumberOfTables(),
                'OverlayCodeTableLocation' => new \PHPExiftool\Driver\Tag\DICOM\OverlayCodeTableLocation(),
                'OverlayBitsForCodeWord' => new \PHPExiftool\Driver\Tag\DICOM\OverlayBitsForCodeWord(),
                'OverlayActivationLayer' => new \PHPExiftool\Driver\Tag\DICOM\OverlayActivationLayer(),
                'OverlayDescriptorGray' => new \PHPExiftool\Driver\Tag\DICOM\OverlayDescriptorGray(),
                'OverlayDescriptorRed' => new \PHPExiftool\Driver\Tag\DICOM\OverlayDescriptorRed(),
                'OverlayDescriptorGreen' => new \PHPExiftool\Driver\Tag\DICOM\OverlayDescriptorGreen(),
                'OverlayDescriptorBlue' => new \PHPExiftool\Driver\Tag\DICOM\OverlayDescriptorBlue(),
                'OverlaysGray' => new \PHPExiftool\Driver\Tag\DICOM\OverlaysGray(),
                'OverlaysRed' => new \PHPExiftool\Driver\Tag\DICOM\OverlaysRed(),
                'OverlaysGreen' => new \PHPExiftool\Driver\Tag\DICOM\OverlaysGreen(),
                'OverlaysBlue' => new \PHPExiftool\Driver\Tag\DICOM\OverlaysBlue(),
                'ROIArea' => new \PHPExiftool\Driver\Tag\DICOM\ROIArea(),
                'ROIMean' => new \PHPExiftool\Driver\Tag\DICOM\ROIMean(),
                'ROIStandardDeviation' => new \PHPExiftool\Driver\Tag\DICOM\ROIStandardDeviation(),
                'OverlayLabel' => new \PHPExiftool\Driver\Tag\DICOM\OverlayLabel(),
                'OverlayData' => new \PHPExiftool\Driver\Tag\DICOM\OverlayData(),
                'OverlayComments' => new \PHPExiftool\Driver\Tag\DICOM\OverlayComments(),
                'PixelDataGroupLength' => new \PHPExiftool\Driver\Tag\DICOM\PixelDataGroupLength(),
                'PixelData' => new \PHPExiftool\Driver\Tag\DICOM\PixelData(),
                'VariableNextDataGroup' => new \PHPExiftool\Driver\Tag\DICOM\VariableNextDataGroup(),
                'VariableCoefficientsSDVN' => new \PHPExiftool\Driver\Tag\DICOM\VariableCoefficientsSDVN(),
                'VariableCoefficientsSDHN' => new \PHPExiftool\Driver\Tag\DICOM\VariableCoefficientsSDHN(),
                'VariableCoefficientsSDDN' => new \PHPExiftool\Driver\Tag\DICOM\VariableCoefficientsSDDN(),
                'DigitalSignaturesSequence' => new \PHPExiftool\Driver\Tag\DICOM\DigitalSignaturesSequence(),
                'DataSetTrailingPadding' => new \PHPExiftool\Driver\Tag\DICOM\DataSetTrailingPadding(),
                'StartOfItem' => new \PHPExiftool\Driver\Tag\DICOM\StartOfItem(),
                'EndOfItems' => new \PHPExiftool\Driver\Tag\DICOM\EndOfItems(),
                'EndOfSequence' => new \PHPExiftool\Driver\Tag\DICOM\EndOfSequence(),
            );
        });
        $this['ExifIFD'] = $this->share(function(){
            return array(
                'MakerNoteNikon' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteNikon(),
                'MakerNoteCanon' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteCanon(),
                'MakerNoteCasio' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteCasio(),
                'MakerNoteCasio2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteCasio2(),
                'MakerNoteFujiFilm' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteFujiFilm(),
                'MakerNoteGE' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteGE(),
                'MakerNoteGE2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteGE2(),
                'MakerNoteHasselblad' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHasselblad(),
                'MakerNoteHP' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHP(),
                'MakerNoteHP2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHP2(),
                'MakerNoteHP4' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHP4(),
                'MakerNoteHP6' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHP6(),
                'MakerNoteISL' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteISL(),
                'MakerNoteJVC' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteJVC(),
                'MakerNoteJVCText' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteJVCText(),
                'MakerNoteKodak1a' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak1a(),
                'MakerNoteKodak1b' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak1b(),
                'MakerNoteKodak2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak2(),
                'MakerNoteKodak3' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak3(),
                'MakerNoteKodak4' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak4(),
                'MakerNoteKodak5' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak5(),
                'MakerNoteKodak6a' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak6a(),
                'MakerNoteKodak6b' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak6b(),
                'MakerNoteKodak7' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak7(),
                'MakerNoteKodak8a' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak8a(),
                'MakerNoteKodak8b' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak8b(),
                'MakerNoteKodak9' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak9(),
                'MakerNoteKodak10' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak10(),
                'MakerNoteKodakUnknown' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodakUnknown(),
                'MakerNoteKyocera' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKyocera(),
                'MakerNoteMinolta' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteMinolta(),
                'MakerNoteMinolta2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteMinolta2(),
                'MakerNoteMinolta3' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteMinolta3(),
                'MakerNoteNikon2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteNikon2(),
                'MakerNoteNikon3' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteNikon3(),
                'MakerNoteOlympus' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteOlympus(),
                'MakerNoteOlympus2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteOlympus2(),
                'MakerNoteLeica' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica(),
                'MakerNoteLeica2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica2(),
                'MakerNoteLeica3' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica3(),
                'MakerNoteLeica4' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica4(),
                'MakerNoteLeica5' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica5(),
                'MakerNoteLeica6' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica6(),
                'MakerNotePanasonic' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePanasonic(),
                'MakerNotePanasonic2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePanasonic2(),
                'MakerNotePentax' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax(),
                'MakerNotePentax2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax2(),
                'MakerNotePentax3' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax3(),
                'MakerNotePentax4' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax4(),
                'MakerNotePentax5' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax5(),
                'MakerNotePentax6' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax6(),
                'MakerNotePhaseOne' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNotePhaseOne(),
                'MakerNoteReconyx' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteReconyx(),
                'MakerNoteRicoh' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteRicoh(),
                'MakerNoteRicohText' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteRicohText(),
                'MakerNoteSamsung1a' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSamsung1a(),
                'MakerNoteSamsung1b' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSamsung1b(),
                'MakerNoteSamsung2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSamsung2(),
                'MakerNoteSanyo' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSanyo(),
                'MakerNoteSanyoC4' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSanyoC4(),
                'MakerNoteSanyoPatch' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSanyoPatch(),
                'MakerNoteSigma' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSigma(),
                'MakerNoteSony' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSony(),
                'MakerNoteSony2' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSony2(),
                'MakerNoteSony3' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSony3(),
                'MakerNoteSony4' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSony4(),
                'MakerNoteSonyEricsson' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSonyEricsson(),
                'MakerNoteSonySRF' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSonySRF(),
                'MakerNoteUnknownText' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteUnknownText(),
                'MakerNoteUnknown' => new \PHPExiftool\Driver\Tag\ExifIFD\MakerNoteUnknown(),
                'StripOffsets' => new \PHPExiftool\Driver\Tag\ExifIFD\StripOffsets(),
                'StripByteCounts' => new \PHPExiftool\Driver\Tag\ExifIFD\StripByteCounts(),
                'FreeOffsets' => new \PHPExiftool\Driver\Tag\ExifIFD\FreeOffsets(),
                'FreeByteCounts' => new \PHPExiftool\Driver\Tag\ExifIFD\FreeByteCounts(),
                'GrayResponseCurve' => new \PHPExiftool\Driver\Tag\ExifIFD\GrayResponseCurve(),
                'T4Options' => new \PHPExiftool\Driver\Tag\ExifIFD\T4Options(),
                'T6Options' => new \PHPExiftool\Driver\Tag\ExifIFD\T6Options(),
                'ColorResponseUnit' => new \PHPExiftool\Driver\Tag\ExifIFD\ColorResponseUnit(),
                'ColorMap' => new \PHPExiftool\Driver\Tag\ExifIFD\ColorMap(),
                'TileOffsets' => new \PHPExiftool\Driver\Tag\ExifIFD\TileOffsets(),
                'TileByteCounts' => new \PHPExiftool\Driver\Tag\ExifIFD\TileByteCounts(),
                'BadFaxLines' => new \PHPExiftool\Driver\Tag\ExifIFD\BadFaxLines(),
                'CleanFaxData' => new \PHPExiftool\Driver\Tag\ExifIFD\CleanFaxData(),
                'ConsecutiveBadFaxLines' => new \PHPExiftool\Driver\Tag\ExifIFD\ConsecutiveBadFaxLines(),
                'A100DataOffset' => new \PHPExiftool\Driver\Tag\ExifIFD\A100DataOffset(),
                'InkNames' => new \PHPExiftool\Driver\Tag\ExifIFD\InkNames(),
                'NumberofInks' => new \PHPExiftool\Driver\Tag\ExifIFD\NumberofInks(),
                'TargetPrinter' => new \PHPExiftool\Driver\Tag\ExifIFD\TargetPrinter(),
                'ExtraSamples' => new \PHPExiftool\Driver\Tag\ExifIFD\ExtraSamples(),
                'SampleFormat' => new \PHPExiftool\Driver\Tag\ExifIFD\SampleFormat(),
                'SMinSampleValue' => new \PHPExiftool\Driver\Tag\ExifIFD\SMinSampleValue(),
                'SMaxSampleValue' => new \PHPExiftool\Driver\Tag\ExifIFD\SMaxSampleValue(),
                'TransferRange' => new \PHPExiftool\Driver\Tag\ExifIFD\TransferRange(),
                'ClipPath' => new \PHPExiftool\Driver\Tag\ExifIFD\ClipPath(),
                'XClipPathUnits' => new \PHPExiftool\Driver\Tag\ExifIFD\XClipPathUnits(),
                'YClipPathUnits' => new \PHPExiftool\Driver\Tag\ExifIFD\YClipPathUnits(),
                'Indexed' => new \PHPExiftool\Driver\Tag\ExifIFD\Indexed(),
                'JPEGTables' => new \PHPExiftool\Driver\Tag\ExifIFD\JPEGTables(),
                'OPIProxy' => new \PHPExiftool\Driver\Tag\ExifIFD\OPIProxy(),
                'ProfileType' => new \PHPExiftool\Driver\Tag\ExifIFD\ProfileType(),
                'FaxProfile' => new \PHPExiftool\Driver\Tag\ExifIFD\FaxProfile(),
                'CodingMethods' => new \PHPExiftool\Driver\Tag\ExifIFD\CodingMethods(),
                'VersionYear' => new \PHPExiftool\Driver\Tag\ExifIFD\VersionYear(),
                'ModeNumber' => new \PHPExiftool\Driver\Tag\ExifIFD\ModeNumber(),
                'Decode' => new \PHPExiftool\Driver\Tag\ExifIFD\Decode(),
                'DefaultImageColor' => new \PHPExiftool\Driver\Tag\ExifIFD\DefaultImageColor(),
                'T82Options' => new \PHPExiftool\Driver\Tag\ExifIFD\T82Options(),
                'JPEGProc' => new \PHPExiftool\Driver\Tag\ExifIFD\JPEGProc(),
                'OtherImageStart' => new \PHPExiftool\Driver\Tag\ExifIFD\OtherImageStart(),
                'OtherImageLength' => new \PHPExiftool\Driver\Tag\ExifIFD\OtherImageLength(),
                'JPEGRestartInterval' => new \PHPExiftool\Driver\Tag\ExifIFD\JPEGRestartInterval(),
                'JPEGLosslessPredictors' => new \PHPExiftool\Driver\Tag\ExifIFD\JPEGLosslessPredictors(),
                'JPEGPointTransforms' => new \PHPExiftool\Driver\Tag\ExifIFD\JPEGPointTransforms(),
                'JPEGQTables' => new \PHPExiftool\Driver\Tag\ExifIFD\JPEGQTables(),
                'JPEGDCTables' => new \PHPExiftool\Driver\Tag\ExifIFD\JPEGDCTables(),
                'JPEGACTables' => new \PHPExiftool\Driver\Tag\ExifIFD\JPEGACTables(),
                'StripRowCounts' => new \PHPExiftool\Driver\Tag\ExifIFD\StripRowCounts(),
                'ApplicationNotes' => new \PHPExiftool\Driver\Tag\ExifIFD\ApplicationNotes(),
                'USPTOMiscellaneous' => new \PHPExiftool\Driver\Tag\ExifIFD\USPTOMiscellaneous(),
                'XP_DIP_XML' => new \PHPExiftool\Driver\Tag\ExifIFD\XPDIPXML(),
                'ImageID' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageID(),
                'WangTag1' => new \PHPExiftool\Driver\Tag\ExifIFD\WangTag1(),
                'WangAnnotation' => new \PHPExiftool\Driver\Tag\ExifIFD\WangAnnotation(),
                'WangTag3' => new \PHPExiftool\Driver\Tag\ExifIFD\WangTag3(),
                'WangTag4' => new \PHPExiftool\Driver\Tag\ExifIFD\WangTag4(),
                'Matteing' => new \PHPExiftool\Driver\Tag\ExifIFD\Matteing(),
                'DataType' => new \PHPExiftool\Driver\Tag\ExifIFD\DataType(),
                'ImageDepth' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageDepth(),
                'TileDepth' => new \PHPExiftool\Driver\Tag\ExifIFD\TileDepth(),
                'Model2' => new \PHPExiftool\Driver\Tag\ExifIFD\Model2(),
                'BatteryLevel' => new \PHPExiftool\Driver\Tag\ExifIFD\BatteryLevel(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\ExifIFD\ExposureTime(),
                'FNumber' => new \PHPExiftool\Driver\Tag\ExifIFD\FNumber(),
                'MDFileTag' => new \PHPExiftool\Driver\Tag\ExifIFD\MDFileTag(),
                'MDScalePixel' => new \PHPExiftool\Driver\Tag\ExifIFD\MDScalePixel(),
                'MDColorTable' => new \PHPExiftool\Driver\Tag\ExifIFD\MDColorTable(),
                'MDLabName' => new \PHPExiftool\Driver\Tag\ExifIFD\MDLabName(),
                'MDSampleInfo' => new \PHPExiftool\Driver\Tag\ExifIFD\MDSampleInfo(),
                'MDPrepDate' => new \PHPExiftool\Driver\Tag\ExifIFD\MDPrepDate(),
                'MDPrepTime' => new \PHPExiftool\Driver\Tag\ExifIFD\MDPrepTime(),
                'MDFileUnits' => new \PHPExiftool\Driver\Tag\ExifIFD\MDFileUnits(),
                'PixelScale' => new \PHPExiftool\Driver\Tag\ExifIFD\PixelScale(),
                'AdventScale' => new \PHPExiftool\Driver\Tag\ExifIFD\AdventScale(),
                'AdventRevision' => new \PHPExiftool\Driver\Tag\ExifIFD\AdventRevision(),
                'UIC1Tag' => new \PHPExiftool\Driver\Tag\ExifIFD\UIC1Tag(),
                'UIC2Tag' => new \PHPExiftool\Driver\Tag\ExifIFD\UIC2Tag(),
                'UIC3Tag' => new \PHPExiftool\Driver\Tag\ExifIFD\UIC3Tag(),
                'UIC4Tag' => new \PHPExiftool\Driver\Tag\ExifIFD\UIC4Tag(),
                'IntergraphPacketData' => new \PHPExiftool\Driver\Tag\ExifIFD\IntergraphPacketData(),
                'IntergraphFlagRegisters' => new \PHPExiftool\Driver\Tag\ExifIFD\IntergraphFlagRegisters(),
                'IntergraphMatrix' => new \PHPExiftool\Driver\Tag\ExifIFD\IntergraphMatrix(),
                'INGRReserved' => new \PHPExiftool\Driver\Tag\ExifIFD\INGRReserved(),
                'ModelTiePoint' => new \PHPExiftool\Driver\Tag\ExifIFD\ModelTiePoint(),
                'Site' => new \PHPExiftool\Driver\Tag\ExifIFD\Site(),
                'ColorSequence' => new \PHPExiftool\Driver\Tag\ExifIFD\ColorSequence(),
                'IT8Header' => new \PHPExiftool\Driver\Tag\ExifIFD\IT8Header(),
                'RasterPadding' => new \PHPExiftool\Driver\Tag\ExifIFD\RasterPadding(),
                'BitsPerRunLength' => new \PHPExiftool\Driver\Tag\ExifIFD\BitsPerRunLength(),
                'BitsPerExtendedRunLength' => new \PHPExiftool\Driver\Tag\ExifIFD\BitsPerExtendedRunLength(),
                'ColorTable' => new \PHPExiftool\Driver\Tag\ExifIFD\ColorTable(),
                'ImageColorIndicator' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageColorIndicator(),
                'BackgroundColorIndicator' => new \PHPExiftool\Driver\Tag\ExifIFD\BackgroundColorIndicator(),
                'ImageColorValue' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageColorValue(),
                'BackgroundColorValue' => new \PHPExiftool\Driver\Tag\ExifIFD\BackgroundColorValue(),
                'PixelIntensityRange' => new \PHPExiftool\Driver\Tag\ExifIFD\PixelIntensityRange(),
                'TransparencyIndicator' => new \PHPExiftool\Driver\Tag\ExifIFD\TransparencyIndicator(),
                'ColorCharacterization' => new \PHPExiftool\Driver\Tag\ExifIFD\ColorCharacterization(),
                'HCUsage' => new \PHPExiftool\Driver\Tag\ExifIFD\HCUsage(),
                'TrapIndicator' => new \PHPExiftool\Driver\Tag\ExifIFD\TrapIndicator(),
                'CMYKEquivalent' => new \PHPExiftool\Driver\Tag\ExifIFD\CMYKEquivalent(),
                'PixelMagicJBIGOptions' => new \PHPExiftool\Driver\Tag\ExifIFD\PixelMagicJBIGOptions(),
                'ModelTransform' => new \PHPExiftool\Driver\Tag\ExifIFD\ModelTransform(),
                'WB_GRGBLevels' => new \PHPExiftool\Driver\Tag\ExifIFD\WBGRGBLevels(),
                'TIFF_FXExtensions' => new \PHPExiftool\Driver\Tag\ExifIFD\TIFFFXExtensions(),
                'MultiProfiles' => new \PHPExiftool\Driver\Tag\ExifIFD\MultiProfiles(),
                'SharedData' => new \PHPExiftool\Driver\Tag\ExifIFD\SharedData(),
                'T88Options' => new \PHPExiftool\Driver\Tag\ExifIFD\T88Options(),
                'ImageLayer' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageLayer(),
                'GeoTiffDirectory' => new \PHPExiftool\Driver\Tag\ExifIFD\GeoTiffDirectory(),
                'GeoTiffDoubleParams' => new \PHPExiftool\Driver\Tag\ExifIFD\GeoTiffDoubleParams(),
                'GeoTiffAsciiParams' => new \PHPExiftool\Driver\Tag\ExifIFD\GeoTiffAsciiParams(),
                'ExposureProgram' => new \PHPExiftool\Driver\Tag\ExifIFD\ExposureProgram(),
                'SpectralSensitivity' => new \PHPExiftool\Driver\Tag\ExifIFD\SpectralSensitivity(),
                'ISO' => new \PHPExiftool\Driver\Tag\ExifIFD\ISO(),
                'Opto-ElectricConvFactor' => new \PHPExiftool\Driver\Tag\ExifIFD\OptoElectricConvFactor(),
                'Interlace' => new \PHPExiftool\Driver\Tag\ExifIFD\Interlace(),
                'TimeZoneOffset' => new \PHPExiftool\Driver\Tag\ExifIFD\TimeZoneOffset(),
                'SelfTimerMode' => new \PHPExiftool\Driver\Tag\ExifIFD\SelfTimerMode(),
                'SensitivityType' => new \PHPExiftool\Driver\Tag\ExifIFD\SensitivityType(),
                'StandardOutputSensitivity' => new \PHPExiftool\Driver\Tag\ExifIFD\StandardOutputSensitivity(),
                'RecommendedExposureIndex' => new \PHPExiftool\Driver\Tag\ExifIFD\RecommendedExposureIndex(),
                'ISOSpeed' => new \PHPExiftool\Driver\Tag\ExifIFD\ISOSpeed(),
                'ISOSpeedLatitudeyyy' => new \PHPExiftool\Driver\Tag\ExifIFD\ISOSpeedLatitudeyyy(),
                'ISOSpeedLatitudezzz' => new \PHPExiftool\Driver\Tag\ExifIFD\ISOSpeedLatitudezzz(),
                'FaxRecvParams' => new \PHPExiftool\Driver\Tag\ExifIFD\FaxRecvParams(),
                'FaxSubAddress' => new \PHPExiftool\Driver\Tag\ExifIFD\FaxSubAddress(),
                'FaxRecvTime' => new \PHPExiftool\Driver\Tag\ExifIFD\FaxRecvTime(),
                'ExifVersion' => new \PHPExiftool\Driver\Tag\ExifIFD\ExifVersion(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\ExifIFD\DateTimeOriginal(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\ExifIFD\CreateDate(),
                'ComponentsConfiguration' => new \PHPExiftool\Driver\Tag\ExifIFD\ComponentsConfiguration(),
                'CompressedBitsPerPixel' => new \PHPExiftool\Driver\Tag\ExifIFD\CompressedBitsPerPixel(),
                'ShutterSpeedValue' => new \PHPExiftool\Driver\Tag\ExifIFD\ShutterSpeedValue(),
                'ApertureValue' => new \PHPExiftool\Driver\Tag\ExifIFD\ApertureValue(),
                'BrightnessValue' => new \PHPExiftool\Driver\Tag\ExifIFD\BrightnessValue(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\ExifIFD\ExposureCompensation(),
                'MaxApertureValue' => new \PHPExiftool\Driver\Tag\ExifIFD\MaxApertureValue(),
                'SubjectDistance' => new \PHPExiftool\Driver\Tag\ExifIFD\SubjectDistance(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\ExifIFD\MeteringMode(),
                'LightSource' => new \PHPExiftool\Driver\Tag\ExifIFD\LightSource(),
                'Flash' => new \PHPExiftool\Driver\Tag\ExifIFD\Flash(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\ExifIFD\FocalLength(),
                'FlashEnergy' => new \PHPExiftool\Driver\Tag\ExifIFD\FlashEnergy(),
                'SpatialFrequencyResponse' => new \PHPExiftool\Driver\Tag\ExifIFD\SpatialFrequencyResponse(),
                'Noise' => new \PHPExiftool\Driver\Tag\ExifIFD\Noise(),
                'FocalPlaneXResolution' => new \PHPExiftool\Driver\Tag\ExifIFD\FocalPlaneXResolution(),
                'FocalPlaneYResolution' => new \PHPExiftool\Driver\Tag\ExifIFD\FocalPlaneYResolution(),
                'FocalPlaneResolutionUnit' => new \PHPExiftool\Driver\Tag\ExifIFD\FocalPlaneResolutionUnit(),
                'ImageNumber' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageNumber(),
                'SecurityClassification' => new \PHPExiftool\Driver\Tag\ExifIFD\SecurityClassification(),
                'ImageHistory' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageHistory(),
                'SubjectArea' => new \PHPExiftool\Driver\Tag\ExifIFD\SubjectArea(),
                'ExposureIndex' => new \PHPExiftool\Driver\Tag\ExifIFD\ExposureIndex(),
                'TIFF-EPStandardID' => new \PHPExiftool\Driver\Tag\ExifIFD\TIFFEPStandardID(),
                'SensingMethod' => new \PHPExiftool\Driver\Tag\ExifIFD\SensingMethod(),
                'CIP3DataFile' => new \PHPExiftool\Driver\Tag\ExifIFD\CIP3DataFile(),
                'CIP3Sheet' => new \PHPExiftool\Driver\Tag\ExifIFD\CIP3Sheet(),
                'CIP3Side' => new \PHPExiftool\Driver\Tag\ExifIFD\CIP3Side(),
                'StoNits' => new \PHPExiftool\Driver\Tag\ExifIFD\StoNits(),
                'UserComment' => new \PHPExiftool\Driver\Tag\ExifIFD\UserComment(),
                'SubSecTime' => new \PHPExiftool\Driver\Tag\ExifIFD\SubSecTime(),
                'SubSecTimeOriginal' => new \PHPExiftool\Driver\Tag\ExifIFD\SubSecTimeOriginal(),
                'SubSecTimeDigitized' => new \PHPExiftool\Driver\Tag\ExifIFD\SubSecTimeDigitized(),
                'MSDocumentText' => new \PHPExiftool\Driver\Tag\ExifIFD\MSDocumentText(),
                'MSPropertySetStorage' => new \PHPExiftool\Driver\Tag\ExifIFD\MSPropertySetStorage(),
                'MSDocumentTextPosition' => new \PHPExiftool\Driver\Tag\ExifIFD\MSDocumentTextPosition(),
                'FlashpixVersion' => new \PHPExiftool\Driver\Tag\ExifIFD\FlashpixVersion(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\ExifIFD\ColorSpace(),
                'ExifImageWidth' => new \PHPExiftool\Driver\Tag\ExifIFD\ExifImageWidth(),
                'ExifImageHeight' => new \PHPExiftool\Driver\Tag\ExifIFD\ExifImageHeight(),
                'RelatedSoundFile' => new \PHPExiftool\Driver\Tag\ExifIFD\RelatedSoundFile(),
                'SubjectLocation' => new \PHPExiftool\Driver\Tag\ExifIFD\SubjectLocation(),
                'FileSource' => new \PHPExiftool\Driver\Tag\ExifIFD\FileSource(),
                'SceneType' => new \PHPExiftool\Driver\Tag\ExifIFD\SceneType(),
                'CFAPattern' => new \PHPExiftool\Driver\Tag\ExifIFD\CFAPattern(),
                'CustomRendered' => new \PHPExiftool\Driver\Tag\ExifIFD\CustomRendered(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\ExifIFD\ExposureMode(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\ExifIFD\WhiteBalance(),
                'DigitalZoomRatio' => new \PHPExiftool\Driver\Tag\ExifIFD\DigitalZoomRatio(),
                'FocalLengthIn35mmFormat' => new \PHPExiftool\Driver\Tag\ExifIFD\FocalLengthIn35mmFormat(),
                'SceneCaptureType' => new \PHPExiftool\Driver\Tag\ExifIFD\SceneCaptureType(),
                'GainControl' => new \PHPExiftool\Driver\Tag\ExifIFD\GainControl(),
                'Contrast' => new \PHPExiftool\Driver\Tag\ExifIFD\Contrast(),
                'Saturation' => new \PHPExiftool\Driver\Tag\ExifIFD\Saturation(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\ExifIFD\Sharpness(),
                'DeviceSettingDescription' => new \PHPExiftool\Driver\Tag\ExifIFD\DeviceSettingDescription(),
                'SubjectDistanceRange' => new \PHPExiftool\Driver\Tag\ExifIFD\SubjectDistanceRange(),
                'ImageUniqueID' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageUniqueID(),
                'OwnerName' => new \PHPExiftool\Driver\Tag\ExifIFD\OwnerName(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\ExifIFD\SerialNumber(),
                'LensInfo' => new \PHPExiftool\Driver\Tag\ExifIFD\LensInfo(),
                'LensMake' => new \PHPExiftool\Driver\Tag\ExifIFD\LensMake(),
                'LensModel' => new \PHPExiftool\Driver\Tag\ExifIFD\LensModel(),
                'LensSerialNumber' => new \PHPExiftool\Driver\Tag\ExifIFD\LensSerialNumber(),
                'GDALMetadata' => new \PHPExiftool\Driver\Tag\ExifIFD\GDALMetadata(),
                'GDALNoData' => new \PHPExiftool\Driver\Tag\ExifIFD\GDALNoData(),
                'Gamma' => new \PHPExiftool\Driver\Tag\ExifIFD\Gamma(),
                'ExpandSoftware' => new \PHPExiftool\Driver\Tag\ExifIFD\ExpandSoftware(),
                'ExpandLens' => new \PHPExiftool\Driver\Tag\ExifIFD\ExpandLens(),
                'ExpandFilm' => new \PHPExiftool\Driver\Tag\ExifIFD\ExpandFilm(),
                'ExpandFilterLens' => new \PHPExiftool\Driver\Tag\ExifIFD\ExpandFilterLens(),
                'ExpandScanner' => new \PHPExiftool\Driver\Tag\ExifIFD\ExpandScanner(),
                'ExpandFlashLamp' => new \PHPExiftool\Driver\Tag\ExifIFD\ExpandFlashLamp(),
                'PixelFormat' => new \PHPExiftool\Driver\Tag\ExifIFD\PixelFormat(),
                'Transformation' => new \PHPExiftool\Driver\Tag\ExifIFD\Transformation(),
                'Uncompressed' => new \PHPExiftool\Driver\Tag\ExifIFD\Uncompressed(),
                'ImageType' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageType(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageHeight(),
                'WidthResolution' => new \PHPExiftool\Driver\Tag\ExifIFD\WidthResolution(),
                'HeightResolution' => new \PHPExiftool\Driver\Tag\ExifIFD\HeightResolution(),
                'ImageOffset' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageOffset(),
                'ImageByteCount' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageByteCount(),
                'AlphaOffset' => new \PHPExiftool\Driver\Tag\ExifIFD\AlphaOffset(),
                'AlphaByteCount' => new \PHPExiftool\Driver\Tag\ExifIFD\AlphaByteCount(),
                'ImageDataDiscard' => new \PHPExiftool\Driver\Tag\ExifIFD\ImageDataDiscard(),
                'AlphaDataDiscard' => new \PHPExiftool\Driver\Tag\ExifIFD\AlphaDataDiscard(),
                'OceScanjobDesc' => new \PHPExiftool\Driver\Tag\ExifIFD\OceScanjobDesc(),
                'OceApplicationSelector' => new \PHPExiftool\Driver\Tag\ExifIFD\OceApplicationSelector(),
                'OceIDNumber' => new \PHPExiftool\Driver\Tag\ExifIFD\OceIDNumber(),
                'OceImageLogic' => new \PHPExiftool\Driver\Tag\ExifIFD\OceImageLogic(),
                'Annotations' => new \PHPExiftool\Driver\Tag\ExifIFD\Annotations(),
                'USPTOOriginalContentType' => new \PHPExiftool\Driver\Tag\ExifIFD\USPTOOriginalContentType(),
                'CFAPlaneColor' => new \PHPExiftool\Driver\Tag\ExifIFD\CFAPlaneColor(),
                'CFALayout' => new \PHPExiftool\Driver\Tag\ExifIFD\CFALayout(),
                'BlackLevelDeltaH' => new \PHPExiftool\Driver\Tag\ExifIFD\BlackLevelDeltaH(),
                'BlackLevelDeltaV' => new \PHPExiftool\Driver\Tag\ExifIFD\BlackLevelDeltaV(),
                'DNGPrivateData' => new \PHPExiftool\Driver\Tag\ExifIFD\DNGPrivateData(),
                'RawImageSegmentation' => new \PHPExiftool\Driver\Tag\ExifIFD\RawImageSegmentation(),
                'AliasLayerMetadata' => new \PHPExiftool\Driver\Tag\ExifIFD\AliasLayerMetadata(),
                'SubTileBlockSize' => new \PHPExiftool\Driver\Tag\ExifIFD\SubTileBlockSize(),
                'RowInterleaveFactor' => new \PHPExiftool\Driver\Tag\ExifIFD\RowInterleaveFactor(),
                'OpcodeList1' => new \PHPExiftool\Driver\Tag\ExifIFD\OpcodeList1(),
                'OpcodeList2' => new \PHPExiftool\Driver\Tag\ExifIFD\OpcodeList2(),
                'OpcodeList3' => new \PHPExiftool\Driver\Tag\ExifIFD\OpcodeList3(),
                'NoiseProfile' => new \PHPExiftool\Driver\Tag\ExifIFD\NoiseProfile(),
                'Padding' => new \PHPExiftool\Driver\Tag\ExifIFD\Padding(),
                'OffsetSchema' => new \PHPExiftool\Driver\Tag\ExifIFD\OffsetSchema(),
                'Lens' => new \PHPExiftool\Driver\Tag\ExifIFD\Lens(),
                'RawFile' => new \PHPExiftool\Driver\Tag\ExifIFD\RawFile(),
                'Converter' => new \PHPExiftool\Driver\Tag\ExifIFD\Converter(),
                'Exposure' => new \PHPExiftool\Driver\Tag\ExifIFD\Exposure(),
                'Shadows' => new \PHPExiftool\Driver\Tag\ExifIFD\Shadows(),
                'Brightness' => new \PHPExiftool\Driver\Tag\ExifIFD\Brightness(),
                'Smoothness' => new \PHPExiftool\Driver\Tag\ExifIFD\Smoothness(),
                'MoireFilter' => new \PHPExiftool\Driver\Tag\ExifIFD\MoireFilter(),
            );
        });
        $this['DNG'] = $this->share(function(){
            return array(
                'OriginalRawImage' => new \PHPExiftool\Driver\Tag\DNG\OriginalRawImage(),
                'OriginalRawResource' => new \PHPExiftool\Driver\Tag\DNG\OriginalRawResource(),
                'OriginalRawFileType' => new \PHPExiftool\Driver\Tag\DNG\OriginalRawFileType(),
                'OriginalRawCreator' => new \PHPExiftool\Driver\Tag\DNG\OriginalRawCreator(),
                'OriginalTHMImage' => new \PHPExiftool\Driver\Tag\DNG\OriginalTHMImage(),
                'OriginalTHMResource' => new \PHPExiftool\Driver\Tag\DNG\OriginalTHMResource(),
                'OriginalTHMFileType' => new \PHPExiftool\Driver\Tag\DNG\OriginalTHMFileType(),
                'OriginalTHMCreator' => new \PHPExiftool\Driver\Tag\DNG\OriginalTHMCreator(),
            );
        });
        $this['DV'] = $this->share(function(){
            return array(
                'AspectRatio' => new \PHPExiftool\Driver\Tag\DV\AspectRatio(),
                'AudioBitsPerSample' => new \PHPExiftool\Driver\Tag\DV\AudioBitsPerSample(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\DV\AudioChannels(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\DV\AudioSampleRate(),
                'Colorimetry' => new \PHPExiftool\Driver\Tag\DV\Colorimetry(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\DV\DateTimeOriginal(),
                'Duration' => new \PHPExiftool\Driver\Tag\DV\Duration(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\DV\FrameRate(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\DV\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\DV\ImageWidth(),
                'TotalBitrate' => new \PHPExiftool\Driver\Tag\DV\TotalBitrate(),
                'VideoFormat' => new \PHPExiftool\Driver\Tag\DV\VideoFormat(),
                'VideoScanType' => new \PHPExiftool\Driver\Tag\DV\VideoScanType(),
            );
        });
        $this['DjVu'] = $this->share(function(){
            return array(
                'SubfileType' => new \PHPExiftool\Driver\Tag\DjVu\SubfileType(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\DjVu\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\DjVu\ImageHeight(),
                'DjVuVersion' => new \PHPExiftool\Driver\Tag\DjVu\DjVuVersion(),
                'SpatialResolution' => new \PHPExiftool\Driver\Tag\DjVu\SpatialResolution(),
                'Gamma' => new \PHPExiftool\Driver\Tag\DjVu\Gamma(),
                'Orientation' => new \PHPExiftool\Driver\Tag\DjVu\Orientation(),
                'IncludedFileID' => new \PHPExiftool\Driver\Tag\DjVu\IncludedFileID(),
            );
        });
        $this['DjVu-Meta'] = $this->share(function(){
            return array(
                'Author' => new \PHPExiftool\Driver\Tag\DjVuMeta\Author(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\DjVuMeta\CreateDate(),
                'Creator' => new \PHPExiftool\Driver\Tag\DjVuMeta\Creator(),
                'Keywords' => new \PHPExiftool\Driver\Tag\DjVuMeta\Keywords(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\DjVuMeta\ModifyDate(),
                'Producer' => new \PHPExiftool\Driver\Tag\DjVuMeta\Producer(),
                'Subject' => new \PHPExiftool\Driver\Tag\DjVuMeta\Subject(),
                'Title' => new \PHPExiftool\Driver\Tag\DjVuMeta\Title(),
                'Trapped' => new \PHPExiftool\Driver\Tag\DjVuMeta\Trapped(),
                'Address' => new \PHPExiftool\Driver\Tag\DjVuMeta\Address(),
                'Annotation' => new \PHPExiftool\Driver\Tag\DjVuMeta\Annotation(),
                'BookTitle' => new \PHPExiftool\Driver\Tag\DjVuMeta\BookTitle(),
                'Chapter' => new \PHPExiftool\Driver\Tag\DjVuMeta\Chapter(),
                'CrossRef' => new \PHPExiftool\Driver\Tag\DjVuMeta\CrossRef(),
                'Edition' => new \PHPExiftool\Driver\Tag\DjVuMeta\Edition(),
                'EPrint' => new \PHPExiftool\Driver\Tag\DjVuMeta\EPrint(),
                'HowPublished' => new \PHPExiftool\Driver\Tag\DjVuMeta\HowPublished(),
                'Institution' => new \PHPExiftool\Driver\Tag\DjVuMeta\Institution(),
                'Journal' => new \PHPExiftool\Driver\Tag\DjVuMeta\Journal(),
                'Key' => new \PHPExiftool\Driver\Tag\DjVuMeta\Key(),
                'Month' => new \PHPExiftool\Driver\Tag\DjVuMeta\Month(),
                'Note' => new \PHPExiftool\Driver\Tag\DjVuMeta\Note(),
                'Number' => new \PHPExiftool\Driver\Tag\DjVuMeta\Number(),
                'Organization' => new \PHPExiftool\Driver\Tag\DjVuMeta\Organization(),
                'Pages' => new \PHPExiftool\Driver\Tag\DjVuMeta\Pages(),
                'Publisher' => new \PHPExiftool\Driver\Tag\DjVuMeta\Publisher(),
                'School' => new \PHPExiftool\Driver\Tag\DjVuMeta\School(),
                'Series' => new \PHPExiftool\Driver\Tag\DjVuMeta\Series(),
                'Type' => new \PHPExiftool\Driver\Tag\DjVuMeta\Type(),
                'URL' => new \PHPExiftool\Driver\Tag\DjVuMeta\URL(),
                'Volume' => new \PHPExiftool\Driver\Tag\DjVuMeta\Volume(),
                'Year' => new \PHPExiftool\Driver\Tag\DjVuMeta\Year(),
            );
        });
        $this['EXE'] = $this->share(function(){
            return array(
                'CHMVersion' => new \PHPExiftool\Driver\Tag\EXE\CHMVersion(),
                'LanguageCode' => new \PHPExiftool\Driver\Tag\EXE\LanguageCode(),
                'CPUArchitecture' => new \PHPExiftool\Driver\Tag\EXE\CPUArchitecture(),
                'CPUByteOrder' => new \PHPExiftool\Driver\Tag\EXE\CPUByteOrder(),
                'ObjectFileType' => new \PHPExiftool\Driver\Tag\EXE\ObjectFileType(),
                'CPUType' => new \PHPExiftool\Driver\Tag\EXE\CPUType(),
                'CPUCount' => new \PHPExiftool\Driver\Tag\EXE\CPUCount(),
                'CPUSubtype' => new \PHPExiftool\Driver\Tag\EXE\CPUSubtype(),
                'MachineType' => new \PHPExiftool\Driver\Tag\EXE\MachineType(),
                'TimeStamp' => new \PHPExiftool\Driver\Tag\EXE\TimeStamp(),
                'PEType' => new \PHPExiftool\Driver\Tag\EXE\PEType(),
                'LinkerVersion' => new \PHPExiftool\Driver\Tag\EXE\LinkerVersion(),
                'CodeSize' => new \PHPExiftool\Driver\Tag\EXE\CodeSize(),
                'InitializedDataSize' => new \PHPExiftool\Driver\Tag\EXE\InitializedDataSize(),
                'UninitializedDataSize' => new \PHPExiftool\Driver\Tag\EXE\UninitializedDataSize(),
                'EntryPoint' => new \PHPExiftool\Driver\Tag\EXE\EntryPoint(),
                'OSVersion' => new \PHPExiftool\Driver\Tag\EXE\OSVersion(),
                'ImageVersion' => new \PHPExiftool\Driver\Tag\EXE\ImageVersion(),
                'SubsystemVersion' => new \PHPExiftool\Driver\Tag\EXE\SubsystemVersion(),
                'Subsystem' => new \PHPExiftool\Driver\Tag\EXE\Subsystem(),
                'PEFVersion' => new \PHPExiftool\Driver\Tag\EXE\PEFVersion(),
                'BuildDate' => new \PHPExiftool\Driver\Tag\EXE\BuildDate(),
                'BuildVersion' => new \PHPExiftool\Driver\Tag\EXE\BuildVersion(),
                'CharacterSet' => new \PHPExiftool\Driver\Tag\EXE\CharacterSet(),
                'Comments' => new \PHPExiftool\Driver\Tag\EXE\Comments(),
                'CompanyName' => new \PHPExiftool\Driver\Tag\EXE\CompanyName(),
                'Copyright' => new \PHPExiftool\Driver\Tag\EXE\Copyright(),
                'FileDescription' => new \PHPExiftool\Driver\Tag\EXE\FileDescription(),
                'FileVersion' => new \PHPExiftool\Driver\Tag\EXE\FileVersion(),
                'InternalName' => new \PHPExiftool\Driver\Tag\EXE\InternalName(),
                'LegalCopyright' => new \PHPExiftool\Driver\Tag\EXE\LegalCopyright(),
                'LegalTrademarks' => new \PHPExiftool\Driver\Tag\EXE\LegalTrademarks(),
                'OriginalFilename' => new \PHPExiftool\Driver\Tag\EXE\OriginalFilename(),
                'PrivateBuild' => new \PHPExiftool\Driver\Tag\EXE\PrivateBuild(),
                'ProductName' => new \PHPExiftool\Driver\Tag\EXE\ProductName(),
                'ProductVersion' => new \PHPExiftool\Driver\Tag\EXE\ProductVersion(),
                'SpecialBuild' => new \PHPExiftool\Driver\Tag\EXE\SpecialBuild(),
                'FileVersionNumber' => new \PHPExiftool\Driver\Tag\EXE\FileVersionNumber(),
                'ProductVersionNumber' => new \PHPExiftool\Driver\Tag\EXE\ProductVersionNumber(),
                'FileFlagsMask' => new \PHPExiftool\Driver\Tag\EXE\FileFlagsMask(),
                'FileFlags' => new \PHPExiftool\Driver\Tag\EXE\FileFlags(),
                'FileOS' => new \PHPExiftool\Driver\Tag\EXE\FileOS(),
                'FileSubtype' => new \PHPExiftool\Driver\Tag\EXE\FileSubtype(),
            );
        });
        $this['InteropIFD'] = $this->share(function(){
            return array(
                'InteropIndex' => new \PHPExiftool\Driver\Tag\InteropIFD\InteropIndex(),
                'InteropVersion' => new \PHPExiftool\Driver\Tag\InteropIFD\InteropVersion(),
                'RelatedImageFileFormat' => new \PHPExiftool\Driver\Tag\InteropIFD\RelatedImageFileFormat(),
                'RelatedImageWidth' => new \PHPExiftool\Driver\Tag\InteropIFD\RelatedImageWidth(),
                'RelatedImageHeight' => new \PHPExiftool\Driver\Tag\InteropIFD\RelatedImageHeight(),
            );
        });
        $this['IFD0'] = $this->share(function(){
            return array(
                'ProcessingSoftware' => new \PHPExiftool\Driver\Tag\IFD0\ProcessingSoftware(),
                'SubfileType' => new \PHPExiftool\Driver\Tag\IFD0\SubfileType(),
                'OldSubfileType' => new \PHPExiftool\Driver\Tag\IFD0\OldSubfileType(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\IFD0\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\IFD0\ImageHeight(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\IFD0\BitsPerSample(),
                'Compression' => new \PHPExiftool\Driver\Tag\IFD0\Compression(),
                'PhotometricInterpretation' => new \PHPExiftool\Driver\Tag\IFD0\PhotometricInterpretation(),
                'Thresholding' => new \PHPExiftool\Driver\Tag\IFD0\Thresholding(),
                'CellWidth' => new \PHPExiftool\Driver\Tag\IFD0\CellWidth(),
                'CellLength' => new \PHPExiftool\Driver\Tag\IFD0\CellLength(),
                'FillOrder' => new \PHPExiftool\Driver\Tag\IFD0\FillOrder(),
                'DocumentName' => new \PHPExiftool\Driver\Tag\IFD0\DocumentName(),
                'ImageDescription' => new \PHPExiftool\Driver\Tag\IFD0\ImageDescription(),
                'Make' => new \PHPExiftool\Driver\Tag\IFD0\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\IFD0\Model(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\IFD0\PreviewImageStart(),
                'Orientation' => new \PHPExiftool\Driver\Tag\IFD0\Orientation(),
                'SamplesPerPixel' => new \PHPExiftool\Driver\Tag\IFD0\SamplesPerPixel(),
                'RowsPerStrip' => new \PHPExiftool\Driver\Tag\IFD0\RowsPerStrip(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\IFD0\PreviewImageLength(),
                'MinSampleValue' => new \PHPExiftool\Driver\Tag\IFD0\MinSampleValue(),
                'MaxSampleValue' => new \PHPExiftool\Driver\Tag\IFD0\MaxSampleValue(),
                'XResolution' => new \PHPExiftool\Driver\Tag\IFD0\XResolution(),
                'YResolution' => new \PHPExiftool\Driver\Tag\IFD0\YResolution(),
                'PlanarConfiguration' => new \PHPExiftool\Driver\Tag\IFD0\PlanarConfiguration(),
                'PageName' => new \PHPExiftool\Driver\Tag\IFD0\PageName(),
                'XPosition' => new \PHPExiftool\Driver\Tag\IFD0\XPosition(),
                'YPosition' => new \PHPExiftool\Driver\Tag\IFD0\YPosition(),
                'GrayResponseUnit' => new \PHPExiftool\Driver\Tag\IFD0\GrayResponseUnit(),
                'ResolutionUnit' => new \PHPExiftool\Driver\Tag\IFD0\ResolutionUnit(),
                'PageNumber' => new \PHPExiftool\Driver\Tag\IFD0\PageNumber(),
                'TransferFunction' => new \PHPExiftool\Driver\Tag\IFD0\TransferFunction(),
                'Software' => new \PHPExiftool\Driver\Tag\IFD0\Software(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\IFD0\ModifyDate(),
                'Artist' => new \PHPExiftool\Driver\Tag\IFD0\Artist(),
                'HostComputer' => new \PHPExiftool\Driver\Tag\IFD0\HostComputer(),
                'Predictor' => new \PHPExiftool\Driver\Tag\IFD0\Predictor(),
                'WhitePoint' => new \PHPExiftool\Driver\Tag\IFD0\WhitePoint(),
                'PrimaryChromaticities' => new \PHPExiftool\Driver\Tag\IFD0\PrimaryChromaticities(),
                'HalftoneHints' => new \PHPExiftool\Driver\Tag\IFD0\HalftoneHints(),
                'TileWidth' => new \PHPExiftool\Driver\Tag\IFD0\TileWidth(),
                'TileLength' => new \PHPExiftool\Driver\Tag\IFD0\TileLength(),
                'InkSet' => new \PHPExiftool\Driver\Tag\IFD0\InkSet(),
                'DotRange' => new \PHPExiftool\Driver\Tag\IFD0\DotRange(),
                'ThumbnailOffset' => new \PHPExiftool\Driver\Tag\IFD0\ThumbnailOffset(),
                'ThumbnailLength' => new \PHPExiftool\Driver\Tag\IFD0\ThumbnailLength(),
                'YCbCrCoefficients' => new \PHPExiftool\Driver\Tag\IFD0\YCbCrCoefficients(),
                'YCbCrSubSampling' => new \PHPExiftool\Driver\Tag\IFD0\YCbCrSubSampling(),
                'YCbCrPositioning' => new \PHPExiftool\Driver\Tag\IFD0\YCbCrPositioning(),
                'ReferenceBlackWhite' => new \PHPExiftool\Driver\Tag\IFD0\ReferenceBlackWhite(),
                'Rating' => new \PHPExiftool\Driver\Tag\IFD0\Rating(),
                'RatingPercent' => new \PHPExiftool\Driver\Tag\IFD0\RatingPercent(),
                'Copyright' => new \PHPExiftool\Driver\Tag\IFD0\Copyright(),
                'IPTC-NAA' => new \PHPExiftool\Driver\Tag\IFD0\IPTCNAA(),
                'SEMInfo' => new \PHPExiftool\Driver\Tag\IFD0\SEMInfo(),
                'ImageSourceData' => new \PHPExiftool\Driver\Tag\IFD0\ImageSourceData(),
                'XPTitle' => new \PHPExiftool\Driver\Tag\IFD0\XPTitle(),
                'XPComment' => new \PHPExiftool\Driver\Tag\IFD0\XPComment(),
                'XPAuthor' => new \PHPExiftool\Driver\Tag\IFD0\XPAuthor(),
                'XPKeywords' => new \PHPExiftool\Driver\Tag\IFD0\XPKeywords(),
                'XPSubject' => new \PHPExiftool\Driver\Tag\IFD0\XPSubject(),
                'PrintIM' => new \PHPExiftool\Driver\Tag\IFD0\PrintIM(),
                'DNGVersion' => new \PHPExiftool\Driver\Tag\IFD0\DNGVersion(),
                'DNGBackwardVersion' => new \PHPExiftool\Driver\Tag\IFD0\DNGBackwardVersion(),
                'UniqueCameraModel' => new \PHPExiftool\Driver\Tag\IFD0\UniqueCameraModel(),
                'LocalizedCameraModel' => new \PHPExiftool\Driver\Tag\IFD0\LocalizedCameraModel(),
                'ColorMatrix1' => new \PHPExiftool\Driver\Tag\IFD0\ColorMatrix1(),
                'ColorMatrix2' => new \PHPExiftool\Driver\Tag\IFD0\ColorMatrix2(),
                'CameraCalibration1' => new \PHPExiftool\Driver\Tag\IFD0\CameraCalibration1(),
                'CameraCalibration2' => new \PHPExiftool\Driver\Tag\IFD0\CameraCalibration2(),
                'ReductionMatrix1' => new \PHPExiftool\Driver\Tag\IFD0\ReductionMatrix1(),
                'ReductionMatrix2' => new \PHPExiftool\Driver\Tag\IFD0\ReductionMatrix2(),
                'AnalogBalance' => new \PHPExiftool\Driver\Tag\IFD0\AnalogBalance(),
                'AsShotNeutral' => new \PHPExiftool\Driver\Tag\IFD0\AsShotNeutral(),
                'AsShotWhiteXY' => new \PHPExiftool\Driver\Tag\IFD0\AsShotWhiteXY(),
                'BaselineExposure' => new \PHPExiftool\Driver\Tag\IFD0\BaselineExposure(),
                'BaselineNoise' => new \PHPExiftool\Driver\Tag\IFD0\BaselineNoise(),
                'BaselineSharpness' => new \PHPExiftool\Driver\Tag\IFD0\BaselineSharpness(),
                'LinearResponseLimit' => new \PHPExiftool\Driver\Tag\IFD0\LinearResponseLimit(),
                'CameraSerialNumber' => new \PHPExiftool\Driver\Tag\IFD0\CameraSerialNumber(),
                'DNGLensInfo' => new \PHPExiftool\Driver\Tag\IFD0\DNGLensInfo(),
                'ShadowScale' => new \PHPExiftool\Driver\Tag\IFD0\ShadowScale(),
                'MakerNoteSafety' => new \PHPExiftool\Driver\Tag\IFD0\MakerNoteSafety(),
                'CalibrationIlluminant1' => new \PHPExiftool\Driver\Tag\IFD0\CalibrationIlluminant1(),
                'CalibrationIlluminant2' => new \PHPExiftool\Driver\Tag\IFD0\CalibrationIlluminant2(),
                'RawDataUniqueID' => new \PHPExiftool\Driver\Tag\IFD0\RawDataUniqueID(),
                'OriginalRawFileName' => new \PHPExiftool\Driver\Tag\IFD0\OriginalRawFileName(),
                'OriginalRawFileData' => new \PHPExiftool\Driver\Tag\IFD0\OriginalRawFileData(),
                'AsShotICCProfile' => new \PHPExiftool\Driver\Tag\IFD0\AsShotICCProfile(),
                'AsShotPreProfileMatrix' => new \PHPExiftool\Driver\Tag\IFD0\AsShotPreProfileMatrix(),
                'CurrentICCProfile' => new \PHPExiftool\Driver\Tag\IFD0\CurrentICCProfile(),
                'CurrentPreProfileMatrix' => new \PHPExiftool\Driver\Tag\IFD0\CurrentPreProfileMatrix(),
                'ColorimetricReference' => new \PHPExiftool\Driver\Tag\IFD0\ColorimetricReference(),
                'PanasonicTitle' => new \PHPExiftool\Driver\Tag\IFD0\PanasonicTitle(),
                'PanasonicTitle2' => new \PHPExiftool\Driver\Tag\IFD0\PanasonicTitle2(),
                'CameraCalibrationSig' => new \PHPExiftool\Driver\Tag\IFD0\CameraCalibrationSig(),
                'ProfileCalibrationSig' => new \PHPExiftool\Driver\Tag\IFD0\ProfileCalibrationSig(),
                'AsShotProfileName' => new \PHPExiftool\Driver\Tag\IFD0\AsShotProfileName(),
                'ProfileName' => new \PHPExiftool\Driver\Tag\IFD0\ProfileName(),
                'ProfileHueSatMapDims' => new \PHPExiftool\Driver\Tag\IFD0\ProfileHueSatMapDims(),
                'ProfileHueSatMapData1' => new \PHPExiftool\Driver\Tag\IFD0\ProfileHueSatMapData1(),
                'ProfileHueSatMapData2' => new \PHPExiftool\Driver\Tag\IFD0\ProfileHueSatMapData2(),
                'ProfileToneCurve' => new \PHPExiftool\Driver\Tag\IFD0\ProfileToneCurve(),
                'ProfileEmbedPolicy' => new \PHPExiftool\Driver\Tag\IFD0\ProfileEmbedPolicy(),
                'ProfileCopyright' => new \PHPExiftool\Driver\Tag\IFD0\ProfileCopyright(),
                'ForwardMatrix1' => new \PHPExiftool\Driver\Tag\IFD0\ForwardMatrix1(),
                'ForwardMatrix2' => new \PHPExiftool\Driver\Tag\IFD0\ForwardMatrix2(),
                'PreviewApplicationName' => new \PHPExiftool\Driver\Tag\IFD0\PreviewApplicationName(),
                'PreviewApplicationVersion' => new \PHPExiftool\Driver\Tag\IFD0\PreviewApplicationVersion(),
                'PreviewSettingsName' => new \PHPExiftool\Driver\Tag\IFD0\PreviewSettingsName(),
                'PreviewSettingsDigest' => new \PHPExiftool\Driver\Tag\IFD0\PreviewSettingsDigest(),
                'PreviewColorSpace' => new \PHPExiftool\Driver\Tag\IFD0\PreviewColorSpace(),
                'PreviewDateTime' => new \PHPExiftool\Driver\Tag\IFD0\PreviewDateTime(),
                'RawImageDigest' => new \PHPExiftool\Driver\Tag\IFD0\RawImageDigest(),
                'OriginalRawFileDigest' => new \PHPExiftool\Driver\Tag\IFD0\OriginalRawFileDigest(),
                'ProfileLookTableDims' => new \PHPExiftool\Driver\Tag\IFD0\ProfileLookTableDims(),
                'ProfileLookTableData' => new \PHPExiftool\Driver\Tag\IFD0\ProfileLookTableData(),
                'OriginalDefaultFinalSize' => new \PHPExiftool\Driver\Tag\IFD0\OriginalDefaultFinalSize(),
                'OriginalBestQualitySize' => new \PHPExiftool\Driver\Tag\IFD0\OriginalBestQualitySize(),
                'OriginalDefaultCropSize' => new \PHPExiftool\Driver\Tag\IFD0\OriginalDefaultCropSize(),
                'ProfileHueSatMapEncoding' => new \PHPExiftool\Driver\Tag\IFD0\ProfileHueSatMapEncoding(),
                'ProfileLookTableEncoding' => new \PHPExiftool\Driver\Tag\IFD0\ProfileLookTableEncoding(),
                'BaselineExposureOffset' => new \PHPExiftool\Driver\Tag\IFD0\BaselineExposureOffset(),
                'DefaultBlackRender' => new \PHPExiftool\Driver\Tag\IFD0\DefaultBlackRender(),
                'NewRawImageDigest' => new \PHPExiftool\Driver\Tag\IFD0\NewRawImageDigest(),
                'RawToPreviewGain' => new \PHPExiftool\Driver\Tag\IFD0\RawToPreviewGain(),
                'PanasonicRawVersion' => new \PHPExiftool\Driver\Tag\IFD0\PanasonicRawVersion(),
                'SensorWidth' => new \PHPExiftool\Driver\Tag\IFD0\SensorWidth(),
                'SensorHeight' => new \PHPExiftool\Driver\Tag\IFD0\SensorHeight(),
                'SensorTopBorder' => new \PHPExiftool\Driver\Tag\IFD0\SensorTopBorder(),
                'SensorLeftBorder' => new \PHPExiftool\Driver\Tag\IFD0\SensorLeftBorder(),
                'SensorBottomBorder' => new \PHPExiftool\Driver\Tag\IFD0\SensorBottomBorder(),
                'SensorRightBorder' => new \PHPExiftool\Driver\Tag\IFD0\SensorRightBorder(),
                'RedBalance' => new \PHPExiftool\Driver\Tag\IFD0\RedBalance(),
                'BlueBalance' => new \PHPExiftool\Driver\Tag\IFD0\BlueBalance(),
                'ISO' => new \PHPExiftool\Driver\Tag\IFD0\ISO(),
                'WBRedLevel' => new \PHPExiftool\Driver\Tag\IFD0\WBRedLevel(),
                'WBGreenLevel' => new \PHPExiftool\Driver\Tag\IFD0\WBGreenLevel(),
                'WBBlueLevel' => new \PHPExiftool\Driver\Tag\IFD0\WBBlueLevel(),
                'JpgFromRaw' => new \PHPExiftool\Driver\Tag\IFD0\JpgFromRaw(),
                'StripOffsets' => new \PHPExiftool\Driver\Tag\IFD0\StripOffsets(),
                'StripByteCounts' => new \PHPExiftool\Driver\Tag\IFD0\StripByteCounts(),
                'RawDataOffset' => new \PHPExiftool\Driver\Tag\IFD0\RawDataOffset(),
                'ApplicationNotes' => new \PHPExiftool\Driver\Tag\IFD0\ApplicationNotes(),
            );
        });
        $this['SubIFD1'] = $this->share(function(){
            return array(
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\SubIFD1\PreviewImageStart(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\SubIFD1\PreviewImageLength(),
                'OtherImageStart' => new \PHPExiftool\Driver\Tag\SubIFD1\OtherImageStart(),
                'OtherImageLength' => new \PHPExiftool\Driver\Tag\SubIFD1\OtherImageLength(),
            );
        });
        $this['SubIFD2'] = $this->share(function(){
            return array(
                'JpgFromRawStart' => new \PHPExiftool\Driver\Tag\SubIFD2\JpgFromRawStart(),
                'JpgFromRawLength' => new \PHPExiftool\Driver\Tag\SubIFD2\JpgFromRawLength(),
                'OtherImageStart' => new \PHPExiftool\Driver\Tag\SubIFD2\OtherImageStart(),
                'OtherImageLength' => new \PHPExiftool\Driver\Tag\SubIFD2\OtherImageLength(),
            );
        });
        $this['IFD1'] = $this->share(function(){
            return array(
                'ThumbnailOffset' => new \PHPExiftool\Driver\Tag\IFD1\ThumbnailOffset(),
                'ThumbnailLength' => new \PHPExiftool\Driver\Tag\IFD1\ThumbnailLength(),
            );
        });
        $this['SubIFD'] = $this->share(function(){
            return array(
                'ThumbnailOffset' => new \PHPExiftool\Driver\Tag\SubIFD\ThumbnailOffset(),
                'JpgFromRawStart' => new \PHPExiftool\Driver\Tag\SubIFD\JpgFromRawStart(),
                'ThumbnailLength' => new \PHPExiftool\Driver\Tag\SubIFD\ThumbnailLength(),
                'JpgFromRawLength' => new \PHPExiftool\Driver\Tag\SubIFD\JpgFromRawLength(),
                'CFARepeatPatternDim' => new \PHPExiftool\Driver\Tag\SubIFD\CFARepeatPatternDim(),
                'CFAPattern2' => new \PHPExiftool\Driver\Tag\SubIFD\CFAPattern2(),
                'LinearizationTable' => new \PHPExiftool\Driver\Tag\SubIFD\LinearizationTable(),
                'BlackLevelRepeatDim' => new \PHPExiftool\Driver\Tag\SubIFD\BlackLevelRepeatDim(),
                'BlackLevel' => new \PHPExiftool\Driver\Tag\SubIFD\BlackLevel(),
                'WhiteLevel' => new \PHPExiftool\Driver\Tag\SubIFD\WhiteLevel(),
                'DefaultScale' => new \PHPExiftool\Driver\Tag\SubIFD\DefaultScale(),
                'DefaultCropOrigin' => new \PHPExiftool\Driver\Tag\SubIFD\DefaultCropOrigin(),
                'DefaultCropSize' => new \PHPExiftool\Driver\Tag\SubIFD\DefaultCropSize(),
                'BayerGreenSplit' => new \PHPExiftool\Driver\Tag\SubIFD\BayerGreenSplit(),
                'ChromaBlurRadius' => new \PHPExiftool\Driver\Tag\SubIFD\ChromaBlurRadius(),
                'AntiAliasStrength' => new \PHPExiftool\Driver\Tag\SubIFD\AntiAliasStrength(),
                'BestQualityScale' => new \PHPExiftool\Driver\Tag\SubIFD\BestQualityScale(),
                'ActiveArea' => new \PHPExiftool\Driver\Tag\SubIFD\ActiveArea(),
                'MaskedAreas' => new \PHPExiftool\Driver\Tag\SubIFD\MaskedAreas(),
                'NoiseReductionApplied' => new \PHPExiftool\Driver\Tag\SubIFD\NoiseReductionApplied(),
                'DefaultUserCrop' => new \PHPExiftool\Driver\Tag\SubIFD\DefaultUserCrop(),
            );
        });
        $this['IFD2'] = $this->share(function(){
            return array(
                'JpgFromRawStart' => new \PHPExiftool\Driver\Tag\IFD2\JpgFromRawStart(),
                'JpgFromRawLength' => new \PHPExiftool\Driver\Tag\IFD2\JpgFromRawLength(),
            );
        });
        $this['Adobe'] = $this->share(function(){
            return array(
                'Adobe' => new \PHPExiftool\Driver\Tag\Adobe\Adobe(),
                'DCTEncodeVersion' => new \PHPExiftool\Driver\Tag\Adobe\DCTEncodeVersion(),
                'APP14Flags0' => new \PHPExiftool\Driver\Tag\Adobe\APP14Flags0(),
                'APP14Flags1' => new \PHPExiftool\Driver\Tag\Adobe\APP14Flags1(),
                'ColorTransform' => new \PHPExiftool\Driver\Tag\Adobe\ColorTransform(),
            );
        });
        $this['System'] = $this->share(function(){
            return array(
                'Directory' => new \PHPExiftool\Driver\Tag\System\Directory(),
                'FileAccessDate' => new \PHPExiftool\Driver\Tag\System\FileAccessDate(),
                'FileCreateDate' => new \PHPExiftool\Driver\Tag\System\FileCreateDate(),
                'FileInodeChangeDate' => new \PHPExiftool\Driver\Tag\System\FileInodeChangeDate(),
                'FileModifyDate' => new \PHPExiftool\Driver\Tag\System\FileModifyDate(),
                'FileName' => new \PHPExiftool\Driver\Tag\System\FileName(),
                'FilePermissions' => new \PHPExiftool\Driver\Tag\System\FilePermissions(),
                'FileSize' => new \PHPExiftool\Driver\Tag\System\FileSize(),
                'ResourceForkSize' => new \PHPExiftool\Driver\Tag\System\ResourceForkSize(),
            );
        });
        $this['EXIF'] = $this->share(function(){
            return array(
                'EXIF' => new \PHPExiftool\Driver\Tag\EXIF\EXIF(),
            );
        });
        $this['ExifTool'] = $this->share(function(){
            return array(
                'Error' => new \PHPExiftool\Driver\Tag\ExifTool\Error(),
                'ExifToolVersion' => new \PHPExiftool\Driver\Tag\ExifTool\ExifToolVersion(),
                'FileSequence' => new \PHPExiftool\Driver\Tag\ExifTool\FileSequence(),
                'NewGUID' => new \PHPExiftool\Driver\Tag\ExifTool\NewGUID(),
                'Now' => new \PHPExiftool\Driver\Tag\ExifTool\Now(),
                'Warning' => new \PHPExiftool\Driver\Tag\ExifTool\Warning(),
            );
        });
        $this['ICC_Profile'] = $this->share(function(){
            return array(
                'ICC_Profile' => new \PHPExiftool\Driver\Tag\ICCProfile\ICCProfile(),
                'AToB0' => new \PHPExiftool\Driver\Tag\ICCProfile\AToB0(),
                'AToB1' => new \PHPExiftool\Driver\Tag\ICCProfile\AToB1(),
                'AToB2' => new \PHPExiftool\Driver\Tag\ICCProfile\AToB2(),
                'BToA0' => new \PHPExiftool\Driver\Tag\ICCProfile\BToA0(),
                'BToA1' => new \PHPExiftool\Driver\Tag\ICCProfile\BToA1(),
                'BToA2' => new \PHPExiftool\Driver\Tag\ICCProfile\BToA2(),
                'BToD0' => new \PHPExiftool\Driver\Tag\ICCProfile\BToD0(),
                'BToD1' => new \PHPExiftool\Driver\Tag\ICCProfile\BToD1(),
                'BToD2' => new \PHPExiftool\Driver\Tag\ICCProfile\BToD2(),
                'BToD3' => new \PHPExiftool\Driver\Tag\ICCProfile\BToD3(),
                'DToB0' => new \PHPExiftool\Driver\Tag\ICCProfile\DToB0(),
                'DToB1' => new \PHPExiftool\Driver\Tag\ICCProfile\DToB1(),
                'DToB2' => new \PHPExiftool\Driver\Tag\ICCProfile\DToB2(),
                'DToB3' => new \PHPExiftool\Driver\Tag\ICCProfile\DToB3(),
                'WCSProfiles' => new \PHPExiftool\Driver\Tag\ICCProfile\WCSProfiles(),
                'BlueTRC' => new \PHPExiftool\Driver\Tag\ICCProfile\BlueTRC(),
                'BlueMatrixColumn' => new \PHPExiftool\Driver\Tag\ICCProfile\BlueMatrixColumn(),
                'UCRBG' => new \PHPExiftool\Driver\Tag\ICCProfile\UCRBG(),
                'MediaBlackPoint' => new \PHPExiftool\Driver\Tag\ICCProfile\MediaBlackPoint(),
                'CalibrationDateTime' => new \PHPExiftool\Driver\Tag\ICCProfile\CalibrationDateTime(),
                'ChromaticAdaptation' => new \PHPExiftool\Driver\Tag\ICCProfile\ChromaticAdaptation(),
                'ColorimetricIntentImageState' => new \PHPExiftool\Driver\Tag\ICCProfile\ColorimetricIntentImageState(),
                'ColorantTableOut' => new \PHPExiftool\Driver\Tag\ICCProfile\ColorantTableOut(),
                'ColorantOrder' => new \PHPExiftool\Driver\Tag\ICCProfile\ColorantOrder(),
                'ProfileCopyright' => new \PHPExiftool\Driver\Tag\ICCProfile\ProfileCopyright(),
                'CRDInfo' => new \PHPExiftool\Driver\Tag\ICCProfile\CRDInfo(),
                'ProfileDescription' => new \PHPExiftool\Driver\Tag\ICCProfile\ProfileDescription(),
                'DeviceSettings' => new \PHPExiftool\Driver\Tag\ICCProfile\DeviceSettings(),
                'DeviceModelDesc' => new \PHPExiftool\Driver\Tag\ICCProfile\DeviceModelDesc(),
                'DeviceMfgDesc' => new \PHPExiftool\Driver\Tag\ICCProfile\DeviceMfgDesc(),
                'ProfileDescriptionML' => new \PHPExiftool\Driver\Tag\ICCProfile\ProfileDescriptionML(),
                'FocalPlaneColorimetryEstimates' => new \PHPExiftool\Driver\Tag\ICCProfile\FocalPlaneColorimetryEstimates(),
                'GreenTRC' => new \PHPExiftool\Driver\Tag\ICCProfile\GreenTRC(),
                'GreenMatrixColumn' => new \PHPExiftool\Driver\Tag\ICCProfile\GreenMatrixColumn(),
                'Gamut' => new \PHPExiftool\Driver\Tag\ICCProfile\Gamut(),
                'GrayTRC' => new \PHPExiftool\Driver\Tag\ICCProfile\GrayTRC(),
                'Luminance' => new \PHPExiftool\Driver\Tag\ICCProfile\Luminance(),
                'MakeAndModel' => new \PHPExiftool\Driver\Tag\ICCProfile\MakeAndModel(),
                'NamedColor2' => new \PHPExiftool\Driver\Tag\ICCProfile\NamedColor2(),
                'NamedColor' => new \PHPExiftool\Driver\Tag\ICCProfile\NamedColor(),
                'NativeDisplayInfo' => new \PHPExiftool\Driver\Tag\ICCProfile\NativeDisplayInfo(),
                'Preview0' => new \PHPExiftool\Driver\Tag\ICCProfile\Preview0(),
                'Preview1' => new \PHPExiftool\Driver\Tag\ICCProfile\Preview1(),
                'Preview2' => new \PHPExiftool\Driver\Tag\ICCProfile\Preview2(),
                'PS2RenderingIntent' => new \PHPExiftool\Driver\Tag\ICCProfile\PS2RenderingIntent(),
                'PostScript2CSA' => new \PHPExiftool\Driver\Tag\ICCProfile\PostScript2CSA(),
                'PostScript2CRD0' => new \PHPExiftool\Driver\Tag\ICCProfile\PostScript2CRD0(),
                'PostScript2CRD1' => new \PHPExiftool\Driver\Tag\ICCProfile\PostScript2CRD1(),
                'PostScript2CRD2' => new \PHPExiftool\Driver\Tag\ICCProfile\PostScript2CRD2(),
                'ProfileSequenceDesc' => new \PHPExiftool\Driver\Tag\ICCProfile\ProfileSequenceDesc(),
                'ProfileSequenceIdentifier' => new \PHPExiftool\Driver\Tag\ICCProfile\ProfileSequenceIdentifier(),
                'PS2CRDVMSize' => new \PHPExiftool\Driver\Tag\ICCProfile\PS2CRDVMSize(),
                'RedTRC' => new \PHPExiftool\Driver\Tag\ICCProfile\RedTRC(),
                'RedMatrixColumn' => new \PHPExiftool\Driver\Tag\ICCProfile\RedMatrixColumn(),
                'OutputResponse' => new \PHPExiftool\Driver\Tag\ICCProfile\OutputResponse(),
                'ReflectionHardcopyOrigColorimetry' => new \PHPExiftool\Driver\Tag\ICCProfile\ReflectionHardcopyOrigColorimetry(),
                'PerceptualRenderingIntentGamut' => new \PHPExiftool\Driver\Tag\ICCProfile\PerceptualRenderingIntentGamut(),
                'SaturationRenderingIntentGamut' => new \PHPExiftool\Driver\Tag\ICCProfile\SaturationRenderingIntentGamut(),
                'ReflectionPrintOutputColorimetry' => new \PHPExiftool\Driver\Tag\ICCProfile\ReflectionPrintOutputColorimetry(),
                'SceneAppearanceEstimates' => new \PHPExiftool\Driver\Tag\ICCProfile\SceneAppearanceEstimates(),
                'SceneColorimetryEstimates' => new \PHPExiftool\Driver\Tag\ICCProfile\SceneColorimetryEstimates(),
                'ScreeningDesc' => new \PHPExiftool\Driver\Tag\ICCProfile\ScreeningDesc(),
                'Screening' => new \PHPExiftool\Driver\Tag\ICCProfile\Screening(),
                'CharTarget' => new \PHPExiftool\Driver\Tag\ICCProfile\CharTarget(),
                'Technology' => new \PHPExiftool\Driver\Tag\ICCProfile\Technology(),
                'VideoCardGamma' => new \PHPExiftool\Driver\Tag\ICCProfile\VideoCardGamma(),
                'ViewingCondDesc' => new \PHPExiftool\Driver\Tag\ICCProfile\ViewingCondDesc(),
                'MediaWhitePoint' => new \PHPExiftool\Driver\Tag\ICCProfile\MediaWhitePoint(),
            );
        });
        $this['IPTC'] = $this->share(function(){
            return array(
                'IPTC' => new \PHPExiftool\Driver\Tag\IPTC\IPTC(),
                'ApplicationRecordVersion' => new \PHPExiftool\Driver\Tag\IPTC\ApplicationRecordVersion(),
                'ObjectTypeReference' => new \PHPExiftool\Driver\Tag\IPTC\ObjectTypeReference(),
                'ObjectAttributeReference' => new \PHPExiftool\Driver\Tag\IPTC\ObjectAttributeReference(),
                'ObjectName' => new \PHPExiftool\Driver\Tag\IPTC\ObjectName(),
                'EditStatus' => new \PHPExiftool\Driver\Tag\IPTC\EditStatus(),
                'EditorialUpdate' => new \PHPExiftool\Driver\Tag\IPTC\EditorialUpdate(),
                'Urgency' => new \PHPExiftool\Driver\Tag\IPTC\Urgency(),
                'SubjectReference' => new \PHPExiftool\Driver\Tag\IPTC\SubjectReference(),
                'Category' => new \PHPExiftool\Driver\Tag\IPTC\Category(),
                'SupplementalCategories' => new \PHPExiftool\Driver\Tag\IPTC\SupplementalCategories(),
                'FixtureIdentifier' => new \PHPExiftool\Driver\Tag\IPTC\FixtureIdentifier(),
                'Keywords' => new \PHPExiftool\Driver\Tag\IPTC\Keywords(),
                'ContentLocationCode' => new \PHPExiftool\Driver\Tag\IPTC\ContentLocationCode(),
                'ContentLocationName' => new \PHPExiftool\Driver\Tag\IPTC\ContentLocationName(),
                'ReleaseDate' => new \PHPExiftool\Driver\Tag\IPTC\ReleaseDate(),
                'ReleaseTime' => new \PHPExiftool\Driver\Tag\IPTC\ReleaseTime(),
                'ExpirationDate' => new \PHPExiftool\Driver\Tag\IPTC\ExpirationDate(),
                'ExpirationTime' => new \PHPExiftool\Driver\Tag\IPTC\ExpirationTime(),
                'SpecialInstructions' => new \PHPExiftool\Driver\Tag\IPTC\SpecialInstructions(),
                'ActionAdvised' => new \PHPExiftool\Driver\Tag\IPTC\ActionAdvised(),
                'ReferenceService' => new \PHPExiftool\Driver\Tag\IPTC\ReferenceService(),
                'ReferenceDate' => new \PHPExiftool\Driver\Tag\IPTC\ReferenceDate(),
                'ReferenceNumber' => new \PHPExiftool\Driver\Tag\IPTC\ReferenceNumber(),
                'DateCreated' => new \PHPExiftool\Driver\Tag\IPTC\DateCreated(),
                'TimeCreated' => new \PHPExiftool\Driver\Tag\IPTC\TimeCreated(),
                'DigitalCreationDate' => new \PHPExiftool\Driver\Tag\IPTC\DigitalCreationDate(),
                'DigitalCreationTime' => new \PHPExiftool\Driver\Tag\IPTC\DigitalCreationTime(),
                'OriginatingProgram' => new \PHPExiftool\Driver\Tag\IPTC\OriginatingProgram(),
                'ProgramVersion' => new \PHPExiftool\Driver\Tag\IPTC\ProgramVersion(),
                'ObjectCycle' => new \PHPExiftool\Driver\Tag\IPTC\ObjectCycle(),
                'By-line' => new \PHPExiftool\Driver\Tag\IPTC\ByLine(),
                'By-lineTitle' => new \PHPExiftool\Driver\Tag\IPTC\ByLineTitle(),
                'City' => new \PHPExiftool\Driver\Tag\IPTC\City(),
                'Sub-location' => new \PHPExiftool\Driver\Tag\IPTC\SubLocation(),
                'Province-State' => new \PHPExiftool\Driver\Tag\IPTC\ProvinceState(),
                'Country-PrimaryLocationCode' => new \PHPExiftool\Driver\Tag\IPTC\CountryPrimaryLocationCode(),
                'Country-PrimaryLocationName' => new \PHPExiftool\Driver\Tag\IPTC\CountryPrimaryLocationName(),
                'OriginalTransmissionReference' => new \PHPExiftool\Driver\Tag\IPTC\OriginalTransmissionReference(),
                'Headline' => new \PHPExiftool\Driver\Tag\IPTC\Headline(),
                'Credit' => new \PHPExiftool\Driver\Tag\IPTC\Credit(),
                'Source' => new \PHPExiftool\Driver\Tag\IPTC\Source(),
                'CopyrightNotice' => new \PHPExiftool\Driver\Tag\IPTC\CopyrightNotice(),
                'Contact' => new \PHPExiftool\Driver\Tag\IPTC\Contact(),
                'Caption-Abstract' => new \PHPExiftool\Driver\Tag\IPTC\CaptionAbstract(),
                'LocalCaption' => new \PHPExiftool\Driver\Tag\IPTC\LocalCaption(),
                'Writer-Editor' => new \PHPExiftool\Driver\Tag\IPTC\WriterEditor(),
                'RasterizedCaption' => new \PHPExiftool\Driver\Tag\IPTC\RasterizedCaption(),
                'ImageType' => new \PHPExiftool\Driver\Tag\IPTC\ImageType(),
                'ImageOrientation' => new \PHPExiftool\Driver\Tag\IPTC\ImageOrientation(),
                'LanguageIdentifier' => new \PHPExiftool\Driver\Tag\IPTC\LanguageIdentifier(),
                'AudioType' => new \PHPExiftool\Driver\Tag\IPTC\AudioType(),
                'AudioSamplingRate' => new \PHPExiftool\Driver\Tag\IPTC\AudioSamplingRate(),
                'AudioSamplingResolution' => new \PHPExiftool\Driver\Tag\IPTC\AudioSamplingResolution(),
                'AudioDuration' => new \PHPExiftool\Driver\Tag\IPTC\AudioDuration(),
                'AudioOutcue' => new \PHPExiftool\Driver\Tag\IPTC\AudioOutcue(),
                'JobID' => new \PHPExiftool\Driver\Tag\IPTC\JobID(),
                'MasterDocumentID' => new \PHPExiftool\Driver\Tag\IPTC\MasterDocumentID(),
                'ShortDocumentID' => new \PHPExiftool\Driver\Tag\IPTC\ShortDocumentID(),
                'UniqueDocumentID' => new \PHPExiftool\Driver\Tag\IPTC\UniqueDocumentID(),
                'OwnerID' => new \PHPExiftool\Driver\Tag\IPTC\OwnerID(),
                'ObjectPreviewFileFormat' => new \PHPExiftool\Driver\Tag\IPTC\ObjectPreviewFileFormat(),
                'ObjectPreviewFileVersion' => new \PHPExiftool\Driver\Tag\IPTC\ObjectPreviewFileVersion(),
                'ObjectPreviewData' => new \PHPExiftool\Driver\Tag\IPTC\ObjectPreviewData(),
                'Prefs' => new \PHPExiftool\Driver\Tag\IPTC\Prefs(),
                'ClassifyState' => new \PHPExiftool\Driver\Tag\IPTC\ClassifyState(),
                'SimilarityIndex' => new \PHPExiftool\Driver\Tag\IPTC\SimilarityIndex(),
                'DocumentNotes' => new \PHPExiftool\Driver\Tag\IPTC\DocumentNotes(),
                'DocumentHistory' => new \PHPExiftool\Driver\Tag\IPTC\DocumentHistory(),
                'ExifCameraInfo' => new \PHPExiftool\Driver\Tag\IPTC\ExifCameraInfo(),
                'CatalogSets' => new \PHPExiftool\Driver\Tag\IPTC\CatalogSets(),
                'EnvelopeRecordVersion' => new \PHPExiftool\Driver\Tag\IPTC\EnvelopeRecordVersion(),
                'Destination' => new \PHPExiftool\Driver\Tag\IPTC\Destination(),
                'FileFormat' => new \PHPExiftool\Driver\Tag\IPTC\FileFormat(),
                'FileVersion' => new \PHPExiftool\Driver\Tag\IPTC\FileVersion(),
                'ServiceIdentifier' => new \PHPExiftool\Driver\Tag\IPTC\ServiceIdentifier(),
                'EnvelopeNumber' => new \PHPExiftool\Driver\Tag\IPTC\EnvelopeNumber(),
                'ProductID' => new \PHPExiftool\Driver\Tag\IPTC\ProductID(),
                'EnvelopePriority' => new \PHPExiftool\Driver\Tag\IPTC\EnvelopePriority(),
                'DateSent' => new \PHPExiftool\Driver\Tag\IPTC\DateSent(),
                'TimeSent' => new \PHPExiftool\Driver\Tag\IPTC\TimeSent(),
                'CodedCharacterSet' => new \PHPExiftool\Driver\Tag\IPTC\CodedCharacterSet(),
                'UniqueObjectName' => new \PHPExiftool\Driver\Tag\IPTC\UniqueObjectName(),
                'ARMIdentifier' => new \PHPExiftool\Driver\Tag\IPTC\ARMIdentifier(),
                'ARMVersion' => new \PHPExiftool\Driver\Tag\IPTC\ARMVersion(),
                'NewsPhotoVersion' => new \PHPExiftool\Driver\Tag\IPTC\NewsPhotoVersion(),
                'IPTCPictureNumber' => new \PHPExiftool\Driver\Tag\IPTC\IPTCPictureNumber(),
                'IPTCImageWidth' => new \PHPExiftool\Driver\Tag\IPTC\IPTCImageWidth(),
                'IPTCImageHeight' => new \PHPExiftool\Driver\Tag\IPTC\IPTCImageHeight(),
                'IPTCPixelWidth' => new \PHPExiftool\Driver\Tag\IPTC\IPTCPixelWidth(),
                'IPTCPixelHeight' => new \PHPExiftool\Driver\Tag\IPTC\IPTCPixelHeight(),
                'SupplementalType' => new \PHPExiftool\Driver\Tag\IPTC\SupplementalType(),
                'ColorRepresentation' => new \PHPExiftool\Driver\Tag\IPTC\ColorRepresentation(),
                'InterchangeColorSpace' => new \PHPExiftool\Driver\Tag\IPTC\InterchangeColorSpace(),
                'ColorSequence' => new \PHPExiftool\Driver\Tag\IPTC\ColorSequence(),
                'ICC_Profile' => new \PHPExiftool\Driver\Tag\IPTC\ICCProfile(),
                'ColorCalibrationMatrix' => new \PHPExiftool\Driver\Tag\IPTC\ColorCalibrationMatrix(),
                'LookupTable' => new \PHPExiftool\Driver\Tag\IPTC\LookupTable(),
                'NumIndexEntries' => new \PHPExiftool\Driver\Tag\IPTC\NumIndexEntries(),
                'ColorPalette' => new \PHPExiftool\Driver\Tag\IPTC\ColorPalette(),
                'IPTCBitsPerSample' => new \PHPExiftool\Driver\Tag\IPTC\IPTCBitsPerSample(),
                'SampleStructure' => new \PHPExiftool\Driver\Tag\IPTC\SampleStructure(),
                'ScanningDirection' => new \PHPExiftool\Driver\Tag\IPTC\ScanningDirection(),
                'IPTCImageRotation' => new \PHPExiftool\Driver\Tag\IPTC\IPTCImageRotation(),
                'DataCompressionMethod' => new \PHPExiftool\Driver\Tag\IPTC\DataCompressionMethod(),
                'QuantizationMethod' => new \PHPExiftool\Driver\Tag\IPTC\QuantizationMethod(),
                'EndPoints' => new \PHPExiftool\Driver\Tag\IPTC\EndPoints(),
                'ExcursionTolerance' => new \PHPExiftool\Driver\Tag\IPTC\ExcursionTolerance(),
                'BitsPerComponent' => new \PHPExiftool\Driver\Tag\IPTC\BitsPerComponent(),
                'MaximumDensityRange' => new \PHPExiftool\Driver\Tag\IPTC\MaximumDensityRange(),
                'GammaCompensatedValue' => new \PHPExiftool\Driver\Tag\IPTC\GammaCompensatedValue(),
                'SubFile' => new \PHPExiftool\Driver\Tag\IPTC\SubFile(),
                'ConfirmedObjectSize' => new \PHPExiftool\Driver\Tag\IPTC\ConfirmedObjectSize(),
                'SizeMode' => new \PHPExiftool\Driver\Tag\IPTC\SizeMode(),
                'MaxSubfileSize' => new \PHPExiftool\Driver\Tag\IPTC\MaxSubfileSize(),
                'ObjectSizeAnnounced' => new \PHPExiftool\Driver\Tag\IPTC\ObjectSizeAnnounced(),
                'MaximumObjectSize' => new \PHPExiftool\Driver\Tag\IPTC\MaximumObjectSize(),
            );
        });
        $this['XMP'] = $this->share(function(){
            return array(
                'XMP' => new \PHPExiftool\Driver\Tag\XMP\XMP(),
            );
        });
        $this['FLAC'] = $this->share(function(){
            return array(
                'Padding' => new \PHPExiftool\Driver\Tag\FLAC\Padding(),
                'Application' => new \PHPExiftool\Driver\Tag\FLAC\Application(),
                'SeekTable' => new \PHPExiftool\Driver\Tag\FLAC\SeekTable(),
                'CueSheet' => new \PHPExiftool\Driver\Tag\FLAC\CueSheet(),
                'PictureType' => new \PHPExiftool\Driver\Tag\FLAC\PictureType(),
                'PictureMIMEType' => new \PHPExiftool\Driver\Tag\FLAC\PictureMIMEType(),
                'PictureDescription' => new \PHPExiftool\Driver\Tag\FLAC\PictureDescription(),
                'PictureWidth' => new \PHPExiftool\Driver\Tag\FLAC\PictureWidth(),
                'PictureHeight' => new \PHPExiftool\Driver\Tag\FLAC\PictureHeight(),
                'PictureBitsPerPixel' => new \PHPExiftool\Driver\Tag\FLAC\PictureBitsPerPixel(),
                'PictureIndexedColors' => new \PHPExiftool\Driver\Tag\FLAC\PictureIndexedColors(),
                'PictureLength' => new \PHPExiftool\Driver\Tag\FLAC\PictureLength(),
                'Picture' => new \PHPExiftool\Driver\Tag\FLAC\Picture(),
                'BlockSizeMin' => new \PHPExiftool\Driver\Tag\FLAC\BlockSizeMin(),
                'BlockSizeMax' => new \PHPExiftool\Driver\Tag\FLAC\BlockSizeMax(),
                'FrameSizeMin' => new \PHPExiftool\Driver\Tag\FLAC\FrameSizeMin(),
                'FrameSizeMax' => new \PHPExiftool\Driver\Tag\FLAC\FrameSizeMax(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\FLAC\SampleRate(),
                'Channels' => new \PHPExiftool\Driver\Tag\FLAC\Channels(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\FLAC\BitsPerSample(),
                'TotalSamples' => new \PHPExiftool\Driver\Tag\FLAC\TotalSamples(),
            );
        });
        $this['Flash'] = $this->share(function(){
            return array(
                'AudioEncoding' => new \PHPExiftool\Driver\Tag\Flash\AudioEncoding(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\Flash\AudioSampleRate(),
                'AudioBitsPerSample' => new \PHPExiftool\Driver\Tag\Flash\AudioBitsPerSample(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\Flash\AudioChannels(),
                'Name' => new \PHPExiftool\Driver\Tag\Flash\Name(),
                'Time' => new \PHPExiftool\Driver\Tag\Flash\Time(),
                'Type' => new \PHPExiftool\Driver\Tag\Flash\Type(),
                'FileAttributes' => new \PHPExiftool\Driver\Tag\Flash\FileAttributes(),
                'Compressed' => new \PHPExiftool\Driver\Tag\Flash\Compressed(),
                'Duration' => new \PHPExiftool\Driver\Tag\Flash\Duration(),
                'FlashVersion' => new \PHPExiftool\Driver\Tag\Flash\FlashVersion(),
                'FrameCount' => new \PHPExiftool\Driver\Tag\Flash\FrameCount(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\Flash\FrameRate(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\Flash\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\Flash\ImageWidth(),
                'AudioCodecID' => new \PHPExiftool\Driver\Tag\Flash\AudioCodecID(),
                'AudioBitrate' => new \PHPExiftool\Driver\Tag\Flash\AudioBitrate(),
                'AudioDelay' => new \PHPExiftool\Driver\Tag\Flash\AudioDelay(),
                'AudioSampleSize' => new \PHPExiftool\Driver\Tag\Flash\AudioSampleSize(),
                'AudioSize' => new \PHPExiftool\Driver\Tag\Flash\AudioSize(),
                'ByteLength' => new \PHPExiftool\Driver\Tag\Flash\ByteLength(),
                'CanSeekToEnd' => new \PHPExiftool\Driver\Tag\Flash\CanSeekToEnd(),
                'CanSeekOnTime' => new \PHPExiftool\Driver\Tag\Flash\CanSeekOnTime(),
                'CreatedBy' => new \PHPExiftool\Driver\Tag\Flash\CreatedBy(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\Flash\CreateDate(),
                'DataSize' => new \PHPExiftool\Driver\Tag\Flash\DataSize(),
                'FileSizeBytes' => new \PHPExiftool\Driver\Tag\Flash\FileSizeBytes(),
                'HasAudio' => new \PHPExiftool\Driver\Tag\Flash\HasAudio(),
                'HasCuePoints' => new \PHPExiftool\Driver\Tag\Flash\HasCuePoints(),
                'HasKeyFrames' => new \PHPExiftool\Driver\Tag\Flash\HasKeyFrames(),
                'HasMetadata' => new \PHPExiftool\Driver\Tag\Flash\HasMetadata(),
                'HasVideo' => new \PHPExiftool\Driver\Tag\Flash\HasVideo(),
                'HTTPHostHeader' => new \PHPExiftool\Driver\Tag\Flash\HTTPHostHeader(),
                'KeyFramePositions' => new \PHPExiftool\Driver\Tag\Flash\KeyFramePositions(),
                'KeyFramesTimes' => new \PHPExiftool\Driver\Tag\Flash\KeyFramesTimes(),
                'LastKeyFrameTime' => new \PHPExiftool\Driver\Tag\Flash\LastKeyFrameTime(),
                'LastTimeStamp' => new \PHPExiftool\Driver\Tag\Flash\LastTimeStamp(),
                'MetadataCreator' => new \PHPExiftool\Driver\Tag\Flash\MetadataCreator(),
                'MetadataDate' => new \PHPExiftool\Driver\Tag\Flash\MetadataDate(),
                'Message' => new \PHPExiftool\Driver\Tag\Flash\Message(),
                'URL' => new \PHPExiftool\Driver\Tag\Flash\URL(),
                'SourceData' => new \PHPExiftool\Driver\Tag\Flash\SourceData(),
                'StartTime' => new \PHPExiftool\Driver\Tag\Flash\StartTime(),
                'Stereo' => new \PHPExiftool\Driver\Tag\Flash\Stereo(),
                'TotalDataRate' => new \PHPExiftool\Driver\Tag\Flash\TotalDataRate(),
                'TotalDuration' => new \PHPExiftool\Driver\Tag\Flash\TotalDuration(),
                'VideoCodecID' => new \PHPExiftool\Driver\Tag\Flash\VideoCodecID(),
                'VideoBitrate' => new \PHPExiftool\Driver\Tag\Flash\VideoBitrate(),
                'VideoSize' => new \PHPExiftool\Driver\Tag\Flash\VideoSize(),
                'VideoEncoding' => new \PHPExiftool\Driver\Tag\Flash\VideoEncoding(),
            );
        });
        $this['FlashPix'] = $this->share(function(){
            return array(
                'CompObjUserTypeLen' => new \PHPExiftool\Driver\Tag\FlashPix\CompObjUserTypeLen(),
                'CompObjUserType' => new \PHPExiftool\Driver\Tag\FlashPix\CompObjUserType(),
                'DataObjectID' => new \PHPExiftool\Driver\Tag\FlashPix\DataObjectID(),
                'LockedPropertyList' => new \PHPExiftool\Driver\Tag\FlashPix\LockedPropertyList(),
                'DataObjectTitle' => new \PHPExiftool\Driver\Tag\FlashPix\DataObjectTitle(),
                'LastModifier' => new \PHPExiftool\Driver\Tag\FlashPix\LastModifier(),
                'RevisionNumber' => new \PHPExiftool\Driver\Tag\FlashPix\RevisionNumber(),
                'DataCreateDate' => new \PHPExiftool\Driver\Tag\FlashPix\DataCreateDate(),
                'DataModifyDate' => new \PHPExiftool\Driver\Tag\FlashPix\DataModifyDate(),
                'CreatingApplication' => new \PHPExiftool\Driver\Tag\FlashPix\CreatingApplication(),
                'DataObjectStatus' => new \PHPExiftool\Driver\Tag\FlashPix\DataObjectStatus(),
                'CreatingTransform' => new \PHPExiftool\Driver\Tag\FlashPix\CreatingTransform(),
                'UsingTransforms' => new \PHPExiftool\Driver\Tag\FlashPix\UsingTransforms(),
                'CachedImageHeight' => new \PHPExiftool\Driver\Tag\FlashPix\CachedImageHeight(),
                'CachedImageWidth' => new \PHPExiftool\Driver\Tag\FlashPix\CachedImageWidth(),
                'Category' => new \PHPExiftool\Driver\Tag\FlashPix\Category(),
                'PresentationTarget' => new \PHPExiftool\Driver\Tag\FlashPix\PresentationTarget(),
                'Bytes' => new \PHPExiftool\Driver\Tag\FlashPix\Bytes(),
                'Lines' => new \PHPExiftool\Driver\Tag\FlashPix\Lines(),
                'Paragraphs' => new \PHPExiftool\Driver\Tag\FlashPix\Paragraphs(),
                'Slides' => new \PHPExiftool\Driver\Tag\FlashPix\Slides(),
                'Notes' => new \PHPExiftool\Driver\Tag\FlashPix\Notes(),
                'HiddenSlides' => new \PHPExiftool\Driver\Tag\FlashPix\HiddenSlides(),
                'MMClips' => new \PHPExiftool\Driver\Tag\FlashPix\MMClips(),
                'ScaleCrop' => new \PHPExiftool\Driver\Tag\FlashPix\ScaleCrop(),
                'HeadingPairs' => new \PHPExiftool\Driver\Tag\FlashPix\HeadingPairs(),
                'TitleOfParts' => new \PHPExiftool\Driver\Tag\FlashPix\TitleOfParts(),
                'Manager' => new \PHPExiftool\Driver\Tag\FlashPix\Manager(),
                'Company' => new \PHPExiftool\Driver\Tag\FlashPix\Company(),
                'LinksUpToDate' => new \PHPExiftool\Driver\Tag\FlashPix\LinksUpToDate(),
                'CharCountWithSpaces' => new \PHPExiftool\Driver\Tag\FlashPix\CharCountWithSpaces(),
                'SharedDoc' => new \PHPExiftool\Driver\Tag\FlashPix\SharedDoc(),
                'HyperlinksChanged' => new \PHPExiftool\Driver\Tag\FlashPix\HyperlinksChanged(),
                'AppVersion' => new \PHPExiftool\Driver\Tag\FlashPix\AppVersion(),
                'Hyperlinks' => new \PHPExiftool\Driver\Tag\FlashPix\Hyperlinks(),
                'HyperlinkBase' => new \PHPExiftool\Driver\Tag\FlashPix\HyperlinkBase(),
                'ExtensionName' => new \PHPExiftool\Driver\Tag\FlashPix\ExtensionName(),
                'ExtensionClassID' => new \PHPExiftool\Driver\Tag\FlashPix\ExtensionClassID(),
                'ExtensionPersistence' => new \PHPExiftool\Driver\Tag\FlashPix\ExtensionPersistence(),
                'ExtensionCreateDate' => new \PHPExiftool\Driver\Tag\FlashPix\ExtensionCreateDate(),
                'ExtensionModifyDate' => new \PHPExiftool\Driver\Tag\FlashPix\ExtensionModifyDate(),
                'ExtensionDescription' => new \PHPExiftool\Driver\Tag\FlashPix\ExtensionDescription(),
                'Storage-StreamPathname' => new \PHPExiftool\Driver\Tag\FlashPix\StorageStreamPathname(),
                'FlashPixStreamPathname' => new \PHPExiftool\Driver\Tag\FlashPix\FlashPixStreamPathname(),
                'FlashPixStreamFieldOffset' => new \PHPExiftool\Driver\Tag\FlashPix\FlashPixStreamFieldOffset(),
                'PropertySetPathname' => new \PHPExiftool\Driver\Tag\FlashPix\PropertySetPathname(),
                'PropertySetIDCodes' => new \PHPExiftool\Driver\Tag\FlashPix\PropertySetIDCodes(),
                'PropertyVectorElements' => new \PHPExiftool\Driver\Tag\FlashPix\PropertyVectorElements(),
                'SubimageResolutions' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageResolutions(),
                'UsedExtensionNumbers' => new \PHPExiftool\Driver\Tag\FlashPix\UsedExtensionNumbers(),
                'TransformedImageTitle' => new \PHPExiftool\Driver\Tag\FlashPix\TransformedImageTitle(),
                'VisibleOutputs' => new \PHPExiftool\Driver\Tag\FlashPix\VisibleOutputs(),
                'MaximumImageIndex' => new \PHPExiftool\Driver\Tag\FlashPix\MaximumImageIndex(),
                'MaximumTransformIndex' => new \PHPExiftool\Driver\Tag\FlashPix\MaximumTransformIndex(),
                'MaximumOperationIndex' => new \PHPExiftool\Driver\Tag\FlashPix\MaximumOperationIndex(),
                'NumberOfResolutions' => new \PHPExiftool\Driver\Tag\FlashPix\NumberOfResolutions(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\FlashPix\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\FlashPix\ImageHeight(),
                'DefaultDisplayHeight' => new \PHPExiftool\Driver\Tag\FlashPix\DefaultDisplayHeight(),
                'DefaultDisplayWidth' => new \PHPExiftool\Driver\Tag\FlashPix\DefaultDisplayWidth(),
                'DisplayUnits' => new \PHPExiftool\Driver\Tag\FlashPix\DisplayUnits(),
                'SubimageWidth' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageWidth(),
                'SubimageHeight' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageHeight(),
                'SubimageColor' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageColor(),
                'SubimageNumericalFormat' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageNumericalFormat(),
                'DecimationMethod' => new \PHPExiftool\Driver\Tag\FlashPix\DecimationMethod(),
                'DecimationPrefilterWidth' => new \PHPExiftool\Driver\Tag\FlashPix\DecimationPrefilterWidth(),
                'SubimageICC_Profile' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageICCProfile(),
                'JPEGTables' => new \PHPExiftool\Driver\Tag\FlashPix\JPEGTables(),
                'MaxJPEGTableIndex' => new \PHPExiftool\Driver\Tag\FlashPix\MaxJPEGTableIndex(),
                'FileSource' => new \PHPExiftool\Driver\Tag\FlashPix\FileSource(),
                'SceneType' => new \PHPExiftool\Driver\Tag\FlashPix\SceneType(),
                'CreationPathVector' => new \PHPExiftool\Driver\Tag\FlashPix\CreationPathVector(),
                'SoftwareRelease' => new \PHPExiftool\Driver\Tag\FlashPix\SoftwareRelease(),
                'UserDefinedID' => new \PHPExiftool\Driver\Tag\FlashPix\UserDefinedID(),
                'SharpnessApproximation' => new \PHPExiftool\Driver\Tag\FlashPix\SharpnessApproximation(),
                'Copyright' => new \PHPExiftool\Driver\Tag\FlashPix\Copyright(),
                'OriginalImageBroker' => new \PHPExiftool\Driver\Tag\FlashPix\OriginalImageBroker(),
                'DigitalImageBroker' => new \PHPExiftool\Driver\Tag\FlashPix\DigitalImageBroker(),
                'Authorship' => new \PHPExiftool\Driver\Tag\FlashPix\Authorship(),
                'IntellectualPropertyNotes' => new \PHPExiftool\Driver\Tag\FlashPix\IntellectualPropertyNotes(),
                'TestTarget' => new \PHPExiftool\Driver\Tag\FlashPix\TestTarget(),
                'GroupCaption' => new \PHPExiftool\Driver\Tag\FlashPix\GroupCaption(),
                'CaptionText' => new \PHPExiftool\Driver\Tag\FlashPix\CaptionText(),
                'People' => new \PHPExiftool\Driver\Tag\FlashPix\People(),
                'Things' => new \PHPExiftool\Driver\Tag\FlashPix\Things(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\FlashPix\DateTimeOriginal(),
                'Events' => new \PHPExiftool\Driver\Tag\FlashPix\Events(),
                'Places' => new \PHPExiftool\Driver\Tag\FlashPix\Places(),
                'ContentDescriptionNotes' => new \PHPExiftool\Driver\Tag\FlashPix\ContentDescriptionNotes(),
                'Make' => new \PHPExiftool\Driver\Tag\FlashPix\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\FlashPix\Model(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\FlashPix\SerialNumber(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\FlashPix\CreateDate(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\FlashPix\ExposureTime(),
                'FNumber' => new \PHPExiftool\Driver\Tag\FlashPix\FNumber(),
                'ExposureProgram' => new \PHPExiftool\Driver\Tag\FlashPix\ExposureProgram(),
                'BrightnessValue' => new \PHPExiftool\Driver\Tag\FlashPix\BrightnessValue(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\FlashPix\ExposureCompensation(),
                'SubjectDistance' => new \PHPExiftool\Driver\Tag\FlashPix\SubjectDistance(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\FlashPix\MeteringMode(),
                'LightSource' => new \PHPExiftool\Driver\Tag\FlashPix\LightSource(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\FlashPix\FocalLength(),
                'MaxApertureValue' => new \PHPExiftool\Driver\Tag\FlashPix\MaxApertureValue(),
                'Flash' => new \PHPExiftool\Driver\Tag\FlashPix\Flash(),
                'FlashEnergy' => new \PHPExiftool\Driver\Tag\FlashPix\FlashEnergy(),
                'FlashReturn' => new \PHPExiftool\Driver\Tag\FlashPix\FlashReturn(),
                'BackLight' => new \PHPExiftool\Driver\Tag\FlashPix\BackLight(),
                'SubjectLocation' => new \PHPExiftool\Driver\Tag\FlashPix\SubjectLocation(),
                'ExposureIndex' => new \PHPExiftool\Driver\Tag\FlashPix\ExposureIndex(),
                'SpecialEffectsOpticalFilter' => new \PHPExiftool\Driver\Tag\FlashPix\SpecialEffectsOpticalFilter(),
                'PerPictureNotes' => new \PHPExiftool\Driver\Tag\FlashPix\PerPictureNotes(),
                'SensingMethod' => new \PHPExiftool\Driver\Tag\FlashPix\SensingMethod(),
                'FocalPlaneXResolution' => new \PHPExiftool\Driver\Tag\FlashPix\FocalPlaneXResolution(),
                'FocalPlaneYResolution' => new \PHPExiftool\Driver\Tag\FlashPix\FocalPlaneYResolution(),
                'FocalPlaneResolutionUnit' => new \PHPExiftool\Driver\Tag\FlashPix\FocalPlaneResolutionUnit(),
                'SpatialFrequencyResponse' => new \PHPExiftool\Driver\Tag\FlashPix\SpatialFrequencyResponse(),
                'CFAPattern' => new \PHPExiftool\Driver\Tag\FlashPix\CFAPattern(),
                'ISO' => new \PHPExiftool\Driver\Tag\FlashPix\ISO(),
                'Opto-ElectricConvFactor' => new \PHPExiftool\Driver\Tag\FlashPix\OptoElectricConvFactor(),
                'FilmBrand' => new \PHPExiftool\Driver\Tag\FlashPix\FilmBrand(),
                'FilmCategory' => new \PHPExiftool\Driver\Tag\FlashPix\FilmCategory(),
                'FilmSize' => new \PHPExiftool\Driver\Tag\FlashPix\FilmSize(),
                'FilmRollNumber' => new \PHPExiftool\Driver\Tag\FlashPix\FilmRollNumber(),
                'FilmFrameNumber' => new \PHPExiftool\Driver\Tag\FlashPix\FilmFrameNumber(),
                'ScannerMake' => new \PHPExiftool\Driver\Tag\FlashPix\ScannerMake(),
                'ScannerModel' => new \PHPExiftool\Driver\Tag\FlashPix\ScannerModel(),
                'ScannerSerialNumber' => new \PHPExiftool\Driver\Tag\FlashPix\ScannerSerialNumber(),
                'ScanSoftware' => new \PHPExiftool\Driver\Tag\FlashPix\ScanSoftware(),
                'ScanSoftwareRevisionDate' => new \PHPExiftool\Driver\Tag\FlashPix\ScanSoftwareRevisionDate(),
                'ServiceOrganizationName' => new \PHPExiftool\Driver\Tag\FlashPix\ServiceOrganizationName(),
                'ScanOperatorID' => new \PHPExiftool\Driver\Tag\FlashPix\ScanOperatorID(),
                'ScanDate' => new \PHPExiftool\Driver\Tag\FlashPix\ScanDate(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\FlashPix\ModifyDate(),
                'ScannerPixelSize' => new \PHPExiftool\Driver\Tag\FlashPix\ScannerPixelSize(),
                'OriginalScannedImageSize' => new \PHPExiftool\Driver\Tag\FlashPix\OriginalScannedImageSize(),
                'OriginalDocumentSize' => new \PHPExiftool\Driver\Tag\FlashPix\OriginalDocumentSize(),
                'OriginalMedium' => new \PHPExiftool\Driver\Tag\FlashPix\OriginalMedium(),
                'TypeOfOriginal' => new \PHPExiftool\Driver\Tag\FlashPix\TypeOfOriginal(),
                'ScreenNail' => new \PHPExiftool\Driver\Tag\FlashPix\ScreenNail(),
                'AudioStream' => new \PHPExiftool\Driver\Tag\FlashPix\AudioStream(),
                'CurrentUser' => new \PHPExiftool\Driver\Tag\FlashPix\CurrentUser(),
                'OperationID' => new \PHPExiftool\Driver\Tag\FlashPix\OperationID(),
                'SubimageTileCount' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageTileCount(),
                'SubimageTileWidth' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageTileWidth(),
                'SubimageTileHeight' => new \PHPExiftool\Driver\Tag\FlashPix\SubimageTileHeight(),
                'NumChannels' => new \PHPExiftool\Driver\Tag\FlashPix\NumChannels(),
                'Dictionary' => new \PHPExiftool\Driver\Tag\FlashPix\Dictionary(),
                'CodePage' => new \PHPExiftool\Driver\Tag\FlashPix\CodePage(),
                'Title' => new \PHPExiftool\Driver\Tag\FlashPix\Title(),
                'Subject' => new \PHPExiftool\Driver\Tag\FlashPix\Subject(),
                'Author' => new \PHPExiftool\Driver\Tag\FlashPix\Author(),
                'Keywords' => new \PHPExiftool\Driver\Tag\FlashPix\Keywords(),
                'Comments' => new \PHPExiftool\Driver\Tag\FlashPix\Comments(),
                'Template' => new \PHPExiftool\Driver\Tag\FlashPix\Template(),
                'LastModifiedBy' => new \PHPExiftool\Driver\Tag\FlashPix\LastModifiedBy(),
                'TotalEditTime' => new \PHPExiftool\Driver\Tag\FlashPix\TotalEditTime(),
                'LastPrinted' => new \PHPExiftool\Driver\Tag\FlashPix\LastPrinted(),
                'Pages' => new \PHPExiftool\Driver\Tag\FlashPix\Pages(),
                'Words' => new \PHPExiftool\Driver\Tag\FlashPix\Words(),
                'Characters' => new \PHPExiftool\Driver\Tag\FlashPix\Characters(),
                'ThumbnailClip' => new \PHPExiftool\Driver\Tag\FlashPix\ThumbnailClip(),
                'Software' => new \PHPExiftool\Driver\Tag\FlashPix\Software(),
                'Security' => new \PHPExiftool\Driver\Tag\FlashPix\Security(),
                'LocaleIndicator' => new \PHPExiftool\Driver\Tag\FlashPix\LocaleIndicator(),
                'TransformNodeID' => new \PHPExiftool\Driver\Tag\FlashPix\TransformNodeID(),
                'OperationClassID' => new \PHPExiftool\Driver\Tag\FlashPix\OperationClassID(),
                'TransformTitle' => new \PHPExiftool\Driver\Tag\FlashPix\TransformTitle(),
                'TransformCreateDate' => new \PHPExiftool\Driver\Tag\FlashPix\TransformCreateDate(),
                'TransformModifyDate' => new \PHPExiftool\Driver\Tag\FlashPix\TransformModifyDate(),
                'InputDataObjectList' => new \PHPExiftool\Driver\Tag\FlashPix\InputDataObjectList(),
                'OutputDataObjectList' => new \PHPExiftool\Driver\Tag\FlashPix\OutputDataObjectList(),
                'OperationNumber' => new \PHPExiftool\Driver\Tag\FlashPix\OperationNumber(),
                'ResultAspectRatio' => new \PHPExiftool\Driver\Tag\FlashPix\ResultAspectRatio(),
                'RectangleOfInterest' => new \PHPExiftool\Driver\Tag\FlashPix\RectangleOfInterest(),
                'Filtering' => new \PHPExiftool\Driver\Tag\FlashPix\Filtering(),
                'SpatialOrientation' => new \PHPExiftool\Driver\Tag\FlashPix\SpatialOrientation(),
                'ColorTwistMatrix' => new \PHPExiftool\Driver\Tag\FlashPix\ColorTwistMatrix(),
                'ContrastAdjustment' => new \PHPExiftool\Driver\Tag\FlashPix\ContrastAdjustment(),
            );
        });
        $this['Font'] = $this->share(function(){
            return array(
                'Ascender' => new \PHPExiftool\Driver\Tag\Font\Ascender(),
                'CapHeight' => new \PHPExiftool\Driver\Tag\Font\CapHeight(),
                'CharacterSet' => new \PHPExiftool\Driver\Tag\Font\CharacterSet(),
                'Characters' => new \PHPExiftool\Driver\Tag\Font\Characters(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\Font\CreateDate(),
                'Descender' => new \PHPExiftool\Driver\Tag\Font\Descender(),
                'EncodingScheme' => new \PHPExiftool\Driver\Tag\Font\EncodingScheme(),
                'EscChar' => new \PHPExiftool\Driver\Tag\Font\EscChar(),
                'FontFamily' => new \PHPExiftool\Driver\Tag\Font\FontFamily(),
                'FontName' => new \PHPExiftool\Driver\Tag\Font\FontName(),
                'FullName' => new \PHPExiftool\Driver\Tag\Font\FullName(),
                'IsBaseFont' => new \PHPExiftool\Driver\Tag\Font\IsBaseFont(),
                'IsFixedV' => new \PHPExiftool\Driver\Tag\Font\IsFixedV(),
                'MappingScheme' => new \PHPExiftool\Driver\Tag\Font\MappingScheme(),
                'Notice' => new \PHPExiftool\Driver\Tag\Font\Notice(),
                'Version' => new \PHPExiftool\Driver\Tag\Font\Version(),
                'Weight' => new \PHPExiftool\Driver\Tag\Font\Weight(),
                'XHeight' => new \PHPExiftool\Driver\Tag\Font\XHeight(),
                'NumFonts' => new \PHPExiftool\Driver\Tag\Font\NumFonts(),
                'PostScriptFontName' => new \PHPExiftool\Driver\Tag\Font\PostScriptFontName(),
                'Copyright' => new \PHPExiftool\Driver\Tag\Font\Copyright(),
                'FontSubfamily' => new \PHPExiftool\Driver\Tag\Font\FontSubfamily(),
                'FontSubfamilyID' => new \PHPExiftool\Driver\Tag\Font\FontSubfamilyID(),
                'NameTableVersion' => new \PHPExiftool\Driver\Tag\Font\NameTableVersion(),
                'Trademark' => new \PHPExiftool\Driver\Tag\Font\Trademark(),
                'Manufacturer' => new \PHPExiftool\Driver\Tag\Font\Manufacturer(),
                'Designer' => new \PHPExiftool\Driver\Tag\Font\Designer(),
                'Description' => new \PHPExiftool\Driver\Tag\Font\Description(),
                'VendorURL' => new \PHPExiftool\Driver\Tag\Font\VendorURL(),
                'DesignerURL' => new \PHPExiftool\Driver\Tag\Font\DesignerURL(),
                'License' => new \PHPExiftool\Driver\Tag\Font\License(),
                'LicenseInfoURL' => new \PHPExiftool\Driver\Tag\Font\LicenseInfoURL(),
                'PreferredFamily' => new \PHPExiftool\Driver\Tag\Font\PreferredFamily(),
                'PreferredSubfamily' => new \PHPExiftool\Driver\Tag\Font\PreferredSubfamily(),
                'CompatibleFontName' => new \PHPExiftool\Driver\Tag\Font\CompatibleFontName(),
                'SampleText' => new \PHPExiftool\Driver\Tag\Font\SampleText(),
                'WWSFamilyName' => new \PHPExiftool\Driver\Tag\Font\WWSFamilyName(),
                'WWSSubfamilyName' => new \PHPExiftool\Driver\Tag\Font\WWSSubfamilyName(),
                'PFMVersion' => new \PHPExiftool\Driver\Tag\Font\PFMVersion(),
                'FontType' => new \PHPExiftool\Driver\Tag\Font\FontType(),
                'PointSize' => new \PHPExiftool\Driver\Tag\Font\PointSize(),
                'YResolution' => new \PHPExiftool\Driver\Tag\Font\YResolution(),
                'XResolution' => new \PHPExiftool\Driver\Tag\Font\XResolution(),
                'Ascent' => new \PHPExiftool\Driver\Tag\Font\Ascent(),
                'InternalLeading' => new \PHPExiftool\Driver\Tag\Font\InternalLeading(),
                'ExternalLeading' => new \PHPExiftool\Driver\Tag\Font\ExternalLeading(),
                'Italic' => new \PHPExiftool\Driver\Tag\Font\Italic(),
                'Underline' => new \PHPExiftool\Driver\Tag\Font\Underline(),
                'Strikeout' => new \PHPExiftool\Driver\Tag\Font\Strikeout(),
                'PixWidth' => new \PHPExiftool\Driver\Tag\Font\PixWidth(),
                'PixHeight' => new \PHPExiftool\Driver\Tag\Font\PixHeight(),
                'PitchAndFamily' => new \PHPExiftool\Driver\Tag\Font\PitchAndFamily(),
                'AvgWidth' => new \PHPExiftool\Driver\Tag\Font\AvgWidth(),
                'MaxWidth' => new \PHPExiftool\Driver\Tag\Font\MaxWidth(),
                'FirstChar' => new \PHPExiftool\Driver\Tag\Font\FirstChar(),
                'LastChar' => new \PHPExiftool\Driver\Tag\Font\LastChar(),
                'DefaultChar' => new \PHPExiftool\Driver\Tag\Font\DefaultChar(),
                'BreakChar' => new \PHPExiftool\Driver\Tag\Font\BreakChar(),
                'WidthBytes' => new \PHPExiftool\Driver\Tag\Font\WidthBytes(),
                'FSType' => new \PHPExiftool\Driver\Tag\Font\FSType(),
                'ItalicAngle' => new \PHPExiftool\Driver\Tag\Font\ItalicAngle(),
                'UnderlinePosition' => new \PHPExiftool\Driver\Tag\Font\UnderlinePosition(),
                'UnderlineThickness' => new \PHPExiftool\Driver\Tag\Font\UnderlineThickness(),
                'IsFixedPitch' => new \PHPExiftool\Driver\Tag\Font\IsFixedPitch(),
            );
        });
        $this['FotoStation'] = $this->share(function(){
            return array(
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\FotoStation\ThumbnailImage(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\FotoStation\PreviewImage(),
                'OriginalImageWidth' => new \PHPExiftool\Driver\Tag\FotoStation\OriginalImageWidth(),
                'OriginalImageHeight' => new \PHPExiftool\Driver\Tag\FotoStation\OriginalImageHeight(),
                'ColorPlanes' => new \PHPExiftool\Driver\Tag\FotoStation\ColorPlanes(),
                'XYResolution' => new \PHPExiftool\Driver\Tag\FotoStation\XYResolution(),
                'Rotation' => new \PHPExiftool\Driver\Tag\FotoStation\Rotation(),
                'CropLeft' => new \PHPExiftool\Driver\Tag\FotoStation\CropLeft(),
                'CropTop' => new \PHPExiftool\Driver\Tag\FotoStation\CropTop(),
                'CropRight' => new \PHPExiftool\Driver\Tag\FotoStation\CropRight(),
                'CropBottom' => new \PHPExiftool\Driver\Tag\FotoStation\CropBottom(),
                'CropRotation' => new \PHPExiftool\Driver\Tag\FotoStation\CropRotation(),
            );
        });
        $this['FujiFilm'] = $this->share(function(){
            return array(
                'MovieStreamName' => new \PHPExiftool\Driver\Tag\FujiFilm\MovieStreamName(),
                'Face1Birthday' => new \PHPExiftool\Driver\Tag\FujiFilm\Face1Birthday(),
                'Face1Category' => new \PHPExiftool\Driver\Tag\FujiFilm\Face1Category(),
                'Face1Name' => new \PHPExiftool\Driver\Tag\FujiFilm\Face1Name(),
                'Face2Birthday' => new \PHPExiftool\Driver\Tag\FujiFilm\Face2Birthday(),
                'Face2Category' => new \PHPExiftool\Driver\Tag\FujiFilm\Face2Category(),
                'Face2Name' => new \PHPExiftool\Driver\Tag\FujiFilm\Face2Name(),
                'Face3Birthday' => new \PHPExiftool\Driver\Tag\FujiFilm\Face3Birthday(),
                'Face3Category' => new \PHPExiftool\Driver\Tag\FujiFilm\Face3Category(),
                'Face3Name' => new \PHPExiftool\Driver\Tag\FujiFilm\Face3Name(),
                'Face4Birthday' => new \PHPExiftool\Driver\Tag\FujiFilm\Face4Birthday(),
                'Face4Category' => new \PHPExiftool\Driver\Tag\FujiFilm\Face4Category(),
                'Face4Name' => new \PHPExiftool\Driver\Tag\FujiFilm\Face4Name(),
                'Face5Birthday' => new \PHPExiftool\Driver\Tag\FujiFilm\Face5Birthday(),
                'Face5Category' => new \PHPExiftool\Driver\Tag\FujiFilm\Face5Category(),
                'Face5Name' => new \PHPExiftool\Driver\Tag\FujiFilm\Face5Name(),
                'Face6Birthday' => new \PHPExiftool\Driver\Tag\FujiFilm\Face6Birthday(),
                'Face6Category' => new \PHPExiftool\Driver\Tag\FujiFilm\Face6Category(),
                'Face6Name' => new \PHPExiftool\Driver\Tag\FujiFilm\Face6Name(),
                'Face7Birthday' => new \PHPExiftool\Driver\Tag\FujiFilm\Face7Birthday(),
                'Face7Category' => new \PHPExiftool\Driver\Tag\FujiFilm\Face7Category(),
                'Face7Name' => new \PHPExiftool\Driver\Tag\FujiFilm\Face7Name(),
                'Face8Birthday' => new \PHPExiftool\Driver\Tag\FujiFilm\Face8Birthday(),
                'Face8Category' => new \PHPExiftool\Driver\Tag\FujiFilm\Face8Category(),
                'Face8Name' => new \PHPExiftool\Driver\Tag\FujiFilm\Face8Name(),
                'Version' => new \PHPExiftool\Driver\Tag\FujiFilm\Version(),
                'InternalSerialNumber' => new \PHPExiftool\Driver\Tag\FujiFilm\InternalSerialNumber(),
                'Quality' => new \PHPExiftool\Driver\Tag\FujiFilm\Quality(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\FujiFilm\Sharpness(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\FujiFilm\WhiteBalance(),
                'Saturation' => new \PHPExiftool\Driver\Tag\FujiFilm\Saturation(),
                'Contrast' => new \PHPExiftool\Driver\Tag\FujiFilm\Contrast(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\FujiFilm\ColorTemperature(),
                'WhiteBalanceFineTune' => new \PHPExiftool\Driver\Tag\FujiFilm\WhiteBalanceFineTune(),
                'NoiseReduction' => new \PHPExiftool\Driver\Tag\FujiFilm\NoiseReduction(),
                'HighISONoiseReduction' => new \PHPExiftool\Driver\Tag\FujiFilm\HighISONoiseReduction(),
                'FujiFlashMode' => new \PHPExiftool\Driver\Tag\FujiFilm\FujiFlashMode(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\FujiFilm\FlashExposureComp(),
                'Macro' => new \PHPExiftool\Driver\Tag\FujiFilm\Macro(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\FujiFilm\FocusMode(),
                'FocusPixel' => new \PHPExiftool\Driver\Tag\FujiFilm\FocusPixel(),
                'SlowSync' => new \PHPExiftool\Driver\Tag\FujiFilm\SlowSync(),
                'PictureMode' => new \PHPExiftool\Driver\Tag\FujiFilm\PictureMode(),
                'EXRAuto' => new \PHPExiftool\Driver\Tag\FujiFilm\EXRAuto(),
                'EXRMode' => new \PHPExiftool\Driver\Tag\FujiFilm\EXRMode(),
                'AutoBracketing' => new \PHPExiftool\Driver\Tag\FujiFilm\AutoBracketing(),
                'SequenceNumber' => new \PHPExiftool\Driver\Tag\FujiFilm\SequenceNumber(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\FujiFilm\ColorMode(),
                'BlurWarning' => new \PHPExiftool\Driver\Tag\FujiFilm\BlurWarning(),
                'FocusWarning' => new \PHPExiftool\Driver\Tag\FujiFilm\FocusWarning(),
                'ExposureWarning' => new \PHPExiftool\Driver\Tag\FujiFilm\ExposureWarning(),
                'GEImageSize' => new \PHPExiftool\Driver\Tag\FujiFilm\GEImageSize(),
                'DynamicRange' => new \PHPExiftool\Driver\Tag\FujiFilm\DynamicRange(),
                'FilmMode' => new \PHPExiftool\Driver\Tag\FujiFilm\FilmMode(),
                'DynamicRangeSetting' => new \PHPExiftool\Driver\Tag\FujiFilm\DynamicRangeSetting(),
                'DevelopmentDynamicRange' => new \PHPExiftool\Driver\Tag\FujiFilm\DevelopmentDynamicRange(),
                'MinFocalLength' => new \PHPExiftool\Driver\Tag\FujiFilm\MinFocalLength(),
                'MaxFocalLength' => new \PHPExiftool\Driver\Tag\FujiFilm\MaxFocalLength(),
                'MaxApertureAtMinFocal' => new \PHPExiftool\Driver\Tag\FujiFilm\MaxApertureAtMinFocal(),
                'MaxApertureAtMaxFocal' => new \PHPExiftool\Driver\Tag\FujiFilm\MaxApertureAtMaxFocal(),
                'AutoDynamicRange' => new \PHPExiftool\Driver\Tag\FujiFilm\AutoDynamicRange(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\FujiFilm\FacesDetected(),
                'FacePositions' => new \PHPExiftool\Driver\Tag\FujiFilm\FacePositions(),
                'FileSource' => new \PHPExiftool\Driver\Tag\FujiFilm\FileSource(),
                'OrderNumber' => new \PHPExiftool\Driver\Tag\FujiFilm\OrderNumber(),
                'FrameNumber' => new \PHPExiftool\Driver\Tag\FujiFilm\FrameNumber(),
                'Parallax' => new \PHPExiftool\Driver\Tag\FujiFilm\Parallax(),
                'RawImageWidth' => new \PHPExiftool\Driver\Tag\FujiFilm\RawImageWidth(),
                'RawImageHeight' => new \PHPExiftool\Driver\Tag\FujiFilm\RawImageHeight(),
            );
        });
        $this['FujiIFD'] = $this->share(function(){
            return array(
                'RawImageFullWidth' => new \PHPExiftool\Driver\Tag\FujiIFD\RawImageFullWidth(),
                'RawImageFullHeight' => new \PHPExiftool\Driver\Tag\FujiIFD\RawImageFullHeight(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\FujiIFD\BitsPerSample(),
                'StripOffsets' => new \PHPExiftool\Driver\Tag\FujiIFD\StripOffsets(),
                'StripByteCounts' => new \PHPExiftool\Driver\Tag\FujiIFD\StripByteCounts(),
                'WB_GRBLevels' => new \PHPExiftool\Driver\Tag\FujiIFD\WBGRBLevels(),
            );
        });
        $this['RAF2'] = $this->share(function(){
            return array(
                'RawImageFullSize' => new \PHPExiftool\Driver\Tag\RAF2\RawImageFullSize(),
            );
        });
        $this['RAF'] = $this->share(function(){
            return array(
                'RawImageSize' => new \PHPExiftool\Driver\Tag\RAF\RawImageSize(),
                'FujiLayout' => new \PHPExiftool\Driver\Tag\RAF\FujiLayout(),
                'WB_GRGBLevels' => new \PHPExiftool\Driver\Tag\RAF\WBGRGBLevels(),
            );
        });
        $this['GE'] = $this->share(function(){
            return array(
                'Macro' => new \PHPExiftool\Driver\Tag\GE\Macro(),
                'GEModel' => new \PHPExiftool\Driver\Tag\GE\GEModel(),
                'GEMake' => new \PHPExiftool\Driver\Tag\GE\GEMake(),
            );
        });
        $this['GIF'] = $this->share(function(){
            return array(
                'AnimationIterations' => new \PHPExiftool\Driver\Tag\GIF\AnimationIterations(),
                'Comment' => new \PHPExiftool\Driver\Tag\GIF\Comment(),
                'Duration' => new \PHPExiftool\Driver\Tag\GIF\Duration(),
                'FrameCount' => new \PHPExiftool\Driver\Tag\GIF\FrameCount(),
                'GIFVersion' => new \PHPExiftool\Driver\Tag\GIF\GIFVersion(),
                'Text' => new \PHPExiftool\Driver\Tag\GIF\Text(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\GIF\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\GIF\ImageHeight(),
                'HasColorMap' => new \PHPExiftool\Driver\Tag\GIF\HasColorMap(),
                'ColorResolutionDepth' => new \PHPExiftool\Driver\Tag\GIF\ColorResolutionDepth(),
                'BitsPerPixel' => new \PHPExiftool\Driver\Tag\GIF\BitsPerPixel(),
                'BackgroundColor' => new \PHPExiftool\Driver\Tag\GIF\BackgroundColor(),
            );
        });
        $this['GIMP'] = $this->share(function(){
            return array(
                'XCFVersion' => new \PHPExiftool\Driver\Tag\GIMP\XCFVersion(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\GIMP\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\GIMP\ImageHeight(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\GIMP\ColorMode(),
                'Compression' => new \PHPExiftool\Driver\Tag\GIMP\Compression(),
                'Comment' => new \PHPExiftool\Driver\Tag\GIMP\Comment(),
                'ICCProfileName' => new \PHPExiftool\Driver\Tag\GIMP\ICCProfileName(),
                'XResolution' => new \PHPExiftool\Driver\Tag\GIMP\XResolution(),
                'YResolution' => new \PHPExiftool\Driver\Tag\GIMP\YResolution(),
            );
        });
        $this['GPS'] = $this->share(function(){
            return array(
                'GPSVersionID' => new \PHPExiftool\Driver\Tag\GPS\GPSVersionID(),
                'GPSLatitudeRef' => new \PHPExiftool\Driver\Tag\GPS\GPSLatitudeRef(),
                'GPSLatitude' => new \PHPExiftool\Driver\Tag\GPS\GPSLatitude(),
                'GPSLongitudeRef' => new \PHPExiftool\Driver\Tag\GPS\GPSLongitudeRef(),
                'GPSLongitude' => new \PHPExiftool\Driver\Tag\GPS\GPSLongitude(),
                'GPSAltitudeRef' => new \PHPExiftool\Driver\Tag\GPS\GPSAltitudeRef(),
                'GPSAltitude' => new \PHPExiftool\Driver\Tag\GPS\GPSAltitude(),
                'GPSTimeStamp' => new \PHPExiftool\Driver\Tag\GPS\GPSTimeStamp(),
                'GPSSatellites' => new \PHPExiftool\Driver\Tag\GPS\GPSSatellites(),
                'GPSStatus' => new \PHPExiftool\Driver\Tag\GPS\GPSStatus(),
                'GPSMeasureMode' => new \PHPExiftool\Driver\Tag\GPS\GPSMeasureMode(),
                'GPSDOP' => new \PHPExiftool\Driver\Tag\GPS\GPSDOP(),
                'GPSSpeedRef' => new \PHPExiftool\Driver\Tag\GPS\GPSSpeedRef(),
                'GPSSpeed' => new \PHPExiftool\Driver\Tag\GPS\GPSSpeed(),
                'GPSTrackRef' => new \PHPExiftool\Driver\Tag\GPS\GPSTrackRef(),
                'GPSTrack' => new \PHPExiftool\Driver\Tag\GPS\GPSTrack(),
                'GPSImgDirectionRef' => new \PHPExiftool\Driver\Tag\GPS\GPSImgDirectionRef(),
                'GPSImgDirection' => new \PHPExiftool\Driver\Tag\GPS\GPSImgDirection(),
                'GPSMapDatum' => new \PHPExiftool\Driver\Tag\GPS\GPSMapDatum(),
                'GPSDestLatitudeRef' => new \PHPExiftool\Driver\Tag\GPS\GPSDestLatitudeRef(),
                'GPSDestLatitude' => new \PHPExiftool\Driver\Tag\GPS\GPSDestLatitude(),
                'GPSDestLongitudeRef' => new \PHPExiftool\Driver\Tag\GPS\GPSDestLongitudeRef(),
                'GPSDestLongitude' => new \PHPExiftool\Driver\Tag\GPS\GPSDestLongitude(),
                'GPSDestBearingRef' => new \PHPExiftool\Driver\Tag\GPS\GPSDestBearingRef(),
                'GPSDestBearing' => new \PHPExiftool\Driver\Tag\GPS\GPSDestBearing(),
                'GPSDestDistanceRef' => new \PHPExiftool\Driver\Tag\GPS\GPSDestDistanceRef(),
                'GPSDestDistance' => new \PHPExiftool\Driver\Tag\GPS\GPSDestDistance(),
                'GPSProcessingMethod' => new \PHPExiftool\Driver\Tag\GPS\GPSProcessingMethod(),
                'GPSAreaInformation' => new \PHPExiftool\Driver\Tag\GPS\GPSAreaInformation(),
                'GPSDateStamp' => new \PHPExiftool\Driver\Tag\GPS\GPSDateStamp(),
                'GPSDifferential' => new \PHPExiftool\Driver\Tag\GPS\GPSDifferential(),
                'GPSHPositioningError' => new \PHPExiftool\Driver\Tag\GPS\GPSHPositioningError(),
            );
        });
        $this['GeoTiff'] = $this->share(function(){
            return array(
                'GeoTiffVersion' => new \PHPExiftool\Driver\Tag\GeoTiff\GeoTiffVersion(),
                'GTModelType' => new \PHPExiftool\Driver\Tag\GeoTiff\GTModelType(),
                'GTRasterType' => new \PHPExiftool\Driver\Tag\GeoTiff\GTRasterType(),
                'GTCitation' => new \PHPExiftool\Driver\Tag\GeoTiff\GTCitation(),
                'GeographicType' => new \PHPExiftool\Driver\Tag\GeoTiff\GeographicType(),
                'GeogCitation' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogCitation(),
                'GeogGeodeticDatum' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogGeodeticDatum(),
                'GeogPrimeMeridian' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogPrimeMeridian(),
                'GeogLinearUnits' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogLinearUnits(),
                'GeogLinearUnitSize' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogLinearUnitSize(),
                'GeogAngularUnits' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogAngularUnits(),
                'GeogAngularUnitSize' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogAngularUnitSize(),
                'GeogEllipsoid' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogEllipsoid(),
                'GeogSemiMajorAxis' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogSemiMajorAxis(),
                'GeogSemiMinorAxis' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogSemiMinorAxis(),
                'GeogInvFlattening' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogInvFlattening(),
                'GeogAzimuthUnits' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogAzimuthUnits(),
                'GeogPrimeMeridianLong' => new \PHPExiftool\Driver\Tag\GeoTiff\GeogPrimeMeridianLong(),
                'ProjectedCSType' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjectedCSType(),
                'PCSCitation' => new \PHPExiftool\Driver\Tag\GeoTiff\PCSCitation(),
                'Projection' => new \PHPExiftool\Driver\Tag\GeoTiff\Projection(),
                'ProjCoordTrans' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjCoordTrans(),
                'ProjLinearUnits' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjLinearUnits(),
                'ProjLinearUnitSize' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjLinearUnitSize(),
                'ProjStdParallel1' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjStdParallel1(),
                'ProjStdParallel2' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjStdParallel2(),
                'ProjNatOriginLong' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjNatOriginLong(),
                'ProjNatOriginLat' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjNatOriginLat(),
                'ProjFalseEasting' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjFalseEasting(),
                'ProjFalseNorthing' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjFalseNorthing(),
                'ProjFalseOriginLong' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjFalseOriginLong(),
                'ProjFalseOriginLat' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjFalseOriginLat(),
                'ProjFalseOriginEasting' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjFalseOriginEasting(),
                'ProjFalseOriginNorthing' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjFalseOriginNorthing(),
                'ProjCenterLong' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjCenterLong(),
                'ProjCenterLat' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjCenterLat(),
                'ProjCenterEasting' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjCenterEasting(),
                'ProjCenterNorthing' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjCenterNorthing(),
                'ProjScaleAtNatOrigin' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjScaleAtNatOrigin(),
                'ProjScaleAtCenter' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjScaleAtCenter(),
                'ProjAzimuthAngle' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjAzimuthAngle(),
                'ProjStraightVertPoleLong' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjStraightVertPoleLong(),
                'ProjRectifiedGridAngle' => new \PHPExiftool\Driver\Tag\GeoTiff\ProjRectifiedGridAngle(),
                'VerticalCSType' => new \PHPExiftool\Driver\Tag\GeoTiff\VerticalCSType(),
                'VerticalCitation' => new \PHPExiftool\Driver\Tag\GeoTiff\VerticalCitation(),
                'VerticalDatum' => new \PHPExiftool\Driver\Tag\GeoTiff\VerticalDatum(),
                'VerticalUnits' => new \PHPExiftool\Driver\Tag\GeoTiff\VerticalUnits(),
            );
        });
        $this['H264'] = $this->share(function(){
            return array(
                'ApertureSetting' => new \PHPExiftool\Driver\Tag\H264\ApertureSetting(),
                'Gain' => new \PHPExiftool\Driver\Tag\H264\Gain(),
                'ExposureProgram' => new \PHPExiftool\Driver\Tag\H264\ExposureProgram(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\H264\WhiteBalance(),
                'Focus' => new \PHPExiftool\Driver\Tag\H264\Focus(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\H264\ImageStabilization(),
                'CaptureFrameRate' => new \PHPExiftool\Driver\Tag\H264\CaptureFrameRate(),
                'VideoFrameRate' => new \PHPExiftool\Driver\Tag\H264\VideoFrameRate(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\H264\DateTimeOriginal(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\H264\ExposureTime(),
                'FNumber' => new \PHPExiftool\Driver\Tag\H264\FNumber(),
                'BrightnessValue' => new \PHPExiftool\Driver\Tag\H264\BrightnessValue(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\H264\ExposureCompensation(),
                'MaxApertureValue' => new \PHPExiftool\Driver\Tag\H264\MaxApertureValue(),
                'Flash' => new \PHPExiftool\Driver\Tag\H264\Flash(),
                'CustomRendered' => new \PHPExiftool\Driver\Tag\H264\CustomRendered(),
                'FocalLengthIn35mmFormat' => new \PHPExiftool\Driver\Tag\H264\FocalLengthIn35mmFormat(),
                'SceneCaptureType' => new \PHPExiftool\Driver\Tag\H264\SceneCaptureType(),
                'Model' => new \PHPExiftool\Driver\Tag\H264\Model(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\H264\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\H264\ImageWidth(),
                'Make' => new \PHPExiftool\Driver\Tag\H264\Make(),
                'RecordingMode' => new \PHPExiftool\Driver\Tag\H264\RecordingMode(),
            );
        });
        $this['HP'] = $this->share(function(){
            return array(
                'SerialNumber' => new \PHPExiftool\Driver\Tag\HP\SerialNumber(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\HP\FirmwareVersion(),
                'LensShading' => new \PHPExiftool\Driver\Tag\HP\LensShading(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\HP\PreviewImage(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\HP\MaxAperture(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\HP\ExposureTime(),
                'CameraDateTime' => new \PHPExiftool\Driver\Tag\HP\CameraDateTime(),
                'ISO' => new \PHPExiftool\Driver\Tag\HP\ISO(),
                'FNumber' => new \PHPExiftool\Driver\Tag\HP\FNumber(),
            );
        });
        $this['HTML'] = $this->share(function(){
            return array(
                'Abstract' => new \PHPExiftool\Driver\Tag\HTML\Abstract0(),
                'Author' => new \PHPExiftool\Driver\Tag\HTML\Author(),
                'Classification' => new \PHPExiftool\Driver\Tag\HTML\Classification(),
                'ContentLanguage' => new \PHPExiftool\Driver\Tag\HTML\ContentLanguage(),
                'Copyright' => new \PHPExiftool\Driver\Tag\HTML\Copyright(),
                'Description' => new \PHPExiftool\Driver\Tag\HTML\Description(),
                'Distribution' => new \PHPExiftool\Driver\Tag\HTML\Distribution(),
                'DocClass' => new \PHPExiftool\Driver\Tag\HTML\DocClass(),
                'DocRights' => new \PHPExiftool\Driver\Tag\HTML\DocRights(),
                'DocType' => new \PHPExiftool\Driver\Tag\HTML\DocType(),
                'Formatter' => new \PHPExiftool\Driver\Tag\HTML\Formatter(),
                'Generator' => new \PHPExiftool\Driver\Tag\HTML\Generator(),
                'GeneratorVersion' => new \PHPExiftool\Driver\Tag\HTML\GeneratorVersion(),
                'GoogleBot' => new \PHPExiftool\Driver\Tag\HTML\GoogleBot(),
                'Keywords' => new \PHPExiftool\Driver\Tag\HTML\Keywords(),
                'NoMSSmartTags' => new \PHPExiftool\Driver\Tag\HTML\NoMSSmartTags(),
                'Originator' => new \PHPExiftool\Driver\Tag\HTML\Originator(),
                'Owner' => new \PHPExiftool\Driver\Tag\HTML\Owner(),
                'ProgID' => new \PHPExiftool\Driver\Tag\HTML\ProgID(),
                'Rating' => new \PHPExiftool\Driver\Tag\HTML\Rating(),
                'Refresh' => new \PHPExiftool\Driver\Tag\HTML\Refresh(),
                'ResourceType' => new \PHPExiftool\Driver\Tag\HTML\ResourceType(),
                'RevisitAfter' => new \PHPExiftool\Driver\Tag\HTML\RevisitAfter(),
                'Robots' => new \PHPExiftool\Driver\Tag\HTML\Robots(),
                'Title' => new \PHPExiftool\Driver\Tag\HTML\Title(),
            );
        });
        $this['HTML-office'] = $this->share(function(){
            return array(
                'Author' => new \PHPExiftool\Driver\Tag\HTMLOffice\Author(),
                'Category' => new \PHPExiftool\Driver\Tag\HTMLOffice\Category(),
                'Characters' => new \PHPExiftool\Driver\Tag\HTMLOffice\Characters(),
                'CharactersWithSpaces' => new \PHPExiftool\Driver\Tag\HTMLOffice\CharactersWithSpaces(),
                'Company' => new \PHPExiftool\Driver\Tag\HTMLOffice\Company(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\HTMLOffice\CreateDate(),
                'Description' => new \PHPExiftool\Driver\Tag\HTMLOffice\Description(),
                'Keywords' => new \PHPExiftool\Driver\Tag\HTMLOffice\Keywords(),
                'LastAuthor' => new \PHPExiftool\Driver\Tag\HTMLOffice\LastAuthor(),
                'LastPrinted' => new \PHPExiftool\Driver\Tag\HTMLOffice\LastPrinted(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\HTMLOffice\ModifyDate(),
                'Lines' => new \PHPExiftool\Driver\Tag\HTMLOffice\Lines(),
                'Manager' => new \PHPExiftool\Driver\Tag\HTMLOffice\Manager(),
                'Pages' => new \PHPExiftool\Driver\Tag\HTMLOffice\Pages(),
                'Paragraphs' => new \PHPExiftool\Driver\Tag\HTMLOffice\Paragraphs(),
                'RevisionNumber' => new \PHPExiftool\Driver\Tag\HTMLOffice\RevisionNumber(),
                'Subject' => new \PHPExiftool\Driver\Tag\HTMLOffice\Subject(),
                'Template' => new \PHPExiftool\Driver\Tag\HTMLOffice\Template(),
                'TotalEditTime' => new \PHPExiftool\Driver\Tag\HTMLOffice\TotalEditTime(),
                'Words' => new \PHPExiftool\Driver\Tag\HTMLOffice\Words(),
            );
        });
        $this['HTML-dc'] = $this->share(function(){
            return array(
                'Contributor' => new \PHPExiftool\Driver\Tag\HTMLDc\Contributor(),
                'Coverage' => new \PHPExiftool\Driver\Tag\HTMLDc\Coverage(),
                'Creator' => new \PHPExiftool\Driver\Tag\HTMLDc\Creator(),
                'Date' => new \PHPExiftool\Driver\Tag\HTMLDc\Date(),
                'Description' => new \PHPExiftool\Driver\Tag\HTMLDc\Description(),
                'Format' => new \PHPExiftool\Driver\Tag\HTMLDc\Format(),
                'Identifier' => new \PHPExiftool\Driver\Tag\HTMLDc\Identifier(),
                'Language' => new \PHPExiftool\Driver\Tag\HTMLDc\Language(),
                'Publisher' => new \PHPExiftool\Driver\Tag\HTMLDc\Publisher(),
                'Relation' => new \PHPExiftool\Driver\Tag\HTMLDc\Relation(),
                'Rights' => new \PHPExiftool\Driver\Tag\HTMLDc\Rights(),
                'Source' => new \PHPExiftool\Driver\Tag\HTMLDc\Source(),
                'Subject' => new \PHPExiftool\Driver\Tag\HTMLDc\Subject(),
                'Title' => new \PHPExiftool\Driver\Tag\HTMLDc\Title(),
                'Type' => new \PHPExiftool\Driver\Tag\HTMLDc\Type(),
            );
        });
        $this['HTTP-equiv'] = $this->share(function(){
            return array(
                'CacheControl' => new \PHPExiftool\Driver\Tag\HTTPEquiv\CacheControl(),
                'ContentDisposition' => new \PHPExiftool\Driver\Tag\HTTPEquiv\ContentDisposition(),
                'ContentLanguage' => new \PHPExiftool\Driver\Tag\HTTPEquiv\ContentLanguage(),
                'ContentScriptType' => new \PHPExiftool\Driver\Tag\HTTPEquiv\ContentScriptType(),
                'ContentStyleType' => new \PHPExiftool\Driver\Tag\HTTPEquiv\ContentStyleType(),
                'ContentType' => new \PHPExiftool\Driver\Tag\HTTPEquiv\ContentType(),
                'DefaultStyle' => new \PHPExiftool\Driver\Tag\HTTPEquiv\DefaultStyle(),
                'Expires' => new \PHPExiftool\Driver\Tag\HTTPEquiv\Expires(),
                'ExtCache' => new \PHPExiftool\Driver\Tag\HTTPEquiv\ExtCache(),
                'ImageToolbar' => new \PHPExiftool\Driver\Tag\HTTPEquiv\ImageToolbar(),
                'Lotus' => new \PHPExiftool\Driver\Tag\HTTPEquiv\Lotus(),
                'PageEnter' => new \PHPExiftool\Driver\Tag\HTTPEquiv\PageEnter(),
                'PageExit' => new \PHPExiftool\Driver\Tag\HTTPEquiv\PageExit(),
                'PicsLabel' => new \PHPExiftool\Driver\Tag\HTTPEquiv\PicsLabel(),
                'Pragma' => new \PHPExiftool\Driver\Tag\HTTPEquiv\Pragma(),
                'Refresh' => new \PHPExiftool\Driver\Tag\HTTPEquiv\Refresh(),
                'ReplyTo' => new \PHPExiftool\Driver\Tag\HTTPEquiv\ReplyTo(),
                'SetCookie' => new \PHPExiftool\Driver\Tag\HTTPEquiv\SetCookie(),
                'SiteEnter' => new \PHPExiftool\Driver\Tag\HTTPEquiv\SiteEnter(),
                'SiteExit' => new \PHPExiftool\Driver\Tag\HTTPEquiv\SiteExit(),
                'Vary' => new \PHPExiftool\Driver\Tag\HTTPEquiv\Vary(),
                'WindowTarget' => new \PHPExiftool\Driver\Tag\HTTPEquiv\WindowTarget(),
            );
        });
        $this['HTML-ncc'] = $this->share(function(){
            return array(
                'CharacterSet' => new \PHPExiftool\Driver\Tag\HTMLNcc\CharacterSet(),
                'Depth' => new \PHPExiftool\Driver\Tag\HTMLNcc\Depth(),
                'Files' => new \PHPExiftool\Driver\Tag\HTMLNcc\Files(),
                'Footnotes' => new \PHPExiftool\Driver\Tag\HTMLNcc\Footnotes(),
                'Generator' => new \PHPExiftool\Driver\Tag\HTMLNcc\Generator(),
                'KByteSize' => new \PHPExiftool\Driver\Tag\HTMLNcc\KByteSize(),
                'MaxPageNormal' => new \PHPExiftool\Driver\Tag\HTMLNcc\MaxPageNormal(),
                'MultimediaType' => new \PHPExiftool\Driver\Tag\HTMLNcc\MultimediaType(),
                'Narrator' => new \PHPExiftool\Driver\Tag\HTMLNcc\Narrator(),
                'PageFront' => new \PHPExiftool\Driver\Tag\HTMLNcc\PageFront(),
                'PageNormal' => new \PHPExiftool\Driver\Tag\HTMLNcc\PageNormal(),
                'PageSpecial' => new \PHPExiftool\Driver\Tag\HTMLNcc\PageSpecial(),
                'ProdNotes' => new \PHPExiftool\Driver\Tag\HTMLNcc\ProdNotes(),
                'ProducedDate' => new \PHPExiftool\Driver\Tag\HTMLNcc\ProducedDate(),
                'Producer' => new \PHPExiftool\Driver\Tag\HTMLNcc\Producer(),
                'Revision' => new \PHPExiftool\Driver\Tag\HTMLNcc\Revision(),
                'RevisionDate' => new \PHPExiftool\Driver\Tag\HTMLNcc\RevisionDate(),
                'SetInfo' => new \PHPExiftool\Driver\Tag\HTMLNcc\SetInfo(),
                'Sidebars' => new \PHPExiftool\Driver\Tag\HTMLNcc\Sidebars(),
                'SourceDate' => new \PHPExiftool\Driver\Tag\HTMLNcc\SourceDate(),
                'SourceEdition' => new \PHPExiftool\Driver\Tag\HTMLNcc\SourceEdition(),
                'SourcePublisher' => new \PHPExiftool\Driver\Tag\HTMLNcc\SourcePublisher(),
                'SourceRights' => new \PHPExiftool\Driver\Tag\HTMLNcc\SourceRights(),
                'SourceTitle' => new \PHPExiftool\Driver\Tag\HTMLNcc\SourceTitle(),
                'TOCItems' => new \PHPExiftool\Driver\Tag\HTMLNcc\TOCItems(),
                'Duration' => new \PHPExiftool\Driver\Tag\HTMLNcc\Duration(),
            );
        });
        $this['HTML-prod'] = $this->share(function(){
            return array(
                'RecEngineer' => new \PHPExiftool\Driver\Tag\HTMLProd\RecEngineer(),
                'RecLocation' => new \PHPExiftool\Driver\Tag\HTMLProd\RecLocation(),
            );
        });
        $this['HTML-vw96'] = $this->share(function(){
            return array(
                'ObjectType' => new \PHPExiftool\Driver\Tag\HTMLVw96\ObjectType(),
            );
        });
        $this['ICC-chrm'] = $this->share(function(){
            return array(
                'ChromaticityChannels' => new \PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannels(),
                'ChromaticityColorant' => new \PHPExiftool\Driver\Tag\ICCChrm\ChromaticityColorant(),
                'ChromaticityChannel1' => new \PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannel1(),
                'ChromaticityChannel2' => new \PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannel2(),
                'ChromaticityChannel3' => new \PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannel3(),
                'ChromaticityChannel4' => new \PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannel4(),
            );
        });
        $this['ICC-clrt'] = $this->share(function(){
            return array(
                'ColorantCount' => new \PHPExiftool\Driver\Tag\ICCClrt\ColorantCount(),
                'Colorant1Name' => new \PHPExiftool\Driver\Tag\ICCClrt\Colorant1Name(),
                'Colorant1Coordinates' => new \PHPExiftool\Driver\Tag\ICCClrt\Colorant1Coordinates(),
                'Colorant2Name' => new \PHPExiftool\Driver\Tag\ICCClrt\Colorant2Name(),
                'Colorant2Coordinates' => new \PHPExiftool\Driver\Tag\ICCClrt\Colorant2Coordinates(),
                'Colorant3Name' => new \PHPExiftool\Driver\Tag\ICCClrt\Colorant3Name(),
                'Colorant3Coordinates' => new \PHPExiftool\Driver\Tag\ICCClrt\Colorant3Coordinates(),
            );
        });
        $this['ICC-header'] = $this->share(function(){
            return array(
                'ProfileCMMType' => new \PHPExiftool\Driver\Tag\ICCHeader\ProfileCMMType(),
                'ProfileVersion' => new \PHPExiftool\Driver\Tag\ICCHeader\ProfileVersion(),
                'ProfileClass' => new \PHPExiftool\Driver\Tag\ICCHeader\ProfileClass(),
                'ColorSpaceData' => new \PHPExiftool\Driver\Tag\ICCHeader\ColorSpaceData(),
                'ProfileConnectionSpace' => new \PHPExiftool\Driver\Tag\ICCHeader\ProfileConnectionSpace(),
                'ProfileDateTime' => new \PHPExiftool\Driver\Tag\ICCHeader\ProfileDateTime(),
                'ProfileFileSignature' => new \PHPExiftool\Driver\Tag\ICCHeader\ProfileFileSignature(),
                'PrimaryPlatform' => new \PHPExiftool\Driver\Tag\ICCHeader\PrimaryPlatform(),
                'CMMFlags' => new \PHPExiftool\Driver\Tag\ICCHeader\CMMFlags(),
                'DeviceManufacturer' => new \PHPExiftool\Driver\Tag\ICCHeader\DeviceManufacturer(),
                'DeviceModel' => new \PHPExiftool\Driver\Tag\ICCHeader\DeviceModel(),
                'DeviceAttributes' => new \PHPExiftool\Driver\Tag\ICCHeader\DeviceAttributes(),
                'RenderingIntent' => new \PHPExiftool\Driver\Tag\ICCHeader\RenderingIntent(),
                'ConnectionSpaceIlluminant' => new \PHPExiftool\Driver\Tag\ICCHeader\ConnectionSpaceIlluminant(),
                'ProfileCreator' => new \PHPExiftool\Driver\Tag\ICCHeader\ProfileCreator(),
                'ProfileID' => new \PHPExiftool\Driver\Tag\ICCHeader\ProfileID(),
            );
        });
        $this['ICC-meas'] = $this->share(function(){
            return array(
                'MeasurementObserver' => new \PHPExiftool\Driver\Tag\ICCMeas\MeasurementObserver(),
                'MeasurementBacking' => new \PHPExiftool\Driver\Tag\ICCMeas\MeasurementBacking(),
                'MeasurementGeometry' => new \PHPExiftool\Driver\Tag\ICCMeas\MeasurementGeometry(),
                'MeasurementFlare' => new \PHPExiftool\Driver\Tag\ICCMeas\MeasurementFlare(),
                'MeasurementIlluminant' => new \PHPExiftool\Driver\Tag\ICCMeas\MeasurementIlluminant(),
            );
        });
        $this['ICC-meta'] = $this->share(function(){
            return array(
                'ManufacturerName' => new \PHPExiftool\Driver\Tag\ICCMeta\ManufacturerName(),
                'MediaColor' => new \PHPExiftool\Driver\Tag\ICCMeta\MediaColor(),
                'MediaWeight' => new \PHPExiftool\Driver\Tag\ICCMeta\MediaWeight(),
            );
        });
        $this['ICC-view'] = $this->share(function(){
            return array(
                'ViewingCondIlluminant' => new \PHPExiftool\Driver\Tag\ICCView\ViewingCondIlluminant(),
                'ViewingCondSurround' => new \PHPExiftool\Driver\Tag\ICCView\ViewingCondSurround(),
                'ViewingCondIlluminantType' => new \PHPExiftool\Driver\Tag\ICCView\ViewingCondIlluminantType(),
            );
        });
        $this['ID3'] = $this->share(function(){
            return array(
                'AverageLevel' => new \PHPExiftool\Driver\Tag\ID3\AverageLevel(),
                'PeakValue' => new \PHPExiftool\Driver\Tag\ID3\PeakValue(),
                'WM_MediaClassPrimaryID' => new \PHPExiftool\Driver\Tag\ID3\WMMediaClassPrimaryID(),
                'WM_MediaClassSecondaryID' => new \PHPExiftool\Driver\Tag\ID3\WMMediaClassSecondaryID(),
                'WM_Provider' => new \PHPExiftool\Driver\Tag\ID3\WMProvider(),
                'WM_CollectionGroupID' => new \PHPExiftool\Driver\Tag\ID3\WMCollectionGroupID(),
                'WM_CollectionID' => new \PHPExiftool\Driver\Tag\ID3\WMCollectionID(),
                'WM_ContentID' => new \PHPExiftool\Driver\Tag\ID3\WMContentID(),
                'SynchronizedLyricsDescription' => new \PHPExiftool\Driver\Tag\ID3\SynchronizedLyricsDescription(),
                'SynchronizedLyricsText' => new \PHPExiftool\Driver\Tag\ID3\SynchronizedLyricsText(),
                'SynchronizedLyricsType' => new \PHPExiftool\Driver\Tag\ID3\SynchronizedLyricsType(),
            );
        });
        $this['ID3v1'] = $this->share(function(){
            return array(
                'Title' => new \PHPExiftool\Driver\Tag\ID3v1\Title(),
                'Artist' => new \PHPExiftool\Driver\Tag\ID3v1\Artist(),
                'Album' => new \PHPExiftool\Driver\Tag\ID3v1\Album(),
                'Year' => new \PHPExiftool\Driver\Tag\ID3v1\Year(),
                'Comment' => new \PHPExiftool\Driver\Tag\ID3v1\Comment(),
                'Track' => new \PHPExiftool\Driver\Tag\ID3v1\Track(),
                'Genre' => new \PHPExiftool\Driver\Tag\ID3v1\Genre(),
            );
        });
        $this['ID3v1_Enh'] = $this->share(function(){
            return array(
                'Title2' => new \PHPExiftool\Driver\Tag\ID3v1Enh\Title2(),
                'Artist2' => new \PHPExiftool\Driver\Tag\ID3v1Enh\Artist2(),
                'Album2' => new \PHPExiftool\Driver\Tag\ID3v1Enh\Album2(),
                'Speed' => new \PHPExiftool\Driver\Tag\ID3v1Enh\Speed(),
                'Genre' => new \PHPExiftool\Driver\Tag\ID3v1Enh\Genre(),
                'StartTime' => new \PHPExiftool\Driver\Tag\ID3v1Enh\StartTime(),
                'EndTime' => new \PHPExiftool\Driver\Tag\ID3v1Enh\EndTime(),
            );
        });
        $this['ID3v2_2'] = $this->share(function(){
            return array(
                'PlayCounter' => new \PHPExiftool\Driver\Tag\ID3v22\PlayCounter(),
                'Comment' => new \PHPExiftool\Driver\Tag\ID3v22\Comment(),
                'InvolvedPeople' => new \PHPExiftool\Driver\Tag\ID3v22\InvolvedPeople(),
                'iTunesU' => new \PHPExiftool\Driver\Tag\ID3v22\ITunesU(),
                'Podcast' => new \PHPExiftool\Driver\Tag\ID3v22\Podcast(),
                'Picture' => new \PHPExiftool\Driver\Tag\ID3v22\Picture(),
                'PictureFormat' => new \PHPExiftool\Driver\Tag\ID3v22\PictureFormat(),
                'PictureType' => new \PHPExiftool\Driver\Tag\ID3v22\PictureType(),
                'PictureDescription' => new \PHPExiftool\Driver\Tag\ID3v22\PictureDescription(),
                'Popularimeter' => new \PHPExiftool\Driver\Tag\ID3v22\Popularimeter(),
                'RelativeVolumeAdjustment' => new \PHPExiftool\Driver\Tag\ID3v22\RelativeVolumeAdjustment(),
                'Album' => new \PHPExiftool\Driver\Tag\ID3v22\Album(),
                'BeatsPerMinute' => new \PHPExiftool\Driver\Tag\ID3v22\BeatsPerMinute(),
                'Composer' => new \PHPExiftool\Driver\Tag\ID3v22\Composer(),
                'Genre' => new \PHPExiftool\Driver\Tag\ID3v22\Genre(),
                'Compilation' => new \PHPExiftool\Driver\Tag\ID3v22\Compilation(),
                'Copyright' => new \PHPExiftool\Driver\Tag\ID3v22\Copyright(),
                'Date' => new \PHPExiftool\Driver\Tag\ID3v22\Date(),
                'PlaylistDelay' => new \PHPExiftool\Driver\Tag\ID3v22\PlaylistDelay(),
                'EncodedBy' => new \PHPExiftool\Driver\Tag\ID3v22\EncodedBy(),
                'FileType' => new \PHPExiftool\Driver\Tag\ID3v22\FileType(),
                'Time' => new \PHPExiftool\Driver\Tag\ID3v22\Time(),
                'InitialKey' => new \PHPExiftool\Driver\Tag\ID3v22\InitialKey(),
                'Language' => new \PHPExiftool\Driver\Tag\ID3v22\Language(),
                'Length' => new \PHPExiftool\Driver\Tag\ID3v22\Length(),
                'Media' => new \PHPExiftool\Driver\Tag\ID3v22\Media(),
                'OriginalArtist' => new \PHPExiftool\Driver\Tag\ID3v22\OriginalArtist(),
                'OriginalFilename' => new \PHPExiftool\Driver\Tag\ID3v22\OriginalFilename(),
                'OriginalLyricist' => new \PHPExiftool\Driver\Tag\ID3v22\OriginalLyricist(),
                'OriginalReleaseYear' => new \PHPExiftool\Driver\Tag\ID3v22\OriginalReleaseYear(),
                'OriginalAlbum' => new \PHPExiftool\Driver\Tag\ID3v22\OriginalAlbum(),
                'Artist' => new \PHPExiftool\Driver\Tag\ID3v22\Artist(),
                'Band' => new \PHPExiftool\Driver\Tag\ID3v22\Band(),
                'Conductor' => new \PHPExiftool\Driver\Tag\ID3v22\Conductor(),
                'InterpretedBy' => new \PHPExiftool\Driver\Tag\ID3v22\InterpretedBy(),
                'PartOfSet' => new \PHPExiftool\Driver\Tag\ID3v22\PartOfSet(),
                'Publisher' => new \PHPExiftool\Driver\Tag\ID3v22\Publisher(),
                'ISRC' => new \PHPExiftool\Driver\Tag\ID3v22\ISRC(),
                'RecordingDates' => new \PHPExiftool\Driver\Tag\ID3v22\RecordingDates(),
                'Track' => new \PHPExiftool\Driver\Tag\ID3v22\Track(),
                'AlbumArtistSortOrder' => new \PHPExiftool\Driver\Tag\ID3v22\AlbumArtistSortOrder(),
                'AlbumSortOrder' => new \PHPExiftool\Driver\Tag\ID3v22\AlbumSortOrder(),
                'ComposerSortOrder' => new \PHPExiftool\Driver\Tag\ID3v22\ComposerSortOrder(),
                'Size' => new \PHPExiftool\Driver\Tag\ID3v22\Size(),
                'PerformerSortOrder' => new \PHPExiftool\Driver\Tag\ID3v22\PerformerSortOrder(),
                'EncoderSettings' => new \PHPExiftool\Driver\Tag\ID3v22\EncoderSettings(),
                'TitleSortOrder' => new \PHPExiftool\Driver\Tag\ID3v22\TitleSortOrder(),
                'Grouping' => new \PHPExiftool\Driver\Tag\ID3v22\Grouping(),
                'Title' => new \PHPExiftool\Driver\Tag\ID3v22\Title(),
                'Subtitle' => new \PHPExiftool\Driver\Tag\ID3v22\Subtitle(),
                'Lyricist' => new \PHPExiftool\Driver\Tag\ID3v22\Lyricist(),
                'UserDefinedText' => new \PHPExiftool\Driver\Tag\ID3v22\UserDefinedText(),
                'Year' => new \PHPExiftool\Driver\Tag\ID3v22\Year(),
                'Lyrics' => new \PHPExiftool\Driver\Tag\ID3v22\Lyrics(),
                'FileURL' => new \PHPExiftool\Driver\Tag\ID3v22\FileURL(),
                'ArtistURL' => new \PHPExiftool\Driver\Tag\ID3v22\ArtistURL(),
                'SourceURL' => new \PHPExiftool\Driver\Tag\ID3v22\SourceURL(),
                'CommercialURL' => new \PHPExiftool\Driver\Tag\ID3v22\CommercialURL(),
                'CopyrightURL' => new \PHPExiftool\Driver\Tag\ID3v22\CopyrightURL(),
                'PublisherURL' => new \PHPExiftool\Driver\Tag\ID3v22\PublisherURL(),
                'UserDefinedURL' => new \PHPExiftool\Driver\Tag\ID3v22\UserDefinedURL(),
            );
        });
        $this['ID3v2_3'] = $this->share(function(){
            return array(
                'Picture' => new \PHPExiftool\Driver\Tag\ID3v23\Picture(),
                'PictureMimeType' => new \PHPExiftool\Driver\Tag\ID3v23\PictureMimeType(),
                'PictureType' => new \PHPExiftool\Driver\Tag\ID3v23\PictureType(),
                'PictureDescription' => new \PHPExiftool\Driver\Tag\ID3v23\PictureDescription(),
                'Comment' => new \PHPExiftool\Driver\Tag\ID3v23\Comment(),
                'InvolvedPeople' => new \PHPExiftool\Driver\Tag\ID3v23\InvolvedPeople(),
                'MusicCDIdentifier' => new \PHPExiftool\Driver\Tag\ID3v23\MusicCDIdentifier(),
                'Ownership' => new \PHPExiftool\Driver\Tag\ID3v23\Ownership(),
                'PlayCounter' => new \PHPExiftool\Driver\Tag\ID3v23\PlayCounter(),
                'Popularimeter' => new \PHPExiftool\Driver\Tag\ID3v23\Popularimeter(),
                'Album' => new \PHPExiftool\Driver\Tag\ID3v23\Album(),
                'BeatsPerMinute' => new \PHPExiftool\Driver\Tag\ID3v23\BeatsPerMinute(),
                'Compilation' => new \PHPExiftool\Driver\Tag\ID3v23\Compilation(),
                'Composer' => new \PHPExiftool\Driver\Tag\ID3v23\Composer(),
                'Genre' => new \PHPExiftool\Driver\Tag\ID3v23\Genre(),
                'Copyright' => new \PHPExiftool\Driver\Tag\ID3v23\Copyright(),
                'Date' => new \PHPExiftool\Driver\Tag\ID3v23\Date(),
                'PlaylistDelay' => new \PHPExiftool\Driver\Tag\ID3v23\PlaylistDelay(),
                'EncodedBy' => new \PHPExiftool\Driver\Tag\ID3v23\EncodedBy(),
                'Lyricist' => new \PHPExiftool\Driver\Tag\ID3v23\Lyricist(),
                'FileType' => new \PHPExiftool\Driver\Tag\ID3v23\FileType(),
                'Time' => new \PHPExiftool\Driver\Tag\ID3v23\Time(),
                'Grouping' => new \PHPExiftool\Driver\Tag\ID3v23\Grouping(),
                'Title' => new \PHPExiftool\Driver\Tag\ID3v23\Title(),
                'Subtitle' => new \PHPExiftool\Driver\Tag\ID3v23\Subtitle(),
                'InitialKey' => new \PHPExiftool\Driver\Tag\ID3v23\InitialKey(),
                'Language' => new \PHPExiftool\Driver\Tag\ID3v23\Language(),
                'Length' => new \PHPExiftool\Driver\Tag\ID3v23\Length(),
                'Media' => new \PHPExiftool\Driver\Tag\ID3v23\Media(),
                'OriginalAlbum' => new \PHPExiftool\Driver\Tag\ID3v23\OriginalAlbum(),
                'OriginalFilename' => new \PHPExiftool\Driver\Tag\ID3v23\OriginalFilename(),
                'OriginalLyricist' => new \PHPExiftool\Driver\Tag\ID3v23\OriginalLyricist(),
                'OriginalArtist' => new \PHPExiftool\Driver\Tag\ID3v23\OriginalArtist(),
                'OriginalReleaseYear' => new \PHPExiftool\Driver\Tag\ID3v23\OriginalReleaseYear(),
                'FileOwner' => new \PHPExiftool\Driver\Tag\ID3v23\FileOwner(),
                'Artist' => new \PHPExiftool\Driver\Tag\ID3v23\Artist(),
                'Band' => new \PHPExiftool\Driver\Tag\ID3v23\Band(),
                'Conductor' => new \PHPExiftool\Driver\Tag\ID3v23\Conductor(),
                'InterpretedBy' => new \PHPExiftool\Driver\Tag\ID3v23\InterpretedBy(),
                'PartOfSet' => new \PHPExiftool\Driver\Tag\ID3v23\PartOfSet(),
                'Publisher' => new \PHPExiftool\Driver\Tag\ID3v23\Publisher(),
                'Track' => new \PHPExiftool\Driver\Tag\ID3v23\Track(),
                'RecordingDates' => new \PHPExiftool\Driver\Tag\ID3v23\RecordingDates(),
                'InternetRadioStationName' => new \PHPExiftool\Driver\Tag\ID3v23\InternetRadioStationName(),
                'InternetRadioStationOwner' => new \PHPExiftool\Driver\Tag\ID3v23\InternetRadioStationOwner(),
                'Size' => new \PHPExiftool\Driver\Tag\ID3v23\Size(),
                'ISRC' => new \PHPExiftool\Driver\Tag\ID3v23\ISRC(),
                'EncoderSettings' => new \PHPExiftool\Driver\Tag\ID3v23\EncoderSettings(),
                'UserDefinedText' => new \PHPExiftool\Driver\Tag\ID3v23\UserDefinedText(),
                'Year' => new \PHPExiftool\Driver\Tag\ID3v23\Year(),
                'TermsOfUse' => new \PHPExiftool\Driver\Tag\ID3v23\TermsOfUse(),
                'Lyrics' => new \PHPExiftool\Driver\Tag\ID3v23\Lyrics(),
                'CommercialURL' => new \PHPExiftool\Driver\Tag\ID3v23\CommercialURL(),
                'CopyrightURL' => new \PHPExiftool\Driver\Tag\ID3v23\CopyrightURL(),
                'FileURL' => new \PHPExiftool\Driver\Tag\ID3v23\FileURL(),
                'ArtistURL' => new \PHPExiftool\Driver\Tag\ID3v23\ArtistURL(),
                'SourceURL' => new \PHPExiftool\Driver\Tag\ID3v23\SourceURL(),
                'InternetRadioStationURL' => new \PHPExiftool\Driver\Tag\ID3v23\InternetRadioStationURL(),
                'PaymentURL' => new \PHPExiftool\Driver\Tag\ID3v23\PaymentURL(),
                'PublisherURL' => new \PHPExiftool\Driver\Tag\ID3v23\PublisherURL(),
                'UserDefinedURL' => new \PHPExiftool\Driver\Tag\ID3v23\UserDefinedURL(),
            );
        });
        $this['ID3v2_4'] = $this->share(function(){
            return array(
                'Picture' => new \PHPExiftool\Driver\Tag\ID3v24\Picture(),
                'PictureMimeType' => new \PHPExiftool\Driver\Tag\ID3v24\PictureMimeType(),
                'PictureType' => new \PHPExiftool\Driver\Tag\ID3v24\PictureType(),
                'PictureDescription' => new \PHPExiftool\Driver\Tag\ID3v24\PictureDescription(),
                'Comment' => new \PHPExiftool\Driver\Tag\ID3v24\Comment(),
                'iTunesU' => new \PHPExiftool\Driver\Tag\ID3v24\ITunesU(),
                'MusicCDIdentifier' => new \PHPExiftool\Driver\Tag\ID3v24\MusicCDIdentifier(),
                'Ownership' => new \PHPExiftool\Driver\Tag\ID3v24\Ownership(),
                'PlayCounter' => new \PHPExiftool\Driver\Tag\ID3v24\PlayCounter(),
                'Podcast' => new \PHPExiftool\Driver\Tag\ID3v24\Podcast(),
                'Popularimeter' => new \PHPExiftool\Driver\Tag\ID3v24\Popularimeter(),
                'RelativeVolumeAdjustment' => new \PHPExiftool\Driver\Tag\ID3v24\RelativeVolumeAdjustment(),
                'Album' => new \PHPExiftool\Driver\Tag\ID3v24\Album(),
                'BeatsPerMinute' => new \PHPExiftool\Driver\Tag\ID3v24\BeatsPerMinute(),
                'Compilation' => new \PHPExiftool\Driver\Tag\ID3v24\Compilation(),
                'Composer' => new \PHPExiftool\Driver\Tag\ID3v24\Composer(),
                'Genre' => new \PHPExiftool\Driver\Tag\ID3v24\Genre(),
                'Copyright' => new \PHPExiftool\Driver\Tag\ID3v24\Copyright(),
                'EncodingTime' => new \PHPExiftool\Driver\Tag\ID3v24\EncodingTime(),
                'PlaylistDelay' => new \PHPExiftool\Driver\Tag\ID3v24\PlaylistDelay(),
                'OriginalReleaseTime' => new \PHPExiftool\Driver\Tag\ID3v24\OriginalReleaseTime(),
                'RecordingTime' => new \PHPExiftool\Driver\Tag\ID3v24\RecordingTime(),
                'ReleaseTime' => new \PHPExiftool\Driver\Tag\ID3v24\ReleaseTime(),
                'TaggingTime' => new \PHPExiftool\Driver\Tag\ID3v24\TaggingTime(),
                'EncodedBy' => new \PHPExiftool\Driver\Tag\ID3v24\EncodedBy(),
                'Lyricist' => new \PHPExiftool\Driver\Tag\ID3v24\Lyricist(),
                'FileType' => new \PHPExiftool\Driver\Tag\ID3v24\FileType(),
                'InvolvedPeople' => new \PHPExiftool\Driver\Tag\ID3v24\InvolvedPeople(),
                'Grouping' => new \PHPExiftool\Driver\Tag\ID3v24\Grouping(),
                'Title' => new \PHPExiftool\Driver\Tag\ID3v24\Title(),
                'Subtitle' => new \PHPExiftool\Driver\Tag\ID3v24\Subtitle(),
                'InitialKey' => new \PHPExiftool\Driver\Tag\ID3v24\InitialKey(),
                'Language' => new \PHPExiftool\Driver\Tag\ID3v24\Language(),
                'Length' => new \PHPExiftool\Driver\Tag\ID3v24\Length(),
                'MusicianCredits' => new \PHPExiftool\Driver\Tag\ID3v24\MusicianCredits(),
                'Media' => new \PHPExiftool\Driver\Tag\ID3v24\Media(),
                'Mood' => new \PHPExiftool\Driver\Tag\ID3v24\Mood(),
                'OriginalAlbum' => new \PHPExiftool\Driver\Tag\ID3v24\OriginalAlbum(),
                'OriginalFilename' => new \PHPExiftool\Driver\Tag\ID3v24\OriginalFilename(),
                'OriginalLyricist' => new \PHPExiftool\Driver\Tag\ID3v24\OriginalLyricist(),
                'OriginalArtist' => new \PHPExiftool\Driver\Tag\ID3v24\OriginalArtist(),
                'FileOwner' => new \PHPExiftool\Driver\Tag\ID3v24\FileOwner(),
                'Artist' => new \PHPExiftool\Driver\Tag\ID3v24\Artist(),
                'Band' => new \PHPExiftool\Driver\Tag\ID3v24\Band(),
                'Conductor' => new \PHPExiftool\Driver\Tag\ID3v24\Conductor(),
                'InterpretedBy' => new \PHPExiftool\Driver\Tag\ID3v24\InterpretedBy(),
                'PartOfSet' => new \PHPExiftool\Driver\Tag\ID3v24\PartOfSet(),
                'ProducedNotice' => new \PHPExiftool\Driver\Tag\ID3v24\ProducedNotice(),
                'Publisher' => new \PHPExiftool\Driver\Tag\ID3v24\Publisher(),
                'Track' => new \PHPExiftool\Driver\Tag\ID3v24\Track(),
                'InternetRadioStationName' => new \PHPExiftool\Driver\Tag\ID3v24\InternetRadioStationName(),
                'InternetRadioStationOwner' => new \PHPExiftool\Driver\Tag\ID3v24\InternetRadioStationOwner(),
                'AlbumArtistSortOrder' => new \PHPExiftool\Driver\Tag\ID3v24\AlbumArtistSortOrder(),
                'AlbumSortOrder' => new \PHPExiftool\Driver\Tag\ID3v24\AlbumSortOrder(),
                'ComposerSortOrder' => new \PHPExiftool\Driver\Tag\ID3v24\ComposerSortOrder(),
                'PerformerSortOrder' => new \PHPExiftool\Driver\Tag\ID3v24\PerformerSortOrder(),
                'TitleSortOrder' => new \PHPExiftool\Driver\Tag\ID3v24\TitleSortOrder(),
                'ISRC' => new \PHPExiftool\Driver\Tag\ID3v24\ISRC(),
                'EncoderSettings' => new \PHPExiftool\Driver\Tag\ID3v24\EncoderSettings(),
                'SetSubtitle' => new \PHPExiftool\Driver\Tag\ID3v24\SetSubtitle(),
                'UserDefinedText' => new \PHPExiftool\Driver\Tag\ID3v24\UserDefinedText(),
                'TermsOfUse' => new \PHPExiftool\Driver\Tag\ID3v24\TermsOfUse(),
                'Lyrics' => new \PHPExiftool\Driver\Tag\ID3v24\Lyrics(),
                'CommercialURL' => new \PHPExiftool\Driver\Tag\ID3v24\CommercialURL(),
                'CopyrightURL' => new \PHPExiftool\Driver\Tag\ID3v24\CopyrightURL(),
                'FileURL' => new \PHPExiftool\Driver\Tag\ID3v24\FileURL(),
                'ArtistURL' => new \PHPExiftool\Driver\Tag\ID3v24\ArtistURL(),
                'SourceURL' => new \PHPExiftool\Driver\Tag\ID3v24\SourceURL(),
                'InternetRadioStationURL' => new \PHPExiftool\Driver\Tag\ID3v24\InternetRadioStationURL(),
                'PaymentURL' => new \PHPExiftool\Driver\Tag\ID3v24\PaymentURL(),
                'PublisherURL' => new \PHPExiftool\Driver\Tag\ID3v24\PublisherURL(),
                'UserDefinedURL' => new \PHPExiftool\Driver\Tag\ID3v24\UserDefinedURL(),
            );
        });
        $this['ITC'] = $this->share(function(){
            return array(
                'DataType' => new \PHPExiftool\Driver\Tag\ITC\DataType(),
                'LibraryID' => new \PHPExiftool\Driver\Tag\ITC\LibraryID(),
                'TrackID' => new \PHPExiftool\Driver\Tag\ITC\TrackID(),
                'DataLocation' => new \PHPExiftool\Driver\Tag\ITC\DataLocation(),
                'ImageType' => new \PHPExiftool\Driver\Tag\ITC\ImageType(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\ITC\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\ITC\ImageHeight(),
                'ImageData' => new \PHPExiftool\Driver\Tag\ITC\ImageData(),
            );
        });
        $this['JFIF'] = $this->share(function(){
            return array(
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\JFIF\ThumbnailImage(),
                'JFIFVersion' => new \PHPExiftool\Driver\Tag\JFIF\JFIFVersion(),
                'ResolutionUnit' => new \PHPExiftool\Driver\Tag\JFIF\ResolutionUnit(),
                'XResolution' => new \PHPExiftool\Driver\Tag\JFIF\XResolution(),
                'YResolution' => new \PHPExiftool\Driver\Tag\JFIF\YResolution(),
            );
        });
        $this['AVI1'] = $this->share(function(){
            return array(
                'InterleavedField' => new \PHPExiftool\Driver\Tag\AVI1\InterleavedField(),
            );
        });
        $this['AdobeCM'] = $this->share(function(){
            return array(
                'AdobeCMType' => new \PHPExiftool\Driver\Tag\AdobeCM\AdobeCMType(),
            );
        });
        $this['EPPIM'] = $this->share(function(){
            return array(
                'PrintIM' => new \PHPExiftool\Driver\Tag\EPPIM\PrintIM(),
            );
        });
        $this['GraphConv'] = $this->share(function(){
            return array(
                'Quality' => new \PHPExiftool\Driver\Tag\GraphConv\Quality(),
            );
        });
        $this['JPEG'] = $this->share(function(){
            return array(
                'PreviewImage' => new \PHPExiftool\Driver\Tag\JPEG\PreviewImage(),
                'Comment' => new \PHPExiftool\Driver\Tag\JPEG\Comment(),
                'Adobe' => new \PHPExiftool\Driver\Tag\JPEG\Adobe(),
                'DefineQuantizationTable' => new \PHPExiftool\Driver\Tag\JPEG\DefineQuantizationTable(),
            );
        });
        $this['NITF'] = $this->share(function(){
            return array(
                'NITFVersion' => new \PHPExiftool\Driver\Tag\NITF\NITFVersion(),
                'ImageFormat' => new \PHPExiftool\Driver\Tag\NITF\ImageFormat(),
                'BlocksPerRow' => new \PHPExiftool\Driver\Tag\NITF\BlocksPerRow(),
                'BlocksPerColumn' => new \PHPExiftool\Driver\Tag\NITF\BlocksPerColumn(),
                'ImageColor' => new \PHPExiftool\Driver\Tag\NITF\ImageColor(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\NITF\BitDepth(),
                'ImageClass' => new \PHPExiftool\Driver\Tag\NITF\ImageClass(),
                'JPEGProcess' => new \PHPExiftool\Driver\Tag\NITF\JPEGProcess(),
                'Quality' => new \PHPExiftool\Driver\Tag\NITF\Quality(),
                'StreamColor' => new \PHPExiftool\Driver\Tag\NITF\StreamColor(),
                'StreamBitDepth' => new \PHPExiftool\Driver\Tag\NITF\StreamBitDepth(),
                'Flags' => new \PHPExiftool\Driver\Tag\NITF\Flags(),
            );
        });
        $this['Ocad'] = $this->share(function(){
            return array(
                'OcadRevision' => new \PHPExiftool\Driver\Tag\Ocad\OcadRevision(),
            );
        });
        $this['SPIFF'] = $this->share(function(){
            return array(
                'SPIFFVersion' => new \PHPExiftool\Driver\Tag\SPIFF\SPIFFVersion(),
                'ProfileID' => new \PHPExiftool\Driver\Tag\SPIFF\ProfileID(),
                'ColorComponents' => new \PHPExiftool\Driver\Tag\SPIFF\ColorComponents(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\SPIFF\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\SPIFF\ImageWidth(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\SPIFF\ColorSpace(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\SPIFF\BitsPerSample(),
                'Compression' => new \PHPExiftool\Driver\Tag\SPIFF\Compression(),
                'ResolutionUnit' => new \PHPExiftool\Driver\Tag\SPIFF\ResolutionUnit(),
                'YResolution' => new \PHPExiftool\Driver\Tag\SPIFF\YResolution(),
                'XResolution' => new \PHPExiftool\Driver\Tag\SPIFF\XResolution(),
            );
        });
        $this['Scalado'] = $this->share(function(){
            return array(
                'PreviewImageHeight' => new \PHPExiftool\Driver\Tag\Scalado\PreviewImageHeight(),
                'PreviewQuality' => new \PHPExiftool\Driver\Tag\Scalado\PreviewQuality(),
                'DataLength' => new \PHPExiftool\Driver\Tag\Scalado\DataLength(),
                'PreviewImageWidth' => new \PHPExiftool\Driver\Tag\Scalado\PreviewImageWidth(),
            );
        });
        $this['JVC'] = $this->share(function(){
            return array(
                'CPUVersions' => new \PHPExiftool\Driver\Tag\JVC\CPUVersions(),
                'Quality' => new \PHPExiftool\Driver\Tag\JVC\Quality(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\JVC\MakerNoteVersion(),
            );
        });
        $this['Jpeg2000'] = $this->share(function(){
            return array(
                'CaptureYResolution' => new \PHPExiftool\Driver\Tag\Jpeg2000\CaptureYResolution(),
                'CaptureXResolution' => new \PHPExiftool\Driver\Tag\Jpeg2000\CaptureXResolution(),
                'CaptureYResolutionUnit' => new \PHPExiftool\Driver\Tag\Jpeg2000\CaptureYResolutionUnit(),
                'CaptureXResolutionUnit' => new \PHPExiftool\Driver\Tag\Jpeg2000\CaptureXResolutionUnit(),
                'ColorSpecMethod' => new \PHPExiftool\Driver\Tag\Jpeg2000\ColorSpecMethod(),
                'ColorSpecPrecedence' => new \PHPExiftool\Driver\Tag\Jpeg2000\ColorSpecPrecedence(),
                'ColorSpecApproximation' => new \PHPExiftool\Driver\Tag\Jpeg2000\ColorSpecApproximation(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Jpeg2000\ColorSpace(),
                'ColorSpecData' => new \PHPExiftool\Driver\Tag\Jpeg2000\ColorSpecData(),
                'DisplayYResolution' => new \PHPExiftool\Driver\Tag\Jpeg2000\DisplayYResolution(),
                'DisplayXResolution' => new \PHPExiftool\Driver\Tag\Jpeg2000\DisplayXResolution(),
                'DisplayYResolutionUnit' => new \PHPExiftool\Driver\Tag\Jpeg2000\DisplayYResolutionUnit(),
                'DisplayXResolutionUnit' => new \PHPExiftool\Driver\Tag\Jpeg2000\DisplayXResolutionUnit(),
                'MajorBrand' => new \PHPExiftool\Driver\Tag\Jpeg2000\MajorBrand(),
                'MinorVersion' => new \PHPExiftool\Driver\Tag\Jpeg2000\MinorVersion(),
                'CompatibleBrands' => new \PHPExiftool\Driver\Tag\Jpeg2000\CompatibleBrands(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\Jpeg2000\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\Jpeg2000\ImageWidth(),
                'NumberOfComponents' => new \PHPExiftool\Driver\Tag\Jpeg2000\NumberOfComponents(),
                'BitsPerComponent' => new \PHPExiftool\Driver\Tag\Jpeg2000\BitsPerComponent(),
                'Compression' => new \PHPExiftool\Driver\Tag\Jpeg2000\Compression(),
                'Association' => new \PHPExiftool\Driver\Tag\Jpeg2000\Association(),
                'BinaryFilter' => new \PHPExiftool\Driver\Tag\Jpeg2000\BinaryFilter(),
                'ComponentDefinition' => new \PHPExiftool\Driver\Tag\Jpeg2000\ComponentDefinition(),
                'ColorGroup' => new \PHPExiftool\Driver\Tag\Jpeg2000\ColorGroup(),
                'DigitalSignature' => new \PHPExiftool\Driver\Tag\Jpeg2000\DigitalSignature(),
                'ComponentMapping' => new \PHPExiftool\Driver\Tag\Jpeg2000\ComponentMapping(),
                'Composition' => new \PHPExiftool\Driver\Tag\Jpeg2000\Composition(),
                'CompositionOptions' => new \PHPExiftool\Driver\Tag\Jpeg2000\CompositionOptions(),
                'Cross-Reference' => new \PHPExiftool\Driver\Tag\Jpeg2000\CrossReference(),
                'CodestreamRegistration' => new \PHPExiftool\Driver\Tag\Jpeg2000\CodestreamRegistration(),
                'DesiredReproductions' => new \PHPExiftool\Driver\Tag\Jpeg2000\DesiredReproductions(),
                'DataReference' => new \PHPExiftool\Driver\Tag\Jpeg2000\DataReference(),
                'FragmentList' => new \PHPExiftool\Driver\Tag\Jpeg2000\FragmentList(),
                'Free' => new \PHPExiftool\Driver\Tag\Jpeg2000\Free(),
                'FragmentTable' => new \PHPExiftool\Driver\Tag\Jpeg2000\FragmentTable(),
                'GraphicsTechnologyStandardOutput' => new \PHPExiftool\Driver\Tag\Jpeg2000\GraphicsTechnologyStandardOutput(),
                'InstructionSet' => new \PHPExiftool\Driver\Tag\Jpeg2000\InstructionSet(),
                'JP2Signature' => new \PHPExiftool\Driver\Tag\Jpeg2000\JP2Signature(),
                'ContiguousCodestream' => new \PHPExiftool\Driver\Tag\Jpeg2000\ContiguousCodestream(),
                'Label' => new \PHPExiftool\Driver\Tag\Jpeg2000\Label(),
                'MediaData' => new \PHPExiftool\Driver\Tag\Jpeg2000\MediaData(),
                'MPEG7Binary' => new \PHPExiftool\Driver\Tag\Jpeg2000\MPEG7Binary(),
                'NumberList' => new \PHPExiftool\Driver\Tag\Jpeg2000\NumberList(),
                'Opacity' => new \PHPExiftool\Driver\Tag\Jpeg2000\Opacity(),
                'Palette' => new \PHPExiftool\Driver\Tag\Jpeg2000\Palette(),
                'Profile' => new \PHPExiftool\Driver\Tag\Jpeg2000\Profile(),
                'ROIDescription' => new \PHPExiftool\Driver\Tag\Jpeg2000\ROIDescription(),
                'ReaderRequirements' => new \PHPExiftool\Driver\Tag\Jpeg2000\ReaderRequirements(),
                'UUIDList' => new \PHPExiftool\Driver\Tag\Jpeg2000\UUIDList(),
                'URL' => new \PHPExiftool\Driver\Tag\Jpeg2000\URL(),
                'UUID-Unknown' => new \PHPExiftool\Driver\Tag\Jpeg2000\UUIDUnknown(),
                'XML' => new \PHPExiftool\Driver\Tag\Jpeg2000\XML(),
            );
        });
        $this['KodakBordersIFD'] = $this->share(function(){
            return array(
                'BordersVersion' => new \PHPExiftool\Driver\Tag\KodakBordersIFD\BordersVersion(),
                'BorderName' => new \PHPExiftool\Driver\Tag\KodakBordersIFD\BorderName(),
                'BorderID' => new \PHPExiftool\Driver\Tag\KodakBordersIFD\BorderID(),
                'BorderLocation' => new \PHPExiftool\Driver\Tag\KodakBordersIFD\BorderLocation(),
                'BorderType' => new \PHPExiftool\Driver\Tag\KodakBordersIFD\BorderType(),
                'WatermarkType' => new \PHPExiftool\Driver\Tag\KodakBordersIFD\WatermarkType(),
            );
        });
        $this['Kodak'] = $this->share(function(){
            return array(
                'SensorWidth' => new \PHPExiftool\Driver\Tag\Kodak\SensorWidth(),
                'SensorHeight' => new \PHPExiftool\Driver\Tag\Kodak\SensorHeight(),
                'BayerPattern' => new \PHPExiftool\Driver\Tag\Kodak\BayerPattern(),
                'SensorFullWidth' => new \PHPExiftool\Driver\Tag\Kodak\SensorFullWidth(),
                'SensorFullHeight' => new \PHPExiftool\Driver\Tag\Kodak\SensorFullHeight(),
                'KodakImageWidth' => new \PHPExiftool\Driver\Tag\Kodak\KodakImageWidth(),
                'KodakImageHeight' => new \PHPExiftool\Driver\Tag\Kodak\KodakImageHeight(),
                'KodakInfoType' => new \PHPExiftool\Driver\Tag\Kodak\KodakInfoType(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Kodak\SerialNumber(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Kodak\FNumber(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Kodak\ExposureTime(),
                'ISO' => new \PHPExiftool\Driver\Tag\Kodak\ISO(),
                'CameraByteOrder' => new \PHPExiftool\Driver\Tag\Kodak\CameraByteOrder(),
                'ApertureValue' => new \PHPExiftool\Driver\Tag\Kodak\ApertureValue(),
                'BrightnessValue' => new \PHPExiftool\Driver\Tag\Kodak\BrightnessValue(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Kodak\ExposureCompensation(),
                'FocalLengthIn35mmFormat' => new \PHPExiftool\Driver\Tag\Kodak\FocalLengthIn35mmFormat(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Kodak\FocalLength(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\Kodak\FirmwareVersion(),
                'ShutterSpeedValue' => new \PHPExiftool\Driver\Tag\Kodak\ShutterSpeedValue(),
                'Make' => new \PHPExiftool\Driver\Tag\Kodak\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\Kodak\Model(),
                'ModelType' => new \PHPExiftool\Driver\Tag\Kodak\ModelType(),
                'KodakModel' => new \PHPExiftool\Driver\Tag\Kodak\KodakModel(),
                'Quality' => new \PHPExiftool\Driver\Tag\Kodak\Quality(),
                'BurstMode' => new \PHPExiftool\Driver\Tag\Kodak\BurstMode(),
                'YearCreated' => new \PHPExiftool\Driver\Tag\Kodak\YearCreated(),
                'MonthDayCreated' => new \PHPExiftool\Driver\Tag\Kodak\MonthDayCreated(),
                'TimeCreated' => new \PHPExiftool\Driver\Tag\Kodak\TimeCreated(),
                'BurstMode2' => new \PHPExiftool\Driver\Tag\Kodak\BurstMode2(),
                'ShutterMode' => new \PHPExiftool\Driver\Tag\Kodak\ShutterMode(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Kodak\MeteringMode(),
                'SequenceNumber' => new \PHPExiftool\Driver\Tag\Kodak\SequenceNumber(),
                'VariousModes' => new \PHPExiftool\Driver\Tag\Kodak\VariousModes(),
                'Distance1' => new \PHPExiftool\Driver\Tag\Kodak\Distance1(),
                'Distance2' => new \PHPExiftool\Driver\Tag\Kodak\Distance2(),
                'Distance3' => new \PHPExiftool\Driver\Tag\Kodak\Distance3(),
                'Distance4' => new \PHPExiftool\Driver\Tag\Kodak\Distance4(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Kodak\FocusMode(),
                'VariousModes2' => new \PHPExiftool\Driver\Tag\Kodak\VariousModes2(),
                'PanoramaMode' => new \PHPExiftool\Driver\Tag\Kodak\PanoramaMode(),
                'SubjectDistance' => new \PHPExiftool\Driver\Tag\Kodak\SubjectDistance(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Kodak\WhiteBalance(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Kodak\FlashMode(),
                'FlashFired' => new \PHPExiftool\Driver\Tag\Kodak\FlashFired(),
                'ISOSetting' => new \PHPExiftool\Driver\Tag\Kodak\ISOSetting(),
                'TotalZoom' => new \PHPExiftool\Driver\Tag\Kodak\TotalZoom(),
                'DateTimeStamp' => new \PHPExiftool\Driver\Tag\Kodak\DateTimeStamp(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Kodak\ColorMode(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Kodak\DigitalZoom(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Kodak\Sharpness(),
                'WB_RGBLevels' => new \PHPExiftool\Driver\Tag\Kodak\WBRGBLevels(),
                'PreviewImageWidth' => new \PHPExiftool\Driver\Tag\Kodak\PreviewImageWidth(),
                'PreviewImageHeight' => new \PHPExiftool\Driver\Tag\Kodak\PreviewImageHeight(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Kodak\PreviewImageLength(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Kodak\PreviewImage(),
                'SceneMode' => new \PHPExiftool\Driver\Tag\Kodak\SceneMode(),
                'OpticalZoom' => new \PHPExiftool\Driver\Tag\Kodak\OpticalZoom(),
                'ThumbnailWidth' => new \PHPExiftool\Driver\Tag\Kodak\ThumbnailWidth(),
                'ThumbnailHeight' => new \PHPExiftool\Driver\Tag\Kodak\ThumbnailHeight(),
                'SceneModeUsed' => new \PHPExiftool\Driver\Tag\Kodak\SceneModeUsed(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\Kodak\MaxAperture(),
                'Kodak_SubIFD3_0x2007' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x2007(),
                'Kodak_SubIFD3_0x2008' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x2008(),
                'Kodak_SubIFD3_0x2009' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x2009(),
                'Kodak_SubIFD3_0x200a' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x200a(),
                'Kodak_SubIFD3_0x200b' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x200b(),
                'Kodak_SubIFD3_0x3020' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3020(),
                'Kodak_SubIFD3_0x3030' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3030(),
                'Kodak_SubIFD3_0x3040' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3040(),
                'Kodak_SubIFD3_0x3050' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3050(),
                'Kodak_SubIFD3_0x3060' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3060(),
                'Kodak_SubIFD3_0x8001' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8001(),
                'Kodak_SubIFD3_0x8002' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8002(),
                'Kodak_SubIFD3_0x8003' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8003(),
                'Kodak_SubIFD3_0x8004' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8004(),
                'Kodak_SubIFD3_0x8005' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8005(),
                'Kodak_SubIFD3_0x8006' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8006(),
                'Kodak_SubIFD3_0x8007' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8007(),
                'Kodak_SubIFD3_0x8008' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8008(),
                'Kodak_SubIFD3_0x8009' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8009(),
                'Kodak_SubIFD3_0x800a' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x800a(),
                'Kodak_SubIFD3_0x800b' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x800b(),
                'Kodak_SubIFD3_0x800c' => new \PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x800c(),
                'AFMode' => new \PHPExiftool\Driver\Tag\Kodak\AFMode(),
                'ActualCompensation' => new \PHPExiftool\Driver\Tag\Kodak\ActualCompensation(),
                'Aperture' => new \PHPExiftool\Driver\Tag\Kodak\Aperture(),
                'AutoBracket' => new \PHPExiftool\Driver\Tag\Kodak\AutoBracket(),
                'CameraModel' => new \PHPExiftool\Driver\Tag\Kodak\CameraModel(),
                'CameraBody' => new \PHPExiftool\Driver\Tag\Kodak\CameraBody(),
                'Date' => new \PHPExiftool\Driver\Tag\Kodak\Date(),
                'ExposureBias' => new \PHPExiftool\Driver\Tag\Kodak\ExposureBias(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\Kodak\ExposureMode(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\Kodak\FlashExposureComp(),
                'FlashSyncMode' => new \PHPExiftool\Driver\Tag\Kodak\FlashSyncMode(),
                'ImageNumber' => new \PHPExiftool\Driver\Tag\Kodak\ImageNumber(),
                'MeterMode' => new \PHPExiftool\Driver\Tag\Kodak\MeterMode(),
                'MinAperture' => new \PHPExiftool\Driver\Tag\Kodak\MinAperture(),
                'PopupFlash' => new \PHPExiftool\Driver\Tag\Kodak\PopupFlash(),
                'ShootingMode' => new \PHPExiftool\Driver\Tag\Kodak\ShootingMode(),
                'ShutterSpeed' => new \PHPExiftool\Driver\Tag\Kodak\ShutterSpeed(),
                'Temperature' => new \PHPExiftool\Driver\Tag\Kodak\Temperature(),
                'Time' => new \PHPExiftool\Driver\Tag\Kodak\Time(),
                'OtherInfo' => new \PHPExiftool\Driver\Tag\Kodak\OtherInfo(),
                'PreviewImageSize' => new \PHPExiftool\Driver\Tag\Kodak\PreviewImageSize(),
                'KodakMaker' => new \PHPExiftool\Driver\Tag\Kodak\KodakMaker(),
                'OriginalFileName' => new \PHPExiftool\Driver\Tag\Kodak\OriginalFileName(),
                'ImageRotated' => new \PHPExiftool\Driver\Tag\Kodak\ImageRotated(),
                'Macro' => new \PHPExiftool\Driver\Tag\Kodak\Macro(),
                'Flash' => new \PHPExiftool\Driver\Tag\Kodak\Flash(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\Kodak\DateTimeOriginal(),
                'UnknownNumber' => new \PHPExiftool\Driver\Tag\Kodak\UnknownNumber(),
            );
        });
        $this['KodakIFD'] = $this->share(function(){
            return array(
                'UnknownEV' => new \PHPExiftool\Driver\Tag\KodakIFD\UnknownEV(),
                'ExposureValue' => new \PHPExiftool\Driver\Tag\KodakIFD\ExposureValue(),
                'OriginalFileName' => new \PHPExiftool\Driver\Tag\KodakIFD\OriginalFileName(),
                'SensorLeftBorder' => new \PHPExiftool\Driver\Tag\KodakIFD\SensorLeftBorder(),
                'SensorTopBorder' => new \PHPExiftool\Driver\Tag\KodakIFD\SensorTopBorder(),
                'SensorImageWidth' => new \PHPExiftool\Driver\Tag\KodakIFD\SensorImageWidth(),
                'SensorImageHeight' => new \PHPExiftool\Driver\Tag\KodakIFD\SensorImageHeight(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\KodakIFD\WhiteBalance(),
                'Time' => new \PHPExiftool\Driver\Tag\KodakIFD\Time(),
                'NCDFileInfo' => new \PHPExiftool\Driver\Tag\KodakIFD\NCDFileInfo(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\KodakIFD\ColorTemperature(),
                'WB_RGBMul0' => new \PHPExiftool\Driver\Tag\KodakIFD\WBRGBMul0(),
                'WB_RGBMul1' => new \PHPExiftool\Driver\Tag\KodakIFD\WBRGBMul1(),
                'WB_RGBMul2' => new \PHPExiftool\Driver\Tag\KodakIFD\WBRGBMul2(),
                'WB_RGBMul3' => new \PHPExiftool\Driver\Tag\KodakIFD\WBRGBMul3(),
                'WB_RGBCoeffs0' => new \PHPExiftool\Driver\Tag\KodakIFD\WBRGBCoeffs0(),
                'WB_RGBCoeffs1' => new \PHPExiftool\Driver\Tag\KodakIFD\WBRGBCoeffs1(),
                'WB_RGBCoeffs2' => new \PHPExiftool\Driver\Tag\KodakIFD\WBRGBCoeffs2(),
                'WB_RGBCoeffs3' => new \PHPExiftool\Driver\Tag\KodakIFD\WBRGBCoeffs3(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\KodakIFD\FirmwareVersion(),
                'ToneCurveFileName' => new \PHPExiftool\Driver\Tag\KodakIFD\ToneCurveFileName(),
                'ISO' => new \PHPExiftool\Driver\Tag\KodakIFD\ISO(),
            );
        });
        $this['KDC_IFD'] = $this->share(function(){
            return array(
                'SerialNumber' => new \PHPExiftool\Driver\Tag\KDCIFD\SerialNumber(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\KDCIFD\WhiteBalance(),
                'WB_RGBLevelsAuto' => new \PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsAuto(),
                'WB_RGBLevelsTungsten' => new \PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsTungsten(),
                'WB_RGBLevelsFluorescent' => new \PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsFluorescent(),
                'WB_RGBLevelsDaylight' => new \PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsDaylight(),
                'WB_RGBLevelsShade' => new \PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsShade(),
            );
        });
        $this['MetaIFD'] = $this->share(function(){
            return array(
                'FilmProductCode' => new \PHPExiftool\Driver\Tag\MetaIFD\FilmProductCode(),
                'ImageSourceEK' => new \PHPExiftool\Driver\Tag\MetaIFD\ImageSourceEK(),
                'CaptureConditionsPAR' => new \PHPExiftool\Driver\Tag\MetaIFD\CaptureConditionsPAR(),
                'CameraOwner' => new \PHPExiftool\Driver\Tag\MetaIFD\CameraOwner(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\MetaIFD\SerialNumber(),
                'UserSelectGroupTitle' => new \PHPExiftool\Driver\Tag\MetaIFD\UserSelectGroupTitle(),
                'DealerIDNumber' => new \PHPExiftool\Driver\Tag\MetaIFD\DealerIDNumber(),
                'CaptureDeviceFID' => new \PHPExiftool\Driver\Tag\MetaIFD\CaptureDeviceFID(),
                'EnvelopeNumber' => new \PHPExiftool\Driver\Tag\MetaIFD\EnvelopeNumber(),
                'FrameNumber' => new \PHPExiftool\Driver\Tag\MetaIFD\FrameNumber(),
                'FilmCategory' => new \PHPExiftool\Driver\Tag\MetaIFD\FilmCategory(),
                'FilmGencode' => new \PHPExiftool\Driver\Tag\MetaIFD\FilmGencode(),
                'ModelAndVersion' => new \PHPExiftool\Driver\Tag\MetaIFD\ModelAndVersion(),
                'FilmSize' => new \PHPExiftool\Driver\Tag\MetaIFD\FilmSize(),
                'SBA_RGBShifts' => new \PHPExiftool\Driver\Tag\MetaIFD\SBARGBShifts(),
                'SBAInputImageColorspace' => new \PHPExiftool\Driver\Tag\MetaIFD\SBAInputImageColorspace(),
                'SBAInputImageBitDepth' => new \PHPExiftool\Driver\Tag\MetaIFD\SBAInputImageBitDepth(),
                'SBAExposureRecord' => new \PHPExiftool\Driver\Tag\MetaIFD\SBAExposureRecord(),
                'UserAdjSBA_RGBShifts' => new \PHPExiftool\Driver\Tag\MetaIFD\UserAdjSBARGBShifts(),
                'ImageRotationStatus' => new \PHPExiftool\Driver\Tag\MetaIFD\ImageRotationStatus(),
                'RollGuidElements' => new \PHPExiftool\Driver\Tag\MetaIFD\RollGuidElements(),
                'MetadataNumber' => new \PHPExiftool\Driver\Tag\MetaIFD\MetadataNumber(),
                'EditTagArray' => new \PHPExiftool\Driver\Tag\MetaIFD\EditTagArray(),
                'Magnification' => new \PHPExiftool\Driver\Tag\MetaIFD\Magnification(),
                'NativeXResolution' => new \PHPExiftool\Driver\Tag\MetaIFD\NativeXResolution(),
                'NativeYResolution' => new \PHPExiftool\Driver\Tag\MetaIFD\NativeYResolution(),
                'NativeResolutionUnit' => new \PHPExiftool\Driver\Tag\MetaIFD\NativeResolutionUnit(),
                'SourceImageDirectory' => new \PHPExiftool\Driver\Tag\MetaIFD\SourceImageDirectory(),
                'SourceImageFileName' => new \PHPExiftool\Driver\Tag\MetaIFD\SourceImageFileName(),
                'SourceImageVolumeName' => new \PHPExiftool\Driver\Tag\MetaIFD\SourceImageVolumeName(),
                'PrintQuality' => new \PHPExiftool\Driver\Tag\MetaIFD\PrintQuality(),
                'ImagePrintStatus' => new \PHPExiftool\Driver\Tag\MetaIFD\ImagePrintStatus(),
            );
        });
        $this['KodakEffectsIFD'] = $this->share(function(){
            return array(
                'DigitalEffectsVersion' => new \PHPExiftool\Driver\Tag\KodakEffectsIFD\DigitalEffectsVersion(),
                'DigitalEffectsName' => new \PHPExiftool\Driver\Tag\KodakEffectsIFD\DigitalEffectsName(),
                'DigitalEffectsType' => new \PHPExiftool\Driver\Tag\KodakEffectsIFD\DigitalEffectsType(),
            );
        });
        $this['KyoceraRaw'] = $this->share(function(){
            return array(
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\KyoceraRaw\FirmwareVersion(),
                'Model' => new \PHPExiftool\Driver\Tag\KyoceraRaw\Model(),
                'Make' => new \PHPExiftool\Driver\Tag\KyoceraRaw\Make(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\KyoceraRaw\DateTimeOriginal(),
                'ISO' => new \PHPExiftool\Driver\Tag\KyoceraRaw\ISO(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\KyoceraRaw\ExposureTime(),
                'WB_RGGBLevels' => new \PHPExiftool\Driver\Tag\KyoceraRaw\WBRGGBLevels(),
                'FNumber' => new \PHPExiftool\Driver\Tag\KyoceraRaw\FNumber(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\KyoceraRaw\MaxAperture(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\KyoceraRaw\FocalLength(),
                'Lens' => new \PHPExiftool\Driver\Tag\KyoceraRaw\Lens(),
            );
        });
        $this['LNK'] = $this->share(function(){
            return array(
                'FillAttributes' => new \PHPExiftool\Driver\Tag\LNK\FillAttributes(),
                'PopupFillAttributes' => new \PHPExiftool\Driver\Tag\LNK\PopupFillAttributes(),
                'ScreenBufferSize' => new \PHPExiftool\Driver\Tag\LNK\ScreenBufferSize(),
                'WindowSize' => new \PHPExiftool\Driver\Tag\LNK\WindowSize(),
                'WindowOrigin' => new \PHPExiftool\Driver\Tag\LNK\WindowOrigin(),
                'FontSize' => new \PHPExiftool\Driver\Tag\LNK\FontSize(),
                'FontFamily' => new \PHPExiftool\Driver\Tag\LNK\FontFamily(),
                'FontWeight' => new \PHPExiftool\Driver\Tag\LNK\FontWeight(),
                'FontName' => new \PHPExiftool\Driver\Tag\LNK\FontName(),
                'CursorSize' => new \PHPExiftool\Driver\Tag\LNK\CursorSize(),
                'FullScreen' => new \PHPExiftool\Driver\Tag\LNK\FullScreen(),
                'QuickEdit' => new \PHPExiftool\Driver\Tag\LNK\QuickEdit(),
                'InsertMode' => new \PHPExiftool\Driver\Tag\LNK\InsertMode(),
                'WindowOriginAuto' => new \PHPExiftool\Driver\Tag\LNK\WindowOriginAuto(),
                'HistoryBufferSize' => new \PHPExiftool\Driver\Tag\LNK\HistoryBufferSize(),
                'NumHistoryBuffers' => new \PHPExiftool\Driver\Tag\LNK\NumHistoryBuffers(),
                'RemoveHistoryDuplicates' => new \PHPExiftool\Driver\Tag\LNK\RemoveHistoryDuplicates(),
                'CodePage' => new \PHPExiftool\Driver\Tag\LNK\CodePage(),
                'TargetFileDOSName' => new \PHPExiftool\Driver\Tag\LNK\TargetFileDOSName(),
                'CommonNetworkRelLink' => new \PHPExiftool\Driver\Tag\LNK\CommonNetworkRelLink(),
                'CommonPathSuffix' => new \PHPExiftool\Driver\Tag\LNK\CommonPathSuffix(),
                'DeviceName' => new \PHPExiftool\Driver\Tag\LNK\DeviceName(),
                'DriveSerialNumber' => new \PHPExiftool\Driver\Tag\LNK\DriveSerialNumber(),
                'DriveType' => new \PHPExiftool\Driver\Tag\LNK\DriveType(),
                'LocalBasePath' => new \PHPExiftool\Driver\Tag\LNK\LocalBasePath(),
                'NetName' => new \PHPExiftool\Driver\Tag\LNK\NetName(),
                'NetProviderType' => new \PHPExiftool\Driver\Tag\LNK\NetProviderType(),
                'VolumeID' => new \PHPExiftool\Driver\Tag\LNK\VolumeID(),
                'VolumeLabel' => new \PHPExiftool\Driver\Tag\LNK\VolumeLabel(),
                'Flags' => new \PHPExiftool\Driver\Tag\LNK\Flags(),
                'FileAttributes' => new \PHPExiftool\Driver\Tag\LNK\FileAttributes(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\LNK\CreateDate(),
                'AccessDate' => new \PHPExiftool\Driver\Tag\LNK\AccessDate(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\LNK\ModifyDate(),
                'TargetFileSize' => new \PHPExiftool\Driver\Tag\LNK\TargetFileSize(),
                'IconIndex' => new \PHPExiftool\Driver\Tag\LNK\IconIndex(),
                'RunWindow' => new \PHPExiftool\Driver\Tag\LNK\RunWindow(),
                'HotKey' => new \PHPExiftool\Driver\Tag\LNK\HotKey(),
                'Description' => new \PHPExiftool\Driver\Tag\LNK\Description(),
                'RelativePath' => new \PHPExiftool\Driver\Tag\LNK\RelativePath(),
                'WorkingDirectory' => new \PHPExiftool\Driver\Tag\LNK\WorkingDirectory(),
                'CommandLineArguments' => new \PHPExiftool\Driver\Tag\LNK\CommandLineArguments(),
                'IconFileName' => new \PHPExiftool\Driver\Tag\LNK\IconFileName(),
                'MachineID' => new \PHPExiftool\Driver\Tag\LNK\MachineID(),
            );
        });
        $this['Leaf'] = $this->share(function(){
            return array(
                'CameraBackType' => new \PHPExiftool\Driver\Tag\Leaf\CameraBackType(),
                'CameraName' => new \PHPExiftool\Driver\Tag\Leaf\CameraName(),
                'CameraType' => new \PHPExiftool\Driver\Tag\Leaf\CameraType(),
                'CameraProfileVersion' => new \PHPExiftool\Driver\Tag\Leaf\CameraProfileVersion(),
                'ISOSpeed' => new \PHPExiftool\Driver\Tag\Leaf\ISOSpeed(),
                'CameraObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\CameraObjBackType(),
                'LensID' => new \PHPExiftool\Driver\Tag\Leaf\LensID(),
                'LensType' => new \PHPExiftool\Driver\Tag\Leaf\LensType(),
                'CameraObjName' => new \PHPExiftool\Driver\Tag\Leaf\CameraObjName(),
                'Strobe' => new \PHPExiftool\Driver\Tag\Leaf\Strobe(),
                'CameraObjType' => new \PHPExiftool\Driver\Tag\Leaf\CameraObjType(),
                'CameraObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\CameraObjVersion(),
                'CCDRect' => new \PHPExiftool\Driver\Tag\Leaf\CCDRect(),
                'CCDValidRect' => new \PHPExiftool\Driver\Tag\Leaf\CCDValidRect(),
                'CCDVideoRect' => new \PHPExiftool\Driver\Tag\Leaf\CCDVideoRect(),
                'CaptProfBackType' => new \PHPExiftool\Driver\Tag\Leaf\CaptProfBackType(),
                'CenterDarkRect' => new \PHPExiftool\Driver\Tag\Leaf\CenterDarkRect(),
                'ColorAverages' => new \PHPExiftool\Driver\Tag\Leaf\ColorAverages(),
                'ColorMatrix' => new \PHPExiftool\Driver\Tag\Leaf\ColorMatrix(),
                'DarkCorrectionType' => new \PHPExiftool\Driver\Tag\Leaf\DarkCorrectionType(),
                'ImageBounds' => new \PHPExiftool\Driver\Tag\Leaf\ImageBounds(),
                'ImageFields' => new \PHPExiftool\Driver\Tag\Leaf\ImageFields(),
                'ImageOffset' => new \PHPExiftool\Driver\Tag\Leaf\ImageOffset(),
                'LeftDarkRect' => new \PHPExiftool\Driver\Tag\Leaf\LeftDarkRect(),
                'LuminanceConsts' => new \PHPExiftool\Driver\Tag\Leaf\LuminanceConsts(),
                'MosaicPattern' => new \PHPExiftool\Driver\Tag\Leaf\MosaicPattern(),
                'CaptProfName' => new \PHPExiftool\Driver\Tag\Leaf\CaptProfName(),
                'NumberOfPlanes' => new \PHPExiftool\Driver\Tag\Leaf\NumberOfPlanes(),
                'RawDataRotation' => new \PHPExiftool\Driver\Tag\Leaf\RawDataRotation(),
                'ReconstructionType' => new \PHPExiftool\Driver\Tag\Leaf\ReconstructionType(),
                'RightDarkRect' => new \PHPExiftool\Driver\Tag\Leaf\RightDarkRect(),
                'CaptureSerial' => new \PHPExiftool\Driver\Tag\Leaf\CaptureSerial(),
                'CaptProfType' => new \PHPExiftool\Driver\Tag\Leaf\CaptProfType(),
                'CaptProfVersion' => new \PHPExiftool\Driver\Tag\Leaf\CaptProfVersion(),
                'XYOffsetInfo' => new \PHPExiftool\Driver\Tag\Leaf\XYOffsetInfo(),
                'MultiQuality' => new \PHPExiftool\Driver\Tag\Leaf\MultiQuality(),
                'CaptureObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\CaptureObjBackType(),
                'CaptureObjName' => new \PHPExiftool\Driver\Tag\Leaf\CaptureObjName(),
                'SingleQuality' => new \PHPExiftool\Driver\Tag\Leaf\SingleQuality(),
                'CaptureObjType' => new \PHPExiftool\Driver\Tag\Leaf\CaptureObjType(),
                'CaptureObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\CaptureObjVersion(),
                'ColorObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\ColorObjBackType(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Leaf\ColorMode(),
                'ColorType' => new \PHPExiftool\Driver\Tag\Leaf\ColorType(),
                'HasICC' => new \PHPExiftool\Driver\Tag\Leaf\HasICC(),
                'InputProfile' => new \PHPExiftool\Driver\Tag\Leaf\InputProfile(),
                'ColorObjName' => new \PHPExiftool\Driver\Tag\Leaf\ColorObjName(),
                'OutputProfile' => new \PHPExiftool\Driver\Tag\Leaf\OutputProfile(),
                'ColorObjType' => new \PHPExiftool\Driver\Tag\Leaf\ColorObjType(),
                'ColorObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\ColorObjVersion(),
                'ImgProfBackType' => new \PHPExiftool\Driver\Tag\Leaf\ImgProfBackType(),
                'ImageStatus' => new \PHPExiftool\Driver\Tag\Leaf\ImageStatus(),
                'ImgProfName' => new \PHPExiftool\Driver\Tag\Leaf\ImgProfName(),
                'RotationAngle' => new \PHPExiftool\Driver\Tag\Leaf\RotationAngle(),
                'ImgProfType' => new \PHPExiftool\Driver\Tag\Leaf\ImgProfType(),
                'ImgProfVersion' => new \PHPExiftool\Driver\Tag\Leaf\ImgProfVersion(),
                'LookHeadBackType' => new \PHPExiftool\Driver\Tag\Leaf\LookHeadBackType(),
                'LookHeadName' => new \PHPExiftool\Driver\Tag\Leaf\LookHeadName(),
                'LookHeadType' => new \PHPExiftool\Driver\Tag\Leaf\LookHeadType(),
                'LookHeadVersion' => new \PHPExiftool\Driver\Tag\Leaf\LookHeadVersion(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Leaf\PreviewImage(),
                'PreviewInfo' => new \PHPExiftool\Driver\Tag\Leaf\PreviewInfo(),
                'PDAHistogram' => new \PHPExiftool\Driver\Tag\Leaf\PDAHistogram(),
                'BackSerial' => new \PHPExiftool\Driver\Tag\Leaf\BackSerial(),
                'ToneMatrix' => new \PHPExiftool\Driver\Tag\Leaf\ToneMatrix(),
                'ToneSpaceFlow' => new \PHPExiftool\Driver\Tag\Leaf\ToneSpaceFlow(),
                'PatternAngle' => new \PHPExiftool\Driver\Tag\Leaf\PatternAngle(),
                'NeutObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\NeutObjBackType(),
                'ColorCasts' => new \PHPExiftool\Driver\Tag\Leaf\ColorCasts(),
                'HighlightEndPoints' => new \PHPExiftool\Driver\Tag\Leaf\HighlightEndPoints(),
                'NeutObjName' => new \PHPExiftool\Driver\Tag\Leaf\NeutObjName(),
                'Neutrals' => new \PHPExiftool\Driver\Tag\Leaf\Neutrals(),
                'ShadowEndPoints' => new \PHPExiftool\Driver\Tag\Leaf\ShadowEndPoints(),
                'NeutObjType' => new \PHPExiftool\Driver\Tag\Leaf\NeutObjType(),
                'NeutObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\NeutObjVersion(),
                'SaveObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\SaveObjBackType(),
                'LeafAutoActive' => new \PHPExiftool\Driver\Tag\Leaf\LeafAutoActive(),
                'LeafAutoBaseName' => new \PHPExiftool\Driver\Tag\Leaf\LeafAutoBaseName(),
                'LeafHotFolder' => new \PHPExiftool\Driver\Tag\Leaf\LeafHotFolder(),
                'LeafOpenProcHDR' => new \PHPExiftool\Driver\Tag\Leaf\LeafOpenProcHDR(),
                'LeafOutputFileType' => new \PHPExiftool\Driver\Tag\Leaf\LeafOutputFileType(),
                'LeafSaveSelection' => new \PHPExiftool\Driver\Tag\Leaf\LeafSaveSelection(),
                'SaveObjName' => new \PHPExiftool\Driver\Tag\Leaf\SaveObjName(),
                'StdAutoActive' => new \PHPExiftool\Driver\Tag\Leaf\StdAutoActive(),
                'StdBaseName' => new \PHPExiftool\Driver\Tag\Leaf\StdBaseName(),
                'StdHotFolder' => new \PHPExiftool\Driver\Tag\Leaf\StdHotFolder(),
                'StdOpenInPhotoshop' => new \PHPExiftool\Driver\Tag\Leaf\StdOpenInPhotoshop(),
                'StdOutputBitDepth' => new \PHPExiftool\Driver\Tag\Leaf\StdOutputBitDepth(),
                'StdOutputColorMode' => new \PHPExiftool\Driver\Tag\Leaf\StdOutputColorMode(),
                'StdOutputFileType' => new \PHPExiftool\Driver\Tag\Leaf\StdOutputFileType(),
                'StdOxygen' => new \PHPExiftool\Driver\Tag\Leaf\StdOxygen(),
                'StdSaveSelection' => new \PHPExiftool\Driver\Tag\Leaf\StdSaveSelection(),
                'StdScaledOutput' => new \PHPExiftool\Driver\Tag\Leaf\StdScaledOutput(),
                'StdSharpenOutput' => new \PHPExiftool\Driver\Tag\Leaf\StdSharpenOutput(),
                'SaveObjType' => new \PHPExiftool\Driver\Tag\Leaf\SaveObjType(),
                'SaveObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\SaveObjVersion(),
                'SelObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\SelObjBackType(),
                'Locks' => new \PHPExiftool\Driver\Tag\Leaf\Locks(),
                'SelObjName' => new \PHPExiftool\Driver\Tag\Leaf\SelObjName(),
                'Orientation' => new \PHPExiftool\Driver\Tag\Leaf\Orientation(),
                'Rect' => new \PHPExiftool\Driver\Tag\Leaf\Rect(),
                'Resolution' => new \PHPExiftool\Driver\Tag\Leaf\Resolution(),
                'Scale' => new \PHPExiftool\Driver\Tag\Leaf\Scale(),
                'SelObjType' => new \PHPExiftool\Driver\Tag\Leaf\SelObjType(),
                'SelObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\SelObjVersion(),
                'SharpObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\SharpObjBackType(),
                'DataLen' => new \PHPExiftool\Driver\Tag\Leaf\DataLen(),
                'SharpObjName' => new \PHPExiftool\Driver\Tag\Leaf\SharpObjName(),
                'SharpInfo' => new \PHPExiftool\Driver\Tag\Leaf\SharpInfo(),
                'SharpMethod' => new \PHPExiftool\Driver\Tag\Leaf\SharpMethod(),
                'SharpObjType' => new \PHPExiftool\Driver\Tag\Leaf\SharpObjType(),
                'SharpObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\SharpObjVersion(),
                'ShootObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\ShootObjBackType(),
                'ShootObjName' => new \PHPExiftool\Driver\Tag\Leaf\ShootObjName(),
                'ShootObjType' => new \PHPExiftool\Driver\Tag\Leaf\ShootObjType(),
                'ShootObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\ShootObjVersion(),
                'ToneObjBackType' => new \PHPExiftool\Driver\Tag\Leaf\ToneObjBackType(),
                'Gamma' => new \PHPExiftool\Driver\Tag\Leaf\Gamma(),
                'ToneObjName' => new \PHPExiftool\Driver\Tag\Leaf\ToneObjName(),
                'Npts' => new \PHPExiftool\Driver\Tag\Leaf\Npts(),
                'Tones' => new \PHPExiftool\Driver\Tag\Leaf\Tones(),
                'ToneObjType' => new \PHPExiftool\Driver\Tag\Leaf\ToneObjType(),
                'ToneObjVersion' => new \PHPExiftool\Driver\Tag\Leaf\ToneObjVersion(),
            );
        });
        $this['AC3'] = $this->share(function(){
            return array(
                'AudioBitrate' => new \PHPExiftool\Driver\Tag\AC3\AudioBitrate(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\AC3\AudioChannels(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\AC3\AudioSampleRate(),
                'SurroundMode' => new \PHPExiftool\Driver\Tag\AC3\SurroundMode(),
            );
        });
        $this['M2TS'] = $this->share(function(){
            return array(
                'AudioStreamType' => new \PHPExiftool\Driver\Tag\M2TS\AudioStreamType(),
                'Duration' => new \PHPExiftool\Driver\Tag\M2TS\Duration(),
                'VideoStreamType' => new \PHPExiftool\Driver\Tag\M2TS\VideoStreamType(),
            );
        });
        $this['MIE-Audio'] = $this->share(function(){
            return array(
                'RelatedAudioFileType' => new \PHPExiftool\Driver\Tag\MIEAudio\RelatedAudioFileType(),
                'RelatedAudioFileName' => new \PHPExiftool\Driver\Tag\MIEAudio\RelatedAudioFileName(),
                'Channels' => new \PHPExiftool\Driver\Tag\MIEAudio\Channels(),
                'AudioCompression' => new \PHPExiftool\Driver\Tag\MIEAudio\AudioCompression(),
                'Duration' => new \PHPExiftool\Driver\Tag\MIEAudio\Duration(),
                'SampleBits' => new \PHPExiftool\Driver\Tag\MIEAudio\SampleBits(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\MIEAudio\SampleRate(),
                'RelatedAudioFile' => new \PHPExiftool\Driver\Tag\MIEAudio\RelatedAudioFile(),
            );
        });
        $this['MIE-Camera'] = $this->share(function(){
            return array(
                'Brightness' => new \PHPExiftool\Driver\Tag\MIECamera\Brightness(),
                'ColorBalance' => new \PHPExiftool\Driver\Tag\MIECamera\ColorBalance(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\MIECamera\ColorTemperature(),
                'Contrast' => new \PHPExiftool\Driver\Tag\MIECamera\Contrast(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\MIECamera\DigitalZoom(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\MIECamera\ExposureCompensation(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\MIECamera\ExposureMode(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\MIECamera\ExposureTime(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\MIECamera\FirmwareVersion(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\MIECamera\FocusMode(),
                'ISO' => new \PHPExiftool\Driver\Tag\MIECamera\ISO(),
                'ISOSetting' => new \PHPExiftool\Driver\Tag\MIECamera\ISOSetting(),
                'ImageNumber' => new \PHPExiftool\Driver\Tag\MIECamera\ImageNumber(),
                'ImageQuality' => new \PHPExiftool\Driver\Tag\MIECamera\ImageQuality(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\MIECamera\ImageStabilization(),
                'Make' => new \PHPExiftool\Driver\Tag\MIECamera\Make(),
                'MeasuredEV' => new \PHPExiftool\Driver\Tag\MIECamera\MeasuredEV(),
                'Model' => new \PHPExiftool\Driver\Tag\MIECamera\Model(),
                'OwnerName' => new \PHPExiftool\Driver\Tag\MIECamera\OwnerName(),
                'Saturation' => new \PHPExiftool\Driver\Tag\MIECamera\Saturation(),
                'SensorSize' => new \PHPExiftool\Driver\Tag\MIECamera\SensorSize(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\MIECamera\SerialNumber(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\MIECamera\Sharpness(),
                'ShootingMode' => new \PHPExiftool\Driver\Tag\MIECamera\ShootingMode(),
            );
        });
        $this['MIE-Doc'] = $this->share(function(){
            return array(
                'Author' => new \PHPExiftool\Driver\Tag\MIEDoc\Author(),
                'Comment' => new \PHPExiftool\Driver\Tag\MIEDoc\Comment(),
                'Contributors' => new \PHPExiftool\Driver\Tag\MIEDoc\Contributors(),
                'Copyright' => new \PHPExiftool\Driver\Tag\MIEDoc\Copyright(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\MIEDoc\CreateDate(),
                'EMail' => new \PHPExiftool\Driver\Tag\MIEDoc\EMail(),
                'Keywords' => new \PHPExiftool\Driver\Tag\MIEDoc\Keywords(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\MIEDoc\ModifyDate(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\MIEDoc\DateTimeOriginal(),
                'PhoneNumber' => new \PHPExiftool\Driver\Tag\MIEDoc\PhoneNumber(),
                'References' => new \PHPExiftool\Driver\Tag\MIEDoc\References(),
                'Software' => new \PHPExiftool\Driver\Tag\MIEDoc\Software(),
                'Title' => new \PHPExiftool\Driver\Tag\MIEDoc\Title(),
                'URL' => new \PHPExiftool\Driver\Tag\MIEDoc\URL(),
            );
        });
        $this['MIE-Extender'] = $this->share(function(){
            return array(
                'ExtenderMagnification' => new \PHPExiftool\Driver\Tag\MIEExtender\ExtenderMagnification(),
                'ExtenderMake' => new \PHPExiftool\Driver\Tag\MIEExtender\ExtenderMake(),
                'ExtenderModel' => new \PHPExiftool\Driver\Tag\MIEExtender\ExtenderModel(),
                'ExtenderSerialNumber' => new \PHPExiftool\Driver\Tag\MIEExtender\ExtenderSerialNumber(),
            );
        });
        $this['MIE-Flash'] = $this->share(function(){
            return array(
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\MIEFlash\FlashExposureComp(),
                'FlashFired' => new \PHPExiftool\Driver\Tag\MIEFlash\FlashFired(),
                'FlashGuideNumber' => new \PHPExiftool\Driver\Tag\MIEFlash\FlashGuideNumber(),
                'FlashMake' => new \PHPExiftool\Driver\Tag\MIEFlash\FlashMake(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\MIEFlash\FlashMode(),
                'FlashModel' => new \PHPExiftool\Driver\Tag\MIEFlash\FlashModel(),
                'FlashSerialNumber' => new \PHPExiftool\Driver\Tag\MIEFlash\FlashSerialNumber(),
                'FlashType' => new \PHPExiftool\Driver\Tag\MIEFlash\FlashType(),
            );
        });
        $this['MIE-GPS'] = $this->share(function(){
            return array(
                'GPSAltitude' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSAltitude(),
                'GPSDestBearing' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSDestBearing(),
                'GPSDateTime' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSDateTime(),
                'GPSMapDatum' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSMapDatum(),
                'GPSDifferential' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSDifferential(),
                'GPSDestDistance' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSDestDistance(),
                'GPSTrack' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSTrack(),
                'GPSLatitude' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSLatitude(),
                'GPSLongitude' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSLongitude(),
                'GPSMeasureMode' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSMeasureMode(),
                'GPSSatellites' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSSatellites(),
                'GPSSpeed' => new \PHPExiftool\Driver\Tag\MIEGPS\GPSSpeed(),
            );
        });
        $this['MIE-Geo'] = $this->share(function(){
            return array(
                'Address' => new \PHPExiftool\Driver\Tag\MIEGeo\Address(),
                'City' => new \PHPExiftool\Driver\Tag\MIEGeo\City(),
                'Country' => new \PHPExiftool\Driver\Tag\MIEGeo\Country(),
                'PostalCode' => new \PHPExiftool\Driver\Tag\MIEGeo\PostalCode(),
                'State' => new \PHPExiftool\Driver\Tag\MIEGeo\State(),
            );
        });
        $this['MIE-Image'] = $this->share(function(){
            return array(
                'FullSizeImageType' => new \PHPExiftool\Driver\Tag\MIEImage\FullSizeImageType(),
                'FullSizeImageName' => new \PHPExiftool\Driver\Tag\MIEImage\FullSizeImageName(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\MIEImage\BitDepth(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\MIEImage\ColorSpace(),
                'ComponentsConfiguration' => new \PHPExiftool\Driver\Tag\MIEImage\ComponentsConfiguration(),
                'CompressionRatio' => new \PHPExiftool\Driver\Tag\MIEImage\CompressionRatio(),
                'ImageSize' => new \PHPExiftool\Driver\Tag\MIEImage\ImageSize(),
                'Resolution' => new \PHPExiftool\Driver\Tag\MIEImage\Resolution(),
                'FullSizeImage' => new \PHPExiftool\Driver\Tag\MIEImage\FullSizeImage(),
            );
        });
        $this['MIE-Lens'] = $this->share(function(){
            return array(
                'FNumber' => new \PHPExiftool\Driver\Tag\MIELens\FNumber(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\MIELens\FocalLength(),
                'FocusDistance' => new \PHPExiftool\Driver\Tag\MIELens\FocusDistance(),
                'LensMake' => new \PHPExiftool\Driver\Tag\MIELens\LensMake(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\MIELens\MaxAperture(),
                'MaxApertureAtMaxFocal' => new \PHPExiftool\Driver\Tag\MIELens\MaxApertureAtMaxFocal(),
                'MaxFocalLength' => new \PHPExiftool\Driver\Tag\MIELens\MaxFocalLength(),
                'MinAperture' => new \PHPExiftool\Driver\Tag\MIELens\MinAperture(),
                'MinFocalLength' => new \PHPExiftool\Driver\Tag\MIELens\MinFocalLength(),
                'LensModel' => new \PHPExiftool\Driver\Tag\MIELens\LensModel(),
                'OpticalZoom' => new \PHPExiftool\Driver\Tag\MIELens\OpticalZoom(),
                'LensSerialNumber' => new \PHPExiftool\Driver\Tag\MIELens\LensSerialNumber(),
            );
        });
        $this['MIE-Main'] = $this->share(function(){
            return array(
                'SubfileType' => new \PHPExiftool\Driver\Tag\MIEMain\SubfileType(),
                'MIEVersion' => new \PHPExiftool\Driver\Tag\MIEMain\MIEVersion(),
                'SubfileDirectory' => new \PHPExiftool\Driver\Tag\MIEMain\SubfileDirectory(),
                'SubfileName' => new \PHPExiftool\Driver\Tag\MIEMain\SubfileName(),
                'SubfileMIMEType' => new \PHPExiftool\Driver\Tag\MIEMain\SubfileMIMEType(),
                'SubfileData' => new \PHPExiftool\Driver\Tag\MIEMain\SubfileData(),
                'SubfileResource' => new \PHPExiftool\Driver\Tag\MIEMain\SubfileResource(),
                'MD5Digest' => new \PHPExiftool\Driver\Tag\MIEMain\MD5Digest(),
                'TrailerSignature' => new \PHPExiftool\Driver\Tag\MIEMain\TrailerSignature(),
            );
        });
        $this['MIE-Orient'] = $this->share(function(){
            return array(
                'Azimuth' => new \PHPExiftool\Driver\Tag\MIEOrient\Azimuth(),
                'Declination' => new \PHPExiftool\Driver\Tag\MIEOrient\Declination(),
                'Elevation' => new \PHPExiftool\Driver\Tag\MIEOrient\Elevation(),
                'RightAscension' => new \PHPExiftool\Driver\Tag\MIEOrient\RightAscension(),
                'Rotation' => new \PHPExiftool\Driver\Tag\MIEOrient\Rotation(),
            );
        });
        $this['MIE-Preview'] = $this->share(function(){
            return array(
                'PreviewImageType' => new \PHPExiftool\Driver\Tag\MIEPreview\PreviewImageType(),
                'PreviewImageName' => new \PHPExiftool\Driver\Tag\MIEPreview\PreviewImageName(),
                'PreviewImageSize' => new \PHPExiftool\Driver\Tag\MIEPreview\PreviewImageSize(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\MIEPreview\PreviewImage(),
            );
        });
        $this['MIE-Thumbnail'] = $this->share(function(){
            return array(
                'ThumbnailImageType' => new \PHPExiftool\Driver\Tag\MIEThumbnail\ThumbnailImageType(),
                'ThumbnailImageName' => new \PHPExiftool\Driver\Tag\MIEThumbnail\ThumbnailImageName(),
                'ThumbnailImageSize' => new \PHPExiftool\Driver\Tag\MIEThumbnail\ThumbnailImageSize(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\MIEThumbnail\ThumbnailImage(),
            );
        });
        $this['MIE-UTM'] = $this->share(function(){
            return array(
                'UTMMapDatum' => new \PHPExiftool\Driver\Tag\MIEUTM\UTMMapDatum(),
                'UTMEasting' => new \PHPExiftool\Driver\Tag\MIEUTM\UTMEasting(),
                'UTMNorthing' => new \PHPExiftool\Driver\Tag\MIEUTM\UTMNorthing(),
                'UTMZone' => new \PHPExiftool\Driver\Tag\MIEUTM\UTMZone(),
            );
        });
        $this['MIE-Video'] = $this->share(function(){
            return array(
                'RelatedVideoFileType' => new \PHPExiftool\Driver\Tag\MIEVideo\RelatedVideoFileType(),
                'RelatedVideoFileName' => new \PHPExiftool\Driver\Tag\MIEVideo\RelatedVideoFileName(),
                'Codec' => new \PHPExiftool\Driver\Tag\MIEVideo\Codec(),
                'Duration' => new \PHPExiftool\Driver\Tag\MIEVideo\Duration(),
                'RelatedVideoFile' => new \PHPExiftool\Driver\Tag\MIEVideo\RelatedVideoFile(),
            );
        });
        $this['MIFF'] = $this->share(function(){
            return array(
                'BackgroundColor' => new \PHPExiftool\Driver\Tag\MIFF\BackgroundColor(),
                'BluePrimary' => new \PHPExiftool\Driver\Tag\MIFF\BluePrimary(),
                'BorderColor' => new \PHPExiftool\Driver\Tag\MIFF\BorderColor(),
                'Class' => new \PHPExiftool\Driver\Tag\MIFF\Class0(),
                'Colors' => new \PHPExiftool\Driver\Tag\MIFF\Colors(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\MIFF\ColorSpace(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\MIFF\ImageWidth(),
                'Compression' => new \PHPExiftool\Driver\Tag\MIFF\Compression(),
                'Delay' => new \PHPExiftool\Driver\Tag\MIFF\Delay(),
                'Depth' => new \PHPExiftool\Driver\Tag\MIFF\Depth(),
                'Dispose' => new \PHPExiftool\Driver\Tag\MIFF\Dispose(),
                'Gamma' => new \PHPExiftool\Driver\Tag\MIFF\Gamma(),
                'GreenPrimary' => new \PHPExiftool\Driver\Tag\MIFF\GreenPrimary(),
                'ID' => new \PHPExiftool\Driver\Tag\MIFF\ID(),
                'Iterations' => new \PHPExiftool\Driver\Tag\MIFF\Iterations(),
                'Label' => new \PHPExiftool\Driver\Tag\MIFF\Label(),
                'MattColor' => new \PHPExiftool\Driver\Tag\MIFF\MattColor(),
                'Matte' => new \PHPExiftool\Driver\Tag\MIFF\Matte(),
                'Montage' => new \PHPExiftool\Driver\Tag\MIFF\Montage(),
                'Packets' => new \PHPExiftool\Driver\Tag\MIFF\Packets(),
                'Page' => new \PHPExiftool\Driver\Tag\MIFF\Page(),
                'RedPrimary' => new \PHPExiftool\Driver\Tag\MIFF\RedPrimary(),
                'RenderingIntent' => new \PHPExiftool\Driver\Tag\MIFF\RenderingIntent(),
                'Resolution' => new \PHPExiftool\Driver\Tag\MIFF\Resolution(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\MIFF\ImageHeight(),
                'Scene' => new \PHPExiftool\Driver\Tag\MIFF\Scene(),
                'Signature' => new \PHPExiftool\Driver\Tag\MIFF\Signature(),
                'Units' => new \PHPExiftool\Driver\Tag\MIFF\Units(),
                'WhitePoint' => new \PHPExiftool\Driver\Tag\MIFF\WhitePoint(),
            );
        });
        $this['MNG'] = $this->share(function(){
            return array(
                'BackgroundColor' => new \PHPExiftool\Driver\Tag\MNG\BackgroundColor(),
                'MandatoryBackground' => new \PHPExiftool\Driver\Tag\MNG\MandatoryBackground(),
                'BackgroundImageID' => new \PHPExiftool\Driver\Tag\MNG\BackgroundImageID(),
                'BackgroundTiling' => new \PHPExiftool\Driver\Tag\MNG\BackgroundTiling(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\MNG\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\MNG\ImageHeight(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\MNG\BitDepth(),
                'ColorType' => new \PHPExiftool\Driver\Tag\MNG\ColorType(),
                'Compression' => new \PHPExiftool\Driver\Tag\MNG\Compression(),
                'Filter' => new \PHPExiftool\Driver\Tag\MNG\Filter(),
                'Interlace' => new \PHPExiftool\Driver\Tag\MNG\Interlace(),
                'RedSample' => new \PHPExiftool\Driver\Tag\MNG\RedSample(),
                'GreenSample' => new \PHPExiftool\Driver\Tag\MNG\GreenSample(),
                'BlueSample' => new \PHPExiftool\Driver\Tag\MNG\BlueSample(),
                'AlphaSample' => new \PHPExiftool\Driver\Tag\MNG\AlphaSample(),
                'Viewable' => new \PHPExiftool\Driver\Tag\MNG\Viewable(),
                'FirstObject' => new \PHPExiftool\Driver\Tag\MNG\FirstObject(),
                'LastObject' => new \PHPExiftool\Driver\Tag\MNG\LastObject(),
                'DeltaType' => new \PHPExiftool\Driver\Tag\MNG\DeltaType(),
                'ClipBoundary' => new \PHPExiftool\Driver\Tag\MNG\ClipBoundary(),
                'SourceID' => new \PHPExiftool\Driver\Tag\MNG\SourceID(),
                'CloneID' => new \PHPExiftool\Driver\Tag\MNG\CloneID(),
                'CloneType' => new \PHPExiftool\Driver\Tag\MNG\CloneType(),
                'DoNotShow' => new \PHPExiftool\Driver\Tag\MNG\DoNotShow(),
                'ConcreteFlag' => new \PHPExiftool\Driver\Tag\MNG\ConcreteFlag(),
                'LocalDeltaType' => new \PHPExiftool\Driver\Tag\MNG\LocalDeltaType(),
                'DeltaXY' => new \PHPExiftool\Driver\Tag\MNG\DeltaXY(),
                'ObjectID' => new \PHPExiftool\Driver\Tag\MNG\ObjectID(),
                'XYLocation' => new \PHPExiftool\Driver\Tag\MNG\XYLocation(),
                'ClippingBoundary' => new \PHPExiftool\Driver\Tag\MNG\ClippingBoundary(),
                'ImageType' => new \PHPExiftool\Driver\Tag\MNG\ImageType(),
                'BlockSize' => new \PHPExiftool\Driver\Tag\MNG\BlockSize(),
                'BlockLocation' => new \PHPExiftool\Driver\Tag\MNG\BlockLocation(),
                'SnapshotID' => new \PHPExiftool\Driver\Tag\MNG\SnapshotID(),
                'SnapshotName' => new \PHPExiftool\Driver\Tag\MNG\SnapshotName(),
                'Priority' => new \PHPExiftool\Driver\Tag\MNG\Priority(),
                'AlphaBitDepth' => new \PHPExiftool\Driver\Tag\MNG\AlphaBitDepth(),
                'AlphaCompression' => new \PHPExiftool\Driver\Tag\MNG\AlphaCompression(),
                'AlphaFilter' => new \PHPExiftool\Driver\Tag\MNG\AlphaFilter(),
                'AlphaInterlace' => new \PHPExiftool\Driver\Tag\MNG\AlphaInterlace(),
                'NestLevel' => new \PHPExiftool\Driver\Tag\MNG\NestLevel(),
                'IterationCount' => new \PHPExiftool\Driver\Tag\MNG\IterationCount(),
                'TerminationCondition' => new \PHPExiftool\Driver\Tag\MNG\TerminationCondition(),
                'IterationMinMax' => new \PHPExiftool\Driver\Tag\MNG\IterationMinMax(),
                'SignalNumber' => new \PHPExiftool\Driver\Tag\MNG\SignalNumber(),
                'TicksPerSecond' => new \PHPExiftool\Driver\Tag\MNG\TicksPerSecond(),
                'NominalLayerCount' => new \PHPExiftool\Driver\Tag\MNG\NominalLayerCount(),
                'NominalFrameCount' => new \PHPExiftool\Driver\Tag\MNG\NominalFrameCount(),
                'NominalPlayTime' => new \PHPExiftool\Driver\Tag\MNG\NominalPlayTime(),
                'SimplicityProfile' => new \PHPExiftool\Driver\Tag\MNG\SimplicityProfile(),
                'FirstObjectID' => new \PHPExiftool\Driver\Tag\MNG\FirstObjectID(),
                'LastObjectID' => new \PHPExiftool\Driver\Tag\MNG\LastObjectID(),
                'XMethod' => new \PHPExiftool\Driver\Tag\MNG\XMethod(),
                'XMag' => new \PHPExiftool\Driver\Tag\MNG\XMag(),
                'YMag' => new \PHPExiftool\Driver\Tag\MNG\YMag(),
                'LeftMag' => new \PHPExiftool\Driver\Tag\MNG\LeftMag(),
                'RightMag' => new \PHPExiftool\Driver\Tag\MNG\RightMag(),
                'TopMag' => new \PHPExiftool\Driver\Tag\MNG\TopMag(),
                'BottomMag' => new \PHPExiftool\Driver\Tag\MNG\BottomMag(),
                'YMethod' => new \PHPExiftool\Driver\Tag\MNG\YMethod(),
                'DropByKeyword' => new \PHPExiftool\Driver\Tag\MNG\DropByKeyword(),
                'DiscardObjects' => new \PHPExiftool\Driver\Tag\MNG\DiscardObjects(),
                'DropChunks' => new \PHPExiftool\Driver\Tag\MNG\DropChunks(),
                'Frame' => new \PHPExiftool\Driver\Tag\MNG\Frame(),
                'OrderingRestrictions' => new \PHPExiftool\Driver\Tag\MNG\OrderingRestrictions(),
                'PartialPalette' => new \PHPExiftool\Driver\Tag\MNG\PartialPalette(),
                'SaveObjects' => new \PHPExiftool\Driver\Tag\MNG\SaveObjects(),
                'SeekPoint' => new \PHPExiftool\Driver\Tag\MNG\SeekPoint(),
                'ResourcesNeeded' => new \PHPExiftool\Driver\Tag\MNG\ResourcesNeeded(),
                'DestinationID' => new \PHPExiftool\Driver\Tag\MNG\DestinationID(),
                'TargetDeltaType' => new \PHPExiftool\Driver\Tag\MNG\TargetDeltaType(),
                'TargetXY' => new \PHPExiftool\Driver\Tag\MNG\TargetXY(),
                'CompositionMode' => new \PHPExiftool\Driver\Tag\MNG\CompositionMode(),
                'Orientation' => new \PHPExiftool\Driver\Tag\MNG\Orientation(),
                'OffsetOrigin' => new \PHPExiftool\Driver\Tag\MNG\OffsetOrigin(),
                'OffsetXY' => new \PHPExiftool\Driver\Tag\MNG\OffsetXY(),
                'BoundaryOrigin' => new \PHPExiftool\Driver\Tag\MNG\BoundaryOrigin(),
                'PastClippingBoundary' => new \PHPExiftool\Driver\Tag\MNG\PastClippingBoundary(),
                'NewColorType' => new \PHPExiftool\Driver\Tag\MNG\NewColorType(),
                'NewBitDepth' => new \PHPExiftool\Driver\Tag\MNG\NewBitDepth(),
                'FillMethod' => new \PHPExiftool\Driver\Tag\MNG\FillMethod(),
                'ShowMode' => new \PHPExiftool\Driver\Tag\MNG\ShowMode(),
                'TerminationAction' => new \PHPExiftool\Driver\Tag\MNG\TerminationAction(),
                'IterationEndAction' => new \PHPExiftool\Driver\Tag\MNG\IterationEndAction(),
                'Delay' => new \PHPExiftool\Driver\Tag\MNG\Delay(),
                'IterationMax' => new \PHPExiftool\Driver\Tag\MNG\IterationMax(),
            );
        });
        $this['MPC'] = $this->share(function(){
            return array(
                'TotalFrames' => new \PHPExiftool\Driver\Tag\MPC\TotalFrames(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\MPC\SampleRate(),
                'Quality' => new \PHPExiftool\Driver\Tag\MPC\Quality(),
                'MaxBand' => new \PHPExiftool\Driver\Tag\MPC\MaxBand(),
                'ReplayGainTrackPeak' => new \PHPExiftool\Driver\Tag\MPC\ReplayGainTrackPeak(),
                'ReplayGainTrackGain' => new \PHPExiftool\Driver\Tag\MPC\ReplayGainTrackGain(),
                'ReplayGainAlbumPeak' => new \PHPExiftool\Driver\Tag\MPC\ReplayGainAlbumPeak(),
                'ReplayGainAlbumGain' => new \PHPExiftool\Driver\Tag\MPC\ReplayGainAlbumGain(),
                'FastSeek' => new \PHPExiftool\Driver\Tag\MPC\FastSeek(),
                'Gapless' => new \PHPExiftool\Driver\Tag\MPC\Gapless(),
                'EncoderVersion' => new \PHPExiftool\Driver\Tag\MPC\EncoderVersion(),
            );
        });
        $this['MPEG'] = $this->share(function(){
            return array(
                'MPEGAudioVersion' => new \PHPExiftool\Driver\Tag\MPEG\MPEGAudioVersion(),
                'AudioLayer' => new \PHPExiftool\Driver\Tag\MPEG\AudioLayer(),
                'AudioBitrate' => new \PHPExiftool\Driver\Tag\MPEG\AudioBitrate(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\MPEG\SampleRate(),
                'ChannelMode' => new \PHPExiftool\Driver\Tag\MPEG\ChannelMode(),
                'MSStereo' => new \PHPExiftool\Driver\Tag\MPEG\MSStereo(),
                'ModeExtension' => new \PHPExiftool\Driver\Tag\MPEG\ModeExtension(),
                'IntensityStereo' => new \PHPExiftool\Driver\Tag\MPEG\IntensityStereo(),
                'CopyrightFlag' => new \PHPExiftool\Driver\Tag\MPEG\CopyrightFlag(),
                'OriginalMedia' => new \PHPExiftool\Driver\Tag\MPEG\OriginalMedia(),
                'Emphasis' => new \PHPExiftool\Driver\Tag\MPEG\Emphasis(),
                'LameMethod' => new \PHPExiftool\Driver\Tag\MPEG\LameMethod(),
                'LameLowPassFilter' => new \PHPExiftool\Driver\Tag\MPEG\LameLowPassFilter(),
                'LameBitrate' => new \PHPExiftool\Driver\Tag\MPEG\LameBitrate(),
                'LameStereoMode' => new \PHPExiftool\Driver\Tag\MPEG\LameStereoMode(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\MPEG\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\MPEG\ImageHeight(),
                'AspectRatio' => new \PHPExiftool\Driver\Tag\MPEG\AspectRatio(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\MPEG\FrameRate(),
                'VideoBitrate' => new \PHPExiftool\Driver\Tag\MPEG\VideoBitrate(),
                'VBRFrames' => new \PHPExiftool\Driver\Tag\MPEG\VBRFrames(),
                'VBRBytes' => new \PHPExiftool\Driver\Tag\MPEG\VBRBytes(),
                'VBRScale' => new \PHPExiftool\Driver\Tag\MPEG\VBRScale(),
                'Encoder' => new \PHPExiftool\Driver\Tag\MPEG\Encoder(),
                'LameVBRQuality' => new \PHPExiftool\Driver\Tag\MPEG\LameVBRQuality(),
                'LameQuality' => new \PHPExiftool\Driver\Tag\MPEG\LameQuality(),
            );
        });
        $this['MPImage'] = $this->share(function(){
            return array(
                'MPImageFlags' => new \PHPExiftool\Driver\Tag\MPImage\MPImageFlags(),
                'MPImageFormat' => new \PHPExiftool\Driver\Tag\MPImage\MPImageFormat(),
                'MPImageType' => new \PHPExiftool\Driver\Tag\MPImage\MPImageType(),
                'MPImageLength' => new \PHPExiftool\Driver\Tag\MPImage\MPImageLength(),
                'MPImageStart' => new \PHPExiftool\Driver\Tag\MPImage\MPImageStart(),
                'DependentImage1EntryNumber' => new \PHPExiftool\Driver\Tag\MPImage\DependentImage1EntryNumber(),
                'DependentImage2EntryNumber' => new \PHPExiftool\Driver\Tag\MPImage\DependentImage2EntryNumber(),
            );
        });
        $this['MPF0'] = $this->share(function(){
            return array(
                'MPFVersion' => new \PHPExiftool\Driver\Tag\MPF0\MPFVersion(),
                'NumberOfImages' => new \PHPExiftool\Driver\Tag\MPF0\NumberOfImages(),
                'ImageUIDList' => new \PHPExiftool\Driver\Tag\MPF0\ImageUIDList(),
                'TotalFrames' => new \PHPExiftool\Driver\Tag\MPF0\TotalFrames(),
                'MPIndividualNum' => new \PHPExiftool\Driver\Tag\MPF0\MPIndividualNum(),
                'PanOrientation' => new \PHPExiftool\Driver\Tag\MPF0\PanOrientation(),
                'PanOverlapH' => new \PHPExiftool\Driver\Tag\MPF0\PanOverlapH(),
                'PanOverlapV' => new \PHPExiftool\Driver\Tag\MPF0\PanOverlapV(),
                'BaseViewpointNum' => new \PHPExiftool\Driver\Tag\MPF0\BaseViewpointNum(),
                'ConvergenceAngle' => new \PHPExiftool\Driver\Tag\MPF0\ConvergenceAngle(),
                'BaselineLength' => new \PHPExiftool\Driver\Tag\MPF0\BaselineLength(),
                'VerticalDivergence' => new \PHPExiftool\Driver\Tag\MPF0\VerticalDivergence(),
                'AxisDistanceX' => new \PHPExiftool\Driver\Tag\MPF0\AxisDistanceX(),
                'AxisDistanceY' => new \PHPExiftool\Driver\Tag\MPF0\AxisDistanceY(),
                'AxisDistanceZ' => new \PHPExiftool\Driver\Tag\MPF0\AxisDistanceZ(),
                'YawAngle' => new \PHPExiftool\Driver\Tag\MPF0\YawAngle(),
                'PitchAngle' => new \PHPExiftool\Driver\Tag\MPF0\PitchAngle(),
                'RollAngle' => new \PHPExiftool\Driver\Tag\MPF0\RollAngle(),
            );
        });
        $this['MXF'] = $this->share(function(){
            return array(
                'MXFVersion' => new \PHPExiftool\Driver\Tag\MXF\MXFVersion(),
                'FooterPosition' => new \PHPExiftool\Driver\Tag\MXF\FooterPosition(),
                'HeaderSize' => new \PHPExiftool\Driver\Tag\MXF\HeaderSize(),
                'OrganizationID' => new \PHPExiftool\Driver\Tag\MXF\OrganizationID(),
                'UPID' => new \PHPExiftool\Driver\Tag\MXF\UPID(),
                'UPN' => new \PHPExiftool\Driver\Tag\MXF\UPN(),
                'IBTN' => new \PHPExiftool\Driver\Tag\MXF\IBTN(),
                'ISAN' => new \PHPExiftool\Driver\Tag\MXF\ISAN(),
                'ISBN' => new \PHPExiftool\Driver\Tag\MXF\ISBN(),
                'ISSN' => new \PHPExiftool\Driver\Tag\MXF\ISSN(),
                'ISWC' => new \PHPExiftool\Driver\Tag\MXF\ISWC(),
                'ISMN' => new \PHPExiftool\Driver\Tag\MXF\ISMN(),
                'ISCI' => new \PHPExiftool\Driver\Tag\MXF\ISCI(),
                'ISRC' => new \PHPExiftool\Driver\Tag\MXF\ISRC(),
                'ISRN' => new \PHPExiftool\Driver\Tag\MXF\ISRN(),
                'ISBD' => new \PHPExiftool\Driver\Tag\MXF\ISBD(),
                'ISTC' => new \PHPExiftool\Driver\Tag\MXF\ISTC(),
                'SICI' => new \PHPExiftool\Driver\Tag\MXF\SICI(),
                'BICI' => new \PHPExiftool\Driver\Tag\MXF\BICI(),
                'AICI' => new \PHPExiftool\Driver\Tag\MXF\AICI(),
                'PII' => new \PHPExiftool\Driver\Tag\MXF\PII(),
                'DOI' => new \PHPExiftool\Driver\Tag\MXF\DOI(),
                'InstanceUID' => new \PHPExiftool\Driver\Tag\MXF\InstanceUID(),
                'PackageID' => new \PHPExiftool\Driver\Tag\MXF\PackageID(),
                'DeviceDesignation' => new \PHPExiftool\Driver\Tag\MXF\DeviceDesignation(),
                'DeviceModel' => new \PHPExiftool\Driver\Tag\MXF\DeviceModel(),
                'DeviceSerialNumber' => new \PHPExiftool\Driver\Tag\MXF\DeviceSerialNumber(),
                'URL' => new \PHPExiftool\Driver\Tag\MXF\URL(),
                'PURL' => new \PHPExiftool\Driver\Tag\MXF\PURL(),
                'URN' => new \PHPExiftool\Driver\Tag\MXF\URN(),
                'TransmissionID' => new \PHPExiftool\Driver\Tag\MXF\TransmissionID(),
                'ArchiveID' => new \PHPExiftool\Driver\Tag\MXF\ArchiveID(),
                'ItemID' => new \PHPExiftool\Driver\Tag\MXF\ItemID(),
                'AccountingReferenceNumber' => new \PHPExiftool\Driver\Tag\MXF\AccountingReferenceNumber(),
                'TrafficID' => new \PHPExiftool\Driver\Tag\MXF\TrafficID(),
                'ReelOrRollNumber' => new \PHPExiftool\Driver\Tag\MXF\ReelOrRollNumber(),
                'LocalTapeNumber' => new \PHPExiftool\Driver\Tag\MXF\LocalTapeNumber(),
                'LUID' => new \PHPExiftool\Driver\Tag\MXF\LUID(),
                'PackageName' => new \PHPExiftool\Driver\Tag\MXF\PackageName(),
                'LocalFilePath' => new \PHPExiftool\Driver\Tag\MXF\LocalFilePath(),
                'EdgeCode' => new \PHPExiftool\Driver\Tag\MXF\EdgeCode(),
                'FrameCode' => new \PHPExiftool\Driver\Tag\MXF\FrameCode(),
                'KeyCode' => new \PHPExiftool\Driver\Tag\MXF\KeyCode(),
                'InkNumber' => new \PHPExiftool\Driver\Tag\MXF\InkNumber(),
                'KeyText' => new \PHPExiftool\Driver\Tag\MXF\KeyText(),
                'KeyFrame' => new \PHPExiftool\Driver\Tag\MXF\KeyFrame(),
                'KeySound' => new \PHPExiftool\Driver\Tag\MXF\KeySound(),
                'KeyDataOrProgram' => new \PHPExiftool\Driver\Tag\MXF\KeyDataOrProgram(),
                'TitleKind' => new \PHPExiftool\Driver\Tag\MXF\TitleKind(),
                'MainTitle' => new \PHPExiftool\Driver\Tag\MXF\MainTitle(),
                'SecondaryTitle' => new \PHPExiftool\Driver\Tag\MXF\SecondaryTitle(),
                'SeriesNumber' => new \PHPExiftool\Driver\Tag\MXF\SeriesNumber(),
                'EpisodeNumber' => new \PHPExiftool\Driver\Tag\MXF\EpisodeNumber(),
                'SceneNumber' => new \PHPExiftool\Driver\Tag\MXF\SceneNumber(),
                'TakeNumber' => new \PHPExiftool\Driver\Tag\MXF\TakeNumber(),
                'CISACLegalEntityID' => new \PHPExiftool\Driver\Tag\MXF\CISACLegalEntityID(),
                'AGICOAID' => new \PHPExiftool\Driver\Tag\MXF\AGICOAID(),
                'SourceOrganization' => new \PHPExiftool\Driver\Tag\MXF\SourceOrganization(),
                'SupplyContractNumber' => new \PHPExiftool\Driver\Tag\MXF\SupplyContractNumber(),
                'OriginalProducerName' => new \PHPExiftool\Driver\Tag\MXF\OriginalProducerName(),
                'TotalEpisodeCount' => new \PHPExiftool\Driver\Tag\MXF\TotalEpisodeCount(),
                'CopyrightStatus' => new \PHPExiftool\Driver\Tag\MXF\CopyrightStatus(),
                'CopyrightOwnerName' => new \PHPExiftool\Driver\Tag\MXF\CopyrightOwnerName(),
                'IntellectualPropertyDescription' => new \PHPExiftool\Driver\Tag\MXF\IntellectualPropertyDescription(),
                'IntellectualPropertyRights' => new \PHPExiftool\Driver\Tag\MXF\IntellectualPropertyRights(),
                'Rightsholder' => new \PHPExiftool\Driver\Tag\MXF\Rightsholder(),
                'RightsManagementAuthority' => new \PHPExiftool\Driver\Tag\MXF\RightsManagementAuthority(),
                'InterestedPartyName' => new \PHPExiftool\Driver\Tag\MXF\InterestedPartyName(),
                'MaximumUseCount' => new \PHPExiftool\Driver\Tag\MXF\MaximumUseCount(),
                'LicenseOptionsDescription' => new \PHPExiftool\Driver\Tag\MXF\LicenseOptionsDescription(),
                'CurrencyCode' => new \PHPExiftool\Driver\Tag\MXF\CurrencyCode(),
                'RoyaltyPaymentInformation' => new \PHPExiftool\Driver\Tag\MXF\RoyaltyPaymentInformation(),
                'RoyaltyIncomeInformation' => new \PHPExiftool\Driver\Tag\MXF\RoyaltyIncomeInformation(),
                'RestrictionsonUse' => new \PHPExiftool\Driver\Tag\MXF\RestrictionsonUse(),
                'ExCCIData' => new \PHPExiftool\Driver\Tag\MXF\ExCCIData(),
                'Username' => new \PHPExiftool\Driver\Tag\MXF\Username(),
                'Password' => new \PHPExiftool\Driver\Tag\MXF\Password(),
                'ScramblingKeyKind' => new \PHPExiftool\Driver\Tag\MXF\ScramblingKeyKind(),
                'ScramblingKeyValue' => new \PHPExiftool\Driver\Tag\MXF\ScramblingKeyValue(),
                'BroadcastOrganizationName' => new \PHPExiftool\Driver\Tag\MXF\BroadcastOrganizationName(),
                'BroadcastChannel' => new \PHPExiftool\Driver\Tag\MXF\BroadcastChannel(),
                'BroadcastMediumKind' => new \PHPExiftool\Driver\Tag\MXF\BroadcastMediumKind(),
                'BroadcastRegion' => new \PHPExiftool\Driver\Tag\MXF\BroadcastRegion(),
                'FirstBroadcastFlag' => new \PHPExiftool\Driver\Tag\MXF\FirstBroadcastFlag(),
                'CurrentRepeatNumber' => new \PHPExiftool\Driver\Tag\MXF\CurrentRepeatNumber(),
                'PreviousRepeatNumber' => new \PHPExiftool\Driver\Tag\MXF\PreviousRepeatNumber(),
                'AudienceRating' => new \PHPExiftool\Driver\Tag\MXF\AudienceRating(),
                'AudienceReach' => new \PHPExiftool\Driver\Tag\MXF\AudienceReach(),
                'NatureOfPersonality' => new \PHPExiftool\Driver\Tag\MXF\NatureOfPersonality(),
                'ContributionStatus' => new \PHPExiftool\Driver\Tag\MXF\ContributionStatus(),
                'SupportOrAdministrationStatus' => new \PHPExiftool\Driver\Tag\MXF\SupportOrAdministrationStatus(),
                'OrganizationKind' => new \PHPExiftool\Driver\Tag\MXF\OrganizationKind(),
                'ProductionOrganizationRole' => new \PHPExiftool\Driver\Tag\MXF\ProductionOrganizationRole(),
                'SupportOrganizationRole' => new \PHPExiftool\Driver\Tag\MXF\SupportOrganizationRole(),
                'JobFunctionName' => new \PHPExiftool\Driver\Tag\MXF\JobFunctionName(),
                'RoleName' => new \PHPExiftool\Driver\Tag\MXF\RoleName(),
                'ContactKind' => new \PHPExiftool\Driver\Tag\MXF\ContactKind(),
                'ContactDepartmentName' => new \PHPExiftool\Driver\Tag\MXF\ContactDepartmentName(),
                'FamilyName' => new \PHPExiftool\Driver\Tag\MXF\FamilyName(),
                'FirstGivenName' => new \PHPExiftool\Driver\Tag\MXF\FirstGivenName(),
                'SecondGivenName' => new \PHPExiftool\Driver\Tag\MXF\SecondGivenName(),
                'ThirdGivenName' => new \PHPExiftool\Driver\Tag\MXF\ThirdGivenName(),
                'MainName' => new \PHPExiftool\Driver\Tag\MXF\MainName(),
                'SupplementaryName' => new \PHPExiftool\Driver\Tag\MXF\SupplementaryName(),
                'OrganizationMainName' => new \PHPExiftool\Driver\Tag\MXF\OrganizationMainName(),
                'SupplementaryOrganizationName' => new \PHPExiftool\Driver\Tag\MXF\SupplementaryOrganizationName(),
                'ISO3166CountryCode' => new \PHPExiftool\Driver\Tag\MXF\ISO3166CountryCode(),
                'ISO639-1LanguageCode' => new \PHPExiftool\Driver\Tag\MXF\ISO6391LanguageCode(),
                'OperatingSystemInterpretations' => new \PHPExiftool\Driver\Tag\MXF\OperatingSystemInterpretations(),
                'ByteOrder' => new \PHPExiftool\Driver\Tag\MXF\ByteOrder(),
                'EssenceIsIdentified' => new \PHPExiftool\Driver\Tag\MXF\EssenceIsIdentified(),
                'LengthSystemName' => new \PHPExiftool\Driver\Tag\MXF\LengthSystemName(),
                'LengthUnitKind' => new \PHPExiftool\Driver\Tag\MXF\LengthUnitKind(),
                'AngularUnitKind' => new \PHPExiftool\Driver\Tag\MXF\AngularUnitKind(),
                'TimeSystemOffset' => new \PHPExiftool\Driver\Tag\MXF\TimeSystemOffset(),
                'TimeUnitKind' => new \PHPExiftool\Driver\Tag\MXF\TimeUnitKind(),
                'ContentCodingSystem' => new \PHPExiftool\Driver\Tag\MXF\ContentCodingSystem(),
                'ProgramKind' => new \PHPExiftool\Driver\Tag\MXF\ProgramKind(),
                'Genre' => new \PHPExiftool\Driver\Tag\MXF\Genre(),
                'TargetAudience' => new \PHPExiftool\Driver\Tag\MXF\TargetAudience(),
                'CatalogDataStatus' => new \PHPExiftool\Driver\Tag\MXF\CatalogDataStatus(),
                'ThesaurusName' => new \PHPExiftool\Driver\Tag\MXF\ThesaurusName(),
                'Theme' => new \PHPExiftool\Driver\Tag\MXF\Theme(),
                'ContentClassification' => new \PHPExiftool\Driver\Tag\MXF\ContentClassification(),
                'Keywords' => new \PHPExiftool\Driver\Tag\MXF\Keywords(),
                'KeyFrames' => new \PHPExiftool\Driver\Tag\MXF\KeyFrames(),
                'KeySounds' => new \PHPExiftool\Driver\Tag\MXF\KeySounds(),
                'KeyData' => new \PHPExiftool\Driver\Tag\MXF\KeyData(),
                'Abstract' => new \PHPExiftool\Driver\Tag\MXF\Abstract0(),
                'Purpose' => new \PHPExiftool\Driver\Tag\MXF\Purpose(),
                'Description' => new \PHPExiftool\Driver\Tag\MXF\Description(),
                'ColorDescriptor' => new \PHPExiftool\Driver\Tag\MXF\ColorDescriptor(),
                'FormatDescriptor' => new \PHPExiftool\Driver\Tag\MXF\FormatDescriptor(),
                'StratumKind' => new \PHPExiftool\Driver\Tag\MXF\StratumKind(),
                'IndividualAwardName' => new \PHPExiftool\Driver\Tag\MXF\IndividualAwardName(),
                'ProgramAwardName' => new \PHPExiftool\Driver\Tag\MXF\ProgramAwardName(),
                'AssetValue' => new \PHPExiftool\Driver\Tag\MXF\AssetValue(),
                'ContentValue' => new \PHPExiftool\Driver\Tag\MXF\ContentValue(),
                'CulturalValue' => new \PHPExiftool\Driver\Tag\MXF\CulturalValue(),
                'AestheticValue' => new \PHPExiftool\Driver\Tag\MXF\AestheticValue(),
                'HistoricalValue' => new \PHPExiftool\Driver\Tag\MXF\HistoricalValue(),
                'TechnicalValue' => new \PHPExiftool\Driver\Tag\MXF\TechnicalValue(),
                'OtherValues' => new \PHPExiftool\Driver\Tag\MXF\OtherValues(),
                'CatalogingSystemName' => new \PHPExiftool\Driver\Tag\MXF\CatalogingSystemName(),
                'ComputedKeywords' => new \PHPExiftool\Driver\Tag\MXF\ComputedKeywords(),
                'ComputedKeyFrames' => new \PHPExiftool\Driver\Tag\MXF\ComputedKeyFrames(),
                'ComputedKeySounds' => new \PHPExiftool\Driver\Tag\MXF\ComputedKeySounds(),
                'ComputedKeyData' => new \PHPExiftool\Driver\Tag\MXF\ComputedKeyData(),
                'ComputedStratumKind' => new \PHPExiftool\Driver\Tag\MXF\ComputedStratumKind(),
                'PresentationAspectRatio' => new \PHPExiftool\Driver\Tag\MXF\PresentationAspectRatio(),
                'CaptureAspectRatio' => new \PHPExiftool\Driver\Tag\MXF\CaptureAspectRatio(),
                'CaptureGammaEquation' => new \PHPExiftool\Driver\Tag\MXF\CaptureGammaEquation(),
                'LumaEquation' => new \PHPExiftool\Driver\Tag\MXF\LumaEquation(),
                'ColorimetryCode' => new \PHPExiftool\Driver\Tag\MXF\ColorimetryCode(),
                'SignalFormCode' => new \PHPExiftool\Driver\Tag\MXF\SignalFormCode(),
                'ColorFieldCode' => new \PHPExiftool\Driver\Tag\MXF\ColorFieldCode(),
                'FieldRate' => new \PHPExiftool\Driver\Tag\MXF\FieldRate(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\MXF\FrameRate(),
                'FrameLayout' => new \PHPExiftool\Driver\Tag\MXF\FrameLayout(),
                'SamplingStructureCode' => new \PHPExiftool\Driver\Tag\MXF\SamplingStructureCode(),
                'TotalLinesperFrame' => new \PHPExiftool\Driver\Tag\MXF\TotalLinesperFrame(),
                'ActiveLinesperFrame' => new \PHPExiftool\Driver\Tag\MXF\ActiveLinesperFrame(),
                'LeadingLines' => new \PHPExiftool\Driver\Tag\MXF\LeadingLines(),
                'TrailingLines' => new \PHPExiftool\Driver\Tag\MXF\TrailingLines(),
                'AnalogVideoSystemName' => new \PHPExiftool\Driver\Tag\MXF\AnalogVideoSystemName(),
                'LuminanceSampleRate' => new \PHPExiftool\Driver\Tag\MXF\LuminanceSampleRate(),
                'ActiveSamplesperLine' => new \PHPExiftool\Driver\Tag\MXF\ActiveSamplesperLine(),
                'TotalSamplesperLine' => new \PHPExiftool\Driver\Tag\MXF\TotalSamplesperLine(),
                'SamplingHierarchyCode' => new \PHPExiftool\Driver\Tag\MXF\SamplingHierarchyCode(),
                'HorizontalSubsampling' => new \PHPExiftool\Driver\Tag\MXF\HorizontalSubsampling(),
                'ColorSiting' => new \PHPExiftool\Driver\Tag\MXF\ColorSiting(),
                'SampledHeight' => new \PHPExiftool\Driver\Tag\MXF\SampledHeight(),
                'SampledWidth' => new \PHPExiftool\Driver\Tag\MXF\SampledWidth(),
                'SampledXOffset' => new \PHPExiftool\Driver\Tag\MXF\SampledXOffset(),
                'SampledYOffset' => new \PHPExiftool\Driver\Tag\MXF\SampledYOffset(),
                'DisplayHeight' => new \PHPExiftool\Driver\Tag\MXF\DisplayHeight(),
                'DisplayWidth' => new \PHPExiftool\Driver\Tag\MXF\DisplayWidth(),
                'DisplayXOffset' => new \PHPExiftool\Driver\Tag\MXF\DisplayXOffset(),
                'DisplayYOffset' => new \PHPExiftool\Driver\Tag\MXF\DisplayYOffset(),
                'FilteringCode' => new \PHPExiftool\Driver\Tag\MXF\FilteringCode(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\MXF\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\MXF\ImageWidth(),
                'BitsperPixel' => new \PHPExiftool\Driver\Tag\MXF\BitsperPixel(),
                'RoundingMethodCode' => new \PHPExiftool\Driver\Tag\MXF\RoundingMethodCode(),
                'BlackReferenceLevel' => new \PHPExiftool\Driver\Tag\MXF\BlackReferenceLevel(),
                'WhiteReferenceLevel' => new \PHPExiftool\Driver\Tag\MXF\WhiteReferenceLevel(),
                'FieldFrameTypeCode' => new \PHPExiftool\Driver\Tag\MXF\FieldFrameTypeCode(),
                'PulldownSequence' => new \PHPExiftool\Driver\Tag\MXF\PulldownSequence(),
                'PulldownFieldDominance' => new \PHPExiftool\Driver\Tag\MXF\PulldownFieldDominance(),
                'VideoAndFilmFrameRelationship' => new \PHPExiftool\Driver\Tag\MXF\VideoAndFilmFrameRelationship(),
                'CaptureFilmFrameRate' => new \PHPExiftool\Driver\Tag\MXF\CaptureFilmFrameRate(),
                'TransferFilmFrameRate' => new \PHPExiftool\Driver\Tag\MXF\TransferFilmFrameRate(),
                'VideoTestParameter' => new \PHPExiftool\Driver\Tag\MXF\VideoTestParameter(),
                'VideoTestResult' => new \PHPExiftool\Driver\Tag\MXF\VideoTestResult(),
                'FilmTestParameter' => new \PHPExiftool\Driver\Tag\MXF\FilmTestParameter(),
                'FilmTestResult' => new \PHPExiftool\Driver\Tag\MXF\FilmTestResult(),
                'ElectrospatialFormulation' => new \PHPExiftool\Driver\Tag\MXF\ElectrospatialFormulation(),
                'FilteringApplied' => new \PHPExiftool\Driver\Tag\MXF\FilteringApplied(),
                'AudioReferenceLevel' => new \PHPExiftool\Driver\Tag\MXF\AudioReferenceLevel(),
                'AudioMonoChannelCount' => new \PHPExiftool\Driver\Tag\MXF\AudioMonoChannelCount(),
                'AudioStereoChannelCount' => new \PHPExiftool\Driver\Tag\MXF\AudioStereoChannelCount(),
                'AnalogSystem' => new \PHPExiftool\Driver\Tag\MXF\AnalogSystem(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\MXF\AudioSampleRate(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\MXF\BitsPerSample(),
                'RoundingLaw' => new \PHPExiftool\Driver\Tag\MXF\RoundingLaw(),
                'Dither' => new \PHPExiftool\Driver\Tag\MXF\Dither(),
                'OpticalTrack' => new \PHPExiftool\Driver\Tag\MXF\OpticalTrack(),
                'MagneticTrack' => new \PHPExiftool\Driver\Tag\MXF\MagneticTrack(),
                'Signal-to-NoiseRatio' => new \PHPExiftool\Driver\Tag\MXF\SignalToNoiseRatio(),
                'Weighting' => new \PHPExiftool\Driver\Tag\MXF\Weighting(),
                'AnalogDataCodingKind' => new \PHPExiftool\Driver\Tag\MXF\AnalogDataCodingKind(),
                'TimecodeKind' => new \PHPExiftool\Driver\Tag\MXF\TimecodeKind(),
                'TimecodeTimebase' => new \PHPExiftool\Driver\Tag\MXF\TimecodeTimebase(),
                'TimecodeUserBitsFlag' => new \PHPExiftool\Driver\Tag\MXF\TimecodeUserBitsFlag(),
                'IncludeSync' => new \PHPExiftool\Driver\Tag\MXF\IncludeSync(),
                'DropFrame' => new \PHPExiftool\Driver\Tag\MXF\DropFrame(),
                'TimecodeSourceKind' => new \PHPExiftool\Driver\Tag\MXF\TimecodeSourceKind(),
                'AnalogMetadataCarrier' => new \PHPExiftool\Driver\Tag\MXF\AnalogMetadataCarrier(),
                'DigitalMetadataCarrier' => new \PHPExiftool\Driver\Tag\MXF\DigitalMetadataCarrier(),
                'AnalogMonitoringAndControlCodingKind' => new \PHPExiftool\Driver\Tag\MXF\AnalogMonitoringAndControlCodingKind(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\MXF\SampleRate(),
                'EssenceLength' => new \PHPExiftool\Driver\Tag\MXF\EssenceLength(),
                'FilmColorProcess' => new \PHPExiftool\Driver\Tag\MXF\FilmColorProcess(),
                'EdgeCodeFormat' => new \PHPExiftool\Driver\Tag\MXF\EdgeCodeFormat(),
                'FilmFormatName' => new \PHPExiftool\Driver\Tag\MXF\FilmFormatName(),
                'FilmStockKind' => new \PHPExiftool\Driver\Tag\MXF\FilmStockKind(),
                'FilmStockManufacturerName' => new \PHPExiftool\Driver\Tag\MXF\FilmStockManufacturerName(),
                'PhysicalMediaLength' => new \PHPExiftool\Driver\Tag\MXF\PhysicalMediaLength(),
                'FilmCaptureAperture' => new \PHPExiftool\Driver\Tag\MXF\FilmCaptureAperture(),
                'ImageCategory' => new \PHPExiftool\Driver\Tag\MXF\ImageCategory(),
                'ImageSourceDeviceKind' => new \PHPExiftool\Driver\Tag\MXF\ImageSourceDeviceKind(),
                'OpticalTestParameterName' => new \PHPExiftool\Driver\Tag\MXF\OpticalTestParameterName(),
                'OpticalTestResult' => new \PHPExiftool\Driver\Tag\MXF\OpticalTestResult(),
                'SensorType' => new \PHPExiftool\Driver\Tag\MXF\SensorType(),
                'PolarCharacteristic' => new \PHPExiftool\Driver\Tag\MXF\PolarCharacteristic(),
                'IntegrationIndication' => new \PHPExiftool\Driver\Tag\MXF\IntegrationIndication(),
                'EventIndication' => new \PHPExiftool\Driver\Tag\MXF\EventIndication(),
                'QualityFlag' => new \PHPExiftool\Driver\Tag\MXF\QualityFlag(),
                'PhysicalInstanceKind' => new \PHPExiftool\Driver\Tag\MXF\PhysicalInstanceKind(),
                'DigitalOrAnalogOrigination' => new \PHPExiftool\Driver\Tag\MXF\DigitalOrAnalogOrigination(),
                'MicrophonePlacementTechniques' => new \PHPExiftool\Driver\Tag\MXF\MicrophonePlacementTechniques(),
                'SimpleFlaggingCount' => new \PHPExiftool\Driver\Tag\MXF\SimpleFlaggingCount(),
                'CopyCount' => new \PHPExiftool\Driver\Tag\MXF\CopyCount(),
                'CloneCount' => new \PHPExiftool\Driver\Tag\MXF\CloneCount(),
                'Work-in-ProgressFlag' => new \PHPExiftool\Driver\Tag\MXF\WorkInProgressFlag(),
                'VideoOrImageCompressionAlgorithm' => new \PHPExiftool\Driver\Tag\MXF\VideoOrImageCompressionAlgorithm(),
                'SplicingMetadata' => new \PHPExiftool\Driver\Tag\MXF\SplicingMetadata(),
                'AudioCompressionAlgorithm' => new \PHPExiftool\Driver\Tag\MXF\AudioCompressionAlgorithm(),
                'VideoNoiseReductionAlgorithm' => new \PHPExiftool\Driver\Tag\MXF\VideoNoiseReductionAlgorithm(),
                'AudioNoiseReductionAlgorithm' => new \PHPExiftool\Driver\Tag\MXF\AudioNoiseReductionAlgorithm(),
                'EnhancementOrModificationDescription' => new \PHPExiftool\Driver\Tag\MXF\EnhancementOrModificationDescription(),
                'VideoDeviceKind' => new \PHPExiftool\Driver\Tag\MXF\VideoDeviceKind(),
                'VideoDeviceParameterName' => new \PHPExiftool\Driver\Tag\MXF\VideoDeviceParameterName(),
                'VideoDeviceParameterSetting' => new \PHPExiftool\Driver\Tag\MXF\VideoDeviceParameterSetting(),
                'AudioEnhancementOrModificationDescription' => new \PHPExiftool\Driver\Tag\MXF\AudioEnhancementOrModificationDescription(),
                'AudioFirstMix-DownProcess' => new \PHPExiftool\Driver\Tag\MXF\AudioFirstMixDownProcess(),
                'AudioDeviceKind' => new \PHPExiftool\Driver\Tag\MXF\AudioDeviceKind(),
                'AudioDeviceParameter' => new \PHPExiftool\Driver\Tag\MXF\AudioDeviceParameter(),
                'AudioDeviceParameterSetting' => new \PHPExiftool\Driver\Tag\MXF\AudioDeviceParameterSetting(),
                'DataEnhancementOrModificationDescription' => new \PHPExiftool\Driver\Tag\MXF\DataEnhancementOrModificationDescription(),
                'DataDeviceKind' => new \PHPExiftool\Driver\Tag\MXF\DataDeviceKind(),
                'DataDeviceParameterName' => new \PHPExiftool\Driver\Tag\MXF\DataDeviceParameterName(),
                'DataDeviceParameterSetting' => new \PHPExiftool\Driver\Tag\MXF\DataDeviceParameterSetting(),
                'DefaultFadeType' => new \PHPExiftool\Driver\Tag\MXF\DefaultFadeType(),
                'ActiveState' => new \PHPExiftool\Driver\Tag\MXF\ActiveState(),
                'Fade-InType' => new \PHPExiftool\Driver\Tag\MXF\FadeInType(),
                'Fade-OutType' => new \PHPExiftool\Driver\Tag\MXF\FadeOutType(),
                'SpeedChangeEffectFlag' => new \PHPExiftool\Driver\Tag\MXF\SpeedChangeEffectFlag(),
                'InputSegmentCount' => new \PHPExiftool\Driver\Tag\MXF\InputSegmentCount(),
                'Bypass' => new \PHPExiftool\Driver\Tag\MXF\Bypass(),
                'VideoCompressionAlgorithm' => new \PHPExiftool\Driver\Tag\MXF\VideoCompressionAlgorithm(),
                'MPEGVideoRecodingDataset' => new \PHPExiftool\Driver\Tag\MXF\MPEGVideoRecodingDataset(),
                'UpstreamAudioCompressionAlgorithm' => new \PHPExiftool\Driver\Tag\MXF\UpstreamAudioCompressionAlgorithm(),
                'MPEGAudioRecodingDataset' => new \PHPExiftool\Driver\Tag\MXF\MPEGAudioRecodingDataset(),
                'ProgramSupportMaterialReference' => new \PHPExiftool\Driver\Tag\MXF\ProgramSupportMaterialReference(),
                'AdvertisingMaterialReference' => new \PHPExiftool\Driver\Tag\MXF\AdvertisingMaterialReference(),
                'ProgramCommercialMaterialReference' => new \PHPExiftool\Driver\Tag\MXF\ProgramCommercialMaterialReference(),
                'ContiguousDataFlag' => new \PHPExiftool\Driver\Tag\MXF\ContiguousDataFlag(),
                'PositionInSequence' => new \PHPExiftool\Driver\Tag\MXF\PositionInSequence(),
                'RelativePositionInSequenceOffset' => new \PHPExiftool\Driver\Tag\MXF\RelativePositionInSequenceOffset(),
                'RelativePositionInSequenceName' => new \PHPExiftool\Driver\Tag\MXF\RelativePositionInSequenceName(),
                'ImageCoordinateSystem' => new \PHPExiftool\Driver\Tag\MXF\ImageCoordinateSystem(),
                'MapDatumUsed' => new \PHPExiftool\Driver\Tag\MXF\MapDatumUsed(),
                'LocalDatumAbsolutePositionAccuracy' => new \PHPExiftool\Driver\Tag\MXF\LocalDatumAbsolutePositionAccuracy(),
                'DeviceAbsolutePositionalAccuracy' => new \PHPExiftool\Driver\Tag\MXF\DeviceAbsolutePositionalAccuracy(),
                'DeviceAltitude' => new \PHPExiftool\Driver\Tag\MXF\DeviceAltitude(),
                'DeviceLatitude' => new \PHPExiftool\Driver\Tag\MXF\DeviceLatitude(),
                'DeviceLongitude' => new \PHPExiftool\Driver\Tag\MXF\DeviceLongitude(),
                'DeviceXDimension' => new \PHPExiftool\Driver\Tag\MXF\DeviceXDimension(),
                'DeviceYDimension' => new \PHPExiftool\Driver\Tag\MXF\DeviceYDimension(),
                'FramePositionalAccuracy' => new \PHPExiftool\Driver\Tag\MXF\FramePositionalAccuracy(),
                'FrameCenterLatitude' => new \PHPExiftool\Driver\Tag\MXF\FrameCenterLatitude(),
                'FrameCenterLongitude' => new \PHPExiftool\Driver\Tag\MXF\FrameCenterLongitude(),
                'FrameCenterLatitudeLongitude' => new \PHPExiftool\Driver\Tag\MXF\FrameCenterLatitudeLongitude(),
                'LocalDatumRelativePositionAccuracy' => new \PHPExiftool\Driver\Tag\MXF\LocalDatumRelativePositionAccuracy(),
                'DeviceRelativePositionalAccuracy' => new \PHPExiftool\Driver\Tag\MXF\DeviceRelativePositionalAccuracy(),
                'DeviceRelativePositionX' => new \PHPExiftool\Driver\Tag\MXF\DeviceRelativePositionX(),
                'DeviceRelativePositionY' => new \PHPExiftool\Driver\Tag\MXF\DeviceRelativePositionY(),
                'DeviceRelativePositionZ' => new \PHPExiftool\Driver\Tag\MXF\DeviceRelativePositionZ(),
                'SubjectRelativePositionalAccuracy' => new \PHPExiftool\Driver\Tag\MXF\SubjectRelativePositionalAccuracy(),
                'PositionWithinViewportImageXCoordinate' => new \PHPExiftool\Driver\Tag\MXF\PositionWithinViewportImageXCoordinate(),
                'PositionWithinViewportImageYCoordinate' => new \PHPExiftool\Driver\Tag\MXF\PositionWithinViewportImageYCoordinate(),
                'SourceImageCenterXCoordinate' => new \PHPExiftool\Driver\Tag\MXF\SourceImageCenterXCoordinate(),
                'SourceImageCenterYCoordinate' => new \PHPExiftool\Driver\Tag\MXF\SourceImageCenterYCoordinate(),
                'ViewportImageCenterCCoordinate' => new \PHPExiftool\Driver\Tag\MXF\ViewportImageCenterCCoordinate(),
                'ViewportImageCenterYCoordinate' => new \PHPExiftool\Driver\Tag\MXF\ViewportImageCenterYCoordinate(),
                'DeviceAbsoluteSpeed' => new \PHPExiftool\Driver\Tag\MXF\DeviceAbsoluteSpeed(),
                'DeviceAbsoluteHeading' => new \PHPExiftool\Driver\Tag\MXF\DeviceAbsoluteHeading(),
                'SubjectAbsoluteSpeed' => new \PHPExiftool\Driver\Tag\MXF\SubjectAbsoluteSpeed(),
                'SubjectAbsoluteHeading' => new \PHPExiftool\Driver\Tag\MXF\SubjectAbsoluteHeading(),
                'DeviceRelativeSpeed' => new \PHPExiftool\Driver\Tag\MXF\DeviceRelativeSpeed(),
                'DeviceRelativeHeading' => new \PHPExiftool\Driver\Tag\MXF\DeviceRelativeHeading(),
                'SubjectRelativeSpeed' => new \PHPExiftool\Driver\Tag\MXF\SubjectRelativeSpeed(),
                'SubjectRelativeHeading' => new \PHPExiftool\Driver\Tag\MXF\SubjectRelativeHeading(),
                'SlantRange' => new \PHPExiftool\Driver\Tag\MXF\SlantRange(),
                'TargetWidth' => new \PHPExiftool\Driver\Tag\MXF\TargetWidth(),
                'ViewportHeight' => new \PHPExiftool\Driver\Tag\MXF\ViewportHeight(),
                'ViewportWidth' => new \PHPExiftool\Driver\Tag\MXF\ViewportWidth(),
                'SensorRollAngle' => new \PHPExiftool\Driver\Tag\MXF\SensorRollAngle(),
                'AngleToNorth' => new \PHPExiftool\Driver\Tag\MXF\AngleToNorth(),
                'ObliquityAngle' => new \PHPExiftool\Driver\Tag\MXF\ObliquityAngle(),
                'PlaceKeyword' => new \PHPExiftool\Driver\Tag\MXF\PlaceKeyword(),
                'ObjectCountryCode' => new \PHPExiftool\Driver\Tag\MXF\ObjectCountryCode(),
                'ShootingCountryCode' => new \PHPExiftool\Driver\Tag\MXF\ShootingCountryCode(),
                'SettingCountryCode' => new \PHPExiftool\Driver\Tag\MXF\SettingCountryCode(),
                'CopyrightLicenseCountryCode' => new \PHPExiftool\Driver\Tag\MXF\CopyrightLicenseCountryCode(),
                'IntellectualPropertyLicenseCountryCode' => new \PHPExiftool\Driver\Tag\MXF\IntellectualPropertyLicenseCountryCode(),
                'ObjectRegionCode' => new \PHPExiftool\Driver\Tag\MXF\ObjectRegionCode(),
                'ShootingRegionCode' => new \PHPExiftool\Driver\Tag\MXF\ShootingRegionCode(),
                'SettingRegionCode' => new \PHPExiftool\Driver\Tag\MXF\SettingRegionCode(),
                'CopyrightLicenseRegionCode' => new \PHPExiftool\Driver\Tag\MXF\CopyrightLicenseRegionCode(),
                'IntellectualPropertyLicenseRegionCode' => new \PHPExiftool\Driver\Tag\MXF\IntellectualPropertyLicenseRegionCode(),
                'RoomNumber' => new \PHPExiftool\Driver\Tag\MXF\RoomNumber(),
                'StreetNumber' => new \PHPExiftool\Driver\Tag\MXF\StreetNumber(),
                'StreetName' => new \PHPExiftool\Driver\Tag\MXF\StreetName(),
                'PostalTown' => new \PHPExiftool\Driver\Tag\MXF\PostalTown(),
                'CityName' => new \PHPExiftool\Driver\Tag\MXF\CityName(),
                'StateOrProvinceOrCountyName' => new \PHPExiftool\Driver\Tag\MXF\StateOrProvinceOrCountyName(),
                'PostalCode' => new \PHPExiftool\Driver\Tag\MXF\PostalCode(),
                'CountryName' => new \PHPExiftool\Driver\Tag\MXF\CountryName(),
                'SettingRoomNumber' => new \PHPExiftool\Driver\Tag\MXF\SettingRoomNumber(),
                'SettingStreetNumberOrBuildingName' => new \PHPExiftool\Driver\Tag\MXF\SettingStreetNumberOrBuildingName(),
                'SettingStreetName' => new \PHPExiftool\Driver\Tag\MXF\SettingStreetName(),
                'SettingTownName' => new \PHPExiftool\Driver\Tag\MXF\SettingTownName(),
                'SettingCityName' => new \PHPExiftool\Driver\Tag\MXF\SettingCityName(),
                'SettingStateOrProvinceOrCountyName' => new \PHPExiftool\Driver\Tag\MXF\SettingStateOrProvinceOrCountyName(),
                'SettingPostalCode' => new \PHPExiftool\Driver\Tag\MXF\SettingPostalCode(),
                'SettingCountryName' => new \PHPExiftool\Driver\Tag\MXF\SettingCountryName(),
                'TelephoneNumber' => new \PHPExiftool\Driver\Tag\MXF\TelephoneNumber(),
                'FaxNumber' => new \PHPExiftool\Driver\Tag\MXF\FaxNumber(),
                'E-MailAddress' => new \PHPExiftool\Driver\Tag\MXF\EMailAddress(),
                'SettingDescription' => new \PHPExiftool\Driver\Tag\MXF\SettingDescription(),
                'UTCUserDateTime' => new \PHPExiftool\Driver\Tag\MXF\UTCUserDateTime(),
                'LocalUserDateTime' => new \PHPExiftool\Driver\Tag\MXF\LocalUserDateTime(),
                'SMPTE309MUserDateTime' => new \PHPExiftool\Driver\Tag\MXF\SMPTE309MUserDateTime(),
                'SMPTE12MUserDateTime' => new \PHPExiftool\Driver\Tag\MXF\SMPTE12MUserDateTime(),
                'UTCStartDateTime' => new \PHPExiftool\Driver\Tag\MXF\UTCStartDateTime(),
                'LocalStartDateTime' => new \PHPExiftool\Driver\Tag\MXF\LocalStartDateTime(),
                'TimecodeStartDateTime' => new \PHPExiftool\Driver\Tag\MXF\TimecodeStartDateTime(),
                'UTCEndDateTime' => new \PHPExiftool\Driver\Tag\MXF\UTCEndDateTime(),
                'LocalEndDateTime' => new \PHPExiftool\Driver\Tag\MXF\LocalEndDateTime(),
                'TimecodeEndDateTime' => new \PHPExiftool\Driver\Tag\MXF\TimecodeEndDateTime(),
                'UTCLastModifyDate' => new \PHPExiftool\Driver\Tag\MXF\UTCLastModifyDate(),
                'LocalLastModifyDate' => new \PHPExiftool\Driver\Tag\MXF\LocalLastModifyDate(),
                'TimecodeLastModifyDate' => new \PHPExiftool\Driver\Tag\MXF\TimecodeLastModifyDate(),
                'UTCEventStartDateTime' => new \PHPExiftool\Driver\Tag\MXF\UTCEventStartDateTime(),
                'LocalEventStartDateTime' => new \PHPExiftool\Driver\Tag\MXF\LocalEventStartDateTime(),
                'TimecodeEventStartDateTime' => new \PHPExiftool\Driver\Tag\MXF\TimecodeEventStartDateTime(),
                'UTCEventEndDateTime' => new \PHPExiftool\Driver\Tag\MXF\UTCEventEndDateTime(),
                'LocalEventEndDateTime' => new \PHPExiftool\Driver\Tag\MXF\LocalEventEndDateTime(),
                'TimecodeEventEndDateTime' => new \PHPExiftool\Driver\Tag\MXF\TimecodeEventEndDateTime(),
                'StartTimeRelativeToReference' => new \PHPExiftool\Driver\Tag\MXF\StartTimeRelativeToReference(),
                'StartTimecodeRelativeToReference' => new \PHPExiftool\Driver\Tag\MXF\StartTimecodeRelativeToReference(),
                'MaterialEndTimeOffset' => new \PHPExiftool\Driver\Tag\MXF\MaterialEndTimeOffset(),
                'MaterialEndTimecodeOffset' => new \PHPExiftool\Driver\Tag\MXF\MaterialEndTimecodeOffset(),
                'EventStartTimeOffset' => new \PHPExiftool\Driver\Tag\MXF\EventStartTimeOffset(),
                'EventStartTimecodeOffset' => new \PHPExiftool\Driver\Tag\MXF\EventStartTimecodeOffset(),
                'EventEndTimeOffset' => new \PHPExiftool\Driver\Tag\MXF\EventEndTimeOffset(),
                'EventEndTimecodeOffset' => new \PHPExiftool\Driver\Tag\MXF\EventEndTimecodeOffset(),
                'FrameCountOffset' => new \PHPExiftool\Driver\Tag\MXF\FrameCountOffset(),
                'TimePeriodName' => new \PHPExiftool\Driver\Tag\MXF\TimePeriodName(),
                'LocalCreationDateTime' => new \PHPExiftool\Driver\Tag\MXF\LocalCreationDateTime(),
                'TimecodeCreationDateTime' => new \PHPExiftool\Driver\Tag\MXF\TimecodeCreationDateTime(),
                'LocalModifyDate' => new \PHPExiftool\Driver\Tag\MXF\LocalModifyDate(),
                'TimecodeModifyDate' => new \PHPExiftool\Driver\Tag\MXF\TimecodeModifyDate(),
                'FrameCount' => new \PHPExiftool\Driver\Tag\MXF\FrameCount(),
                'MaterialAbsoluteDuration' => new \PHPExiftool\Driver\Tag\MXF\MaterialAbsoluteDuration(),
                'TextlessBlackDuration' => new \PHPExiftool\Driver\Tag\MXF\TextlessBlackDuration(),
                'EventAbsoluteDurationFrameCount' => new \PHPExiftool\Driver\Tag\MXF\EventAbsoluteDurationFrameCount(),
                'EventAbsoluteDuration' => new \PHPExiftool\Driver\Tag\MXF\EventAbsoluteDuration(),
                'BufferDelay' => new \PHPExiftool\Driver\Tag\MXF\BufferDelay(),
                'ProgramIdentifier' => new \PHPExiftool\Driver\Tag\MXF\ProgramIdentifier(),
                'ProgramIdentifierString' => new \PHPExiftool\Driver\Tag\MXF\ProgramIdentifierString(),
                'ShimName' => new \PHPExiftool\Driver\Tag\MXF\ShimName(),
                'SignalStandard' => new \PHPExiftool\Driver\Tag\MXF\SignalStandard(),
                'IntendedAFD' => new \PHPExiftool\Driver\Tag\MXF\IntendedAFD(),
                'SlateTitle' => new \PHPExiftool\Driver\Tag\MXF\SlateTitle(),
                'NOLACode' => new \PHPExiftool\Driver\Tag\MXF\NOLACode(),
                'Rating' => new \PHPExiftool\Driver\Tag\MXF\Rating(),
                'NielsenStreamIdentifier' => new \PHPExiftool\Driver\Tag\MXF\NielsenStreamIdentifier(),
                'IsRecording' => new \PHPExiftool\Driver\Tag\MXF\IsRecording(),
                'IsLiveProduction' => new \PHPExiftool\Driver\Tag\MXF\IsLiveProduction(),
                'IsLiveTransmission' => new \PHPExiftool\Driver\Tag\MXF\IsLiveTransmission(),
                'IsDubbed' => new \PHPExiftool\Driver\Tag\MXF\IsDubbed(),
                'IsVoiceover' => new \PHPExiftool\Driver\Tag\MXF\IsVoiceover(),
                'HasAudioWatermark' => new \PHPExiftool\Driver\Tag\MXF\HasAudioWatermark(),
                'AudioWatermarkKind' => new \PHPExiftool\Driver\Tag\MXF\AudioWatermarkKind(),
                'HasVideoWatermark' => new \PHPExiftool\Driver\Tag\MXF\HasVideoWatermark(),
                'VideoWatermarkKind' => new \PHPExiftool\Driver\Tag\MXF\VideoWatermarkKind(),
                'SubtitlesPresent' => new \PHPExiftool\Driver\Tag\MXF\SubtitlesPresent(),
                'CaptionTitles' => new \PHPExiftool\Driver\Tag\MXF\CaptionTitles(),
                'CaptionsViaTeletext' => new \PHPExiftool\Driver\Tag\MXF\CaptionsViaTeletext(),
                'TextlessMaterial' => new \PHPExiftool\Driver\Tag\MXF\TextlessMaterial(),
                'StorageDeviceKind' => new \PHPExiftool\Driver\Tag\MXF\StorageDeviceKind(),
                'StorageMediaKind' => new \PHPExiftool\Driver\Tag\MXF\StorageMediaKind(),
                'StorageMediaID' => new \PHPExiftool\Driver\Tag\MXF\StorageMediaID(),
                'BroadcastDate' => new \PHPExiftool\Driver\Tag\MXF\BroadcastDate(),
                'BroadcastTime' => new \PHPExiftool\Driver\Tag\MXF\BroadcastTime(),
                'IsRepeat' => new \PHPExiftool\Driver\Tag\MXF\IsRepeat(),
                'FirstTransmissionInfo' => new \PHPExiftool\Driver\Tag\MXF\FirstTransmissionInfo(),
                'TeletextSubtitlesAvailable' => new \PHPExiftool\Driver\Tag\MXF\TeletextSubtitlesAvailable(),
                'SeasonEpisodeNumber' => new \PHPExiftool\Driver\Tag\MXF\SeasonEpisodeNumber(),
                'SeasonEpisodeTitle' => new \PHPExiftool\Driver\Tag\MXF\SeasonEpisodeTitle(),
                'EPGProgramSynopsis' => new \PHPExiftool\Driver\Tag\MXF\EPGProgramSynopsis(),
                'DVBParentalRating' => new \PHPExiftool\Driver\Tag\MXF\DVBParentalRating(),
                'ContentMaturityRating' => new \PHPExiftool\Driver\Tag\MXF\ContentMaturityRating(),
                'ContentMaturityDescription' => new \PHPExiftool\Driver\Tag\MXF\ContentMaturityDescription(),
                'ContentMaturityGraphic' => new \PHPExiftool\Driver\Tag\MXF\ContentMaturityGraphic(),
                'ContractEntity' => new \PHPExiftool\Driver\Tag\MXF\ContractEntity(),
                'ContractTypeLink' => new \PHPExiftool\Driver\Tag\MXF\ContractTypeLink(),
                'ConsumerRightsToCopy' => new \PHPExiftool\Driver\Tag\MXF\ConsumerRightsToCopy(),
                'BroadcasterRightsToCopy' => new \PHPExiftool\Driver\Tag\MXF\BroadcasterRightsToCopy(),
                'DirectorName' => new \PHPExiftool\Driver\Tag\MXF\DirectorName(),
                'ProducerName' => new \PHPExiftool\Driver\Tag\MXF\ProducerName(),
                'FemaleLeadActressName' => new \PHPExiftool\Driver\Tag\MXF\FemaleLeadActressName(),
                'MaleLeadActorName' => new \PHPExiftool\Driver\Tag\MXF\MaleLeadActorName(),
                'PresenterName' => new \PHPExiftool\Driver\Tag\MXF\PresenterName(),
                'MainSponsorName' => new \PHPExiftool\Driver\Tag\MXF\MainSponsorName(),
                'VoiceTalentName' => new \PHPExiftool\Driver\Tag\MXF\VoiceTalentName(),
                'PostboxNumber' => new \PHPExiftool\Driver\Tag\MXF\PostboxNumber(),
                'PostCodeForPostbox' => new \PHPExiftool\Driver\Tag\MXF\PostCodeForPostbox(),
                'ProgramNumber' => new \PHPExiftool\Driver\Tag\MXF\ProgramNumber(),
                'DefinitionObjectID' => new \PHPExiftool\Driver\Tag\MXF\DefinitionObjectID(),
                'IEEEDeviceID' => new \PHPExiftool\Driver\Tag\MXF\IEEEDeviceID(),
                'ProjectNumber' => new \PHPExiftool\Driver\Tag\MXF\ProjectNumber(),
                'EdgeCodeHeader' => new \PHPExiftool\Driver\Tag\MXF\EdgeCodeHeader(),
                'ChannelHandle' => new \PHPExiftool\Driver\Tag\MXF\ChannelHandle(),
                'PhysicalMediaLocation' => new \PHPExiftool\Driver\Tag\MXF\PhysicalMediaLocation(),
                'MediaLocation' => new \PHPExiftool\Driver\Tag\MXF\MediaLocation(),
                'TrackNumber' => new \PHPExiftool\Driver\Tag\MXF\TrackNumber(),
                'EdgeCodeStart' => new \PHPExiftool\Driver\Tag\MXF\EdgeCodeStart(),
                'VersionTitle' => new \PHPExiftool\Driver\Tag\MXF\VersionTitle(),
                'TrackID' => new \PHPExiftool\Driver\Tag\MXF\TrackID(),
                'TrackName' => new \PHPExiftool\Driver\Tag\MXF\TrackName(),
                'DefinitionObjectName' => new \PHPExiftool\Driver\Tag\MXF\DefinitionObjectName(),
                'ContentPackageMetadataLink' => new \PHPExiftool\Driver\Tag\MXF\ContentPackageMetadataLink(),
                'DefinedName' => new \PHPExiftool\Driver\Tag\MXF\DefinedName(),
                'DeviceManufacturerName' => new \PHPExiftool\Driver\Tag\MXF\DeviceManufacturerName(),
                'ManufacturerID' => new \PHPExiftool\Driver\Tag\MXF\ManufacturerID(),
                'IEEEManufacturerID' => new \PHPExiftool\Driver\Tag\MXF\IEEEManufacturerID(),
                'AAFManufacturerID' => new \PHPExiftool\Driver\Tag\MXF\AAFManufacturerID(),
                'SupplyingDepartmentName' => new \PHPExiftool\Driver\Tag\MXF\SupplyingDepartmentName(),
                'AudienceShare' => new \PHPExiftool\Driver\Tag\MXF\AudienceShare(),
                'AudienceAppreciation' => new \PHPExiftool\Driver\Tag\MXF\AudienceAppreciation(),
                'Salutation' => new \PHPExiftool\Driver\Tag\MXF\Salutation(),
                'HonorsAndQualifications' => new \PHPExiftool\Driver\Tag\MXF\HonorsAndQualifications(),
                'ObjectModelVersion' => new \PHPExiftool\Driver\Tag\MXF\ObjectModelVersion(),
                'SDKVersion' => new \PHPExiftool\Driver\Tag\MXF\SDKVersion(),
                'IsOptional' => new \PHPExiftool\Driver\Tag\MXF\IsOptional(),
                'IsSearchable' => new \PHPExiftool\Driver\Tag\MXF\IsSearchable(),
                'UseDefaultValue' => new \PHPExiftool\Driver\Tag\MXF\UseDefaultValue(),
                'DefaultDataValue' => new \PHPExiftool\Driver\Tag\MXF\DefaultDataValue(),
                'Size' => new \PHPExiftool\Driver\Tag\MXF\Size(),
                'IsSigned' => new \PHPExiftool\Driver\Tag\MXF\IsSigned(),
                'ElementCount' => new \PHPExiftool\Driver\Tag\MXF\ElementCount(),
                'ElementNameList' => new \PHPExiftool\Driver\Tag\MXF\ElementNameList(),
                'TypeDefinitionElementValueList' => new \PHPExiftool\Driver\Tag\MXF\TypeDefinitionElementValueList(),
                'MemberNameList' => new \PHPExiftool\Driver\Tag\MXF\MemberNameList(),
                'ExtendibleElementNameList' => new \PHPExiftool\Driver\Tag\MXF\ExtendibleElementNameList(),
                'TypeDefinitionExtendibleElementValues' => new \PHPExiftool\Driver\Tag\MXF\TypeDefinitionExtendibleElementValues(),
                'TargetSet' => new \PHPExiftool\Driver\Tag\MXF\TargetSet(),
                'FillerData' => new \PHPExiftool\Driver\Tag\MXF\FillerData(),
                'KLVDataValue' => new \PHPExiftool\Driver\Tag\MXF\KLVDataValue(),
                'PackageKLVData' => new \PHPExiftool\Driver\Tag\MXF\PackageKLVData(),
                'ComponentKLVData' => new \PHPExiftool\Driver\Tag\MXF\ComponentKLVData(),
                'AssignedCategoryName' => new \PHPExiftool\Driver\Tag\MXF\AssignedCategoryName(),
                'AssignedCategoryValue' => new \PHPExiftool\Driver\Tag\MXF\AssignedCategoryValue(),
                'ShotList' => new \PHPExiftool\Driver\Tag\MXF\ShotList(),
                'PackageUserComments' => new \PHPExiftool\Driver\Tag\MXF\PackageUserComments(),
                'Cue-InWords' => new \PHPExiftool\Driver\Tag\MXF\CueInWords(),
                'Cue-OutWords' => new \PHPExiftool\Driver\Tag\MXF\CueOutWords(),
                'ObjectKind' => new \PHPExiftool\Driver\Tag\MXF\ObjectKind(),
                'ObjectDescription' => new \PHPExiftool\Driver\Tag\MXF\ObjectDescription(),
                'ObjectName' => new \PHPExiftool\Driver\Tag\MXF\ObjectName(),
                'MetadataItemName' => new \PHPExiftool\Driver\Tag\MXF\MetadataItemName(),
                'ShotCommentKind' => new \PHPExiftool\Driver\Tag\MXF\ShotCommentKind(),
                'ShotComment' => new \PHPExiftool\Driver\Tag\MXF\ShotComment(),
                'ComputedObjectKind' => new \PHPExiftool\Driver\Tag\MXF\ComputedObjectKind(),
                'VersionNumberString' => new \PHPExiftool\Driver\Tag\MXF\VersionNumberString(),
                'VersionNumber' => new \PHPExiftool\Driver\Tag\MXF\VersionNumber(),
                'WAVESummary' => new \PHPExiftool\Driver\Tag\MXF\WAVESummary(),
                'AIFCSummary' => new \PHPExiftool\Driver\Tag\MXF\AIFCSummary(),
                'TIFFSummary' => new \PHPExiftool\Driver\Tag\MXF\TIFFSummary(),
                'ViewportAspectRatio' => new \PHPExiftool\Driver\Tag\MXF\ViewportAspectRatio(),
                'PresentationGammaEquation' => new \PHPExiftool\Driver\Tag\MXF\PresentationGammaEquation(),
                'FieldDominance' => new \PHPExiftool\Driver\Tag\MXF\FieldDominance(),
                'VideoLineMap' => new \PHPExiftool\Driver\Tag\MXF\VideoLineMap(),
                'VerticalSub-sampling' => new \PHPExiftool\Driver\Tag\MXF\VerticalSubSampling(),
                'ColorRangeLevels' => new \PHPExiftool\Driver\Tag\MXF\ColorRangeLevels(),
                'PixelLayout' => new \PHPExiftool\Driver\Tag\MXF\PixelLayout(),
                'AlphaSampleDepth' => new \PHPExiftool\Driver\Tag\MXF\AlphaSampleDepth(),
                'Palette' => new \PHPExiftool\Driver\Tag\MXF\Palette(),
                'PaletteLayout' => new \PHPExiftool\Driver\Tag\MXF\PaletteLayout(),
                'ComponentDepth' => new \PHPExiftool\Driver\Tag\MXF\ComponentDepth(),
                'VideoCodingSchemeID' => new \PHPExiftool\Driver\Tag\MXF\VideoCodingSchemeID(),
                'RoundedCaptureFilmFrameRate' => new \PHPExiftool\Driver\Tag\MXF\RoundedCaptureFilmFrameRate(),
                'AudioAverageBitrate' => new \PHPExiftool\Driver\Tag\MXF\AudioAverageBitrate(),
                'AudioFixedBitrateFlag' => new \PHPExiftool\Driver\Tag\MXF\AudioFixedBitrateFlag(),
                'CodingLawKind' => new \PHPExiftool\Driver\Tag\MXF\CodingLawKind(),
                'AudioCodingSchemeID' => new \PHPExiftool\Driver\Tag\MXF\AudioCodingSchemeID(),
                'LayerNumber' => new \PHPExiftool\Driver\Tag\MXF\LayerNumber(),
                'RoundedTimecodeTimebase' => new \PHPExiftool\Driver\Tag\MXF\RoundedTimecodeTimebase(),
                'ComponentDataDefinition' => new \PHPExiftool\Driver\Tag\MXF\ComponentDataDefinition(),
                'StreamData' => new \PHPExiftool\Driver\Tag\MXF\StreamData(),
                'TimecodeStreamData' => new \PHPExiftool\Driver\Tag\MXF\TimecodeStreamData(),
                'RecordedFormat' => new \PHPExiftool\Driver\Tag\MXF\RecordedFormat(),
                'TapeShellKind' => new \PHPExiftool\Driver\Tag\MXF\TapeShellKind(),
                'TapeFormulation' => new \PHPExiftool\Driver\Tag\MXF\TapeFormulation(),
                'TapeCapacity' => new \PHPExiftool\Driver\Tag\MXF\TapeCapacity(),
                'TapeManufacturer' => new \PHPExiftool\Driver\Tag\MXF\TapeManufacturer(),
                'TapeStock' => new \PHPExiftool\Driver\Tag\MXF\TapeStock(),
                'TapeBatchNumber' => new \PHPExiftool\Driver\Tag\MXF\TapeBatchNumber(),
                'PerforationsPerFrame' => new \PHPExiftool\Driver\Tag\MXF\PerforationsPerFrame(),
                'FilmBatchNumber' => new \PHPExiftool\Driver\Tag\MXF\FilmBatchNumber(),
                'FilmGauge' => new \PHPExiftool\Driver\Tag\MXF\FilmGauge(),
                'EdgeCodeFilmGauge' => new \PHPExiftool\Driver\Tag\MXF\EdgeCodeFilmGauge(),
                'ExposedAspectRatio' => new \PHPExiftool\Driver\Tag\MXF\ExposedAspectRatio(),
                'ImageAlignmentOffset' => new \PHPExiftool\Driver\Tag\MXF\ImageAlignmentOffset(),
                'ImageStartOffset' => new \PHPExiftool\Driver\Tag\MXF\ImageStartOffset(),
                'ImageEndOffset' => new \PHPExiftool\Driver\Tag\MXF\ImageEndOffset(),
                'PaddingBits' => new \PHPExiftool\Driver\Tag\MXF\PaddingBits(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\MXF\FocalLength(),
                'SensorSize' => new \PHPExiftool\Driver\Tag\MXF\SensorSize(),
                'FNumber' => new \PHPExiftool\Driver\Tag\MXF\FNumber(),
                'SensorTypeCode' => new \PHPExiftool\Driver\Tag\MXF\SensorTypeCode(),
                'FieldOfViewHorizontal' => new \PHPExiftool\Driver\Tag\MXF\FieldOfViewHorizontal(),
                'AnamorphicLensCharacteristic' => new \PHPExiftool\Driver\Tag\MXF\AnamorphicLensCharacteristic(),
                'UniformDataFlag' => new \PHPExiftool\Driver\Tag\MXF\UniformDataFlag(),
                'JPEGTableID' => new \PHPExiftool\Driver\Tag\MXF\JPEGTableID(),
                'AlphaTransparency' => new \PHPExiftool\Driver\Tag\MXF\AlphaTransparency(),
                'GenerationID' => new \PHPExiftool\Driver\Tag\MXF\GenerationID(),
                'ApplicationSupplierName' => new \PHPExiftool\Driver\Tag\MXF\ApplicationSupplierName(),
                'ApplicationName' => new \PHPExiftool\Driver\Tag\MXF\ApplicationName(),
                'ApplicationVersionNumber' => new \PHPExiftool\Driver\Tag\MXF\ApplicationVersionNumber(),
                'ApplicationVersionString' => new \PHPExiftool\Driver\Tag\MXF\ApplicationVersionString(),
                'ApplicationPlatform' => new \PHPExiftool\Driver\Tag\MXF\ApplicationPlatform(),
                'ApplicationProductID' => new \PHPExiftool\Driver\Tag\MXF\ApplicationProductID(),
                'LinkedGenerationID' => new \PHPExiftool\Driver\Tag\MXF\LinkedGenerationID(),
                'ContainerVersion' => new \PHPExiftool\Driver\Tag\MXF\ContainerVersion(),
                'ToolkitVersion' => new \PHPExiftool\Driver\Tag\MXF\ToolkitVersion(),
                'Plug-InCategoryID' => new \PHPExiftool\Driver\Tag\MXF\PlugInCategoryID(),
                'Plug-InPlatformID' => new \PHPExiftool\Driver\Tag\MXF\PlugInPlatformID(),
                'MinimumSupportedPlatformVersion' => new \PHPExiftool\Driver\Tag\MXF\MinimumSupportedPlatformVersion(),
                'MaximumSupportedPlatformVersion' => new \PHPExiftool\Driver\Tag\MXF\MaximumSupportedPlatformVersion(),
                'Plug-InEngineID' => new \PHPExiftool\Driver\Tag\MXF\PlugInEngineID(),
                'MinimumSupportedEngineVersion' => new \PHPExiftool\Driver\Tag\MXF\MinimumSupportedEngineVersion(),
                'MaximumSupportedEngineVersion' => new \PHPExiftool\Driver\Tag\MXF\MaximumSupportedEngineVersion(),
                'Plug-InAPIID' => new \PHPExiftool\Driver\Tag\MXF\PlugInAPIID(),
                'MinimumAPIVersion' => new \PHPExiftool\Driver\Tag\MXF\MinimumAPIVersion(),
                'MaximumAPIVersion' => new \PHPExiftool\Driver\Tag\MXF\MaximumAPIVersion(),
                'Software-OnlySupportFlag' => new \PHPExiftool\Driver\Tag\MXF\SoftwareOnlySupportFlag(),
                'HardwareAcceleratorFlag' => new \PHPExiftool\Driver\Tag\MXF\HardwareAcceleratorFlag(),
                'Plug-InLocatorSet' => new \PHPExiftool\Driver\Tag\MXF\PlugInLocatorSet(),
                'AuthenticationFlag' => new \PHPExiftool\Driver\Tag\MXF\AuthenticationFlag(),
                'AssociatedMetadataDefinition' => new \PHPExiftool\Driver\Tag\MXF\AssociatedMetadataDefinition(),
                'EventTrackEditRate' => new \PHPExiftool\Driver\Tag\MXF\EventTrackEditRate(),
                'DefaultFadeEditRate' => new \PHPExiftool\Driver\Tag\MXF\DefaultFadeEditRate(),
                'EditingEventComment' => new \PHPExiftool\Driver\Tag\MXF\EditingEventComment(),
                'EditRate' => new \PHPExiftool\Driver\Tag\MXF\EditRate(),
                'OperationDefinitionID' => new \PHPExiftool\Driver\Tag\MXF\OperationDefinitionID(),
                'Value' => new \PHPExiftool\Driver\Tag\MXF\Value(),
                'EditHint' => new \PHPExiftool\Driver\Tag\MXF\EditHint(),
                'OperationDataDefinition' => new \PHPExiftool\Driver\Tag\MXF\OperationDataDefinition(),
                'OperationCategory' => new \PHPExiftool\Driver\Tag\MXF\OperationCategory(),
                'DisplayUnits' => new \PHPExiftool\Driver\Tag\MXF\DisplayUnits(),
                'BypassOverride' => new \PHPExiftool\Driver\Tag\MXF\BypassOverride(),
                'TimepointValue' => new \PHPExiftool\Driver\Tag\MXF\TimepointValue(),
                'BeginAnchor' => new \PHPExiftool\Driver\Tag\MXF\BeginAnchor(),
                'EndAnchor' => new \PHPExiftool\Driver\Tag\MXF\EndAnchor(),
                'FilmToVideoTransferDirection' => new \PHPExiftool\Driver\Tag\MXF\FilmToVideoTransferDirection(),
                'FilmToVideoTransferKind' => new \PHPExiftool\Driver\Tag\MXF\FilmToVideoTransferKind(),
                'FilmToVideoTransferPhase' => new \PHPExiftool\Driver\Tag\MXF\FilmToVideoTransferPhase(),
                'TeletextSubtitlesFlag' => new \PHPExiftool\Driver\Tag\MXF\TeletextSubtitlesFlag(),
                'SubtitleDatafileFlag' => new \PHPExiftool\Driver\Tag\MXF\SubtitleDatafileFlag(),
                'ClosedCaptionSubtitlesFlag' => new \PHPExiftool\Driver\Tag\MXF\ClosedCaptionSubtitlesFlag(),
                'SampleIndex' => new \PHPExiftool\Driver\Tag\MXF\SampleIndex(),
                'SourcePackageID' => new \PHPExiftool\Driver\Tag\MXF\SourcePackageID(),
                'SourceTrackID' => new \PHPExiftool\Driver\Tag\MXF\SourceTrackID(),
                'RelativeScope' => new \PHPExiftool\Driver\Tag\MXF\RelativeScope(),
                'RelativeTrack' => new \PHPExiftool\Driver\Tag\MXF\RelativeTrack(),
                'ObjectClass' => new \PHPExiftool\Driver\Tag\MXF\ObjectClass(),
                'EssenceContainerFormat' => new \PHPExiftool\Driver\Tag\MXF\EssenceContainerFormat(),
                'CodecDefinition' => new \PHPExiftool\Driver\Tag\MXF\CodecDefinition(),
                'ParameterDefinition' => new \PHPExiftool\Driver\Tag\MXF\ParameterDefinition(),
                'Interpolation' => new \PHPExiftool\Driver\Tag\MXF\Interpolation(),
                'ParameterDataType' => new \PHPExiftool\Driver\Tag\MXF\ParameterDataType(),
                'CodecEssenceDescriptor' => new \PHPExiftool\Driver\Tag\MXF\CodecEssenceDescriptor(),
                'ContentStorage' => new \PHPExiftool\Driver\Tag\MXF\ContentStorage(),
                'Dictionary' => new \PHPExiftool\Driver\Tag\MXF\Dictionary(),
                'EssenceDescription' => new \PHPExiftool\Driver\Tag\MXF\EssenceDescription(),
                'Sequence' => new \PHPExiftool\Driver\Tag\MXF\Sequence(),
                'TransitionEffect' => new \PHPExiftool\Driver\Tag\MXF\TransitionEffect(),
                'EffectRendering' => new \PHPExiftool\Driver\Tag\MXF\EffectRendering(),
                'InputSegment' => new \PHPExiftool\Driver\Tag\MXF\InputSegment(),
                'StillFrame' => new \PHPExiftool\Driver\Tag\MXF\StillFrame(),
                'Selected' => new \PHPExiftool\Driver\Tag\MXF\Selected(),
                'Annotation' => new \PHPExiftool\Driver\Tag\MXF\Annotation(),
                'ManufacturerInformationObject' => new \PHPExiftool\Driver\Tag\MXF\ManufacturerInformationObject(),
                'CodecEssenceKinds' => new \PHPExiftool\Driver\Tag\MXF\CodecEssenceKinds(),
                'OperationParameters' => new \PHPExiftool\Driver\Tag\MXF\OperationParameters(),
                'DegradedEffects' => new \PHPExiftool\Driver\Tag\MXF\DegradedEffects(),
                'Packages' => new \PHPExiftool\Driver\Tag\MXF\Packages(),
                'EssenceData' => new \PHPExiftool\Driver\Tag\MXF\EssenceData(),
                'OperationDefinitions' => new \PHPExiftool\Driver\Tag\MXF\OperationDefinitions(),
                'ParameterDefinitions' => new \PHPExiftool\Driver\Tag\MXF\ParameterDefinitions(),
                'DataDefinitions' => new \PHPExiftool\Driver\Tag\MXF\DataDefinitions(),
                'Plug-InDefinitions' => new \PHPExiftool\Driver\Tag\MXF\PlugInDefinitions(),
                'CodecDefinitions' => new \PHPExiftool\Driver\Tag\MXF\CodecDefinitions(),
                'ContainerDefinitions' => new \PHPExiftool\Driver\Tag\MXF\ContainerDefinitions(),
                'InterpolationDefinitions' => new \PHPExiftool\Driver\Tag\MXF\InterpolationDefinitions(),
                'AvailableRepresentations' => new \PHPExiftool\Driver\Tag\MXF\AvailableRepresentations(),
                'InputSegments' => new \PHPExiftool\Driver\Tag\MXF\InputSegments(),
                'EssenceLocators' => new \PHPExiftool\Driver\Tag\MXF\EssenceLocators(),
                'IdentificationList' => new \PHPExiftool\Driver\Tag\MXF\IdentificationList(),
                'Tracks' => new \PHPExiftool\Driver\Tag\MXF\Tracks(),
                'ControlPointList' => new \PHPExiftool\Driver\Tag\MXF\ControlPointList(),
                'PackageTracks' => new \PHPExiftool\Driver\Tag\MXF\PackageTracks(),
                'Alternates' => new \PHPExiftool\Driver\Tag\MXF\Alternates(),
                'ComponentsInSequence' => new \PHPExiftool\Driver\Tag\MXF\ComponentsInSequence(),
                'Parameters' => new \PHPExiftool\Driver\Tag\MXF\Parameters(),
                'LinkedPackageID' => new \PHPExiftool\Driver\Tag\MXF\LinkedPackageID(),
                'ParentClass' => new \PHPExiftool\Driver\Tag\MXF\ParentClass(),
                'Properties' => new \PHPExiftool\Driver\Tag\MXF\Properties(),
                'IsConcrete' => new \PHPExiftool\Driver\Tag\MXF\IsConcrete(),
                'PropertyType' => new \PHPExiftool\Driver\Tag\MXF\PropertyType(),
                'LocalID' => new \PHPExiftool\Driver\Tag\MXF\LocalID(),
                'IsUniqueIdentifier' => new \PHPExiftool\Driver\Tag\MXF\IsUniqueIdentifier(),
                'ClassDefinitions' => new \PHPExiftool\Driver\Tag\MXF\ClassDefinitions(),
                'TypeDefinitions' => new \PHPExiftool\Driver\Tag\MXF\TypeDefinitions(),
                'TargetClassOfStrongReference' => new \PHPExiftool\Driver\Tag\MXF\TargetClassOfStrongReference(),
                'TargetClassOfWeakReference' => new \PHPExiftool\Driver\Tag\MXF\TargetClassOfWeakReference(),
                'EnumerationUnderlyingIntegerType' => new \PHPExiftool\Driver\Tag\MXF\EnumerationUnderlyingIntegerType(),
                'FixedArrayElementType' => new \PHPExiftool\Driver\Tag\MXF\FixedArrayElementType(),
                'VariableArrayElementType' => new \PHPExiftool\Driver\Tag\MXF\VariableArrayElementType(),
                'SetElementType' => new \PHPExiftool\Driver\Tag\MXF\SetElementType(),
                'StringElementType' => new \PHPExiftool\Driver\Tag\MXF\StringElementType(),
                'StreamElementType' => new \PHPExiftool\Driver\Tag\MXF\StreamElementType(),
                'MemberTypes' => new \PHPExiftool\Driver\Tag\MXF\MemberTypes(),
                'RenamedType' => new \PHPExiftool\Driver\Tag\MXF\RenamedType(),
                'DictionaryIdentifier' => new \PHPExiftool\Driver\Tag\MXF\DictionaryIdentifier(),
                'DictionaryDescription' => new \PHPExiftool\Driver\Tag\MXF\DictionaryDescription(),
                'BlockContinuityCount' => new \PHPExiftool\Driver\Tag\MXF\BlockContinuityCount(),
                'StreamPositionIndicator' => new \PHPExiftool\Driver\Tag\MXF\StreamPositionIndicator(),
                'Origin' => new \PHPExiftool\Driver\Tag\MXF\Origin(),
                'StartTimecode' => new \PHPExiftool\Driver\Tag\MXF\StartTimecode(),
                'CutPoint' => new \PHPExiftool\Driver\Tag\MXF\CutPoint(),
                'EventStart' => new \PHPExiftool\Driver\Tag\MXF\EventStart(),
                'ControlPointTime' => new \PHPExiftool\Driver\Tag\MXF\ControlPointTime(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\MXF\CreateDate(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\MXF\ModifyDate(),
                'ContainerLastModifyDate' => new \PHPExiftool\Driver\Tag\MXF\ContainerLastModifyDate(),
                'PackageLastModifyDate' => new \PHPExiftool\Driver\Tag\MXF\PackageLastModifyDate(),
                'Duration' => new \PHPExiftool\Driver\Tag\MXF\Duration(),
                'DefaultFadeDuration' => new \PHPExiftool\Driver\Tag\MXF\DefaultFadeDuration(),
                'Fade-InDuration' => new \PHPExiftool\Driver\Tag\MXF\FadeInDuration(),
                'Fade-OutDuration' => new \PHPExiftool\Driver\Tag\MXF\FadeOutDuration(),
                'TapeFormat' => new \PHPExiftool\Driver\Tag\MXF\TapeFormat(),
                'GlobalNumber' => new \PHPExiftool\Driver\Tag\MXF\GlobalNumber(),
                'DeviceIDKind' => new \PHPExiftool\Driver\Tag\MXF\DeviceIDKind(),
                'DeviceKind' => new \PHPExiftool\Driver\Tag\MXF\DeviceKind(),
                'DeviceKindCode' => new \PHPExiftool\Driver\Tag\MXF\DeviceKindCode(),
                'PlatformDesignation' => new \PHPExiftool\Driver\Tag\MXF\PlatformDesignation(),
                'PlatformModel' => new \PHPExiftool\Driver\Tag\MXF\PlatformModel(),
                'PlatformSerialNumber' => new \PHPExiftool\Driver\Tag\MXF\PlatformSerialNumber(),
                'LocalTargetID' => new \PHPExiftool\Driver\Tag\MXF\LocalTargetID(),
                'MagneticDiskNumber' => new \PHPExiftool\Driver\Tag\MXF\MagneticDiskNumber(),
                'OpticalDiscNumber' => new \PHPExiftool\Driver\Tag\MXF\OpticalDiscNumber(),
                'StreamID' => new \PHPExiftool\Driver\Tag\MXF\StreamID(),
                'TransportStreamID' => new \PHPExiftool\Driver\Tag\MXF\TransportStreamID(),
                'OrganizationalProgramNumber' => new \PHPExiftool\Driver\Tag\MXF\OrganizationalProgramNumber(),
                'ItemDesignatorID' => new \PHPExiftool\Driver\Tag\MXF\ItemDesignatorID(),
                'MissionID' => new \PHPExiftool\Driver\Tag\MXF\MissionID(),
                'RecordingLabelName' => new \PHPExiftool\Driver\Tag\MXF\RecordingLabelName(),
                'CollectionName' => new \PHPExiftool\Driver\Tag\MXF\CollectionName(),
                'OriginCode' => new \PHPExiftool\Driver\Tag\MXF\OriginCode(),
                'MainCatalogNumber' => new \PHPExiftool\Driver\Tag\MXF\MainCatalogNumber(),
                'CatalogPrefixNumber' => new \PHPExiftool\Driver\Tag\MXF\CatalogPrefixNumber(),
                'SideNumber' => new \PHPExiftool\Driver\Tag\MXF\SideNumber(),
                'RecordedTrackNumber' => new \PHPExiftool\Driver\Tag\MXF\RecordedTrackNumber(),
                'SeriesinaSeriesGroupCount' => new \PHPExiftool\Driver\Tag\MXF\SeriesinaSeriesGroupCount(),
                'ProgrammingGroupKind' => new \PHPExiftool\Driver\Tag\MXF\ProgrammingGroupKind(),
                'PurchasingOrganizationName' => new \PHPExiftool\Driver\Tag\MXF\PurchasingOrganizationName(),
                'SalesContractNumber' => new \PHPExiftool\Driver\Tag\MXF\SalesContractNumber(),
                'PurchasingDepartment' => new \PHPExiftool\Driver\Tag\MXF\PurchasingDepartment(),
                'ContractType' => new \PHPExiftool\Driver\Tag\MXF\ContractType(),
                'ContractTypeCode' => new \PHPExiftool\Driver\Tag\MXF\ContractTypeCode(),
                'ContractClauseDescription' => new \PHPExiftool\Driver\Tag\MXF\ContractClauseDescription(),
                'ContractLineCode' => new \PHPExiftool\Driver\Tag\MXF\ContractLineCode(),
                'ContractLineName' => new \PHPExiftool\Driver\Tag\MXF\ContractLineName(),
                'ContractTermsOfBusiness' => new \PHPExiftool\Driver\Tag\MXF\ContractTermsOfBusiness(),
                'ContractInstallmentPercentage' => new \PHPExiftool\Driver\Tag\MXF\ContractInstallmentPercentage(),
                'Jurisdiction' => new \PHPExiftool\Driver\Tag\MXF\Jurisdiction(),
                'RightsConditionDescription' => new \PHPExiftool\Driver\Tag\MXF\RightsConditionDescription(),
                'CurrencyName' => new \PHPExiftool\Driver\Tag\MXF\CurrencyName(),
                'TotalPayment' => new \PHPExiftool\Driver\Tag\MXF\TotalPayment(),
                'PayeeAccountName' => new \PHPExiftool\Driver\Tag\MXF\PayeeAccountName(),
                'PayeeAccountNumber' => new \PHPExiftool\Driver\Tag\MXF\PayeeAccountNumber(),
                'PayeeAccountSortCode' => new \PHPExiftool\Driver\Tag\MXF\PayeeAccountSortCode(),
                'TotalIncome' => new \PHPExiftool\Driver\Tag\MXF\TotalIncome(),
                'PayerAccountName' => new \PHPExiftool\Driver\Tag\MXF\PayerAccountName(),
                'PayerAccountNumber' => new \PHPExiftool\Driver\Tag\MXF\PayerAccountNumber(),
                'PayerAccountSortCode' => new \PHPExiftool\Driver\Tag\MXF\PayerAccountSortCode(),
                'SecurityClassification' => new \PHPExiftool\Driver\Tag\MXF\SecurityClassification(),
                'SecurityClassificationCaveats' => new \PHPExiftool\Driver\Tag\MXF\SecurityClassificationCaveats(),
                'ClassifiedBy' => new \PHPExiftool\Driver\Tag\MXF\ClassifiedBy(),
                'ClassificationReason' => new \PHPExiftool\Driver\Tag\MXF\ClassificationReason(),
                'DeclassificationDate' => new \PHPExiftool\Driver\Tag\MXF\DeclassificationDate(),
                'DerivedFrom' => new \PHPExiftool\Driver\Tag\MXF\DerivedFrom(),
                'ClassificationComment' => new \PHPExiftool\Driver\Tag\MXF\ClassificationComment(),
                'ClassificationAndMarkingSystem' => new \PHPExiftool\Driver\Tag\MXF\ClassificationAndMarkingSystem(),
                'BroadcastServiceName' => new \PHPExiftool\Driver\Tag\MXF\BroadcastServiceName(),
                'BroadcastMediumCode' => new \PHPExiftool\Driver\Tag\MXF\BroadcastMediumCode(),
                'JobFunctionCode' => new \PHPExiftool\Driver\Tag\MXF\JobFunctionCode(),
                'JobTitle' => new \PHPExiftool\Driver\Tag\MXF\JobTitle(),
                'PersonDescription' => new \PHPExiftool\Driver\Tag\MXF\PersonDescription(),
                'RegionCode' => new \PHPExiftool\Driver\Tag\MXF\RegionCode(),
                'RegionName' => new \PHPExiftool\Driver\Tag\MXF\RegionName(),
                'LanguageName' => new \PHPExiftool\Driver\Tag\MXF\LanguageName(),
                'TerminatingFillerData' => new \PHPExiftool\Driver\Tag\MXF\TerminatingFillerData(),
                'TimingBiasCorrection' => new \PHPExiftool\Driver\Tag\MXF\TimingBiasCorrection(),
                'TimingBiasCorrectionDescription' => new \PHPExiftool\Driver\Tag\MXF\TimingBiasCorrectionDescription(),
                'ProgramMaterialClassificationCode' => new \PHPExiftool\Driver\Tag\MXF\ProgramMaterialClassificationCode(),
                'SubjectName' => new \PHPExiftool\Driver\Tag\MXF\SubjectName(),
                'KeyFrameSampleCount' => new \PHPExiftool\Driver\Tag\MXF\KeyFrameSampleCount(),
                'IntentDescriptor' => new \PHPExiftool\Driver\Tag\MXF\IntentDescriptor(),
                'TextualDescriptionKind' => new \PHPExiftool\Driver\Tag\MXF\TextualDescriptionKind(),
                'FestivalName' => new \PHPExiftool\Driver\Tag\MXF\FestivalName(),
                'ObjectDescriptionCode' => new \PHPExiftool\Driver\Tag\MXF\ObjectDescriptionCode(),
                'DescriptionKind' => new \PHPExiftool\Driver\Tag\MXF\DescriptionKind(),
                'DescriptiveComment' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveComment(),
                'ContextDescription' => new \PHPExiftool\Driver\Tag\MXF\ContextDescription(),
                'ObjectIdentificationConfidence' => new \PHPExiftool\Driver\Tag\MXF\ObjectIdentificationConfidence(),
                'ObjectHorizontalAverageDimension' => new \PHPExiftool\Driver\Tag\MXF\ObjectHorizontalAverageDimension(),
                'ObjectVerticalAverageDimension' => new \PHPExiftool\Driver\Tag\MXF\ObjectVerticalAverageDimension(),
                'ObjectAreaDimension' => new \PHPExiftool\Driver\Tag\MXF\ObjectAreaDimension(),
                'HorizontalActionSafePercentage' => new \PHPExiftool\Driver\Tag\MXF\HorizontalActionSafePercentage(),
                'VerticalActionSafePercentage' => new \PHPExiftool\Driver\Tag\MXF\VerticalActionSafePercentage(),
                'HorizontalGraphicsSafePercentage' => new \PHPExiftool\Driver\Tag\MXF\HorizontalGraphicsSafePercentage(),
                'VerticalGraphicsSafePercentage' => new \PHPExiftool\Driver\Tag\MXF\VerticalGraphicsSafePercentage(),
                'PerceivedDisplayFormatName' => new \PHPExiftool\Driver\Tag\MXF\PerceivedDisplayFormatName(),
                'PerceivedDisplayFormatCode' => new \PHPExiftool\Driver\Tag\MXF\PerceivedDisplayFormatCode(),
                'VideoColorKind' => new \PHPExiftool\Driver\Tag\MXF\VideoColorKind(),
                'PictureDisplayRate' => new \PHPExiftool\Driver\Tag\MXF\PictureDisplayRate(),
                'VideoAverageBitrate' => new \PHPExiftool\Driver\Tag\MXF\VideoAverageBitrate(),
                'VideoFixedBitrate' => new \PHPExiftool\Driver\Tag\MXF\VideoFixedBitrate(),
                'DigitalVideoFileFormat' => new \PHPExiftool\Driver\Tag\MXF\DigitalVideoFileFormat(),
                'CodingLawName' => new \PHPExiftool\Driver\Tag\MXF\CodingLawName(),
                'AudioCodingSchemeCode' => new \PHPExiftool\Driver\Tag\MXF\AudioCodingSchemeCode(),
                'AudioCodingSchemeName' => new \PHPExiftool\Driver\Tag\MXF\AudioCodingSchemeName(),
                'DigitalEncodingBitrate' => new \PHPExiftool\Driver\Tag\MXF\DigitalEncodingBitrate(),
                'DataEssenceCodingID' => new \PHPExiftool\Driver\Tag\MXF\DataEssenceCodingID(),
                'StorageKind' => new \PHPExiftool\Driver\Tag\MXF\StorageKind(),
                'StorageKindCode' => new \PHPExiftool\Driver\Tag\MXF\StorageKindCode(),
                'TapePartitionCapacity' => new \PHPExiftool\Driver\Tag\MXF\TapePartitionCapacity(),
                'DiscPartitionCapacity' => new \PHPExiftool\Driver\Tag\MXF\DiscPartitionCapacity(),
                'FieldOfViewVertical' => new \PHPExiftool\Driver\Tag\MXF\FieldOfViewVertical(),
                'SystemNameOrNumber' => new \PHPExiftool\Driver\Tag\MXF\SystemNameOrNumber(),
                'LogoFlag' => new \PHPExiftool\Driver\Tag\MXF\LogoFlag(),
                'GraphicKind' => new \PHPExiftool\Driver\Tag\MXF\GraphicKind(),
                'GraphicUsageKind' => new \PHPExiftool\Driver\Tag\MXF\GraphicUsageKind(),
                'SignatureTuneFlag' => new \PHPExiftool\Driver\Tag\MXF\SignatureTuneFlag(),
                'BackgroundMusicFlag' => new \PHPExiftool\Driver\Tag\MXF\BackgroundMusicFlag(),
                'ProductionScriptReference' => new \PHPExiftool\Driver\Tag\MXF\ProductionScriptReference(),
                'TranscriptReference' => new \PHPExiftool\Driver\Tag\MXF\TranscriptReference(),
                'HorizontalDatum' => new \PHPExiftool\Driver\Tag\MXF\HorizontalDatum(),
                'VerticalDatum' => new \PHPExiftool\Driver\Tag\MXF\VerticalDatum(),
                'CornerLatitudePoint1' => new \PHPExiftool\Driver\Tag\MXF\CornerLatitudePoint1(),
                'CornerLatitudePoint2' => new \PHPExiftool\Driver\Tag\MXF\CornerLatitudePoint2(),
                'CornerLatitudePoint3' => new \PHPExiftool\Driver\Tag\MXF\CornerLatitudePoint3(),
                'CornerLatitudePoint4' => new \PHPExiftool\Driver\Tag\MXF\CornerLatitudePoint4(),
                'CornerLongitudePoint1' => new \PHPExiftool\Driver\Tag\MXF\CornerLongitudePoint1(),
                'CornerLongitudePoint2' => new \PHPExiftool\Driver\Tag\MXF\CornerLongitudePoint2(),
                'CornerLongitudePoint3' => new \PHPExiftool\Driver\Tag\MXF\CornerLongitudePoint3(),
                'CornerLongitudePoint4' => new \PHPExiftool\Driver\Tag\MXF\CornerLongitudePoint4(),
                'SubjectDistance' => new \PHPExiftool\Driver\Tag\MXF\SubjectDistance(),
                'ObjectCountryCodeMethod' => new \PHPExiftool\Driver\Tag\MXF\ObjectCountryCodeMethod(),
                'CountryCodeMethod' => new \PHPExiftool\Driver\Tag\MXF\CountryCodeMethod(),
                'Non-USClassifyingCountryCode' => new \PHPExiftool\Driver\Tag\MXF\NonUSClassifyingCountryCode(),
                'ReleasableCountryCode' => new \PHPExiftool\Driver\Tag\MXF\ReleasableCountryCode(),
                'ObjectRegionName' => new \PHPExiftool\Driver\Tag\MXF\ObjectRegionName(),
                'ShootingRegionName' => new \PHPExiftool\Driver\Tag\MXF\ShootingRegionName(),
                'SettingRegionName' => new \PHPExiftool\Driver\Tag\MXF\SettingRegionName(),
                'CopyrightLicenseRegionName' => new \PHPExiftool\Driver\Tag\MXF\CopyrightLicenseRegionName(),
                'IntellectualPropertyLicenseRegionName' => new \PHPExiftool\Driver\Tag\MXF\IntellectualPropertyLicenseRegionName(),
                'POSIXMicroseconds' => new \PHPExiftool\Driver\Tag\MXF\POSIXMicroseconds(),
                'EventElapsedTimeToStart' => new \PHPExiftool\Driver\Tag\MXF\EventElapsedTimeToStart(),
                'EventElapsedTimeToEnd' => new \PHPExiftool\Driver\Tag\MXF\EventElapsedTimeToEnd(),
                'OrganizationIDKind' => new \PHPExiftool\Driver\Tag\MXF\OrganizationIDKind(),
                'SMPTEUL' => new \PHPExiftool\Driver\Tag\MXF\SMPTEUL(),
                'EssenceContainerArray' => new \PHPExiftool\Driver\Tag\MXF\EssenceContainerArray(),
                'EssenceStreamID' => new \PHPExiftool\Driver\Tag\MXF\EssenceStreamID(),
                'IndexStreamID' => new \PHPExiftool\Driver\Tag\MXF\IndexStreamID(),
                'WorkingTitle' => new \PHPExiftool\Driver\Tag\MXF\WorkingTitle(),
                'OriginalTitle' => new \PHPExiftool\Driver\Tag\MXF\OriginalTitle(),
                'ClipNumber' => new \PHPExiftool\Driver\Tag\MXF\ClipNumber(),
                'DescriptiveMetadataTrackIDs' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataTrackIDs(),
                'IdentifierKind' => new \PHPExiftool\Driver\Tag\MXF\IdentifierKind(),
                'IdentifierValue' => new \PHPExiftool\Driver\Tag\MXF\IdentifierValue(),
                'OrganizationCode' => new \PHPExiftool\Driver\Tag\MXF\OrganizationCode(),
                'SupplierIdentificationKind' => new \PHPExiftool\Driver\Tag\MXF\SupplierIdentificationKind(),
                'SupplierIdentificationValue' => new \PHPExiftool\Driver\Tag\MXF\SupplierIdentificationValue(),
                'SupplierAccountNumber' => new \PHPExiftool\Driver\Tag\MXF\SupplierAccountNumber(),
                'SupplierAccountName' => new \PHPExiftool\Driver\Tag\MXF\SupplierAccountName(),
                'EpisodeStartNumber' => new \PHPExiftool\Driver\Tag\MXF\EpisodeStartNumber(),
                'EpisodeEndNumber' => new \PHPExiftool\Driver\Tag\MXF\EpisodeEndNumber(),
                'PurchaserIdentificationKind' => new \PHPExiftool\Driver\Tag\MXF\PurchaserIdentificationKind(),
                'PurchaserIdentificationValue' => new \PHPExiftool\Driver\Tag\MXF\PurchaserIdentificationValue(),
                'PurchaserAccountNumber' => new \PHPExiftool\Driver\Tag\MXF\PurchaserAccountNumber(),
                'PurchaserAccountName' => new \PHPExiftool\Driver\Tag\MXF\PurchaserAccountName(),
                'TotalCurrencyAmount' => new \PHPExiftool\Driver\Tag\MXF\TotalCurrencyAmount(),
                'InstallmentNumber' => new \PHPExiftool\Driver\Tag\MXF\InstallmentNumber(),
                'IdentifierIssuingAuthority' => new \PHPExiftool\Driver\Tag\MXF\IdentifierIssuingAuthority(),
                'PublishingOrganizationName' => new \PHPExiftool\Driver\Tag\MXF\PublishingOrganizationName(),
                'PublishingServiceName' => new \PHPExiftool\Driver\Tag\MXF\PublishingServiceName(),
                'PublishingMediumName' => new \PHPExiftool\Driver\Tag\MXF\PublishingMediumName(),
                'PublishingRegionName' => new \PHPExiftool\Driver\Tag\MXF\PublishingRegionName(),
                'OtherGivenNames' => new \PHPExiftool\Driver\Tag\MXF\OtherGivenNames(),
                'AlternateName' => new \PHPExiftool\Driver\Tag\MXF\AlternateName(),
                'ISO639TextLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\ISO639TextLanguageCode(),
                'ISO639CaptionsLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\ISO639CaptionsLanguageCode(),
                'PrimarySpokenLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\PrimarySpokenLanguageCode(),
                'SecondarySpokenLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\SecondarySpokenLanguageCode(),
                'PrimaryOriginalLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\PrimaryOriginalLanguageCode(),
                'SecondaryOriginalLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\SecondaryOriginalLanguageCode(),
                'MajorVersion' => new \PHPExiftool\Driver\Tag\MXF\MajorVersion(),
                'MinorVersion' => new \PHPExiftool\Driver\Tag\MXF\MinorVersion(),
                'SectorSize' => new \PHPExiftool\Driver\Tag\MXF\SectorSize(),
                'ElementLength' => new \PHPExiftool\Driver\Tag\MXF\ElementLength(),
                'KeypointKind' => new \PHPExiftool\Driver\Tag\MXF\KeypointKind(),
                'KeypointValue' => new \PHPExiftool\Driver\Tag\MXF\KeypointValue(),
                'AwardName' => new \PHPExiftool\Driver\Tag\MXF\AwardName(),
                'AwardCategory' => new \PHPExiftool\Driver\Tag\MXF\AwardCategory(),
                'SlateInformation' => new \PHPExiftool\Driver\Tag\MXF\SlateInformation(),
                'LockedIndicator' => new \PHPExiftool\Driver\Tag\MXF\LockedIndicator(),
                'BitsPerAudioSample' => new \PHPExiftool\Driver\Tag\MXF\BitsPerAudioSample(),
                'CaptionKind' => new \PHPExiftool\Driver\Tag\MXF\CaptionKind(),
                'SliceCount' => new \PHPExiftool\Driver\Tag\MXF\SliceCount(),
                'SliceNumber' => new \PHPExiftool\Driver\Tag\MXF\SliceNumber(),
                'ElementDelta' => new \PHPExiftool\Driver\Tag\MXF\ElementDelta(),
                'PositionTableIndexing' => new \PHPExiftool\Driver\Tag\MXF\PositionTableIndexing(),
                'SliceOffsetList' => new \PHPExiftool\Driver\Tag\MXF\SliceOffsetList(),
                'PosTableArray' => new \PHPExiftool\Driver\Tag\MXF\PosTableArray(),
                'StreamOffset' => new \PHPExiftool\Driver\Tag\MXF\StreamOffset(),
                'EditUnitFlags' => new \PHPExiftool\Driver\Tag\MXF\EditUnitFlags(),
                'TemporalOffset' => new \PHPExiftool\Driver\Tag\MXF\TemporalOffset(),
                'AnchorOffset' => new \PHPExiftool\Driver\Tag\MXF\AnchorOffset(),
                'EditUnitLength' => new \PHPExiftool\Driver\Tag\MXF\EditUnitLength(),
                'HeaderByteCount' => new \PHPExiftool\Driver\Tag\MXF\HeaderByteCount(),
                'IndexByteCount' => new \PHPExiftool\Driver\Tag\MXF\IndexByteCount(),
                'PackLength' => new \PHPExiftool\Driver\Tag\MXF\PackLength(),
                'PrimaryPackage' => new \PHPExiftool\Driver\Tag\MXF\PrimaryPackage(),
                'DescriptiveMetadataSets' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataSets(),
                'DescriptiveMetadataSetReferences' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataSetReferences(),
                'FileDescriptors' => new \PHPExiftool\Driver\Tag\MXF\FileDescriptors(),
                'OffsetToMetadata' => new \PHPExiftool\Driver\Tag\MXF\OffsetToMetadata(),
                'OffsetToIndexTable' => new \PHPExiftool\Driver\Tag\MXF\OffsetToIndexTable(),
                'ByteOffset' => new \PHPExiftool\Driver\Tag\MXF\ByteOffset(),
                'ReversePlay' => new \PHPExiftool\Driver\Tag\MXF\ReversePlay(),
                'FirstNumberInSequence' => new \PHPExiftool\Driver\Tag\MXF\FirstNumberInSequence(),
                'PreviousNumberInSequence' => new \PHPExiftool\Driver\Tag\MXF\PreviousNumberInSequence(),
                'CurrentNumberInSequence' => new \PHPExiftool\Driver\Tag\MXF\CurrentNumberInSequence(),
                'NextNumberInSequence' => new \PHPExiftool\Driver\Tag\MXF\NextNumberInSequence(),
                'LastNumberInSequence' => new \PHPExiftool\Driver\Tag\MXF\LastNumberInSequence(),
                'CentralTelephoneNumber' => new \PHPExiftool\Driver\Tag\MXF\CentralTelephoneNumber(),
                'MobileTelephoneNumber' => new \PHPExiftool\Driver\Tag\MXF\MobileTelephoneNumber(),
                'LocationDescription' => new \PHPExiftool\Driver\Tag\MXF\LocationDescription(),
                'LocationKind' => new \PHPExiftool\Driver\Tag\MXF\LocationKind(),
                'KeyTimePoint' => new \PHPExiftool\Driver\Tag\MXF\KeyTimePoint(),
                'SettingDateTime' => new \PHPExiftool\Driver\Tag\MXF\SettingDateTime(),
                'ContractDateTime' => new \PHPExiftool\Driver\Tag\MXF\ContractDateTime(),
                'RightsStartDateTime' => new \PHPExiftool\Driver\Tag\MXF\RightsStartDateTime(),
                'RightsStopDateTime' => new \PHPExiftool\Driver\Tag\MXF\RightsStopDateTime(),
                'PaymentDueDateTime' => new \PHPExiftool\Driver\Tag\MXF\PaymentDueDateTime(),
                'ClipID' => new \PHPExiftool\Driver\Tag\MXF\ClipID(),
                'DeviceAssetNumber' => new \PHPExiftool\Driver\Tag\MXF\DeviceAssetNumber(),
                'IdentificationUL' => new \PHPExiftool\Driver\Tag\MXF\IdentificationUL(),
                'OperationalPatternUL' => new \PHPExiftool\Driver\Tag\MXF\OperationalPatternUL(),
                'EssenceContainers' => new \PHPExiftool\Driver\Tag\MXF\EssenceContainers(),
                'DescriptiveMetadataSchemes' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataSchemes(),
                'ProjectName' => new \PHPExiftool\Driver\Tag\MXF\ProjectName(),
                'LocalTagValue' => new \PHPExiftool\Driver\Tag\MXF\LocalTagValue(),
                'LocalTagUniqueID' => new \PHPExiftool\Driver\Tag\MXF\LocalTagUniqueID(),
                'BrandMainTitle' => new \PHPExiftool\Driver\Tag\MXF\BrandMainTitle(),
                'BrandOriginalTitle' => new \PHPExiftool\Driver\Tag\MXF\BrandOriginalTitle(),
                'FrameworkTitle' => new \PHPExiftool\Driver\Tag\MXF\FrameworkTitle(),
                'SourceTrackIDs' => new \PHPExiftool\Driver\Tag\MXF\SourceTrackIDs(),
                'ShotTrackIDs' => new \PHPExiftool\Driver\Tag\MXF\ShotTrackIDs(),
                'ProgrammingGroupTitle' => new \PHPExiftool\Driver\Tag\MXF\ProgrammingGroupTitle(),
                'LinkingName' => new \PHPExiftool\Driver\Tag\MXF\LinkingName(),
                'NameSuffix' => new \PHPExiftool\Driver\Tag\MXF\NameSuffix(),
                'FormerFamilyName' => new \PHPExiftool\Driver\Tag\MXF\FormerFamilyName(),
                'Nationality' => new \PHPExiftool\Driver\Tag\MXF\Nationality(),
                'Citizenship' => new \PHPExiftool\Driver\Tag\MXF\Citizenship(),
                'FrameworkTextLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\FrameworkTextLanguageCode(),
                'KAGSize' => new \PHPExiftool\Driver\Tag\MXF\KAGSize(),
                'ReversedByteOrder' => new \PHPExiftool\Driver\Tag\MXF\ReversedByteOrder(),
                'ItemName' => new \PHPExiftool\Driver\Tag\MXF\ItemName(),
                'ItemValue' => new \PHPExiftool\Driver\Tag\MXF\ItemValue(),
                'XMLDocumentText' => new \PHPExiftool\Driver\Tag\MXF\XMLDocumentText(),
                'FrameworkThesaurusName' => new \PHPExiftool\Driver\Tag\MXF\FrameworkThesaurusName(),
                'GroupSynopsis' => new \PHPExiftool\Driver\Tag\MXF\GroupSynopsis(),
                'AnnotationSynopsis' => new \PHPExiftool\Driver\Tag\MXF\AnnotationSynopsis(),
                'AnnotationDescription' => new \PHPExiftool\Driver\Tag\MXF\AnnotationDescription(),
                'ScriptingKind' => new \PHPExiftool\Driver\Tag\MXF\ScriptingKind(),
                'ScriptingText' => new \PHPExiftool\Driver\Tag\MXF\ScriptingText(),
                'ShotDescription' => new \PHPExiftool\Driver\Tag\MXF\ShotDescription(),
                'AnnotationKind' => new \PHPExiftool\Driver\Tag\MXF\AnnotationKind(),
                'RelatedMaterialDescription' => new \PHPExiftool\Driver\Tag\MXF\RelatedMaterialDescription(),
                'ClipKind' => new \PHPExiftool\Driver\Tag\MXF\ClipKind(),
                'DeviceUsageDescription' => new \PHPExiftool\Driver\Tag\MXF\DeviceUsageDescription(),
                'DisplayF2Offset' => new \PHPExiftool\Driver\Tag\MXF\DisplayF2Offset(),
                'StoredF2Offset' => new \PHPExiftool\Driver\Tag\MXF\StoredF2Offset(),
                'ActiveFormatDescriptor' => new \PHPExiftool\Driver\Tag\MXF\ActiveFormatDescriptor(),
                'LineNumber' => new \PHPExiftool\Driver\Tag\MXF\LineNumber(),
                'ScanningDirection' => new \PHPExiftool\Driver\Tag\MXF\ScanningDirection(),
                'ComponentMaximumRef' => new \PHPExiftool\Driver\Tag\MXF\ComponentMaximumRef(),
                'ComponentMinimumRef' => new \PHPExiftool\Driver\Tag\MXF\ComponentMinimumRef(),
                'AlphaMaximumRef' => new \PHPExiftool\Driver\Tag\MXF\AlphaMaximumRef(),
                'AlphaMinimumRef' => new \PHPExiftool\Driver\Tag\MXF\AlphaMinimumRef(),
                'VideoPayloadIdentifier' => new \PHPExiftool\Driver\Tag\MXF\VideoPayloadIdentifier(),
                'VideoPayloadIdentifier2002' => new \PHPExiftool\Driver\Tag\MXF\VideoPayloadIdentifier2002(),
                'SingleSequenceFlag' => new \PHPExiftool\Driver\Tag\MXF\SingleSequenceFlag(),
                'ConstantBPictureFlag' => new \PHPExiftool\Driver\Tag\MXF\ConstantBPictureFlag(),
                'CodedContentScanningKind' => new \PHPExiftool\Driver\Tag\MXF\CodedContentScanningKind(),
                'LowDelayIndicator' => new \PHPExiftool\Driver\Tag\MXF\LowDelayIndicator(),
                'ClosedGOPIndicator' => new \PHPExiftool\Driver\Tag\MXF\ClosedGOPIndicator(),
                'IdenticalGOPIndicator' => new \PHPExiftool\Driver\Tag\MXF\IdenticalGOPIndicator(),
                'MaximumGOPSize' => new \PHPExiftool\Driver\Tag\MXF\MaximumGOPSize(),
                'MaximumBPictureCount' => new \PHPExiftool\Driver\Tag\MXF\MaximumBPictureCount(),
                'ProfileAndLevel' => new \PHPExiftool\Driver\Tag\MXF\ProfileAndLevel(),
                'Bitrate' => new \PHPExiftool\Driver\Tag\MXF\Bitrate(),
                'ChannelCount' => new \PHPExiftool\Driver\Tag\MXF\ChannelCount(),
                'PeakEnvelope' => new \PHPExiftool\Driver\Tag\MXF\PeakEnvelope(),
                'PeakEnvelopeData' => new \PHPExiftool\Driver\Tag\MXF\PeakEnvelopeData(),
                'BlockAlign' => new \PHPExiftool\Driver\Tag\MXF\BlockAlign(),
                'SequenceOffset' => new \PHPExiftool\Driver\Tag\MXF\SequenceOffset(),
                'BlockStartOffset' => new \PHPExiftool\Driver\Tag\MXF\BlockStartOffset(),
                'FileSecurityReport' => new \PHPExiftool\Driver\Tag\MXF\FileSecurityReport(),
                'FileSecurityWave' => new \PHPExiftool\Driver\Tag\MXF\FileSecurityWave(),
                'AverageBytesPerSecond' => new \PHPExiftool\Driver\Tag\MXF\AverageBytesPerSecond(),
                'AuxiliaryBitsMode' => new \PHPExiftool\Driver\Tag\MXF\AuxiliaryBitsMode(),
                'ChannelStatusMode' => new \PHPExiftool\Driver\Tag\MXF\ChannelStatusMode(),
                'FixedChannelStatusData' => new \PHPExiftool\Driver\Tag\MXF\FixedChannelStatusData(),
                'UserDataMode' => new \PHPExiftool\Driver\Tag\MXF\UserDataMode(),
                'FixedUserData' => new \PHPExiftool\Driver\Tag\MXF\FixedUserData(),
                'Emphasis' => new \PHPExiftool\Driver\Tag\MXF\Emphasis(),
                'BextCodingHistory' => new \PHPExiftool\Driver\Tag\MXF\BextCodingHistory(),
                'QltyBasicData' => new \PHPExiftool\Driver\Tag\MXF\QltyBasicData(),
                'QltyStartOfModulation' => new \PHPExiftool\Driver\Tag\MXF\QltyStartOfModulation(),
                'QltyQualityEvent' => new \PHPExiftool\Driver\Tag\MXF\QltyQualityEvent(),
                'QltyEndOfModulation' => new \PHPExiftool\Driver\Tag\MXF\QltyEndOfModulation(),
                'QltyQualityParameter' => new \PHPExiftool\Driver\Tag\MXF\QltyQualityParameter(),
                'QltyOperatorComment' => new \PHPExiftool\Driver\Tag\MXF\QltyOperatorComment(),
                'QltyCueSheet' => new \PHPExiftool\Driver\Tag\MXF\QltyCueSheet(),
                'DialNorm' => new \PHPExiftool\Driver\Tag\MXF\DialNorm(),
                'DataEssenceCoding' => new \PHPExiftool\Driver\Tag\MXF\DataEssenceCoding(),
                'DateTimeRate' => new \PHPExiftool\Driver\Tag\MXF\DateTimeRate(),
                'DateTimeDropFrameFlag' => new \PHPExiftool\Driver\Tag\MXF\DateTimeDropFrameFlag(),
                'DateTimeEmbeddedFlag' => new \PHPExiftool\Driver\Tag\MXF\DateTimeEmbeddedFlag(),
                'DateTimeKind' => new \PHPExiftool\Driver\Tag\MXF\DateTimeKind(),
                'DeltaEntryArray' => new \PHPExiftool\Driver\Tag\MXF\DeltaEntryArray(),
                'PositionTableCount' => new \PHPExiftool\Driver\Tag\MXF\PositionTableCount(),
                'PositionTable' => new \PHPExiftool\Driver\Tag\MXF\PositionTable(),
                'IndexEntryArray' => new \PHPExiftool\Driver\Tag\MXF\IndexEntryArray(),
                'DataDefinition' => new \PHPExiftool\Driver\Tag\MXF\DataDefinition(),
                'GenerationCopyNumber' => new \PHPExiftool\Driver\Tag\MXF\GenerationCopyNumber(),
                'GenerationCloneNumber' => new \PHPExiftool\Driver\Tag\MXF\GenerationCloneNumber(),
                'ThemeMusicFlag' => new \PHPExiftool\Driver\Tag\MXF\ThemeMusicFlag(),
                'InsertMusicFlag' => new \PHPExiftool\Driver\Tag\MXF\InsertMusicFlag(),
                'IndexEditRate' => new \PHPExiftool\Driver\Tag\MXF\IndexEditRate(),
                'LinkedTrackID' => new \PHPExiftool\Driver\Tag\MXF\LinkedTrackID(),
                'DescriptiveMetadataFramework' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataFramework(),
                'GroupSet' => new \PHPExiftool\Driver\Tag\MXF\GroupSet(),
                'BankDetailsSet' => new \PHPExiftool\Driver\Tag\MXF\BankDetailsSet(),
                'ImageFormatSet' => new \PHPExiftool\Driver\Tag\MXF\ImageFormatSet(),
                'ProcessingSet' => new \PHPExiftool\Driver\Tag\MXF\ProcessingSet(),
                'ProjectSet' => new \PHPExiftool\Driver\Tag\MXF\ProjectSet(),
                'ContactsListSet' => new \PHPExiftool\Driver\Tag\MXF\ContactsListSet(),
                'AnnotationCueWordsSet' => new \PHPExiftool\Driver\Tag\MXF\AnnotationCueWordsSet(),
                'ShotCueWordsSet' => new \PHPExiftool\Driver\Tag\MXF\ShotCueWordsSet(),
                'AwardParticipantSets' => new \PHPExiftool\Driver\Tag\MXF\AwardParticipantSets(),
                'ContractParticipantSets' => new \PHPExiftool\Driver\Tag\MXF\ContractParticipantSets(),
                'PersonSets' => new \PHPExiftool\Driver\Tag\MXF\PersonSets(),
                'ParticipantOrganizationSets' => new \PHPExiftool\Driver\Tag\MXF\ParticipantOrganizationSets(),
                'PersonOrganizationSets' => new \PHPExiftool\Driver\Tag\MXF\PersonOrganizationSets(),
                'LocationSets' => new \PHPExiftool\Driver\Tag\MXF\LocationSets(),
                'TitlesSets' => new \PHPExiftool\Driver\Tag\MXF\TitlesSets(),
                'GroupSets' => new \PHPExiftool\Driver\Tag\MXF\GroupSets(),
                'IdentificationSets' => new \PHPExiftool\Driver\Tag\MXF\IdentificationSets(),
                'EpisodicItemSets' => new \PHPExiftool\Driver\Tag\MXF\EpisodicItemSets(),
                'BrandingSets' => new \PHPExiftool\Driver\Tag\MXF\BrandingSets(),
                'EventSets' => new \PHPExiftool\Driver\Tag\MXF\EventSets(),
                'PublicationSets' => new \PHPExiftool\Driver\Tag\MXF\PublicationSets(),
                'AwardSets' => new \PHPExiftool\Driver\Tag\MXF\AwardSets(),
                'CaptionDescriptionSets' => new \PHPExiftool\Driver\Tag\MXF\CaptionDescriptionSets(),
                'AnnotationSets' => new \PHPExiftool\Driver\Tag\MXF\AnnotationSets(),
                'ProductionSettingPeriodSets' => new \PHPExiftool\Driver\Tag\MXF\ProductionSettingPeriodSets(),
                'SceneSettingPeriodSets' => new \PHPExiftool\Driver\Tag\MXF\SceneSettingPeriodSets(),
                'ScriptingSets' => new \PHPExiftool\Driver\Tag\MXF\ScriptingSets(),
                'ClassificationSets' => new \PHPExiftool\Driver\Tag\MXF\ClassificationSets(),
                'SceneShotSets' => new \PHPExiftool\Driver\Tag\MXF\SceneShotSets(),
                'ClipShotSets' => new \PHPExiftool\Driver\Tag\MXF\ClipShotSets(),
                'KeyPointSets' => new \PHPExiftool\Driver\Tag\MXF\KeyPointSets(),
                'ShotParticipantRoleSets' => new \PHPExiftool\Driver\Tag\MXF\ShotParticipantRoleSets(),
                'ShotPersonSets' => new \PHPExiftool\Driver\Tag\MXF\ShotPersonSets(),
                'OrganizationSets' => new \PHPExiftool\Driver\Tag\MXF\OrganizationSets(),
                'ShotLocationSets' => new \PHPExiftool\Driver\Tag\MXF\ShotLocationSets(),
                'AddressSets' => new \PHPExiftool\Driver\Tag\MXF\AddressSets(),
                'CommunicationSets' => new \PHPExiftool\Driver\Tag\MXF\CommunicationSets(),
                'ContractSets' => new \PHPExiftool\Driver\Tag\MXF\ContractSets(),
                'RightsSets' => new \PHPExiftool\Driver\Tag\MXF\RightsSets(),
                'PaymentsSets' => new \PHPExiftool\Driver\Tag\MXF\PaymentsSets(),
                'DeviceParametersSets' => new \PHPExiftool\Driver\Tag\MXF\DeviceParametersSets(),
                'ClassificationNameValueSets' => new \PHPExiftool\Driver\Tag\MXF\ClassificationNameValueSets(),
                'ContactNameValueSets' => new \PHPExiftool\Driver\Tag\MXF\ContactNameValueSets(),
                'DeviceParameterNameValueSets' => new \PHPExiftool\Driver\Tag\MXF\DeviceParameterNameValueSets(),
                'MetadataServerLocators' => new \PHPExiftool\Driver\Tag\MXF\MetadataServerLocators(),
                'RelatedMaterialLocators' => new \PHPExiftool\Driver\Tag\MXF\RelatedMaterialLocators(),
                'LocalTagEntries' => new \PHPExiftool\Driver\Tag\MXF\LocalTagEntries(),
                'TotalNumberInSequence' => new \PHPExiftool\Driver\Tag\MXF\TotalNumberInSequence(),
                'RoomOrSuiteName' => new \PHPExiftool\Driver\Tag\MXF\RoomOrSuiteName(),
                'BuildingName' => new \PHPExiftool\Driver\Tag\MXF\BuildingName(),
                'LocalFestivalDateTime' => new \PHPExiftool\Driver\Tag\MXF\LocalFestivalDateTime(),
                'ShotStartPosition' => new \PHPExiftool\Driver\Tag\MXF\ShotStartPosition(),
                'IndexingStartPosition' => new \PHPExiftool\Driver\Tag\MXF\IndexingStartPosition(),
                'EventOrigin' => new \PHPExiftool\Driver\Tag\MXF\EventOrigin(),
                'SettingPeriodDescription' => new \PHPExiftool\Driver\Tag\MXF\SettingPeriodDescription(),
                'IndexDuration' => new \PHPExiftool\Driver\Tag\MXF\IndexDuration(),
                'ShotDuration' => new \PHPExiftool\Driver\Tag\MXF\ShotDuration(),
                'ExtendedClipID' => new \PHPExiftool\Driver\Tag\MXF\ExtendedClipID(),
                'ClipIDArray' => new \PHPExiftool\Driver\Tag\MXF\ClipIDArray(),
                'ExtendedClipIDArray' => new \PHPExiftool\Driver\Tag\MXF\ExtendedClipIDArray(),
                'TrackNumberBatch' => new \PHPExiftool\Driver\Tag\MXF\TrackNumberBatch(),
                'ExtendedTextLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\ExtendedTextLanguageCode(),
                'ExtendedCaptionsLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\ExtendedCaptionsLanguageCode(),
                'FrameworkExtendedTextLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\FrameworkExtendedTextLanguageCode(),
                'PrimaryExtendedSpokenLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\PrimaryExtendedSpokenLanguageCode(),
                'SecondaryExtendedSpokenLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\SecondaryExtendedSpokenLanguageCode(),
                'OriginalExtendedSpokenPrimaryLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\OriginalExtendedSpokenPrimaryLanguageCode(),
                'SecondaryOriginalExtendedSpokenLanguageCode' => new \PHPExiftool\Driver\Tag\MXF\SecondaryOriginalExtendedSpokenLanguageCode(),
                'KLVMetadataSequence' => new \PHPExiftool\Driver\Tag\MXF\KLVMetadataSequence(),
                'PackageAttributes' => new \PHPExiftool\Driver\Tag\MXF\PackageAttributes(),
                'ComponentAttributes' => new \PHPExiftool\Driver\Tag\MXF\ComponentAttributes(),
                'MPEG7BiMDecoderInitFrame1' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame1(),
                'MPEG7BiMDecoderInitFrame2' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame2(),
                'MPEG7BiMDecoderInitFrame3' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame3(),
                'MPEG7BiMDecoderInitFrame4' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame4(),
                'MPEG7BiMDecoderInitFrame5' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame5(),
                'MPEG7BiMDecoderInitFrame6' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame6(),
                'MPEG7BiMDecoderInitFrame7' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame7(),
                'MPEG7BiMDecoderInitFrame8' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame8(),
                'MPEG7BiMAccessUnitFrame1' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame1(),
                'MPEG7BiMAccessUnitFrame2' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame2(),
                'MPEG7BiMAccessUnitFrame3' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame3(),
                'MPEG7BiMAccessUnitFrame4' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame4(),
                'MPEG7BiMAccessUnitFrame5' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame5(),
                'MPEG7BiMAccessUnitFrame6' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame6(),
                'MPEG7BiMAccessUnitFrame7' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame7(),
                'MPEG7BiMAccessUnitFrame8' => new \PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame8(),
                'ComponentUserComments' => new \PHPExiftool\Driver\Tag\MXF\ComponentUserComments(),
                'SensorMode' => new \PHPExiftool\Driver\Tag\MXF\SensorMode(),
                'ChannelAssignment' => new \PHPExiftool\Driver\Tag\MXF\ChannelAssignment(),
                'ContentPackageIndexArray' => new \PHPExiftool\Driver\Tag\MXF\ContentPackageIndexArray(),
                'VideoIndexArray' => new \PHPExiftool\Driver\Tag\MXF\VideoIndexArray(),
                'ApproximateImageContainerSize' => new \PHPExiftool\Driver\Tag\MXF\ApproximateImageContainerSize(),
                'MetadataEncodingSchemeCode' => new \PHPExiftool\Driver\Tag\MXF\MetadataEncodingSchemeCode(),
                'MIMEMediaType' => new \PHPExiftool\Driver\Tag\MXF\MIMEMediaType(),
                'FieldOfViewVerticalFP' => new \PHPExiftool\Driver\Tag\MXF\FieldOfViewVerticalFP(),
                'PackageUsageKind' => new \PHPExiftool\Driver\Tag\MXF\PackageUsageKind(),
                'ChannelID' => new \PHPExiftool\Driver\Tag\MXF\ChannelID(),
                'ChannelIDs' => new \PHPExiftool\Driver\Tag\MXF\ChannelIDs(),
                'KLVDataType' => new \PHPExiftool\Driver\Tag\MXF\KLVDataType(),
                'KLVDataParentProperties' => new \PHPExiftool\Driver\Tag\MXF\KLVDataParentProperties(),
                'TaggedValueParentProperties' => new \PHPExiftool\Driver\Tag\MXF\TaggedValueParentProperties(),
                'AnnotationParticipantSets' => new \PHPExiftool\Driver\Tag\MXF\AnnotationParticipantSets(),
                'KLVDataDefinitions' => new \PHPExiftool\Driver\Tag\MXF\KLVDataDefinitions(),
                'TaggedValueDefinitions' => new \PHPExiftool\Driver\Tag\MXF\TaggedValueDefinitions(),
                'AddressNameValueSets' => new \PHPExiftool\Driver\Tag\MXF\AddressNameValueSets(),
                'NMEADocumentText' => new \PHPExiftool\Driver\Tag\MXF\NMEADocumentText(),
                'PlatformRollAngle' => new \PHPExiftool\Driver\Tag\MXF\PlatformRollAngle(),
                'PlatformPitchAngle' => new \PHPExiftool\Driver\Tag\MXF\PlatformPitchAngle(),
                'PlatformHeadingAngle' => new \PHPExiftool\Driver\Tag\MXF\PlatformHeadingAngle(),
                'AddressLine' => new \PHPExiftool\Driver\Tag\MXF\AddressLine(),
                'PlaceName' => new \PHPExiftool\Driver\Tag\MXF\PlaceName(),
                'GeographicalCoordinates' => new \PHPExiftool\Driver\Tag\MXF\GeographicalCoordinates(),
                'AstronomicalBodyName' => new \PHPExiftool\Driver\Tag\MXF\AstronomicalBodyName(),
                'TimecodeArray' => new \PHPExiftool\Driver\Tag\MXF\TimecodeArray(),
                'MarkIn' => new \PHPExiftool\Driver\Tag\MXF\MarkIn(),
                'UserPosition' => new \PHPExiftool\Driver\Tag\MXF\UserPosition(),
                'MarkOut' => new \PHPExiftool\Driver\Tag\MXF\MarkOut(),
                'ClipCreationDateTime' => new \PHPExiftool\Driver\Tag\MXF\ClipCreationDateTime(),
                'VideoClipDuration' => new \PHPExiftool\Driver\Tag\MXF\VideoClipDuration(),
                'ParticipantID' => new \PHPExiftool\Driver\Tag\MXF\ParticipantID(),
                'ContactID' => new \PHPExiftool\Driver\Tag\MXF\ContactID(),
                'DefaultNamespaceURI' => new \PHPExiftool\Driver\Tag\MXF\DefaultNamespaceURI(),
                'NamespaceURI' => new \PHPExiftool\Driver\Tag\MXF\NamespaceURI(),
                'NamespaceURIs' => new \PHPExiftool\Driver\Tag\MXF\NamespaceURIs(),
                'HTMLDOCTYPE' => new \PHPExiftool\Driver\Tag\MXF\HTMLDOCTYPE(),
                'NamespacePrefix' => new \PHPExiftool\Driver\Tag\MXF\NamespacePrefix(),
                'NamespacePrefixes' => new \PHPExiftool\Driver\Tag\MXF\NamespacePrefixes(),
                'RightsComment' => new \PHPExiftool\Driver\Tag\MXF\RightsComment(),
                'NominationCategory' => new \PHPExiftool\Driver\Tag\MXF\NominationCategory(),
                'PeakEnvelopeVersion' => new \PHPExiftool\Driver\Tag\MXF\PeakEnvelopeVersion(),
                'PeakEnvelopeFormat' => new \PHPExiftool\Driver\Tag\MXF\PeakEnvelopeFormat(),
                'PointsPerPeakValue' => new \PHPExiftool\Driver\Tag\MXF\PointsPerPeakValue(),
                'PeakEnvelopeBlockSize' => new \PHPExiftool\Driver\Tag\MXF\PeakEnvelopeBlockSize(),
                'PeakChannelCount' => new \PHPExiftool\Driver\Tag\MXF\PeakChannelCount(),
                'PeakFrameCount' => new \PHPExiftool\Driver\Tag\MXF\PeakFrameCount(),
                'PeakOfPeaksPosition' => new \PHPExiftool\Driver\Tag\MXF\PeakOfPeaksPosition(),
                'PeakEnvelopeTimestamp' => new \PHPExiftool\Driver\Tag\MXF\PeakEnvelopeTimestamp(),
                'RIFFChunkID' => new \PHPExiftool\Driver\Tag\MXF\RIFFChunkID(),
                'RIFFChunkLength' => new \PHPExiftool\Driver\Tag\MXF\RIFFChunkLength(),
                'RIFFChunkData' => new \PHPExiftool\Driver\Tag\MXF\RIFFChunkData(),
                'MIMECharSet' => new \PHPExiftool\Driver\Tag\MXF\MIMECharSet(),
                'MIMEEncoding' => new \PHPExiftool\Driver\Tag\MXF\MIMEEncoding(),
                'MonoSourceTrackIDs' => new \PHPExiftool\Driver\Tag\MXF\MonoSourceTrackIDs(),
                'CompositionRendering' => new \PHPExiftool\Driver\Tag\MXF\CompositionRendering(),
                'CaptionsDescriptionParticipantSets' => new \PHPExiftool\Driver\Tag\MXF\CaptionsDescriptionParticipantSets(),
                'EventAnnotationSets' => new \PHPExiftool\Driver\Tag\MXF\EventAnnotationSets(),
                'ScriptingLocators' => new \PHPExiftool\Driver\Tag\MXF\ScriptingLocators(),
                'UnknownBWFChunks' => new \PHPExiftool\Driver\Tag\MXF\UnknownBWFChunks(),
                'CryptographicContextID' => new \PHPExiftool\Driver\Tag\MXF\CryptographicContextID(),
                'NITFLayerTargetID' => new \PHPExiftool\Driver\Tag\MXF\NITFLayerTargetID(),
                'RP217DataStreamPID' => new \PHPExiftool\Driver\Tag\MXF\RP217DataStreamPID(),
                'RP217VideoStreamPID' => new \PHPExiftool\Driver\Tag\MXF\RP217VideoStreamPID(),
                'CipherAlgorithm' => new \PHPExiftool\Driver\Tag\MXF\CipherAlgorithm(),
                'CryptographicKeyID' => new \PHPExiftool\Driver\Tag\MXF\CryptographicKeyID(),
                'EncryptedSourceValue' => new \PHPExiftool\Driver\Tag\MXF\EncryptedSourceValue(),
                'MICAlgorithm' => new \PHPExiftool\Driver\Tag\MXF\MICAlgorithm(),
                'MIC' => new \PHPExiftool\Driver\Tag\MXF\MIC(),
                'JFIFMarkerDescription' => new \PHPExiftool\Driver\Tag\MXF\JFIFMarkerDescription(),
                'HTMLMetaDescription' => new \PHPExiftool\Driver\Tag\MXF\HTMLMetaDescription(),
                'ColorPrimaries' => new \PHPExiftool\Driver\Tag\MXF\ColorPrimaries(),
                'ProductFormat' => new \PHPExiftool\Driver\Tag\MXF\ProductFormat(),
                'SourceLength' => new \PHPExiftool\Driver\Tag\MXF\SourceLength(),
                'SourceContainerFormat' => new \PHPExiftool\Driver\Tag\MXF\SourceContainerFormat(),
                'SourceKey' => new \PHPExiftool\Driver\Tag\MXF\SourceKey(),
                'DynamicSourcePackageID' => new \PHPExiftool\Driver\Tag\MXF\DynamicSourcePackageID(),
                'DynamicSourceTrackIDs' => new \PHPExiftool\Driver\Tag\MXF\DynamicSourceTrackIDs(),
                'SourceIndex' => new \PHPExiftool\Driver\Tag\MXF\SourceIndex(),
                'SourceSpecies' => new \PHPExiftool\Driver\Tag\MXF\SourceSpecies(),
                'SourceValue' => new \PHPExiftool\Driver\Tag\MXF\SourceValue(),
                'CryptographicContextObject' => new \PHPExiftool\Driver\Tag\MXF\CryptographicContextObject(),
                'mixed' => new \PHPExiftool\Driver\Tag\MXF\SubDescriptors(),
                'EncryptedTrackFileID' => new \PHPExiftool\Driver\Tag\MXF\EncryptedTrackFileID(),
                'CryptographicContextLink' => new \PHPExiftool\Driver\Tag\MXF\CryptographicContextLink(),
                'PlaintextOffset' => new \PHPExiftool\Driver\Tag\MXF\PlaintextOffset(),
                'TripletSequenceNumber' => new \PHPExiftool\Driver\Tag\MXF\TripletSequenceNumber(),
                'BoundingRectangle' => new \PHPExiftool\Driver\Tag\MXF\BoundingRectangle(),
                'GeographicLocation' => new \PHPExiftool\Driver\Tag\MXF\GeographicLocation(),
                'GeographicPolygonCoordinates' => new \PHPExiftool\Driver\Tag\MXF\GeographicPolygonCoordinates(),
                'GeographicAreaNorthwest' => new \PHPExiftool\Driver\Tag\MXF\GeographicAreaNorthwest(),
                'GeographicAreaSoutheast' => new \PHPExiftool\Driver\Tag\MXF\GeographicAreaSoutheast(),
                'GeographicAreaSourceDatum' => new \PHPExiftool\Driver\Tag\MXF\GeographicAreaSourceDatum(),
                'GeographicPolygonSourceDatum' => new \PHPExiftool\Driver\Tag\MXF\GeographicPolygonSourceDatum(),
                'ClassifyingCountryCode' => new \PHPExiftool\Driver\Tag\MXF\ClassifyingCountryCode(),
                'UTCInstantDateTime' => new \PHPExiftool\Driver\Tag\MXF\UTCInstantDateTime(),
                'ToleranceMode' => new \PHPExiftool\Driver\Tag\MXF\ToleranceMode(),
                'ToleranceWindow' => new \PHPExiftool\Driver\Tag\MXF\ToleranceWindow(),
                'ToleranceInterpolationMethod' => new \PHPExiftool\Driver\Tag\MXF\ToleranceInterpolationMethod(),
                'VBILineCount' => new \PHPExiftool\Driver\Tag\MXF\VBILineCount(),
                'StoredVBILineNumber' => new \PHPExiftool\Driver\Tag\MXF\StoredVBILineNumber(),
                'VBIWrappingType' => new \PHPExiftool\Driver\Tag\MXF\VBIWrappingType(),
                'VBIPayloadSampleCount' => new \PHPExiftool\Driver\Tag\MXF\VBIPayloadSampleCount(),
                'VBIPayloadByteArray' => new \PHPExiftool\Driver\Tag\MXF\VBIPayloadByteArray(),
                'ANCPacketCount' => new \PHPExiftool\Driver\Tag\MXF\ANCPacketCount(),
                'StoredANCLineNumber' => new \PHPExiftool\Driver\Tag\MXF\StoredANCLineNumber(),
                'ANCWrappingType' => new \PHPExiftool\Driver\Tag\MXF\ANCWrappingType(),
                'ANCPayloadSampleCount' => new \PHPExiftool\Driver\Tag\MXF\ANCPayloadSampleCount(),
                'ANCPayloadByteArray' => new \PHPExiftool\Driver\Tag\MXF\ANCPayloadByteArray(),
                'VBIPayloadSampleCoding' => new \PHPExiftool\Driver\Tag\MXF\VBIPayloadSampleCoding(),
                'ANCPayloadSampleCoding' => new \PHPExiftool\Driver\Tag\MXF\ANCPayloadSampleCoding(),
                'Rsiz' => new \PHPExiftool\Driver\Tag\MXF\Rsiz(),
                'Xsiz' => new \PHPExiftool\Driver\Tag\MXF\Xsiz(),
                'Ysiz' => new \PHPExiftool\Driver\Tag\MXF\Ysiz(),
                'XOsiz' => new \PHPExiftool\Driver\Tag\MXF\XOsiz(),
                'YOsiz' => new \PHPExiftool\Driver\Tag\MXF\YOsiz(),
                'XTsiz' => new \PHPExiftool\Driver\Tag\MXF\XTsiz(),
                'YTsiz' => new \PHPExiftool\Driver\Tag\MXF\YTsiz(),
                'XTOsiz' => new \PHPExiftool\Driver\Tag\MXF\XTOsiz(),
                'YTOsiz' => new \PHPExiftool\Driver\Tag\MXF\YTOsiz(),
                'Csiz' => new \PHPExiftool\Driver\Tag\MXF\Csiz(),
                'PictureComponentSizing' => new \PHPExiftool\Driver\Tag\MXF\PictureComponentSizing(),
                'CodingStyleDefault' => new \PHPExiftool\Driver\Tag\MXF\CodingStyleDefault(),
                'QuantizationDefault' => new \PHPExiftool\Driver\Tag\MXF\QuantizationDefault(),
                'MPEGAudioBitrate' => new \PHPExiftool\Driver\Tag\MXF\MPEGAudioBitrate(),
                'CBEStartOffset' => new \PHPExiftool\Driver\Tag\MXF\CBEStartOffset(),
                'VBEEndOffset' => new \PHPExiftool\Driver\Tag\MXF\VBEEndOffset(),
                'SubDescriptor' => new \PHPExiftool\Driver\Tag\MXF\SubDescriptor(),
                'RootMetaDictionary' => new \PHPExiftool\Driver\Tag\MXF\RootMetaDictionary(),
                'RootPreface' => new \PHPExiftool\Driver\Tag\MXF\RootPreface(),
                'RootObjectDirectory' => new \PHPExiftool\Driver\Tag\MXF\RootObjectDirectory(),
                'RootFormatVersion' => new \PHPExiftool\Driver\Tag\MXF\RootFormatVersion(),
                'FrameCenterElevation' => new \PHPExiftool\Driver\Tag\MXF\FrameCenterElevation(),
                'PackageMarkInPosition' => new \PHPExiftool\Driver\Tag\MXF\PackageMarkInPosition(),
                'PackageMarkOutPosition' => new \PHPExiftool\Driver\Tag\MXF\PackageMarkOutPosition(),
                'Ad-ID' => new \PHPExiftool\Driver\Tag\MXF\AdID(),
                'ResourceID' => new \PHPExiftool\Driver\Tag\MXF\ResourceID(),
                'AncillaryResourceID' => new \PHPExiftool\Driver\Tag\MXF\AncillaryResourceID(),
                'ApplicationSchemeBatch' => new \PHPExiftool\Driver\Tag\MXF\ApplicationSchemeBatch(),
                'RegisterKind' => new \PHPExiftool\Driver\Tag\MXF\RegisterKind(),
                'RegisterVersion' => new \PHPExiftool\Driver\Tag\MXF\RegisterVersion(),
                'RegisterEditorName' => new \PHPExiftool\Driver\Tag\MXF\RegisterEditorName(),
                'RegisterStatusKind' => new \PHPExiftool\Driver\Tag\MXF\RegisterStatusKind(),
                'RegisterItemName' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemName(),
                'RegisterItemDefinition' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemDefinition(),
                'RegisterItemSymbol' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemSymbol(),
                'RegisterItemDefiningDocumentName' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemDefiningDocumentName(),
                'RegisterItemUL' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemUL(),
                'RegisterItemNotes' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemNotes(),
                'RegisterItemIntroductionVersion' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemIntroductionVersion(),
                'RegisterItemHierarchyLevel' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemHierarchyLevel(),
                'RegisterEntryStatus' => new \PHPExiftool\Driver\Tag\MXF\RegisterEntryStatus(),
                'RegisterAction' => new \PHPExiftool\Driver\Tag\MXF\RegisterAction(),
                'RegisterApproverName' => new \PHPExiftool\Driver\Tag\MXF\RegisterApproverName(),
                'RegisterCreationTime' => new \PHPExiftool\Driver\Tag\MXF\RegisterCreationTime(),
                'RegistrantName' => new \PHPExiftool\Driver\Tag\MXF\RegistrantName(),
                'RegisterItemOriginatorName' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemOriginatorName(),
                'RegisterUserName' => new \PHPExiftool\Driver\Tag\MXF\RegisterUserName(),
                'RegisterUserTime' => new \PHPExiftool\Driver\Tag\MXF\RegisterUserTime(),
                'RegisterAdministrationNotes' => new \PHPExiftool\Driver\Tag\MXF\RegisterAdministrationNotes(),
                'AFDAndBarData' => new \PHPExiftool\Driver\Tag\MXF\AFDAndBarData(),
                'PanScanInformation' => new \PHPExiftool\Driver\Tag\MXF\PanScanInformation(),
                'VC-1InitializationMetadata' => new \PHPExiftool\Driver\Tag\MXF\VC1InitializationMetadata(),
                'VC-1SingleSequence' => new \PHPExiftool\Driver\Tag\MXF\VC1SingleSequence(),
                'VC-1CodedContentType' => new \PHPExiftool\Driver\Tag\MXF\VC1CodedContentType(),
                'VC-1IdenticalGOP' => new \PHPExiftool\Driver\Tag\MXF\VC1IdenticalGOP(),
                'VC-1MaximumGOP' => new \PHPExiftool\Driver\Tag\MXF\VC1MaximumGOP(),
                'VC-1BPictureCount' => new \PHPExiftool\Driver\Tag\MXF\VC1BPictureCount(),
                'VC-1AverageBitrate' => new \PHPExiftool\Driver\Tag\MXF\VC1AverageBitrate(),
                'VC-1MaximumBitrate' => new \PHPExiftool\Driver\Tag\MXF\VC1MaximumBitrate(),
                'VC-1Profile' => new \PHPExiftool\Driver\Tag\MXF\VC1Profile(),
                'VC-1Level' => new \PHPExiftool\Driver\Tag\MXF\VC1Level(),
                'LinkedTimecodeTrackID' => new \PHPExiftool\Driver\Tag\MXF\LinkedTimecodeTrackID(),
                'SMPTE337MDataStreamNumber' => new \PHPExiftool\Driver\Tag\MXF\SMPTE337MDataStreamNumber(),
                'ApplicationScheme' => new \PHPExiftool\Driver\Tag\MXF\ApplicationScheme(),
                'DescriptiveMetadataScheme' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataScheme(),
                'UCSEncoding' => new \PHPExiftool\Driver\Tag\MXF\UCSEncoding(),
                'LinkedApplicationPlug-InInstanceID' => new \PHPExiftool\Driver\Tag\MXF\LinkedApplicationPlugInInstanceID(),
                'LinkedDescriptiveFrameworkPlug-InID' => new \PHPExiftool\Driver\Tag\MXF\LinkedDescriptiveFrameworkPlugInID(),
                'ApplicationPlug-InInstanceID' => new \PHPExiftool\Driver\Tag\MXF\ApplicationPlugInInstanceID(),
                'DescriptiveMetadataPlug-InID' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataPlugInID(),
                'ApplicationEnvironmentID' => new \PHPExiftool\Driver\Tag\MXF\ApplicationEnvironmentID(),
                'DescriptiveMetadataApplicationEnvironmentID' => new \PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataApplicationEnvironmentID(),
                'LinkedDescriptiveObjectPlug-InID' => new \PHPExiftool\Driver\Tag\MXF\LinkedDescriptiveObjectPlugInID(),
                'TimebaseReferenceTrackID' => new \PHPExiftool\Driver\Tag\MXF\TimebaseReferenceTrackID(),
                'ObjectClassDefinition' => new \PHPExiftool\Driver\Tag\MXF\ObjectClassDefinition(),
                'ApplicationPlug-InBatch' => new \PHPExiftool\Driver\Tag\MXF\ApplicationPlugInBatch(),
                'PackageMarker' => new \PHPExiftool\Driver\Tag\MXF\PackageMarker(),
                'PackageTimelineMarkerRef' => new \PHPExiftool\Driver\Tag\MXF\PackageTimelineMarkerRef(),
                'RegisterAdministrationObject' => new \PHPExiftool\Driver\Tag\MXF\RegisterAdministrationObject(),
                'RegisterEntryAdministrationObject' => new \PHPExiftool\Driver\Tag\MXF\RegisterEntryAdministrationObject(),
                'GenericPayloads' => new \PHPExiftool\Driver\Tag\MXF\GenericPayloads(),
                'RegisterEntryArray' => new \PHPExiftool\Driver\Tag\MXF\RegisterEntryArray(),
                'RegisterAdministrationArray' => new \PHPExiftool\Driver\Tag\MXF\RegisterAdministrationArray(),
                'ApplicationInformationArray' => new \PHPExiftool\Driver\Tag\MXF\ApplicationInformationArray(),
                'RegisterChildEntryArray' => new \PHPExiftool\Driver\Tag\MXF\RegisterChildEntryArray(),
                'RegisterReleaseDateTime' => new \PHPExiftool\Driver\Tag\MXF\RegisterReleaseDateTime(),
                'RegisterItemStatusChangeDateTime' => new \PHPExiftool\Driver\Tag\MXF\RegisterItemStatusChangeDateTime(),
                'OpenBodyPartition' => new \PHPExiftool\Driver\Tag\MXF\OpenBodyPartition(),
                'ClosedBodyPartition' => new \PHPExiftool\Driver\Tag\MXF\ClosedBodyPartition(),
                'OpenCompleteBodyPartition' => new \PHPExiftool\Driver\Tag\MXF\OpenCompleteBodyPartition(),
                'ClosedCompleteBodyPartition' => new \PHPExiftool\Driver\Tag\MXF\ClosedCompleteBodyPartition(),
                'Footer' => new \PHPExiftool\Driver\Tag\MXF\Footer(),
                'CompleteFooter' => new \PHPExiftool\Driver\Tag\MXF\CompleteFooter(),
                'RandomIndexMetadataV10' => new \PHPExiftool\Driver\Tag\MXF\RandomIndexMetadataV10(),
                'RandomIndexMetadata' => new \PHPExiftool\Driver\Tag\MXF\RandomIndexMetadata(),
                'PartitionMetadata' => new \PHPExiftool\Driver\Tag\MXF\PartitionMetadata(),
                'SourceClip' => new \PHPExiftool\Driver\Tag\MXF\SourceClip(),
                'V10IndexTableSegment' => new \PHPExiftool\Driver\Tag\MXF\V10IndexTableSegment(),
                'IndexTableSegment' => new \PHPExiftool\Driver\Tag\MXF\IndexTableSegment(),
                'DefaultObject' => new \PHPExiftool\Driver\Tag\MXF\DefaultObject(),
                'CipherAlgorithmAES128CBC' => new \PHPExiftool\Driver\Tag\MXF\CipherAlgorithmAES128CBC(),
                'HMACAlgorithmSHA1128' => new \PHPExiftool\Driver\Tag\MXF\HMACAlgorithmSHA1128(),
                'EncryptedContainerLabel' => new \PHPExiftool\Driver\Tag\MXF\EncryptedContainerLabel(),
                'CryptographicFrameworkLabel' => new \PHPExiftool\Driver\Tag\MXF\CryptographicFrameworkLabel(),
            );
        });
        $this['Matroska'] = $this->share(function(){
            return array(
                'TrackType' => new \PHPExiftool\Driver\Tag\Matroska\TrackType(),
                'ChapterString' => new \PHPExiftool\Driver\Tag\Matroska\ChapterString(),
                'VideoCodecID' => new \PHPExiftool\Driver\Tag\Matroska\VideoCodecID(),
                'AudioCodecID' => new \PHPExiftool\Driver\Tag\Matroska\AudioCodecID(),
                'CodecID' => new \PHPExiftool\Driver\Tag\Matroska\CodecID(),
                'TrackDefault' => new \PHPExiftool\Driver\Tag\Matroska\TrackDefault(),
                'ChapterTrackNumber' => new \PHPExiftool\Driver\Tag\Matroska\ChapterTrackNumber(),
                'ChapterTimeStart' => new \PHPExiftool\Driver\Tag\Matroska\ChapterTimeStart(),
                'ChapterTimeEnd' => new \PHPExiftool\Driver\Tag\Matroska\ChapterTimeEnd(),
                'CueRefTime' => new \PHPExiftool\Driver\Tag\Matroska\CueRefTime(),
                'CueRefCluster' => new \PHPExiftool\Driver\Tag\Matroska\CueRefCluster(),
                'ChapterFlagHidden' => new \PHPExiftool\Driver\Tag\Matroska\ChapterFlagHidden(),
                'VideoScanType' => new \PHPExiftool\Driver\Tag\Matroska\VideoScanType(),
                'BlockDuration' => new \PHPExiftool\Driver\Tag\Matroska\BlockDuration(),
                'TrackLacing' => new \PHPExiftool\Driver\Tag\Matroska\TrackLacing(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\Matroska\AudioChannels(),
                'Block' => new \PHPExiftool\Driver\Tag\Matroska\Block(),
                'BlockVirtual' => new \PHPExiftool\Driver\Tag\Matroska\BlockVirtual(),
                'SimpleBlock' => new \PHPExiftool\Driver\Tag\Matroska\SimpleBlock(),
                'CodecState' => new \PHPExiftool\Driver\Tag\Matroska\CodecState(),
                'BlockAdditional' => new \PHPExiftool\Driver\Tag\Matroska\BlockAdditional(),
                'Position' => new \PHPExiftool\Driver\Tag\Matroska\Position(),
                'CodecDecodeAll' => new \PHPExiftool\Driver\Tag\Matroska\CodecDecodeAll(),
                'PrevSize' => new \PHPExiftool\Driver\Tag\Matroska\PrevSize(),
                'EncryptedBlock' => new \PHPExiftool\Driver\Tag\Matroska\EncryptedBlock(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\Matroska\ImageWidth(),
                'CueTime' => new \PHPExiftool\Driver\Tag\Matroska\CueTime(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\Matroska\AudioSampleRate(),
                'TrackUsed' => new \PHPExiftool\Driver\Tag\Matroska\TrackUsed(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\Matroska\ImageHeight(),
                'CRC-32' => new \PHPExiftool\Driver\Tag\Matroska\CRC32(),
                'BlockAdditionalID' => new \PHPExiftool\Driver\Tag\Matroska\BlockAdditionalID(),
                'LaceNumber' => new \PHPExiftool\Driver\Tag\Matroska\LaceNumber(),
                'FrameNumber' => new \PHPExiftool\Driver\Tag\Matroska\FrameNumber(),
                'Delay' => new \PHPExiftool\Driver\Tag\Matroska\Delay(),
                'ClusterDuration' => new \PHPExiftool\Driver\Tag\Matroska\ClusterDuration(),
                'TrackNumber' => new \PHPExiftool\Driver\Tag\Matroska\TrackNumber(),
                'Timecode' => new \PHPExiftool\Driver\Tag\Matroska\Timecode(),
                'CueCodecState' => new \PHPExiftool\Driver\Tag\Matroska\CueCodecState(),
                'CueRefCodecState' => new \PHPExiftool\Driver\Tag\Matroska\CueRefCodecState(),
                'Void' => new \PHPExiftool\Driver\Tag\Matroska\Void(),
                'BlockAddID' => new \PHPExiftool\Driver\Tag\Matroska\BlockAddID(),
                'CueClusterPosition' => new \PHPExiftool\Driver\Tag\Matroska\CueClusterPosition(),
                'CueTrack' => new \PHPExiftool\Driver\Tag\Matroska\CueTrack(),
                'ReferencePriority' => new \PHPExiftool\Driver\Tag\Matroska\ReferencePriority(),
                'ReferenceBlock' => new \PHPExiftool\Driver\Tag\Matroska\ReferenceBlock(),
                'ReferenceVirtual' => new \PHPExiftool\Driver\Tag\Matroska\ReferenceVirtual(),
                'ContentCompressionAlgorithm' => new \PHPExiftool\Driver\Tag\Matroska\ContentCompressionAlgorithm(),
                'ContentCompressionSettings' => new \PHPExiftool\Driver\Tag\Matroska\ContentCompressionSettings(),
                'DocType' => new \PHPExiftool\Driver\Tag\Matroska\DocType(),
                'DocTypeReadVersion' => new \PHPExiftool\Driver\Tag\Matroska\DocTypeReadVersion(),
                'EBMLVersion' => new \PHPExiftool\Driver\Tag\Matroska\EBMLVersion(),
                'DocTypeVersion' => new \PHPExiftool\Driver\Tag\Matroska\DocTypeVersion(),
                'EBMLMaxIDLength' => new \PHPExiftool\Driver\Tag\Matroska\EBMLMaxIDLength(),
                'EBMLMaxSizeLength' => new \PHPExiftool\Driver\Tag\Matroska\EBMLMaxSizeLength(),
                'EBMLReadVersion' => new \PHPExiftool\Driver\Tag\Matroska\EBMLReadVersion(),
                'ChapterLanguage' => new \PHPExiftool\Driver\Tag\Matroska\ChapterLanguage(),
                'ChapterCountry' => new \PHPExiftool\Driver\Tag\Matroska\ChapterCountry(),
                'SegmentFamily' => new \PHPExiftool\Driver\Tag\Matroska\SegmentFamily(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\Matroska\DateTimeOriginal(),
                'TagLanguage' => new \PHPExiftool\Driver\Tag\Matroska\TagLanguage(),
                'TagDefault' => new \PHPExiftool\Driver\Tag\Matroska\TagDefault(),
                'TagBinary' => new \PHPExiftool\Driver\Tag\Matroska\TagBinary(),
                'TagString' => new \PHPExiftool\Driver\Tag\Matroska\TagString(),
                'Duration' => new \PHPExiftool\Driver\Tag\Matroska\Duration(),
                'ChapterProcessPrivate' => new \PHPExiftool\Driver\Tag\Matroska\ChapterProcessPrivate(),
                'ChapterFlagEnabled' => new \PHPExiftool\Driver\Tag\Matroska\ChapterFlagEnabled(),
                'TagName' => new \PHPExiftool\Driver\Tag\Matroska\TagName(),
                'EditionUID' => new \PHPExiftool\Driver\Tag\Matroska\EditionUID(),
                'EditionFlagHidden' => new \PHPExiftool\Driver\Tag\Matroska\EditionFlagHidden(),
                'EditionFlagDefault' => new \PHPExiftool\Driver\Tag\Matroska\EditionFlagDefault(),
                'EditionFlagOrdered' => new \PHPExiftool\Driver\Tag\Matroska\EditionFlagOrdered(),
                'AttachedFileData' => new \PHPExiftool\Driver\Tag\Matroska\AttachedFileData(),
                'AttachedFileMIMEType' => new \PHPExiftool\Driver\Tag\Matroska\AttachedFileMIMEType(),
                'AttachedFileName' => new \PHPExiftool\Driver\Tag\Matroska\AttachedFileName(),
                'AttachedFileReferral' => new \PHPExiftool\Driver\Tag\Matroska\AttachedFileReferral(),
                'AttachedFileDescription' => new \PHPExiftool\Driver\Tag\Matroska\AttachedFileDescription(),
                'AttachedFileUID' => new \PHPExiftool\Driver\Tag\Matroska\AttachedFileUID(),
                'ContentEncryptionAlgorithm' => new \PHPExiftool\Driver\Tag\Matroska\ContentEncryptionAlgorithm(),
                'ContentEncryptionKeyID' => new \PHPExiftool\Driver\Tag\Matroska\ContentEncryptionKeyID(),
                'ContentSignature' => new \PHPExiftool\Driver\Tag\Matroska\ContentSignature(),
                'ContentSignatureKeyID' => new \PHPExiftool\Driver\Tag\Matroska\ContentSignatureKeyID(),
                'ContentSignatureAlgorithm' => new \PHPExiftool\Driver\Tag\Matroska\ContentSignatureAlgorithm(),
                'ContentSignatureHashAlgorithm' => new \PHPExiftool\Driver\Tag\Matroska\ContentSignatureHashAlgorithm(),
                'MuxingApp' => new \PHPExiftool\Driver\Tag\Matroska\MuxingApp(),
                'ContentEncodingOrder' => new \PHPExiftool\Driver\Tag\Matroska\ContentEncodingOrder(),
                'ContentEncodingScope' => new \PHPExiftool\Driver\Tag\Matroska\ContentEncodingScope(),
                'ContentEncodingType' => new \PHPExiftool\Driver\Tag\Matroska\ContentEncodingType(),
                'CueRefNumber' => new \PHPExiftool\Driver\Tag\Matroska\CueRefNumber(),
                'TrackName' => new \PHPExiftool\Driver\Tag\Matroska\TrackName(),
                'CueBlockNumber' => new \PHPExiftool\Driver\Tag\Matroska\CueBlockNumber(),
                'TrackOffset' => new \PHPExiftool\Driver\Tag\Matroska\TrackOffset(),
                'SeekID' => new \PHPExiftool\Driver\Tag\Matroska\SeekID(),
                'SeekPosition' => new \PHPExiftool\Driver\Tag\Matroska\SeekPosition(),
                'Stereo3DMode' => new \PHPExiftool\Driver\Tag\Matroska\Stereo3DMode(),
                'CropBottom' => new \PHPExiftool\Driver\Tag\Matroska\CropBottom(),
                'DisplayWidth' => new \PHPExiftool\Driver\Tag\Matroska\DisplayWidth(),
                'DisplayUnit' => new \PHPExiftool\Driver\Tag\Matroska\DisplayUnit(),
                'AspectRatioType' => new \PHPExiftool\Driver\Tag\Matroska\AspectRatioType(),
                'DisplayHeight' => new \PHPExiftool\Driver\Tag\Matroska\DisplayHeight(),
                'CropTop' => new \PHPExiftool\Driver\Tag\Matroska\CropTop(),
                'CropLeft' => new \PHPExiftool\Driver\Tag\Matroska\CropLeft(),
                'CropRight' => new \PHPExiftool\Driver\Tag\Matroska\CropRight(),
                'TrackForced' => new \PHPExiftool\Driver\Tag\Matroska\TrackForced(),
                'MaxBlockAdditionID' => new \PHPExiftool\Driver\Tag\Matroska\MaxBlockAdditionID(),
                'WritingApp' => new \PHPExiftool\Driver\Tag\Matroska\WritingApp(),
                'SilentTrackNumber' => new \PHPExiftool\Driver\Tag\Matroska\SilentTrackNumber(),
                'AudioBitsPerSample' => new \PHPExiftool\Driver\Tag\Matroska\AudioBitsPerSample(),
                'CodecPrivate' => new \PHPExiftool\Driver\Tag\Matroska\CodecPrivate(),
                'ChapterPhysicalEquivalent' => new \PHPExiftool\Driver\Tag\Matroska\ChapterPhysicalEquivalent(),
                'TagChapterUID' => new \PHPExiftool\Driver\Tag\Matroska\TagChapterUID(),
                'TagTrackUID' => new \PHPExiftool\Driver\Tag\Matroska\TagTrackUID(),
                'TagAttachmentUID' => new \PHPExiftool\Driver\Tag\Matroska\TagAttachmentUID(),
                'TagEditionUID' => new \PHPExiftool\Driver\Tag\Matroska\TagEditionUID(),
                'TargetType' => new \PHPExiftool\Driver\Tag\Matroska\TargetType(),
                'SignedElement' => new \PHPExiftool\Driver\Tag\Matroska\SignedElement(),
                'TrackTranslateTrackID' => new \PHPExiftool\Driver\Tag\Matroska\TrackTranslateTrackID(),
                'TrackTranslateCodec' => new \PHPExiftool\Driver\Tag\Matroska\TrackTranslateCodec(),
                'TrackTranslateEditionUID' => new \PHPExiftool\Driver\Tag\Matroska\TrackTranslateEditionUID(),
                'TargetTypeValue' => new \PHPExiftool\Driver\Tag\Matroska\TargetTypeValue(),
                'ChapterProcessTime' => new \PHPExiftool\Driver\Tag\Matroska\ChapterProcessTime(),
                'ChapterProcessData' => new \PHPExiftool\Driver\Tag\Matroska\ChapterProcessData(),
                'ChapterProcessCodecID' => new \PHPExiftool\Driver\Tag\Matroska\ChapterProcessCodecID(),
                'ChapterTranslateID' => new \PHPExiftool\Driver\Tag\Matroska\ChapterTranslateID(),
                'ChapterTranslateCodec' => new \PHPExiftool\Driver\Tag\Matroska\ChapterTranslateCodec(),
                'ChapterTranslateEditionUID' => new \PHPExiftool\Driver\Tag\Matroska\ChapterTranslateEditionUID(),
                'MinCache' => new \PHPExiftool\Driver\Tag\Matroska\MinCache(),
                'MaxCache' => new \PHPExiftool\Driver\Tag\Matroska\MaxCache(),
                'ChapterSegmentUID' => new \PHPExiftool\Driver\Tag\Matroska\ChapterSegmentUID(),
                'ChapterSegmentEditionUID' => new \PHPExiftool\Driver\Tag\Matroska\ChapterSegmentEditionUID(),
                'TrackOverlay' => new \PHPExiftool\Driver\Tag\Matroska\TrackOverlay(),
                'SegmentFileName' => new \PHPExiftool\Driver\Tag\Matroska\SegmentFileName(),
                'SegmentUID' => new \PHPExiftool\Driver\Tag\Matroska\SegmentUID(),
                'ChapterUID' => new \PHPExiftool\Driver\Tag\Matroska\ChapterUID(),
                'TrackUID' => new \PHPExiftool\Driver\Tag\Matroska\TrackUID(),
                'TrackAttachmentUID' => new \PHPExiftool\Driver\Tag\Matroska\TrackAttachmentUID(),
                'OutputAudioSampleRate' => new \PHPExiftool\Driver\Tag\Matroska\OutputAudioSampleRate(),
                'Title' => new \PHPExiftool\Driver\Tag\Matroska\Title(),
                'ChannelPositions' => new \PHPExiftool\Driver\Tag\Matroska\ChannelPositions(),
                'SignatureAlgo' => new \PHPExiftool\Driver\Tag\Matroska\SignatureAlgo(),
                'SignatureHash' => new \PHPExiftool\Driver\Tag\Matroska\SignatureHash(),
                'SignaturePublicKey' => new \PHPExiftool\Driver\Tag\Matroska\SignaturePublicKey(),
                'Signature' => new \PHPExiftool\Driver\Tag\Matroska\Signature(),
                'TrackLanguage' => new \PHPExiftool\Driver\Tag\Matroska\TrackLanguage(),
                'TrackTimecodeScale' => new \PHPExiftool\Driver\Tag\Matroska\TrackTimecodeScale(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\Matroska\FrameRate(),
                'VideoFrameRate' => new \PHPExiftool\Driver\Tag\Matroska\VideoFrameRate(),
                'DefaultDuration' => new \PHPExiftool\Driver\Tag\Matroska\DefaultDuration(),
                'VideoCodecName' => new \PHPExiftool\Driver\Tag\Matroska\VideoCodecName(),
                'AudioCodecName' => new \PHPExiftool\Driver\Tag\Matroska\AudioCodecName(),
                'CodecName' => new \PHPExiftool\Driver\Tag\Matroska\CodecName(),
                'CodecDownloadURL' => new \PHPExiftool\Driver\Tag\Matroska\CodecDownloadURL(),
                'TimecodeScale' => new \PHPExiftool\Driver\Tag\Matroska\TimecodeScale(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Matroska\ColorSpace(),
                'Gamma' => new \PHPExiftool\Driver\Tag\Matroska\Gamma(),
                'CodecSettings' => new \PHPExiftool\Driver\Tag\Matroska\CodecSettings(),
                'CodecInfoURL' => new \PHPExiftool\Driver\Tag\Matroska\CodecInfoURL(),
                'PrevFileName' => new \PHPExiftool\Driver\Tag\Matroska\PrevFileName(),
                'PrevUID' => new \PHPExiftool\Driver\Tag\Matroska\PrevUID(),
                'NextFileName' => new \PHPExiftool\Driver\Tag\Matroska\NextFileName(),
                'NextUID' => new \PHPExiftool\Driver\Tag\Matroska\NextUID(),
            );
        });
        $this['XMP-MP'] = $this->share(function(){
            return array(
                'RegionInfoMP' => new \PHPExiftool\Driver\Tag\XMPMP\RegionInfoMP(),
                'RegionInfoDateRegionsValid' => new \PHPExiftool\Driver\Tag\XMPMP\RegionInfoDateRegionsValid(),
                'RegionInfoRegions' => new \PHPExiftool\Driver\Tag\XMPMP\RegionInfoRegions(),
                'RegionPersonDisplayName' => new \PHPExiftool\Driver\Tag\XMPMP\RegionPersonDisplayName(),
                'RegionPersonEmailDigest' => new \PHPExiftool\Driver\Tag\XMPMP\RegionPersonEmailDigest(),
                'RegionPersonLiveIdCID' => new \PHPExiftool\Driver\Tag\XMPMP\RegionPersonLiveIdCID(),
                'RegionPersonSourceID' => new \PHPExiftool\Driver\Tag\XMPMP\RegionPersonSourceID(),
                'RegionRectangle' => new \PHPExiftool\Driver\Tag\XMPMP\RegionRectangle(),
            );
        });
        $this['XMP-MP1'] = $this->share(function(){
            return array(
                'PanoramicStitchCameraMotion' => new \PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchCameraMotion(),
                'PanoramicStitchMapType' => new \PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchMapType(),
                'PanoramicStitchPhi0' => new \PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchPhi0(),
                'PanoramicStitchPhi1' => new \PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchPhi1(),
                'PanoramicStitchTheta0' => new \PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchTheta0(),
                'PanoramicStitchTheta1' => new \PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchTheta1(),
            );
        });
        $this['Microsoft'] = $this->share(function(){
            return array(
                'PanoramicStitchVersion' => new \PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchVersion(),
                'PanoramicStitchCameraMotion' => new \PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchCameraMotion(),
                'PanoramicStitchMapType' => new \PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchMapType(),
                'PanoramicStitchTheta0' => new \PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchTheta0(),
                'PanoramicStitchTheta1' => new \PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchTheta1(),
                'PanoramicStitchPhi0' => new \PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchPhi0(),
                'PanoramicStitchPhi1' => new \PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchPhi1(),
                'Abstract' => new \PHPExiftool\Driver\Tag\Microsoft\Abstract0(),
                'AcquisitionTime' => new \PHPExiftool\Driver\Tag\Microsoft\AcquisitionTime(),
                'AcquisitionTimeDay' => new \PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeDay(),
                'AcquisitionTimeMonth' => new \PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeMonth(),
                'AcquisitionTimeYear' => new \PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeYear(),
                'AcquisitionTimeYearMonth' => new \PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeYearMonth(),
                'AcquisitionTimeYearMonthDay' => new \PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeYearMonthDay(),
                'AlbumArtistSortOrder' => new \PHPExiftool\Driver\Tag\Microsoft\AlbumArtistSortOrder(),
                'AlbumID' => new \PHPExiftool\Driver\Tag\Microsoft\AlbumID(),
                'AlbumIDAlbumArtist' => new \PHPExiftool\Driver\Tag\Microsoft\AlbumIDAlbumArtist(),
                'AlbumTitleSortOrder' => new \PHPExiftool\Driver\Tag\Microsoft\AlbumTitleSortOrder(),
                'AlternateSourceURL' => new \PHPExiftool\Driver\Tag\Microsoft\AlternateSourceURL(),
                'AudioBitrate' => new \PHPExiftool\Driver\Tag\Microsoft\AudioBitrate(),
                'AudioFormat' => new \PHPExiftool\Driver\Tag\Microsoft\AudioFormat(),
                'Author' => new \PHPExiftool\Driver\Tag\Microsoft\Author(),
                'AuthorSortOrder' => new \PHPExiftool\Driver\Tag\Microsoft\AuthorSortOrder(),
                'AverageLevel' => new \PHPExiftool\Driver\Tag\Microsoft\AverageLevel(),
                'Bitrate' => new \PHPExiftool\Driver\Tag\Microsoft\Bitrate(),
                'BuyNow' => new \PHPExiftool\Driver\Tag\Microsoft\BuyNow(),
                'BuyTickets' => new \PHPExiftool\Driver\Tag\Microsoft\BuyTickets(),
                'CDTrackEnabled' => new \PHPExiftool\Driver\Tag\Microsoft\CDTrackEnabled(),
                'CallLetters' => new \PHPExiftool\Driver\Tag\Microsoft\CallLetters(),
                'CameraManufacturer' => new \PHPExiftool\Driver\Tag\Microsoft\CameraManufacturer(),
                'CameraModel' => new \PHPExiftool\Driver\Tag\Microsoft\CameraModel(),
                'Channels' => new \PHPExiftool\Driver\Tag\Microsoft\Channels(),
                'Comment' => new \PHPExiftool\Driver\Tag\Microsoft\Comment(),
                'ContentDistributorDuration' => new \PHPExiftool\Driver\Tag\Microsoft\ContentDistributorDuration(),
                'Copyright' => new \PHPExiftool\Driver\Tag\Microsoft\Copyright(),
                'Count' => new \PHPExiftool\Driver\Tag\Microsoft\Count(),
                'CurrentBitrate' => new \PHPExiftool\Driver\Tag\Microsoft\CurrentBitrate(),
                'DLNAServerUDN' => new \PHPExiftool\Driver\Tag\Microsoft\DLNAServerUDN(),
                'DLNASourceURI' => new \PHPExiftool\Driver\Tag\Microsoft\DLNASourceURI(),
                'DRMIndividualizedVersion' => new \PHPExiftool\Driver\Tag\Microsoft\DRMIndividualizedVersion(),
                'DRMKeyID' => new \PHPExiftool\Driver\Tag\Microsoft\DRMKeyID(),
                'DTCPIPHost' => new \PHPExiftool\Driver\Tag\Microsoft\DTCPIPHost(),
                'DTCPIPPort' => new \PHPExiftool\Driver\Tag\Microsoft\DTCPIPPort(),
                'DVDID' => new \PHPExiftool\Driver\Tag\Microsoft\DVDID(),
                'Description' => new \PHPExiftool\Driver\Tag\Microsoft\Description(),
                'DisplayArtist' => new \PHPExiftool\Driver\Tag\Microsoft\DisplayArtist(),
                'Duration' => new \PHPExiftool\Driver\Tag\Microsoft\Duration(),
                'Event' => new \PHPExiftool\Driver\Tag\Microsoft\Event(),
                'FileSize' => new \PHPExiftool\Driver\Tag\Microsoft\FileSize(),
                'FileType' => new \PHPExiftool\Driver\Tag\Microsoft\FileType(),
                'FormatTag' => new \PHPExiftool\Driver\Tag\Microsoft\FormatTag(),
                'FourCC' => new \PHPExiftool\Driver\Tag\Microsoft\FourCC(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\Microsoft\FrameRate(),
                'Frequency' => new \PHPExiftool\Driver\Tag\Microsoft\Frequency(),
                'IsNetworkFeed' => new \PHPExiftool\Driver\Tag\Microsoft\IsNetworkFeed(),
                'IsVBR' => new \PHPExiftool\Driver\Tag\Microsoft\IsVBR(),
                'IsProtected' => new \PHPExiftool\Driver\Tag\Microsoft\IsProtected(),
                'LeadPerformer' => new \PHPExiftool\Driver\Tag\Microsoft\LeadPerformer(),
                'LibraryID' => new \PHPExiftool\Driver\Tag\Microsoft\LibraryID(),
                'LibraryName' => new \PHPExiftool\Driver\Tag\Microsoft\LibraryName(),
                'Location' => new \PHPExiftool\Driver\Tag\Microsoft\Location(),
                'MediaContentTypes' => new \PHPExiftool\Driver\Tag\Microsoft\MediaContentTypes(),
                'MediaType' => new \PHPExiftool\Driver\Tag\Microsoft\MediaType(),
                'ModifiedBy' => new \PHPExiftool\Driver\Tag\Microsoft\ModifiedBy(),
                'MoreInfo' => new \PHPExiftool\Driver\Tag\Microsoft\MoreInfo(),
                'PartOfSet' => new \PHPExiftool\Driver\Tag\Microsoft\PartOfSet(),
                'PeakValue' => new \PHPExiftool\Driver\Tag\Microsoft\PeakValue(),
                'PixelAspectRatioX' => new \PHPExiftool\Driver\Tag\Microsoft\PixelAspectRatioX(),
                'PixelAspectRatioY' => new \PHPExiftool\Driver\Tag\Microsoft\PixelAspectRatioY(),
                'PlaylistIndex' => new \PHPExiftool\Driver\Tag\Microsoft\PlaylistIndex(),
                'Provider' => new \PHPExiftool\Driver\Tag\Microsoft\Provider(),
                'ProviderLogoURL' => new \PHPExiftool\Driver\Tag\Microsoft\ProviderLogoURL(),
                'ProviderURL' => new \PHPExiftool\Driver\Tag\Microsoft\ProviderURL(),
                'RadioBand' => new \PHPExiftool\Driver\Tag\Microsoft\RadioBand(),
                'RadioFormat' => new \PHPExiftool\Driver\Tag\Microsoft\RadioFormat(),
                'RatingOrg' => new \PHPExiftool\Driver\Tag\Microsoft\RatingOrg(),
                'RecordingTime' => new \PHPExiftool\Driver\Tag\Microsoft\RecordingTime(),
                'RecordingTimeDay' => new \PHPExiftool\Driver\Tag\Microsoft\RecordingTimeDay(),
                'RecordingTimeMonth' => new \PHPExiftool\Driver\Tag\Microsoft\RecordingTimeMonth(),
                'RecordingTimeYear' => new \PHPExiftool\Driver\Tag\Microsoft\RecordingTimeYear(),
                'RecordingTimeYearMonth' => new \PHPExiftool\Driver\Tag\Microsoft\RecordingTimeYearMonth(),
                'RecordingTimeYearMonthDay' => new \PHPExiftool\Driver\Tag\Microsoft\RecordingTimeYearMonthDay(),
                'ReleaseDate' => new \PHPExiftool\Driver\Tag\Microsoft\ReleaseDate(),
                'ReleaseDateDay' => new \PHPExiftool\Driver\Tag\Microsoft\ReleaseDateDay(),
                'ReleaseDateMonth' => new \PHPExiftool\Driver\Tag\Microsoft\ReleaseDateMonth(),
                'ReleaseDateYear' => new \PHPExiftool\Driver\Tag\Microsoft\ReleaseDateYear(),
                'ReleaseDateYearMonth' => new \PHPExiftool\Driver\Tag\Microsoft\ReleaseDateYearMonth(),
                'ReleaseDateYearMonthDay' => new \PHPExiftool\Driver\Tag\Microsoft\ReleaseDateYearMonthDay(),
                'RequestState' => new \PHPExiftool\Driver\Tag\Microsoft\RequestState(),
                'ShadowFilePath' => new \PHPExiftool\Driver\Tag\Microsoft\ShadowFilePath(),
                'SourceURL' => new \PHPExiftool\Driver\Tag\Microsoft\SourceURL(),
                'Subject' => new \PHPExiftool\Driver\Tag\Microsoft\Subject(),
                'Sync01' => new \PHPExiftool\Driver\Tag\Microsoft\Sync01(),
                'Sync02' => new \PHPExiftool\Driver\Tag\Microsoft\Sync02(),
                'Sync03' => new \PHPExiftool\Driver\Tag\Microsoft\Sync03(),
                'Sync04' => new \PHPExiftool\Driver\Tag\Microsoft\Sync04(),
                'Sync05' => new \PHPExiftool\Driver\Tag\Microsoft\Sync05(),
                'Sync06' => new \PHPExiftool\Driver\Tag\Microsoft\Sync06(),
                'Sync07' => new \PHPExiftool\Driver\Tag\Microsoft\Sync07(),
                'Sync08' => new \PHPExiftool\Driver\Tag\Microsoft\Sync08(),
                'Sync09' => new \PHPExiftool\Driver\Tag\Microsoft\Sync09(),
                'Sync10' => new \PHPExiftool\Driver\Tag\Microsoft\Sync10(),
                'Sync11' => new \PHPExiftool\Driver\Tag\Microsoft\Sync11(),
                'Sync12' => new \PHPExiftool\Driver\Tag\Microsoft\Sync12(),
                'Sync13' => new \PHPExiftool\Driver\Tag\Microsoft\Sync13(),
                'Sync14' => new \PHPExiftool\Driver\Tag\Microsoft\Sync14(),
                'Sync15' => new \PHPExiftool\Driver\Tag\Microsoft\Sync15(),
                'Sync16' => new \PHPExiftool\Driver\Tag\Microsoft\Sync16(),
                'SyncOnly' => new \PHPExiftool\Driver\Tag\Microsoft\SyncOnly(),
                'SyncState' => new \PHPExiftool\Driver\Tag\Microsoft\SyncState(),
                'Temporary' => new \PHPExiftool\Driver\Tag\Microsoft\Temporary(),
                'Title' => new \PHPExiftool\Driver\Tag\Microsoft\Title(),
                'TitleSortOrder' => new \PHPExiftool\Driver\Tag\Microsoft\TitleSortOrder(),
                'TotalDuration' => new \PHPExiftool\Driver\Tag\Microsoft\TotalDuration(),
                'TrackingID' => new \PHPExiftool\Driver\Tag\Microsoft\TrackingID(),
                'UserCustom1' => new \PHPExiftool\Driver\Tag\Microsoft\UserCustom1(),
                'UserCustom2' => new \PHPExiftool\Driver\Tag\Microsoft\UserCustom2(),
                'UserEffectiveRating' => new \PHPExiftool\Driver\Tag\Microsoft\UserEffectiveRating(),
                'UserLastPlayedTime' => new \PHPExiftool\Driver\Tag\Microsoft\UserLastPlayedTime(),
                'UserPlayCount' => new \PHPExiftool\Driver\Tag\Microsoft\UserPlayCount(),
                'UserPlaycountAfternoon' => new \PHPExiftool\Driver\Tag\Microsoft\UserPlaycountAfternoon(),
                'UserPlaycountEvening' => new \PHPExiftool\Driver\Tag\Microsoft\UserPlaycountEvening(),
                'UserPlaycountMorning' => new \PHPExiftool\Driver\Tag\Microsoft\UserPlaycountMorning(),
                'UserPlaycountNight' => new \PHPExiftool\Driver\Tag\Microsoft\UserPlaycountNight(),
                'UserPlaycountWeekday' => new \PHPExiftool\Driver\Tag\Microsoft\UserPlaycountWeekday(),
                'UserPlaycountWeekend' => new \PHPExiftool\Driver\Tag\Microsoft\UserPlaycountWeekend(),
                'UserRating' => new \PHPExiftool\Driver\Tag\Microsoft\UserRating(),
                'UserServiceRating' => new \PHPExiftool\Driver\Tag\Microsoft\UserServiceRating(),
                'VideoBitrate' => new \PHPExiftool\Driver\Tag\Microsoft\VideoBitrate(),
                'VideoFormat' => new \PHPExiftool\Driver\Tag\Microsoft\VideoFormat(),
                'AlbumArtist' => new \PHPExiftool\Driver\Tag\Microsoft\AlbumArtist(),
                'AlbumCoverURL' => new \PHPExiftool\Driver\Tag\Microsoft\AlbumCoverURL(),
                'AlbumTitle' => new \PHPExiftool\Driver\Tag\Microsoft\AlbumTitle(),
                'mixed' => new \PHPExiftool\Driver\Tag\Microsoft\BeatsPerMinute(),
                'Category' => new \PHPExiftool\Driver\Tag\Microsoft\Category(),
                'Composer' => new \PHPExiftool\Driver\Tag\Microsoft\Composer(),
                'Conductor' => new \PHPExiftool\Driver\Tag\Microsoft\Conductor(),
                'ContentDistributor' => new \PHPExiftool\Driver\Tag\Microsoft\ContentDistributor(),
                'ContentDistributorType' => new \PHPExiftool\Driver\Tag\Microsoft\ContentDistributorType(),
                'ContentGroupDescription' => new \PHPExiftool\Driver\Tag\Microsoft\ContentGroupDescription(),
                'Director' => new \PHPExiftool\Driver\Tag\Microsoft\Director(),
                'EncodingTime' => new \PHPExiftool\Driver\Tag\Microsoft\EncodingTime(),
                'Genre' => new \PHPExiftool\Driver\Tag\Microsoft\Genre(),
                'GenreID' => new \PHPExiftool\Driver\Tag\Microsoft\GenreID(),
                'InitialKey' => new \PHPExiftool\Driver\Tag\Microsoft\InitialKey(),
                'Language' => new \PHPExiftool\Driver\Tag\Microsoft\Language(),
                'Lyrics' => new \PHPExiftool\Driver\Tag\Microsoft\Lyrics(),
                'MCDI' => new \PHPExiftool\Driver\Tag\Microsoft\MCDI(),
                'MediaClassPrimaryID' => new \PHPExiftool\Driver\Tag\Microsoft\MediaClassPrimaryID(),
                'MediaClassSecondaryID' => new \PHPExiftool\Driver\Tag\Microsoft\MediaClassSecondaryID(),
                'MediaOriginalBroadcastDateTime' => new \PHPExiftool\Driver\Tag\Microsoft\MediaOriginalBroadcastDateTime(),
                'MediaOriginalChannel' => new \PHPExiftool\Driver\Tag\Microsoft\MediaOriginalChannel(),
                'MediaStationName' => new \PHPExiftool\Driver\Tag\Microsoft\MediaStationName(),
                'Mood' => new \PHPExiftool\Driver\Tag\Microsoft\Mood(),
                'OriginalAlbumTitle' => new \PHPExiftool\Driver\Tag\Microsoft\OriginalAlbumTitle(),
                'OriginalArtist' => new \PHPExiftool\Driver\Tag\Microsoft\OriginalArtist(),
                'OriginalLyricist' => new \PHPExiftool\Driver\Tag\Microsoft\OriginalLyricist(),
                'ParentalRating' => new \PHPExiftool\Driver\Tag\Microsoft\ParentalRating(),
                'Period' => new \PHPExiftool\Driver\Tag\Microsoft\Period(),
                'Producer' => new \PHPExiftool\Driver\Tag\Microsoft\Producer(),
                'ProtectionType' => new \PHPExiftool\Driver\Tag\Microsoft\ProtectionType(),
                'ProviderRating' => new \PHPExiftool\Driver\Tag\Microsoft\ProviderRating(),
                'ProviderStyle' => new \PHPExiftool\Driver\Tag\Microsoft\ProviderStyle(),
                'Publisher' => new \PHPExiftool\Driver\Tag\Microsoft\Publisher(),
                'SubTitle' => new \PHPExiftool\Driver\Tag\Microsoft\SubTitle(),
                'SubTitleDescription' => new \PHPExiftool\Driver\Tag\Microsoft\SubTitleDescription(),
                'SubscriptionContentID' => new \PHPExiftool\Driver\Tag\Microsoft\SubscriptionContentID(),
                'TrackNumber' => new \PHPExiftool\Driver\Tag\Microsoft\TrackNumber(),
                'UniqueFileIdentifier' => new \PHPExiftool\Driver\Tag\Microsoft\UniqueFileIdentifier(),
                'VideoFrameRate' => new \PHPExiftool\Driver\Tag\Microsoft\VideoFrameRate(),
                'VideoHeight' => new \PHPExiftool\Driver\Tag\Microsoft\VideoHeight(),
                'VideoWidth' => new \PHPExiftool\Driver\Tag\Microsoft\VideoWidth(),
                'WMCollectionGroupID' => new \PHPExiftool\Driver\Tag\Microsoft\WMCollectionGroupID(),
                'WMCollectionID' => new \PHPExiftool\Driver\Tag\Microsoft\WMCollectionID(),
                'WMContentID' => new \PHPExiftool\Driver\Tag\Microsoft\WMContentID(),
                'WMShadowFileSourceDRMType' => new \PHPExiftool\Driver\Tag\Microsoft\WMShadowFileSourceDRMType(),
                'WMShadowFileSourceFileType' => new \PHPExiftool\Driver\Tag\Microsoft\WMShadowFileSourceFileType(),
                'Writer' => new \PHPExiftool\Driver\Tag\Microsoft\Writer(),
                'Year' => new \PHPExiftool\Driver\Tag\Microsoft\Year(),
                'ChapterNum' => new \PHPExiftool\Driver\Tag\Microsoft\ChapterNum(),
                'TitleNum' => new \PHPExiftool\Driver\Tag\Microsoft\TitleNum(),
                'Resources' => new \PHPExiftool\Driver\Tag\Microsoft\Resources(),
                'Complete' => new \PHPExiftool\Driver\Tag\Microsoft\Complete(),
                'HomeCountry-Region' => new \PHPExiftool\Driver\Tag\Microsoft\HomeCountryRegion(),
                'TaskOwner' => new \PHPExiftool\Driver\Tag\Microsoft\TaskOwner(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\Microsoft\MaxAperture(),
                'OptionalAttendees' => new \PHPExiftool\Driver\Tag\Microsoft\OptionalAttendees(),
                'HomeStreet' => new \PHPExiftool\Driver\Tag\Microsoft\HomeStreet(),
                'RequiredAttendeeAddresses' => new \PHPExiftool\Driver\Tag\Microsoft\RequiredAttendeeAddresses(),
                'SenderAddress' => new \PHPExiftool\Driver\Tag\Microsoft\SenderAddress(),
                'FileVersion' => new \PHPExiftool\Driver\Tag\Microsoft\FileVersion(),
                'ProductName' => new \PHPExiftool\Driver\Tag\Microsoft\ProductName(),
                'ProductVersion' => new \PHPExiftool\Driver\Tag\Microsoft\ProductVersion(),
                'LegalTrademarks' => new \PHPExiftool\Driver\Tag\Microsoft\LegalTrademarks(),
                'SenderName' => new \PHPExiftool\Driver\Tag\Microsoft\SenderName(),
                'ParentalRatingReason' => new \PHPExiftool\Driver\Tag\Microsoft\ParentalRatingReason(),
                'FirstName' => new \PHPExiftool\Driver\Tag\Microsoft\FirstName(),
                'DateImported' => new \PHPExiftool\Driver\Tag\Microsoft\DateImported(),
                'CameraMaker' => new \PHPExiftool\Driver\Tag\Microsoft\CameraMaker(),
                'Orientation' => new \PHPExiftool\Driver\Tag\Microsoft\Orientation(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Microsoft\ExposureTime(),
                'F-stop' => new \PHPExiftool\Driver\Tag\Microsoft\FStop(),
                'ExposureProgram' => new \PHPExiftool\Driver\Tag\Microsoft\ExposureProgram(),
                'ISOSpeed' => new \PHPExiftool\Driver\Tag\Microsoft\ISOSpeed(),
                'DatePictureTaken' => new \PHPExiftool\Driver\Tag\Microsoft\DatePictureTaken(),
                'ExposureBias' => new \PHPExiftool\Driver\Tag\Microsoft\ExposureBias(),
                'SubjectDistance' => new \PHPExiftool\Driver\Tag\Microsoft\SubjectDistance(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Microsoft\MeteringMode(),
                'LightSource' => new \PHPExiftool\Driver\Tag\Microsoft\LightSource(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Microsoft\FlashMode(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Microsoft\FocalLength(),
                'HomePhone' => new \PHPExiftool\Driver\Tag\Microsoft\HomePhone(),
                'PrimaryPhone' => new \PHPExiftool\Driver\Tag\Microsoft\PrimaryPhone(),
                'CellPhone' => new \PHPExiftool\Driver\Tag\Microsoft\CellPhone(),
                'Birthday' => new \PHPExiftool\Driver\Tag\Microsoft\Birthday(),
                'PrimaryE-mail' => new \PHPExiftool\Driver\Tag\Microsoft\PrimaryEMail(),
                'JobTitle' => new \PHPExiftool\Driver\Tag\Microsoft\JobTitle(),
                'HomeCity' => new \PHPExiftool\Driver\Tag\Microsoft\HomeCity(),
                'PersonalTitle' => new \PHPExiftool\Driver\Tag\Microsoft\PersonalTitle(),
                'OfficeLocation' => new \PHPExiftool\Driver\Tag\Microsoft\OfficeLocation(),
                'GivenName' => new \PHPExiftool\Driver\Tag\Microsoft\GivenName(),
                'MiddleName' => new \PHPExiftool\Driver\Tag\Microsoft\MiddleName(),
                'Suffix' => new \PHPExiftool\Driver\Tag\Microsoft\Suffix(),
                'Nickname' => new \PHPExiftool\Driver\Tag\Microsoft\Nickname(),
                'PostalCode' => new \PHPExiftool\Driver\Tag\Microsoft\PostalCode(),
                'StationName' => new \PHPExiftool\Driver\Tag\Microsoft\StationName(),
                'Division' => new \PHPExiftool\Driver\Tag\Microsoft\Division(),
                'Kinds' => new \PHPExiftool\Driver\Tag\Microsoft\Kinds(),
                'ClientID' => new \PHPExiftool\Driver\Tag\Microsoft\ClientID(),
                'Type' => new \PHPExiftool\Driver\Tag\Microsoft\Type(),
                'FileCount' => new \PHPExiftool\Driver\Tag\Microsoft\FileCount(),
                'TotalFileSize' => new \PHPExiftool\Driver\Tag\Microsoft\TotalFileSize(),
                'Computer' => new \PHPExiftool\Driver\Tag\Microsoft\Computer(),
                'PerceivedType' => new \PHPExiftool\Driver\Tag\Microsoft\PerceivedType(),
                'DateAcquired' => new \PHPExiftool\Driver\Tag\Microsoft\DateAcquired(),
                'MediaCreated' => new \PHPExiftool\Driver\Tag\Microsoft\MediaCreated(),
                'IsRecurring' => new \PHPExiftool\Driver\Tag\Microsoft\IsRecurring(),
                'Incomplete' => new \PHPExiftool\Driver\Tag\Microsoft\Incomplete(),
                'E-mail2' => new \PHPExiftool\Driver\Tag\Microsoft\EMail2(),
                'Project' => new \PHPExiftool\Driver\Tag\Microsoft\Project(),
                'Gender' => new \PHPExiftool\Driver\Tag\Microsoft\Gender(),
                'DueDate' => new \PHPExiftool\Driver\Tag\Microsoft\DueDate(),
                'BusinessCity' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessCity(),
                'Filename' => new \PHPExiftool\Driver\Tag\Microsoft\Filename(),
                'DateArchived' => new \PHPExiftool\Driver\Tag\Microsoft\DateArchived(),
                'BusinessStateOrProvince' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessStateOrProvince(),
                'BroadcastDate' => new \PHPExiftool\Driver\Tag\Microsoft\BroadcastDate(),
                'Color' => new \PHPExiftool\Driver\Tag\Microsoft\Color(),
                'StartDate' => new \PHPExiftool\Driver\Tag\Microsoft\StartDate(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Microsoft\Saturation(),
                'SearchRanking' => new \PHPExiftool\Driver\Tag\Microsoft\SearchRanking(),
                'OtherAddress' => new \PHPExiftool\Driver\Tag\Microsoft\OtherAddress(),
                'AutoSummary' => new \PHPExiftool\Driver\Tag\Microsoft\AutoSummary(),
                'Summary' => new \PHPExiftool\Driver\Tag\Microsoft\Summary(),
                'BusinessHomePage' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessHomePage(),
                'Artist' => new \PHPExiftool\Driver\Tag\Microsoft\Artist(),
                'Conductors' => new \PHPExiftool\Driver\Tag\Microsoft\Conductors(),
                'Free-busyStatus' => new \PHPExiftool\Driver\Tag\Microsoft\FreeBusyStatus(),
                'URL' => new \PHPExiftool\Driver\Tag\Microsoft\URL(),
                'DateVisited' => new \PHPExiftool\Driver\Tag\Microsoft\DateVisited(),
                'IsDeleted' => new \PHPExiftool\Driver\Tag\Microsoft\IsDeleted(),
                'HasFlag' => new \PHPExiftool\Driver\Tag\Microsoft\HasFlag(),
                'Hobbies' => new \PHPExiftool\Driver\Tag\Microsoft\Hobbies(),
                'FullName' => new \PHPExiftool\Driver\Tag\Microsoft\FullName(),
                'Street' => new \PHPExiftool\Driver\Tag\Microsoft\Street(),
                'Dimensions' => new \PHPExiftool\Driver\Tag\Microsoft\Dimensions(),
                'Untitled0' => new \PHPExiftool\Driver\Tag\Microsoft\Untitled0(),
                'Untitled1' => new \PHPExiftool\Driver\Tag\Microsoft\Untitled1(),
                'HorizontalResolution' => new \PHPExiftool\Driver\Tag\Microsoft\HorizontalResolution(),
                'VerticalResolution' => new \PHPExiftool\Driver\Tag\Microsoft\VerticalResolution(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\Microsoft\BitDepth(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\Microsoft\AudioSampleRate(),
                'AudioSampleSize' => new \PHPExiftool\Driver\Tag\Microsoft\AudioSampleSize(),
                'VideoCompression' => new \PHPExiftool\Driver\Tag\Microsoft\VideoCompression(),
                'FrameWidth' => new \PHPExiftool\Driver\Tag\Microsoft\FrameWidth(),
                'FrameHeight' => new \PHPExiftool\Driver\Tag\Microsoft\FrameHeight(),
                'TotalBitrate' => new \PHPExiftool\Driver\Tag\Microsoft\TotalBitrate(),
                'DataRate' => new \PHPExiftool\Driver\Tag\Microsoft\DataRate(),
                'Composers' => new \PHPExiftool\Driver\Tag\Microsoft\Composers(),
                'Directors' => new \PHPExiftool\Driver\Tag\Microsoft\Directors(),
                'Producers' => new \PHPExiftool\Driver\Tag\Microsoft\Producers(),
                'Writers' => new \PHPExiftool\Driver\Tag\Microsoft\Writers(),
                'UserWebURL' => new \PHPExiftool\Driver\Tag\Microsoft\UserWebURL(),
                'EncodedBy' => new \PHPExiftool\Driver\Tag\Microsoft\EncodedBy(),
                'Rating' => new \PHPExiftool\Driver\Tag\Microsoft\Rating(),
                'E-mail3' => new \PHPExiftool\Driver\Tag\Microsoft\EMail3(),
                'HomeFax' => new \PHPExiftool\Driver\Tag\Microsoft\HomeFax(),
                'Source' => new \PHPExiftool\Driver\Tag\Microsoft\Source(),
                'FlagColor' => new \PHPExiftool\Driver\Tag\Microsoft\FlagColor(),
                'BusinessPhone' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessPhone(),
                'ProgramMode' => new \PHPExiftool\Driver\Tag\Microsoft\ProgramMode(),
                'OfflineStatus' => new \PHPExiftool\Driver\Tag\Microsoft\OfflineStatus(),
                'ClosedCaptioning' => new \PHPExiftool\Driver\Tag\Microsoft\ClosedCaptioning(),
                'Rerun' => new \PHPExiftool\Driver\Tag\Microsoft\Rerun(),
                'SAP' => new \PHPExiftool\Driver\Tag\Microsoft\SAP(),
                'EpisodeName' => new \PHPExiftool\Driver\Tag\Microsoft\EpisodeName(),
                'ProgramDescription' => new \PHPExiftool\Driver\Tag\Microsoft\ProgramDescription(),
                'StationCallSign' => new \PHPExiftool\Driver\Tag\Microsoft\StationCallSign(),
                'ChannelNumber' => new \PHPExiftool\Driver\Tag\Microsoft\ChannelNumber(),
                'OtherCity' => new \PHPExiftool\Driver\Tag\Microsoft\OtherCity(),
                'OtherStateOrProvince' => new \PHPExiftool\Driver\Tag\Microsoft\OtherStateOrProvince(),
                'Profession' => new \PHPExiftool\Driver\Tag\Microsoft\Profession(),
                'DateCompleted' => new \PHPExiftool\Driver\Tag\Microsoft\DateCompleted(),
                'ReminderTime' => new \PHPExiftool\Driver\Tag\Microsoft\ReminderTime(),
                'BusinessAddress' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessAddress(),
                'OrganizerAddress' => new \PHPExiftool\Driver\Tag\Microsoft\OrganizerAddress(),
                'HomePOBox' => new \PHPExiftool\Driver\Tag\Microsoft\HomePOBox(),
                'E-mailList' => new \PHPExiftool\Driver\Tag\Microsoft\EMailList(),
                'CompanyMainPhone' => new \PHPExiftool\Driver\Tag\Microsoft\CompanyMainPhone(),
                'HomePostalCode' => new \PHPExiftool\Driver\Tag\Microsoft\HomePostalCode(),
                'OtherPOBox' => new \PHPExiftool\Driver\Tag\Microsoft\OtherPOBox(),
                'OtherCountry-Region' => new \PHPExiftool\Driver\Tag\Microsoft\OtherCountryRegion(),
                'LastName' => new \PHPExiftool\Driver\Tag\Microsoft\LastName(),
                'CarPhone' => new \PHPExiftool\Driver\Tag\Microsoft\CarPhone(),
                'BusinessFax' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessFax(),
                'EntryType' => new \PHPExiftool\Driver\Tag\Microsoft\EntryType(),
                'OtherPostalCode' => new \PHPExiftool\Driver\Tag\Microsoft\OtherPostalCode(),
                'Label' => new \PHPExiftool\Driver\Tag\Microsoft\Label(),
                'HomeAddress' => new \PHPExiftool\Driver\Tag\Microsoft\HomeAddress(),
                'AssistantsPhone' => new \PHPExiftool\Driver\Tag\Microsoft\AssistantsPhone(),
                'Anniversary' => new \PHPExiftool\Driver\Tag\Microsoft\Anniversary(),
                'Owner' => new \PHPExiftool\Driver\Tag\Microsoft\Owner(),
                'SpaceFree' => new \PHPExiftool\Driver\Tag\Microsoft\SpaceFree(),
                'TotalSize' => new \PHPExiftool\Driver\Tag\Microsoft\TotalSize(),
                'SpaceUsed' => new \PHPExiftool\Driver\Tag\Microsoft\SpaceUsed(),
                'Priority' => new \PHPExiftool\Driver\Tag\Microsoft\Priority(),
                'HasAttachments' => new \PHPExiftool\Driver\Tag\Microsoft\HasAttachments(),
                'Spouse' => new \PHPExiftool\Driver\Tag\Microsoft\Spouse(),
                'FocalLength35mm' => new \PHPExiftool\Driver\Tag\Microsoft\FocalLength35mm(),
                'IsCompleted' => new \PHPExiftool\Driver\Tag\Microsoft\IsCompleted(),
                'OfflineAvailability' => new \PHPExiftool\Driver\Tag\Microsoft\OfflineAvailability(),
                'OrganizerName' => new \PHPExiftool\Driver\Tag\Microsoft\OrganizerName(),
                'TTY-TTDPhone' => new \PHPExiftool\Driver\Tag\Microsoft\TTYTTDPhone(),
                'Protected' => new \PHPExiftool\Driver\Tag\Microsoft\Protected0(),
                'BusinessCountry-Region' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessCountryRegion(),
                'RequiredAttendees' => new \PHPExiftool\Driver\Tag\Microsoft\RequiredAttendees(),
                'Name' => new \PHPExiftool\Driver\Tag\Microsoft\Name(),
                'Size' => new \PHPExiftool\Driver\Tag\Microsoft\Size(),
                'Attributes' => new \PHPExiftool\Driver\Tag\Microsoft\Attributes(),
                'DateModified' => new \PHPExiftool\Driver\Tag\Microsoft\DateModified(),
                'DateCreated' => new \PHPExiftool\Driver\Tag\Microsoft\DateCreated(),
                'DateAccessed' => new \PHPExiftool\Driver\Tag\Microsoft\DateAccessed(),
                'FolderName' => new \PHPExiftool\Driver\Tag\Microsoft\FolderName(),
                'LinkTarget' => new \PHPExiftool\Driver\Tag\Microsoft\LinkTarget(),
                'LinkStatus' => new \PHPExiftool\Driver\Tag\Microsoft\LinkStatus(),
                'BusinessPOBox' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessPOBox(),
                'ToDoTitle' => new \PHPExiftool\Driver\Tag\Microsoft\ToDoTitle(),
                'CallbackNumber' => new \PHPExiftool\Driver\Tag\Microsoft\CallbackNumber(),
                'IsOnline' => new \PHPExiftool\Driver\Tag\Microsoft\IsOnline(),
                'MailingAddress' => new \PHPExiftool\Driver\Tag\Microsoft\MailingAddress(),
                'Telex' => new \PHPExiftool\Driver\Tag\Microsoft\Telex(),
                'EndDate' => new \PHPExiftool\Driver\Tag\Microsoft\EndDate(),
                'HomeStateOrProvince' => new \PHPExiftool\Driver\Tag\Microsoft\HomeStateOrProvince(),
                'City' => new \PHPExiftool\Driver\Tag\Microsoft\City(),
                'E-mailDisplayName' => new \PHPExiftool\Driver\Tag\Microsoft\EMailDisplayName(),
                'AssistantsName' => new \PHPExiftool\Driver\Tag\Microsoft\AssistantsName(),
                'Creator' => new \PHPExiftool\Driver\Tag\Microsoft\Creator(),
                'EXIFVersion' => new \PHPExiftool\Driver\Tag\Microsoft\EXIFVersion(),
                'BillingInformation' => new \PHPExiftool\Driver\Tag\Microsoft\BillingInformation(),
                'Children' => new \PHPExiftool\Driver\Tag\Microsoft\Children(),
                'Participants' => new \PHPExiftool\Driver\Tag\Microsoft\Participants(),
                'OptionalAttendeeAddresses' => new \PHPExiftool\Driver\Tag\Microsoft\OptionalAttendeeAddresses(),
                'Company' => new \PHPExiftool\Driver\Tag\Microsoft\Company(),
                'ContentType' => new \PHPExiftool\Driver\Tag\Microsoft\ContentType(),
                'Status' => new \PHPExiftool\Driver\Tag\Microsoft\Status(),
                'Slides' => new \PHPExiftool\Driver\Tag\Microsoft\Slides(),
                'Pager' => new \PHPExiftool\Driver\Tag\Microsoft\Pager(),
                'IMAddresses' => new \PHPExiftool\Driver\Tag\Microsoft\IMAddresses(),
                'Folder' => new \PHPExiftool\Driver\Tag\Microsoft\Folder(),
                'ConversationID' => new \PHPExiftool\Driver\Tag\Microsoft\ConversationID(),
                'BusinessStreet' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessStreet(),
                'DateReleased' => new \PHPExiftool\Driver\Tag\Microsoft\DateReleased(),
                'POBox' => new \PHPExiftool\Driver\Tag\Microsoft\POBox(),
                'ContactNames' => new \PHPExiftool\Driver\Tag\Microsoft\ContactNames(),
                'DocumentID' => new \PHPExiftool\Driver\Tag\Microsoft\DocumentID(),
                'LensModel' => new \PHPExiftool\Driver\Tag\Microsoft\LensModel(),
                'BusinessPostalCode' => new \PHPExiftool\Driver\Tag\Microsoft\BusinessPostalCode(),
                'ReadStatus' => new \PHPExiftool\Driver\Tag\Microsoft\ReadStatus(),
                'Importance' => new \PHPExiftool\Driver\Tag\Microsoft\Importance(),
                'FlagStatus' => new \PHPExiftool\Driver\Tag\Microsoft\FlagStatus(),
                'FromAddresses' => new \PHPExiftool\Driver\Tag\Microsoft\FromAddresses(),
                'FromNames' => new \PHPExiftool\Driver\Tag\Microsoft\FromNames(),
                'Store' => new \PHPExiftool\Driver\Tag\Microsoft\Store(),
                'ToAddresses' => new \PHPExiftool\Driver\Tag\Microsoft\ToAddresses(),
                'ToNames' => new \PHPExiftool\Driver\Tag\Microsoft\ToNames(),
                'Webpage' => new \PHPExiftool\Driver\Tag\Microsoft\Webpage(),
                'DateSent' => new \PHPExiftool\Driver\Tag\Microsoft\DateSent(),
                'BccAddresses' => new \PHPExiftool\Driver\Tag\Microsoft\BccAddresses(),
                'DateReceived' => new \PHPExiftool\Driver\Tag\Microsoft\DateReceived(),
                'Attachments' => new \PHPExiftool\Driver\Tag\Microsoft\Attachments(),
                'BccNames' => new \PHPExiftool\Driver\Tag\Microsoft\BccNames(),
                'CcAddresses' => new \PHPExiftool\Driver\Tag\Microsoft\CcAddresses(),
                'CcNames' => new \PHPExiftool\Driver\Tag\Microsoft\CcNames(),
                'FolderPath' => new \PHPExiftool\Driver\Tag\Microsoft\FolderPath(),
                'Path' => new \PHPExiftool\Driver\Tag\Microsoft\Path(),
                'AccountName' => new \PHPExiftool\Driver\Tag\Microsoft\AccountName(),
                'Country-Region' => new \PHPExiftool\Driver\Tag\Microsoft\CountryRegion(),
                'LensMaker' => new \PHPExiftool\Driver\Tag\Microsoft\LensMaker(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Microsoft\WhiteBalance(),
                'Shared' => new \PHPExiftool\Driver\Tag\Microsoft\Shared(),
                'SharedWith' => new \PHPExiftool\Driver\Tag\Microsoft\SharedWith(),
                'StateOrProvince' => new \PHPExiftool\Driver\Tag\Microsoft\StateOrProvince(),
                'FileAs' => new \PHPExiftool\Driver\Tag\Microsoft\FileAs(),
                'IsAttachment' => new \PHPExiftool\Driver\Tag\Microsoft\IsAttachment(),
                'TotalEditingTime' => new \PHPExiftool\Driver\Tag\Microsoft\TotalEditingTime(),
                'LastPrinted' => new \PHPExiftool\Driver\Tag\Microsoft\LastPrinted(),
                'Untitled2' => new \PHPExiftool\Driver\Tag\Microsoft\Untitled2(),
                'DateLastSaved' => new \PHPExiftool\Driver\Tag\Microsoft\DateLastSaved(),
                'Pages' => new \PHPExiftool\Driver\Tag\Microsoft\Pages(),
                'WordCount' => new \PHPExiftool\Driver\Tag\Microsoft\WordCount(),
                'ProgramName' => new \PHPExiftool\Driver\Tag\Microsoft\ProgramName(),
                'Keywords' => new \PHPExiftool\Driver\Tag\Microsoft\Keywords(),
                'Comments' => new \PHPExiftool\Driver\Tag\Microsoft\Comments(),
                'Contributors' => new \PHPExiftool\Driver\Tag\Microsoft\Contributors(),
                'Initials' => new \PHPExiftool\Driver\Tag\Microsoft\Initials(),
                'Date' => new \PHPExiftool\Driver\Tag\Microsoft\Date(),
                'Sensitivity' => new \PHPExiftool\Driver\Tag\Microsoft\Sensitivity(),
                'E-mailAddress' => new \PHPExiftool\Driver\Tag\Microsoft\EMailAddress(),
                'Department' => new \PHPExiftool\Driver\Tag\Microsoft\Department(),
                'Mileage' => new \PHPExiftool\Driver\Tag\Microsoft\Mileage(),
                'OtherStreet' => new \PHPExiftool\Driver\Tag\Microsoft\OtherStreet(),
            );
        });
        $this['XMP-microsoft'] = $this->share(function(){
            return array(
                'CameraSerialNumber' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\CameraSerialNumber(),
                'DateAcquired' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\DateAcquired(),
                'FlashManufacturer' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\FlashManufacturer(),
                'FlashModel' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\FlashModel(),
                'LastKeywordIPTC' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\LastKeywordIPTC(),
                'LastKeywordXMP' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\LastKeywordXMP(),
                'LensManufacturer' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\LensManufacturer(),
                'LensModel' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\LensModel(),
                'RatingPercent' => new \PHPExiftool\Driver\Tag\XMPMicrosoft\RatingPercent(),
            );
        });
        $this['Minolta'] = $this->share(function(){
            return array(
                'AFSensorActive' => new \PHPExiftool\Driver\Tag\Minolta\AFSensorActive(),
                'AFStatusActiveSensor' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusActiveSensor(),
                'AFStatusTop-Right' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusTopRight(),
                'AFStatusBottom-Right' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusBottomRight(),
                'AFStatusBottom' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusBottom(),
                'AFStatusMiddleHorizontal' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusMiddleHorizontal(),
                'AFStatusCenterVertical' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusCenterVertical(),
                'AFStatusTop' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusTop(),
                'AFStatusTop-Left' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusTopLeft(),
                'AFStatusBottom-Left' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusBottomLeft(),
                'FocusLocked' => new \PHPExiftool\Driver\Tag\Minolta\FocusLocked(),
                'AFPoint' => new \PHPExiftool\Driver\Tag\Minolta\AFPoint(),
                'AFMode' => new \PHPExiftool\Driver\Tag\Minolta\AFMode(),
                'AFStatusLeft' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusLeft(),
                'AFStatusCenterHorizontal' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusCenterHorizontal(),
                'AFStatusRight' => new \PHPExiftool\Driver\Tag\Minolta\AFStatusRight(),
                'AFAreaMode' => new \PHPExiftool\Driver\Tag\Minolta\AFAreaMode(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\Minolta\ExposureMode(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Minolta\FlashMode(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Minolta\WhiteBalance(),
                'MinoltaImageSize' => new \PHPExiftool\Driver\Tag\Minolta\MinoltaImageSize(),
                'MinoltaQuality' => new \PHPExiftool\Driver\Tag\Minolta\MinoltaQuality(),
                'DriveMode' => new \PHPExiftool\Driver\Tag\Minolta\DriveMode(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Minolta\MeteringMode(),
                'ISO' => new \PHPExiftool\Driver\Tag\Minolta\ISO(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Minolta\ExposureTime(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Minolta\FNumber(),
                'MacroMode' => new \PHPExiftool\Driver\Tag\Minolta\MacroMode(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Minolta\DigitalZoom(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Minolta\ExposureCompensation(),
                'BracketStep' => new \PHPExiftool\Driver\Tag\Minolta\BracketStep(),
                'IntervalLength' => new \PHPExiftool\Driver\Tag\Minolta\IntervalLength(),
                'IntervalNumber' => new \PHPExiftool\Driver\Tag\Minolta\IntervalNumber(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Minolta\FocalLength(),
                'FocusDistance' => new \PHPExiftool\Driver\Tag\Minolta\FocusDistance(),
                'FlashFired' => new \PHPExiftool\Driver\Tag\Minolta\FlashFired(),
                'MinoltaDate' => new \PHPExiftool\Driver\Tag\Minolta\MinoltaDate(),
                'MinoltaTime' => new \PHPExiftool\Driver\Tag\Minolta\MinoltaTime(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\Minolta\MaxAperture(),
                'FileNumberMemory' => new \PHPExiftool\Driver\Tag\Minolta\FileNumberMemory(),
                'LastFileNumber' => new \PHPExiftool\Driver\Tag\Minolta\LastFileNumber(),
                'ColorBalanceRed' => new \PHPExiftool\Driver\Tag\Minolta\ColorBalanceRed(),
                'ColorBalanceGreen' => new \PHPExiftool\Driver\Tag\Minolta\ColorBalanceGreen(),
                'ColorBalanceBlue' => new \PHPExiftool\Driver\Tag\Minolta\ColorBalanceBlue(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Minolta\Saturation(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Minolta\Contrast(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Minolta\Sharpness(),
                'SubjectProgram' => new \PHPExiftool\Driver\Tag\Minolta\SubjectProgram(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\Minolta\FlashExposureComp(),
                'ISOSetting' => new \PHPExiftool\Driver\Tag\Minolta\ISOSetting(),
                'MinoltaModelID' => new \PHPExiftool\Driver\Tag\Minolta\MinoltaModelID(),
                'IntervalMode' => new \PHPExiftool\Driver\Tag\Minolta\IntervalMode(),
                'FolderName' => new \PHPExiftool\Driver\Tag\Minolta\FolderName(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Minolta\ColorMode(),
                'ColorFilter' => new \PHPExiftool\Driver\Tag\Minolta\ColorFilter(),
                'BWFilter' => new \PHPExiftool\Driver\Tag\Minolta\BWFilter(),
                'InternalFlash' => new \PHPExiftool\Driver\Tag\Minolta\InternalFlash(),
                'Brightness' => new \PHPExiftool\Driver\Tag\Minolta\Brightness(),
                'SpotFocusPointX' => new \PHPExiftool\Driver\Tag\Minolta\SpotFocusPointX(),
                'SpotFocusPointY' => new \PHPExiftool\Driver\Tag\Minolta\SpotFocusPointY(),
                'WideFocusZone' => new \PHPExiftool\Driver\Tag\Minolta\WideFocusZone(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Minolta\FocusMode(),
                'FocusArea' => new \PHPExiftool\Driver\Tag\Minolta\FocusArea(),
                'DECPosition' => new \PHPExiftool\Driver\Tag\Minolta\DECPosition(),
                'ColorProfile' => new \PHPExiftool\Driver\Tag\Minolta\ColorProfile(),
                'DataImprint' => new \PHPExiftool\Driver\Tag\Minolta\DataImprint(),
                'FlashMetering' => new \PHPExiftool\Driver\Tag\Minolta\FlashMetering(),
                'Flash' => new \PHPExiftool\Driver\Tag\Minolta\Flash(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Minolta\ColorSpace(),
                'FreeMemoryCardImages' => new \PHPExiftool\Driver\Tag\Minolta\FreeMemoryCardImages(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\Minolta\ColorTemperature(),
                'HueAdjustment' => new \PHPExiftool\Driver\Tag\Minolta\HueAdjustment(),
                'Rotation' => new \PHPExiftool\Driver\Tag\Minolta\Rotation(),
                'PictureFinish' => new \PHPExiftool\Driver\Tag\Minolta\PictureFinish(),
                'ImageNumber' => new \PHPExiftool\Driver\Tag\Minolta\ImageNumber(),
                'NoiseReduction' => new \PHPExiftool\Driver\Tag\Minolta\NoiseReduction(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\Minolta\ImageStabilization(),
                'AFPoints' => new \PHPExiftool\Driver\Tag\Minolta\AFPoints(),
                'ImageNumber2' => new \PHPExiftool\Driver\Tag\Minolta\ImageNumber2(),
                'ZoneMatchingOn' => new \PHPExiftool\Driver\Tag\Minolta\ZoneMatchingOn(),
                'ExposureCompensationSetting' => new \PHPExiftool\Driver\Tag\Minolta\ExposureCompensationSetting(),
                'HighSpeedSync' => new \PHPExiftool\Driver\Tag\Minolta\HighSpeedSync(),
                'ShutterSpeedSetting' => new \PHPExiftool\Driver\Tag\Minolta\ShutterSpeedSetting(),
                'ApertureSetting' => new \PHPExiftool\Driver\Tag\Minolta\ApertureSetting(),
                'DriveMode2' => new \PHPExiftool\Driver\Tag\Minolta\DriveMode2(),
                'AFPointSelected' => new \PHPExiftool\Driver\Tag\Minolta\AFPointSelected(),
                'FlashExposureCompSet' => new \PHPExiftool\Driver\Tag\Minolta\FlashExposureCompSet(),
                'ZoneMatchingMode' => new \PHPExiftool\Driver\Tag\Minolta\ZoneMatchingMode(),
                'DynamicRangeOptimizer' => new \PHPExiftool\Driver\Tag\Minolta\DynamicRangeOptimizer(),
                'PrioritySetupShutterRelease' => new \PHPExiftool\Driver\Tag\Minolta\PrioritySetupShutterRelease(),
                'SelfTimerTime' => new \PHPExiftool\Driver\Tag\Minolta\SelfTimerTime(),
                'ContinuousBracketing' => new \PHPExiftool\Driver\Tag\Minolta\ContinuousBracketing(),
                'SingleFrameBracketing' => new \PHPExiftool\Driver\Tag\Minolta\SingleFrameBracketing(),
                'WhiteBalanceBracketing' => new \PHPExiftool\Driver\Tag\Minolta\WhiteBalanceBracketing(),
                'WhiteBalanceSetting' => new \PHPExiftool\Driver\Tag\Minolta\WhiteBalanceSetting(),
                'PresetWhiteBalance' => new \PHPExiftool\Driver\Tag\Minolta\PresetWhiteBalance(),
                'ColorTemperatureSetting' => new \PHPExiftool\Driver\Tag\Minolta\ColorTemperatureSetting(),
                'CustomWBSetting' => new \PHPExiftool\Driver\Tag\Minolta\CustomWBSetting(),
                'DynamicRangeOptimizerSetting' => new \PHPExiftool\Driver\Tag\Minolta\DynamicRangeOptimizerSetting(),
                'CustomWBRedLevel' => new \PHPExiftool\Driver\Tag\Minolta\CustomWBRedLevel(),
                'CustomWBGreenLevel' => new \PHPExiftool\Driver\Tag\Minolta\CustomWBGreenLevel(),
                'CustomWBBlueLevel' => new \PHPExiftool\Driver\Tag\Minolta\CustomWBBlueLevel(),
                'CustomWBError' => new \PHPExiftool\Driver\Tag\Minolta\CustomWBError(),
                'WhiteBalanceFineTune' => new \PHPExiftool\Driver\Tag\Minolta\WhiteBalanceFineTune(),
                'ColorCompensationFilter' => new \PHPExiftool\Driver\Tag\Minolta\ColorCompensationFilter(),
                'SonyImageSize' => new \PHPExiftool\Driver\Tag\Minolta\SonyImageSize(),
                'SonyQuality' => new \PHPExiftool\Driver\Tag\Minolta\SonyQuality(),
                'InstantPlaybackTime' => new \PHPExiftool\Driver\Tag\Minolta\InstantPlaybackTime(),
                'InstantPlaybackSetup' => new \PHPExiftool\Driver\Tag\Minolta\InstantPlaybackSetup(),
                'EyeStartAF' => new \PHPExiftool\Driver\Tag\Minolta\EyeStartAF(),
                'RedEyeReduction' => new \PHPExiftool\Driver\Tag\Minolta\RedEyeReduction(),
                'FlashDefault' => new \PHPExiftool\Driver\Tag\Minolta\FlashDefault(),
                'AutoBracketOrder' => new \PHPExiftool\Driver\Tag\Minolta\AutoBracketOrder(),
                'FocusHoldButton' => new \PHPExiftool\Driver\Tag\Minolta\FocusHoldButton(),
                'AELButton' => new \PHPExiftool\Driver\Tag\Minolta\AELButton(),
                'ControlDialSet' => new \PHPExiftool\Driver\Tag\Minolta\ControlDialSet(),
                'ExposureCompensationMode' => new \PHPExiftool\Driver\Tag\Minolta\ExposureCompensationMode(),
                'AFAssist' => new \PHPExiftool\Driver\Tag\Minolta\AFAssist(),
                'CardShutterLock' => new \PHPExiftool\Driver\Tag\Minolta\CardShutterLock(),
                'LensShutterLock' => new \PHPExiftool\Driver\Tag\Minolta\LensShutterLock(),
                'AFAreaIllumination' => new \PHPExiftool\Driver\Tag\Minolta\AFAreaIllumination(),
                'MonitorDisplayOff' => new \PHPExiftool\Driver\Tag\Minolta\MonitorDisplayOff(),
                'RecordDisplay' => new \PHPExiftool\Driver\Tag\Minolta\RecordDisplay(),
                'PlayDisplay' => new \PHPExiftool\Driver\Tag\Minolta\PlayDisplay(),
                'ExposureIndicator' => new \PHPExiftool\Driver\Tag\Minolta\ExposureIndicator(),
                'AELExposureIndicator' => new \PHPExiftool\Driver\Tag\Minolta\AELExposureIndicator(),
                'ExposureBracketingIndicatorLast' => new \PHPExiftool\Driver\Tag\Minolta\ExposureBracketingIndicatorLast(),
                'MeteringOffScaleIndicator' => new \PHPExiftool\Driver\Tag\Minolta\MeteringOffScaleIndicator(),
                'FlashExposureIndicator' => new \PHPExiftool\Driver\Tag\Minolta\FlashExposureIndicator(),
                'FlashExposureIndicatorNext' => new \PHPExiftool\Driver\Tag\Minolta\FlashExposureIndicatorNext(),
                'FlashExposureIndicatorLast' => new \PHPExiftool\Driver\Tag\Minolta\FlashExposureIndicatorLast(),
                'FocusModeSwitch' => new \PHPExiftool\Driver\Tag\Minolta\FocusModeSwitch(),
                'FlashType' => new \PHPExiftool\Driver\Tag\Minolta\FlashType(),
                'AELock' => new \PHPExiftool\Driver\Tag\Minolta\AELock(),
                'BatteryState' => new \PHPExiftool\Driver\Tag\Minolta\BatteryState(),
                'Make' => new \PHPExiftool\Driver\Tag\Minolta\Make(),
                'SoftwareVersion' => new \PHPExiftool\Driver\Tag\Minolta\SoftwareVersion(),
                'ModelType' => new \PHPExiftool\Driver\Tag\Minolta\ModelType(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Minolta\MakerNoteVersion(),
                'CompressedImageSize' => new \PHPExiftool\Driver\Tag\Minolta\CompressedImageSize(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Minolta\PreviewImage(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Minolta\PreviewImageStart(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Minolta\PreviewImageLength(),
                'SceneMode' => new \PHPExiftool\Driver\Tag\Minolta\SceneMode(),
                'Teleconverter' => new \PHPExiftool\Driver\Tag\Minolta\Teleconverter(),
                'RawAndJpgRecording' => new \PHPExiftool\Driver\Tag\Minolta\RawAndJpgRecording(),
                'ZoneMatching' => new \PHPExiftool\Driver\Tag\Minolta\ZoneMatching(),
                'LensType' => new \PHPExiftool\Driver\Tag\Minolta\LensType(),
                'MinoltaCameraSettings2' => new \PHPExiftool\Driver\Tag\Minolta\MinoltaCameraSettings2(),
                'ImageStabilizationSetting' => new \PHPExiftool\Driver\Tag\Minolta\ImageStabilizationSetting(),
                'DynamicRangeOptimizerMode' => new \PHPExiftool\Driver\Tag\Minolta\DynamicRangeOptimizerMode(),
                'WBBracketShotNumber' => new \PHPExiftool\Driver\Tag\Minolta\WBBracketShotNumber(),
                'ExposureBracketShotNumber' => new \PHPExiftool\Driver\Tag\Minolta\ExposureBracketShotNumber(),
                'FlashFunction' => new \PHPExiftool\Driver\Tag\Minolta\FlashFunction(),
                'AverageLV' => new \PHPExiftool\Driver\Tag\Minolta\AverageLV(),
                'FrameNumber' => new \PHPExiftool\Driver\Tag\Minolta\FrameNumber(),
                'WB_RGBLevels' => new \PHPExiftool\Driver\Tag\Minolta\WBRGBLevels(),
                'WB_GBRGLevels' => new \PHPExiftool\Driver\Tag\Minolta\WBGBRGLevels(),
                'WB_RedLevelsTungsten' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevelsTungsten(),
                'WB_BlueLevelsTungsten' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsTungsten(),
                'WB_RedLevelsDaylight' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevelsDaylight(),
                'WB_BlueLevelsDaylight' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsDaylight(),
                'WB_RedLevelsCloudy' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevelsCloudy(),
                'WB_BlueLevelsCloudy' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsCloudy(),
                'WB_RedLevelsFlash' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevelsFlash(),
                'WB_BlueLevelsFlash' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsFlash(),
                'WB_RedLevelsFluorescent' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevelsFluorescent(),
                'WB_BlueLevelsFluorescent' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsFluorescent(),
                'WB_RedLevelsShade' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevelsShade(),
                'WB_BlueLevelsShade' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsShade(),
                'WB_RedLevel6500K' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevel6500K(),
                'WB_BlueLevel6500K' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevel6500K(),
                'WB_RedLevelCustom' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevelCustom(),
                'WB_BlueLevelCustom' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevelCustom(),
                'WB_RedLevel3500K' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevel3500K(),
                'WB_BlueLevel3500K' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevel3500K(),
                'WB_RedLevelsKelvin' => new \PHPExiftool\Driver\Tag\Minolta\WBRedLevelsKelvin(),
                'WB_BlueLevelsKelvin' => new \PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsKelvin(),
                'WB_RBLevelsFlash' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevelsFlash(),
                'WB_RBLevelsCoolWhiteF' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevelsCoolWhiteF(),
                'WB_RBLevelsTungsten' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevelsTungsten(),
                'WB_RBLevelsDaylight' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevelsDaylight(),
                'WB_RBLevelsCloudy' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevelsCloudy(),
                'WB_RBLevelsShade' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevelsShade(),
                'WB_RBLevels6500K' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevels6500K(),
                'WB_RBLevelsCustom' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevelsCustom(),
                'WB_RBLevels3500K' => new \PHPExiftool\Driver\Tag\Minolta\WBRBLevels3500K(),
                'AEMeteringSegments' => new \PHPExiftool\Driver\Tag\Minolta\AEMeteringSegments(),
                'MeasuredLV' => new \PHPExiftool\Driver\Tag\Minolta\MeasuredLV(),
                'BrightnessValue' => new \PHPExiftool\Driver\Tag\Minolta\BrightnessValue(),
                'InternalSerialNumber' => new \PHPExiftool\Driver\Tag\Minolta\InternalSerialNumber(),
            );
        });
        $this['MinoltaRaw'] = $this->share(function(){
            return array(
                'FirmwareID' => new \PHPExiftool\Driver\Tag\MinoltaRaw\FirmwareID(),
                'SensorHeight' => new \PHPExiftool\Driver\Tag\MinoltaRaw\SensorHeight(),
                'SensorWidth' => new \PHPExiftool\Driver\Tag\MinoltaRaw\SensorWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\MinoltaRaw\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\MinoltaRaw\ImageWidth(),
                'RawDepth' => new \PHPExiftool\Driver\Tag\MinoltaRaw\RawDepth(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\MinoltaRaw\BitDepth(),
                'StorageMethod' => new \PHPExiftool\Driver\Tag\MinoltaRaw\StorageMethod(),
                'BayerPattern' => new \PHPExiftool\Driver\Tag\MinoltaRaw\BayerPattern(),
                'Saturation' => new \PHPExiftool\Driver\Tag\MinoltaRaw\Saturation(),
                'Contrast' => new \PHPExiftool\Driver\Tag\MinoltaRaw\Contrast(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\MinoltaRaw\Sharpness(),
                'WBMode' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBMode(),
                'ProgramMode' => new \PHPExiftool\Driver\Tag\MinoltaRaw\ProgramMode(),
                'ISOSetting' => new \PHPExiftool\Driver\Tag\MinoltaRaw\ISOSetting(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\MinoltaRaw\ColorMode(),
                'WB_RBLevelsTungsten' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsTungsten(),
                'WB_RBLevelsDaylight' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsDaylight(),
                'WB_RBLevelsCloudy' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsCloudy(),
                'WB_RBLevelsCoolWhiteF' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsCoolWhiteF(),
                'WB_RBLevelsFlash' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsFlash(),
                'WB_RBLevelsUnknown' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsUnknown(),
                'WB_RBLevelsShade' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsShade(),
                'WB_RBLevelsDaylightF' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsDaylightF(),
                'WB_RBLevelsDayWhiteF' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsDayWhiteF(),
                'WB_RBLevelsWhiteF' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsWhiteF(),
                'ColorFilter' => new \PHPExiftool\Driver\Tag\MinoltaRaw\ColorFilter(),
                'BWFilter' => new \PHPExiftool\Driver\Tag\MinoltaRaw\BWFilter(),
                'ZoneMatching' => new \PHPExiftool\Driver\Tag\MinoltaRaw\ZoneMatching(),
                'Hue' => new \PHPExiftool\Driver\Tag\MinoltaRaw\Hue(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\MinoltaRaw\ColorTemperature(),
                'RawDataLength' => new \PHPExiftool\Driver\Tag\MinoltaRaw\RawDataLength(),
                'WBScale' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBScale(),
                'WB_GBRGLevels' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBGBRGLevels(),
                'WB_RGGBLevels' => new \PHPExiftool\Driver\Tag\MinoltaRaw\WBRGGBLevels(),
            );
        });
        $this['Nikon'] = $this->share(function(){
            return array(
                'AFAreaMode' => new \PHPExiftool\Driver\Tag\Nikon\AFAreaMode(),
                'AFPoint' => new \PHPExiftool\Driver\Tag\Nikon\AFPoint(),
                'AFPointsInFocus' => new \PHPExiftool\Driver\Tag\Nikon\AFPointsInFocus(),
                'AFInfo2Version' => new \PHPExiftool\Driver\Tag\Nikon\AFInfo2Version(),
                'ContrastDetectAF' => new \PHPExiftool\Driver\Tag\Nikon\ContrastDetectAF(),
                'PhaseDetectAF' => new \PHPExiftool\Driver\Tag\Nikon\PhaseDetectAF(),
                'PrimaryAFPoint' => new \PHPExiftool\Driver\Tag\Nikon\PrimaryAFPoint(),
                'AFPointsUsed' => new \PHPExiftool\Driver\Tag\Nikon\AFPointsUsed(),
                'AFImageWidth' => new \PHPExiftool\Driver\Tag\Nikon\AFImageWidth(),
                'AFImageHeight' => new \PHPExiftool\Driver\Tag\Nikon\AFImageHeight(),
                'AFAreaXPosition' => new \PHPExiftool\Driver\Tag\Nikon\AFAreaXPosition(),
                'AFAreaYPosition' => new \PHPExiftool\Driver\Tag\Nikon\AFAreaYPosition(),
                'AFAreaWidth' => new \PHPExiftool\Driver\Tag\Nikon\AFAreaWidth(),
                'AFAreaHeight' => new \PHPExiftool\Driver\Tag\Nikon\AFAreaHeight(),
                'ContrastDetectAFInFocus' => new \PHPExiftool\Driver\Tag\Nikon\ContrastDetectAFInFocus(),
                'AFFineTune' => new \PHPExiftool\Driver\Tag\Nikon\AFFineTune(),
                'AFFineTuneIndex' => new \PHPExiftool\Driver\Tag\Nikon\AFFineTuneIndex(),
                'AFFineTuneAdj' => new \PHPExiftool\Driver\Tag\Nikon\AFFineTuneAdj(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\Nikon\ThumbnailImage(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Nikon\PreviewImage(),
                'Make' => new \PHPExiftool\Driver\Tag\Nikon\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\Nikon\Model(),
                'Software' => new \PHPExiftool\Driver\Tag\Nikon\Software(),
                'Equipment' => new \PHPExiftool\Driver\Tag\Nikon\Equipment(),
                'Orientation' => new \PHPExiftool\Driver\Tag\Nikon\Orientation(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Nikon\ExposureTime(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Nikon\FNumber(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Nikon\ExposureCompensation(),
                'MaxApertureValue' => new \PHPExiftool\Driver\Tag\Nikon\MaxApertureValue(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Nikon\MeteringMode(),
                'Nikon_AVITags_0x000d' => new \PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x000d(),
                'Nikon_AVITags_0x000e' => new \PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x000e(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Nikon\FocalLength(),
                'XResolution' => new \PHPExiftool\Driver\Tag\Nikon\XResolution(),
                'YResolution' => new \PHPExiftool\Driver\Tag\Nikon\YResolution(),
                'ResolutionUnit' => new \PHPExiftool\Driver\Tag\Nikon\ResolutionUnit(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\Nikon\DateTimeOriginal(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\Nikon\CreateDate(),
                'Nikon_AVITags_0x0015' => new \PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x0015(),
                'Duration' => new \PHPExiftool\Driver\Tag\Nikon\Duration(),
                'Nikon_AVITags_0x0017' => new \PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x0017(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Nikon\FocusMode(),
                'Nikon_AVITags_0x0019' => new \PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x0019(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Nikon\DigitalZoom(),
                'Nikon_AVITags_0x001c' => new \PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x001c(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Nikon\ColorMode(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Nikon\Sharpness(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Nikon\WhiteBalance(),
                'NoiseReduction' => new \PHPExiftool\Driver\Tag\Nikon\NoiseReduction(),
                'Nikon_AVITags_0x801a' => new \PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x801a(),
                'MakerNoteType' => new \PHPExiftool\Driver\Tag\Nikon\MakerNoteType(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Nikon\MakerNoteVersion(),
                'IFD0_Offset' => new \PHPExiftool\Driver\Tag\Nikon\IFD0Offset(),
                'PreviewIFD_Offset' => new \PHPExiftool\Driver\Tag\Nikon\PreviewIFDOffset(),
                'SubIFD_Offset' => new \PHPExiftool\Driver\Tag\Nikon\SubIFDOffset(),
                'OutputImageWidth' => new \PHPExiftool\Driver\Tag\Nikon\OutputImageWidth(),
                'OutputImageHeight' => new \PHPExiftool\Driver\Tag\Nikon\OutputImageHeight(),
                'OutputResolution' => new \PHPExiftool\Driver\Tag\Nikon\OutputResolution(),
                'WB_RBGGLevels' => new \PHPExiftool\Driver\Tag\Nikon\WBRBGGLevels(),
                'WB_RGGBLevels' => new \PHPExiftool\Driver\Tag\Nikon\WBRGGBLevels(),
                'WB_RGBGLevels' => new \PHPExiftool\Driver\Tag\Nikon\WBRGBGLevels(),
                'WB_GRBGLevels' => new \PHPExiftool\Driver\Tag\Nikon\WBGRBGLevels(),
                'RedBalance' => new \PHPExiftool\Driver\Tag\Nikon\RedBalance(),
                'BlueBalance' => new \PHPExiftool\Driver\Tag\Nikon\BlueBalance(),
                'DistortionVersion' => new \PHPExiftool\Driver\Tag\Nikon\DistortionVersion(),
                'AutoDistortionControl' => new \PHPExiftool\Driver\Tag\Nikon\AutoDistortionControl(),
                'FaceDetectFrameSize' => new \PHPExiftool\Driver\Tag\Nikon\FaceDetectFrameSize(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Nikon\FacesDetected(),
                'Face1Position' => new \PHPExiftool\Driver\Tag\Nikon\Face1Position(),
                'Face2Position' => new \PHPExiftool\Driver\Tag\Nikon\Face2Position(),
                'Face3Position' => new \PHPExiftool\Driver\Tag\Nikon\Face3Position(),
                'Face4Position' => new \PHPExiftool\Driver\Tag\Nikon\Face4Position(),
                'Face5Position' => new \PHPExiftool\Driver\Tag\Nikon\Face5Position(),
                'Face6Position' => new \PHPExiftool\Driver\Tag\Nikon\Face6Position(),
                'Face7Position' => new \PHPExiftool\Driver\Tag\Nikon\Face7Position(),
                'Face8Position' => new \PHPExiftool\Driver\Tag\Nikon\Face8Position(),
                'Face9Position' => new \PHPExiftool\Driver\Tag\Nikon\Face9Position(),
                'Face10Position' => new \PHPExiftool\Driver\Tag\Nikon\Face10Position(),
                'Face11Position' => new \PHPExiftool\Driver\Tag\Nikon\Face11Position(),
                'Face12Position' => new \PHPExiftool\Driver\Tag\Nikon\Face12Position(),
                'FileInfoVersion' => new \PHPExiftool\Driver\Tag\Nikon\FileInfoVersion(),
                'DirectoryNumber' => new \PHPExiftool\Driver\Tag\Nikon\DirectoryNumber(),
                'FileNumber' => new \PHPExiftool\Driver\Tag\Nikon\FileNumber(),
                'FlashInfoVersion' => new \PHPExiftool\Driver\Tag\Nikon\FlashInfoVersion(),
                'FlashSource' => new \PHPExiftool\Driver\Tag\Nikon\FlashSource(),
                'ExternalFlashFirmware' => new \PHPExiftool\Driver\Tag\Nikon\ExternalFlashFirmware(),
                'ExternalFlashFlags' => new \PHPExiftool\Driver\Tag\Nikon\ExternalFlashFlags(),
                'FlashCommanderMode' => new \PHPExiftool\Driver\Tag\Nikon\FlashCommanderMode(),
                'FlashControlMode' => new \PHPExiftool\Driver\Tag\Nikon\FlashControlMode(),
                'FlashOutput' => new \PHPExiftool\Driver\Tag\Nikon\FlashOutput(),
                'FlashCompensation' => new \PHPExiftool\Driver\Tag\Nikon\FlashCompensation(),
                'FlashFocalLength' => new \PHPExiftool\Driver\Tag\Nikon\FlashFocalLength(),
                'RepeatingFlashRate' => new \PHPExiftool\Driver\Tag\Nikon\RepeatingFlashRate(),
                'RepeatingFlashCount' => new \PHPExiftool\Driver\Tag\Nikon\RepeatingFlashCount(),
                'FlashGNDistance' => new \PHPExiftool\Driver\Tag\Nikon\FlashGNDistance(),
                'FlashGroupAControlMode' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupAControlMode(),
                'FlashGroupBControlMode' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupBControlMode(),
                'FlashGroupAOutput' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupAOutput(),
                'FlashGroupACompensation' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupACompensation(),
                'FlashGroupBOutput' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupBOutput(),
                'FlashGroupBCompensation' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupBCompensation(),
                'FlashGroupCControlMode' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupCControlMode(),
                'FlashGroupCOutput' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupCOutput(),
                'FlashGroupCCompensation' => new \PHPExiftool\Driver\Tag\Nikon\FlashGroupCCompensation(),
                'FlashColorFilter' => new \PHPExiftool\Driver\Tag\Nikon\FlashColorFilter(),
                'HDR' => new \PHPExiftool\Driver\Tag\Nikon\HDR(),
                'HDRLevel' => new \PHPExiftool\Driver\Tag\Nikon\HDRLevel(),
                'HDRSmoothing' => new \PHPExiftool\Driver\Tag\Nikon\HDRSmoothing(),
                'ISO' => new \PHPExiftool\Driver\Tag\Nikon\ISO(),
                'ISOExpansion' => new \PHPExiftool\Driver\Tag\Nikon\ISOExpansion(),
                'ISO2' => new \PHPExiftool\Driver\Tag\Nikon\ISO2(),
                'ISOExpansion2' => new \PHPExiftool\Driver\Tag\Nikon\ISOExpansion2(),
                'LensDataVersion' => new \PHPExiftool\Driver\Tag\Nikon\LensDataVersion(),
                'LensIDNumber' => new \PHPExiftool\Driver\Tag\Nikon\LensIDNumber(),
                'LensFStops' => new \PHPExiftool\Driver\Tag\Nikon\LensFStops(),
                'MinFocalLength' => new \PHPExiftool\Driver\Tag\Nikon\MinFocalLength(),
                'MaxFocalLength' => new \PHPExiftool\Driver\Tag\Nikon\MaxFocalLength(),
                'MaxApertureAtMinFocal' => new \PHPExiftool\Driver\Tag\Nikon\MaxApertureAtMinFocal(),
                'MaxApertureAtMaxFocal' => new \PHPExiftool\Driver\Tag\Nikon\MaxApertureAtMaxFocal(),
                'MCUVersion' => new \PHPExiftool\Driver\Tag\Nikon\MCUVersion(),
                'ExitPupilPosition' => new \PHPExiftool\Driver\Tag\Nikon\ExitPupilPosition(),
                'AFAperture' => new \PHPExiftool\Driver\Tag\Nikon\AFAperture(),
                'FocusPosition' => new \PHPExiftool\Driver\Tag\Nikon\FocusPosition(),
                'FocusDistance' => new \PHPExiftool\Driver\Tag\Nikon\FocusDistance(),
                'EffectiveMaxAperture' => new \PHPExiftool\Driver\Tag\Nikon\EffectiveMaxAperture(),
                'LensModel' => new \PHPExiftool\Driver\Tag\Nikon\LensModel(),
                'LocationInfoVersion' => new \PHPExiftool\Driver\Tag\Nikon\LocationInfoVersion(),
                'TextEncoding' => new \PHPExiftool\Driver\Tag\Nikon\TextEncoding(),
                'CountryCode' => new \PHPExiftool\Driver\Tag\Nikon\CountryCode(),
                'Location' => new \PHPExiftool\Driver\Tag\Nikon\Location(),
                'Quality' => new \PHPExiftool\Driver\Tag\Nikon\Quality(),
                'FlashSetting' => new \PHPExiftool\Driver\Tag\Nikon\FlashSetting(),
                'FlashType' => new \PHPExiftool\Driver\Tag\Nikon\FlashType(),
                'WhiteBalanceFineTune' => new \PHPExiftool\Driver\Tag\Nikon\WhiteBalanceFineTune(),
                'WB_RBLevels' => new \PHPExiftool\Driver\Tag\Nikon\WBRBLevels(),
                'ProgramShift' => new \PHPExiftool\Driver\Tag\Nikon\ProgramShift(),
                'ExposureDifference' => new \PHPExiftool\Driver\Tag\Nikon\ExposureDifference(),
                'ISOSelection' => new \PHPExiftool\Driver\Tag\Nikon\ISOSelection(),
                'DataDump' => new \PHPExiftool\Driver\Tag\Nikon\DataDump(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\Nikon\FlashExposureComp(),
                'ISOSetting' => new \PHPExiftool\Driver\Tag\Nikon\ISOSetting(),
                'NRWData' => new \PHPExiftool\Driver\Tag\Nikon\NRWData(),
                'ImageBoundary' => new \PHPExiftool\Driver\Tag\Nikon\ImageBoundary(),
                'ExternalFlashExposureComp' => new \PHPExiftool\Driver\Tag\Nikon\ExternalFlashExposureComp(),
                'FlashExposureBracketValue' => new \PHPExiftool\Driver\Tag\Nikon\FlashExposureBracketValue(),
                'ExposureBracketValue' => new \PHPExiftool\Driver\Tag\Nikon\ExposureBracketValue(),
                'ImageProcessing' => new \PHPExiftool\Driver\Tag\Nikon\ImageProcessing(),
                'CropHiSpeed' => new \PHPExiftool\Driver\Tag\Nikon\CropHiSpeed(),
                'ExposureTuning' => new \PHPExiftool\Driver\Tag\Nikon\ExposureTuning(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Nikon\SerialNumber(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Nikon\ColorSpace(),
                'ImageAuthentication' => new \PHPExiftool\Driver\Tag\Nikon\ImageAuthentication(),
                'ActiveD-Lighting' => new \PHPExiftool\Driver\Tag\Nikon\ActiveDLighting(),
                'PictureControlData' => new \PHPExiftool\Driver\Tag\Nikon\PictureControlData(),
                'VignetteControl' => new \PHPExiftool\Driver\Tag\Nikon\VignetteControl(),
                'ImageAdjustment' => new \PHPExiftool\Driver\Tag\Nikon\ImageAdjustment(),
                'ToneComp' => new \PHPExiftool\Driver\Tag\Nikon\ToneComp(),
                'AuxiliaryLens' => new \PHPExiftool\Driver\Tag\Nikon\AuxiliaryLens(),
                'LensType' => new \PHPExiftool\Driver\Tag\Nikon\LensType(),
                'Lens' => new \PHPExiftool\Driver\Tag\Nikon\Lens(),
                'ManualFocusDistance' => new \PHPExiftool\Driver\Tag\Nikon\ManualFocusDistance(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Nikon\FlashMode(),
                'ShootingMode' => new \PHPExiftool\Driver\Tag\Nikon\ShootingMode(),
                'ContrastCurve' => new \PHPExiftool\Driver\Tag\Nikon\ContrastCurve(),
                'ColorHue' => new \PHPExiftool\Driver\Tag\Nikon\ColorHue(),
                'SceneMode' => new \PHPExiftool\Driver\Tag\Nikon\SceneMode(),
                'LightSource' => new \PHPExiftool\Driver\Tag\Nikon\LightSource(),
                'HueAdjustment' => new \PHPExiftool\Driver\Tag\Nikon\HueAdjustment(),
                'NEFCompression' => new \PHPExiftool\Driver\Tag\Nikon\NEFCompression(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Nikon\Saturation(),
                'NEFLinearizationTable' => new \PHPExiftool\Driver\Tag\Nikon\NEFLinearizationTable(),
                'ColorBalanceUnknown' => new \PHPExiftool\Driver\Tag\Nikon\ColorBalanceUnknown(),
                'RawImageCenter' => new \PHPExiftool\Driver\Tag\Nikon\RawImageCenter(),
                'SensorPixelSize' => new \PHPExiftool\Driver\Tag\Nikon\SensorPixelSize(),
                'SceneAssist' => new \PHPExiftool\Driver\Tag\Nikon\SceneAssist(),
                'RetouchHistory' => new \PHPExiftool\Driver\Tag\Nikon\RetouchHistory(),
                'ImageDataSize' => new \PHPExiftool\Driver\Tag\Nikon\ImageDataSize(),
                'ImageCount' => new \PHPExiftool\Driver\Tag\Nikon\ImageCount(),
                'DeletedImageCount' => new \PHPExiftool\Driver\Tag\Nikon\DeletedImageCount(),
                'ShutterCount' => new \PHPExiftool\Driver\Tag\Nikon\ShutterCount(),
                'ImageOptimization' => new \PHPExiftool\Driver\Tag\Nikon\ImageOptimization(),
                'VariProgram' => new \PHPExiftool\Driver\Tag\Nikon\VariProgram(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\Nikon\ImageStabilization(),
                'AFResponse' => new \PHPExiftool\Driver\Tag\Nikon\AFResponse(),
                'HighISONoiseReduction' => new \PHPExiftool\Driver\Tag\Nikon\HighISONoiseReduction(),
                'ToningEffect' => new \PHPExiftool\Driver\Tag\Nikon\ToningEffect(),
                'PowerUpTime' => new \PHPExiftool\Driver\Tag\Nikon\PowerUpTime(),
                'NikonCaptureData' => new \PHPExiftool\Driver\Tag\Nikon\NikonCaptureData(),
                'NikonCaptureVersion' => new \PHPExiftool\Driver\Tag\Nikon\NikonCaptureVersion(),
                'NikonCaptureEditVersions' => new \PHPExiftool\Driver\Tag\Nikon\NikonCaptureEditVersions(),
                'NikonICCProfile' => new \PHPExiftool\Driver\Tag\Nikon\NikonICCProfile(),
                'NikonCaptureOutput' => new \PHPExiftool\Driver\Tag\Nikon\NikonCaptureOutput(),
                'NEFBitDepth' => new \PHPExiftool\Driver\Tag\Nikon\NEFBitDepth(),
                'MultiExposureVersion' => new \PHPExiftool\Driver\Tag\Nikon\MultiExposureVersion(),
                'MultiExposureMode' => new \PHPExiftool\Driver\Tag\Nikon\MultiExposureMode(),
                'MultiExposureShots' => new \PHPExiftool\Driver\Tag\Nikon\MultiExposureShots(),
                'MultiExposureAutoGain' => new \PHPExiftool\Driver\Tag\Nikon\MultiExposureAutoGain(),
                'FrameCount' => new \PHPExiftool\Driver\Tag\Nikon\FrameCount(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\Nikon\FrameRate(),
                'FrameWidth' => new \PHPExiftool\Driver\Tag\Nikon\FrameWidth(),
                'FrameHeight' => new \PHPExiftool\Driver\Tag\Nikon\FrameHeight(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\Nikon\AudioChannels(),
                'AudioBitsPerSample' => new \PHPExiftool\Driver\Tag\Nikon\AudioBitsPerSample(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\Nikon\AudioSampleRate(),
                'ExposureProgram' => new \PHPExiftool\Driver\Tag\Nikon\ExposureProgram(),
                'GPSVersionID' => new \PHPExiftool\Driver\Tag\Nikon\GPSVersionID(),
                'GPSLatitudeRef' => new \PHPExiftool\Driver\Tag\Nikon\GPSLatitudeRef(),
                'GPSLatitude' => new \PHPExiftool\Driver\Tag\Nikon\GPSLatitude(),
                'GPSLongitudeRef' => new \PHPExiftool\Driver\Tag\Nikon\GPSLongitudeRef(),
                'GPSLongitude' => new \PHPExiftool\Driver\Tag\Nikon\GPSLongitude(),
                'GPSAltitudeRef' => new \PHPExiftool\Driver\Tag\Nikon\GPSAltitudeRef(),
                'GPSAltitude' => new \PHPExiftool\Driver\Tag\Nikon\GPSAltitude(),
                'GPSTimeStamp' => new \PHPExiftool\Driver\Tag\Nikon\GPSTimeStamp(),
                'GPSSatellites' => new \PHPExiftool\Driver\Tag\Nikon\GPSSatellites(),
                'GPSImgDirectionRef' => new \PHPExiftool\Driver\Tag\Nikon\GPSImgDirectionRef(),
                'GPSImgDirection' => new \PHPExiftool\Driver\Tag\Nikon\GPSImgDirection(),
                'GPSMapDatum' => new \PHPExiftool\Driver\Tag\Nikon\GPSMapDatum(),
                'GPSDateStamp' => new \PHPExiftool\Driver\Tag\Nikon\GPSDateStamp(),
                'PictureControlVersion' => new \PHPExiftool\Driver\Tag\Nikon\PictureControlVersion(),
                'PictureControlName' => new \PHPExiftool\Driver\Tag\Nikon\PictureControlName(),
                'PictureControlBase' => new \PHPExiftool\Driver\Tag\Nikon\PictureControlBase(),
                'PictureControlAdjust' => new \PHPExiftool\Driver\Tag\Nikon\PictureControlAdjust(),
                'PictureControlQuickAdjust' => new \PHPExiftool\Driver\Tag\Nikon\PictureControlQuickAdjust(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Nikon\Contrast(),
                'Brightness' => new \PHPExiftool\Driver\Tag\Nikon\Brightness(),
                'FilterEffect' => new \PHPExiftool\Driver\Tag\Nikon\FilterEffect(),
                'ToningSaturation' => new \PHPExiftool\Driver\Tag\Nikon\ToningSaturation(),
                'ShotInfoVersion' => new \PHPExiftool\Driver\Tag\Nikon\ShotInfoVersion(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\Nikon\FirmwareVersion(),
                'DistortionControl' => new \PHPExiftool\Driver\Tag\Nikon\DistortionControl(),
                'VR_0x66' => new \PHPExiftool\Driver\Tag\Nikon\VR0x66(),
                'VibrationReduction' => new \PHPExiftool\Driver\Tag\Nikon\VibrationReduction(),
                'ImageArea' => new \PHPExiftool\Driver\Tag\Nikon\ImageArea(),
                'NikonImageSize' => new \PHPExiftool\Driver\Tag\Nikon\NikonImageSize(),
                'ImageQuality' => new \PHPExiftool\Driver\Tag\Nikon\ImageQuality(),
                'PreFlashReturnStrength' => new \PHPExiftool\Driver\Tag\Nikon\PreFlashReturnStrength(),
                'Rotation' => new \PHPExiftool\Driver\Tag\Nikon\Rotation(),
                'FlashFired' => new \PHPExiftool\Driver\Tag\Nikon\FlashFired(),
                'CCDSensitivity' => new \PHPExiftool\Driver\Tag\Nikon\CCDSensitivity(),
                'Focus' => new \PHPExiftool\Driver\Tag\Nikon\Focus(),
                'Converter' => new \PHPExiftool\Driver\Tag\Nikon\Converter(),
                'UnknownInfoVersion' => new \PHPExiftool\Driver\Tag\Nikon\UnknownInfoVersion(),
                'UnknownInfo2Version' => new \PHPExiftool\Driver\Tag\Nikon\UnknownInfo2Version(),
                'VRInfoVersion' => new \PHPExiftool\Driver\Tag\Nikon\VRInfoVersion(),
                'Timezone' => new \PHPExiftool\Driver\Tag\Nikon\Timezone(),
                'DaylightSavings' => new \PHPExiftool\Driver\Tag\Nikon\DaylightSavings(),
                'DateDisplayFormat' => new \PHPExiftool\Driver\Tag\Nikon\DateDisplayFormat(),
            );
        });
        $this['NikonScan'] = $this->share(function(){
            return array(
                'DigitalGEM' => new \PHPExiftool\Driver\Tag\NikonScan\DigitalGEM(),
                'DigitalROC' => new \PHPExiftool\Driver\Tag\NikonScan\DigitalROC(),
                'FilmType' => new \PHPExiftool\Driver\Tag\NikonScan\FilmType(),
                'MultiSample' => new \PHPExiftool\Driver\Tag\NikonScan\MultiSample(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\NikonScan\BitDepth(),
                'MasterGain' => new \PHPExiftool\Driver\Tag\NikonScan\MasterGain(),
                'ColorGain' => new \PHPExiftool\Driver\Tag\NikonScan\ColorGain(),
                'ScanImageEnhancer' => new \PHPExiftool\Driver\Tag\NikonScan\ScanImageEnhancer(),
                'DigitalICE' => new \PHPExiftool\Driver\Tag\NikonScan\DigitalICE(),
                'DigitalDEEShadowAdj' => new \PHPExiftool\Driver\Tag\NikonScan\DigitalDEEShadowAdj(),
                'DigitalDEEThreshold' => new \PHPExiftool\Driver\Tag\NikonScan\DigitalDEEThreshold(),
                'DigitalDEEHighlightAdj' => new \PHPExiftool\Driver\Tag\NikonScan\DigitalDEEHighlightAdj(),
            );
        });
        $this['PreviewIFD'] = $this->share(function(){
            return array(
                'SubfileType' => new \PHPExiftool\Driver\Tag\PreviewIFD\SubfileType(),
                'Compression' => new \PHPExiftool\Driver\Tag\PreviewIFD\Compression(),
                'XResolution' => new \PHPExiftool\Driver\Tag\PreviewIFD\XResolution(),
                'YResolution' => new \PHPExiftool\Driver\Tag\PreviewIFD\YResolution(),
                'ResolutionUnit' => new \PHPExiftool\Driver\Tag\PreviewIFD\ResolutionUnit(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\PreviewIFD\PreviewImageStart(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\PreviewIFD\PreviewImageLength(),
                'YCbCrPositioning' => new \PHPExiftool\Driver\Tag\PreviewIFD\YCbCrPositioning(),
            );
        });
        $this['NikonCapture'] = $this->share(function(){
            return array(
                'BrightnessAdj' => new \PHPExiftool\Driver\Tag\NikonCapture\BrightnessAdj(),
                'EnhanceDarkTones' => new \PHPExiftool\Driver\Tag\NikonCapture\EnhanceDarkTones(),
                'ColorBoostType' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorBoostType(),
                'ColorBoostLevel' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorBoostLevel(),
                'CropLeft' => new \PHPExiftool\Driver\Tag\NikonCapture\CropLeft(),
                'CropTop' => new \PHPExiftool\Driver\Tag\NikonCapture\CropTop(),
                'CropRight' => new \PHPExiftool\Driver\Tag\NikonCapture\CropRight(),
                'CropBottom' => new \PHPExiftool\Driver\Tag\NikonCapture\CropBottom(),
                'CropOutputWidthInches' => new \PHPExiftool\Driver\Tag\NikonCapture\CropOutputWidthInches(),
                'CropOutputHeightInches' => new \PHPExiftool\Driver\Tag\NikonCapture\CropOutputHeightInches(),
                'CropScaledResolution' => new \PHPExiftool\Driver\Tag\NikonCapture\CropScaledResolution(),
                'CropSourceResolution' => new \PHPExiftool\Driver\Tag\NikonCapture\CropSourceResolution(),
                'CropOutputResolution' => new \PHPExiftool\Driver\Tag\NikonCapture\CropOutputResolution(),
                'CropOutputScale' => new \PHPExiftool\Driver\Tag\NikonCapture\CropOutputScale(),
                'CropOutputWidth' => new \PHPExiftool\Driver\Tag\NikonCapture\CropOutputWidth(),
                'CropOutputHeight' => new \PHPExiftool\Driver\Tag\NikonCapture\CropOutputHeight(),
                'CropOutputPixels' => new \PHPExiftool\Driver\Tag\NikonCapture\CropOutputPixels(),
                'D-LightingHQShadow' => new \PHPExiftool\Driver\Tag\NikonCapture\DLightingHQShadow(),
                'D-LightingHQHighlight' => new \PHPExiftool\Driver\Tag\NikonCapture\DLightingHQHighlight(),
                'D-LightingHQColorBoost' => new \PHPExiftool\Driver\Tag\NikonCapture\DLightingHQColorBoost(),
                'D-LightingHSAdjustment' => new \PHPExiftool\Driver\Tag\NikonCapture\DLightingHSAdjustment(),
                'D-LightingHSColorBoost' => new \PHPExiftool\Driver\Tag\NikonCapture\DLightingHSColorBoost(),
                'ExposureAdj' => new \PHPExiftool\Driver\Tag\NikonCapture\ExposureAdj(),
                'ExposureAdj2' => new \PHPExiftool\Driver\Tag\NikonCapture\ExposureAdj2(),
                'ActiveD-Lighting' => new \PHPExiftool\Driver\Tag\NikonCapture\ActiveDLighting(),
                'ActiveD-LightingMode' => new \PHPExiftool\Driver\Tag\NikonCapture\ActiveDLightingMode(),
                'ShadowProtection' => new \PHPExiftool\Driver\Tag\NikonCapture\ShadowProtection(),
                'SaturationAdj' => new \PHPExiftool\Driver\Tag\NikonCapture\SaturationAdj(),
                'HighlightProtection' => new \PHPExiftool\Driver\Tag\NikonCapture\HighlightProtection(),
                'LCHEditor' => new \PHPExiftool\Driver\Tag\NikonCapture\LCHEditor(),
                'HistogramXML' => new \PHPExiftool\Driver\Tag\NikonCapture\HistogramXML(),
                'ColorAberrationControl' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorAberrationControl(),
                'D-LightingHQ' => new \PHPExiftool\Driver\Tag\NikonCapture\DLightingHQ(),
                'StraightenAngle' => new \PHPExiftool\Driver\Tag\NikonCapture\StraightenAngle(),
                'EditVersionName' => new \PHPExiftool\Driver\Tag\NikonCapture\EditVersionName(),
                'ColorBooster' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorBooster(),
                'D-LightingHQSelected' => new \PHPExiftool\Driver\Tag\NikonCapture\DLightingHQSelected(),
                'NoiseReduction' => new \PHPExiftool\Driver\Tag\NikonCapture\NoiseReduction(),
                'UnsharpMask' => new \PHPExiftool\Driver\Tag\NikonCapture\UnsharpMask(),
                'Curves' => new \PHPExiftool\Driver\Tag\NikonCapture\Curves(),
                'ColorBalanceAdj' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorBalanceAdj(),
                'AdvancedRaw' => new \PHPExiftool\Driver\Tag\NikonCapture\AdvancedRaw(),
                'WhiteBalanceAdj' => new \PHPExiftool\Driver\Tag\NikonCapture\WhiteBalanceAdj(),
                'VignetteControl' => new \PHPExiftool\Driver\Tag\NikonCapture\VignetteControl(),
                'FlipHorizontal' => new \PHPExiftool\Driver\Tag\NikonCapture\FlipHorizontal(),
                'Rotation' => new \PHPExiftool\Driver\Tag\NikonCapture\Rotation(),
                'PhotoEffects' => new \PHPExiftool\Driver\Tag\NikonCapture\PhotoEffects(),
                'VignetteControlIntensity' => new \PHPExiftool\Driver\Tag\NikonCapture\VignetteControlIntensity(),
                'D-LightingHS' => new \PHPExiftool\Driver\Tag\NikonCapture\DLightingHS(),
                'PictureControl' => new \PHPExiftool\Driver\Tag\NikonCapture\PictureControl(),
                'PhotoEffectHistoryXML' => new \PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectHistoryXML(),
                'AutoRedEye' => new \PHPExiftool\Driver\Tag\NikonCapture\AutoRedEye(),
                'ImageDustOff' => new \PHPExiftool\Driver\Tag\NikonCapture\ImageDustOff(),
                'EdgeNoiseReduction' => new \PHPExiftool\Driver\Tag\NikonCapture\EdgeNoiseReduction(),
                'ColorMoireReductionMode' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorMoireReductionMode(),
                'NoiseReductionIntensity' => new \PHPExiftool\Driver\Tag\NikonCapture\NoiseReductionIntensity(),
                'NoiseReductionSharpness' => new \PHPExiftool\Driver\Tag\NikonCapture\NoiseReductionSharpness(),
                'NoiseReductionMethod' => new \PHPExiftool\Driver\Tag\NikonCapture\NoiseReductionMethod(),
                'ColorMoireReduction' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorMoireReduction(),
                'ColorNoiseReductionIntensity' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorNoiseReductionIntensity(),
                'ColorNoiseReductionSharpness' => new \PHPExiftool\Driver\Tag\NikonCapture\ColorNoiseReductionSharpness(),
                'PhotoEffectsType' => new \PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectsType(),
                'PhotoEffectsRed' => new \PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectsRed(),
                'PhotoEffectsGreen' => new \PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectsGreen(),
                'PhotoEffectsBlue' => new \PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectsBlue(),
                'PictureControlActive' => new \PHPExiftool\Driver\Tag\NikonCapture\PictureControlActive(),
                'PictureControlMode' => new \PHPExiftool\Driver\Tag\NikonCapture\PictureControlMode(),
                'QuickAdjust' => new \PHPExiftool\Driver\Tag\NikonCapture\QuickAdjust(),
                'SharpeningAdj' => new \PHPExiftool\Driver\Tag\NikonCapture\SharpeningAdj(),
                'ContrastAdj' => new \PHPExiftool\Driver\Tag\NikonCapture\ContrastAdj(),
                'HueAdj' => new \PHPExiftool\Driver\Tag\NikonCapture\HueAdj(),
                'RedEyeCorrection' => new \PHPExiftool\Driver\Tag\NikonCapture\RedEyeCorrection(),
                'UnsharpCount' => new \PHPExiftool\Driver\Tag\NikonCapture\UnsharpCount(),
                'Unsharp1Color' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp1Color(),
                'Unsharp1Intensity' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp1Intensity(),
                'Unsharp1HaloWidth' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp1HaloWidth(),
                'Unsharp1Threshold' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp1Threshold(),
                'Unsharp2Color' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp2Color(),
                'Unsharp2Intensity' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp2Intensity(),
                'Unsharp2HaloWidth' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp2HaloWidth(),
                'Unsharp2Threshold' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp2Threshold(),
                'Unsharp3Color' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp3Color(),
                'Unsharp3Intensity' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp3Intensity(),
                'Unsharp3HaloWidth' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp3HaloWidth(),
                'Unsharp3Threshold' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp3Threshold(),
                'Unsharp4Color' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp4Color(),
                'Unsharp4Intensity' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp4Intensity(),
                'Unsharp4HaloWidth' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp4HaloWidth(),
                'Unsharp4Threshold' => new \PHPExiftool\Driver\Tag\NikonCapture\Unsharp4Threshold(),
                'WBAdjRedBalance' => new \PHPExiftool\Driver\Tag\NikonCapture\WBAdjRedBalance(),
                'WBAdjBlueBalance' => new \PHPExiftool\Driver\Tag\NikonCapture\WBAdjBlueBalance(),
                'WBAdjMode' => new \PHPExiftool\Driver\Tag\NikonCapture\WBAdjMode(),
                'WBAdjLightingSubtype' => new \PHPExiftool\Driver\Tag\NikonCapture\WBAdjLightingSubtype(),
                'WBAdjLighting' => new \PHPExiftool\Driver\Tag\NikonCapture\WBAdjLighting(),
                'WBAdjTemperature' => new \PHPExiftool\Driver\Tag\NikonCapture\WBAdjTemperature(),
                'WBAdjTint' => new \PHPExiftool\Driver\Tag\NikonCapture\WBAdjTint(),
            );
        });
        $this['NikonCustom'] = $this->share(function(){
            return array(
                'CustomSettingsBank' => new \PHPExiftool\Driver\Tag\NikonCustom\CustomSettingsBank(),
                'CustomSettingsAllDefault' => new \PHPExiftool\Driver\Tag\NikonCustom\CustomSettingsAllDefault(),
                'AF-CPrioritySelection' => new \PHPExiftool\Driver\Tag\NikonCustom\AFCPrioritySelection(),
                'AF-SPrioritySelection' => new \PHPExiftool\Driver\Tag\NikonCustom\AFSPrioritySelection(),
                'AFPointSelection' => new \PHPExiftool\Driver\Tag\NikonCustom\AFPointSelection(),
                'DynamicAFArea' => new \PHPExiftool\Driver\Tag\NikonCustom\DynamicAFArea(),
                'FocusTrackingLockOn' => new \PHPExiftool\Driver\Tag\NikonCustom\FocusTrackingLockOn(),
                'AFActivation' => new \PHPExiftool\Driver\Tag\NikonCustom\AFActivation(),
                'FocusPointWrap' => new \PHPExiftool\Driver\Tag\NikonCustom\FocusPointWrap(),
                'AFPointIllumination' => new \PHPExiftool\Driver\Tag\NikonCustom\AFPointIllumination(),
                'AFPointBrightness' => new \PHPExiftool\Driver\Tag\NikonCustom\AFPointBrightness(),
                'AFAssist' => new \PHPExiftool\Driver\Tag\NikonCustom\AFAssist(),
                'AFOnButton' => new \PHPExiftool\Driver\Tag\NikonCustom\AFOnButton(),
                'VerticalAFOnButton' => new \PHPExiftool\Driver\Tag\NikonCustom\VerticalAFOnButton(),
                'AF-OnForMB-D10' => new \PHPExiftool\Driver\Tag\NikonCustom\AFOnForMBD10(),
                'AssignBktButton' => new \PHPExiftool\Driver\Tag\NikonCustom\AssignBktButton(),
                'MultiSelectorLiveView' => new \PHPExiftool\Driver\Tag\NikonCustom\MultiSelectorLiveView(),
                'InitialZoomLiveView' => new \PHPExiftool\Driver\Tag\NikonCustom\InitialZoomLiveView(),
                'ISOStepSize' => new \PHPExiftool\Driver\Tag\NikonCustom\ISOStepSize(),
                'ExposureControlStepSize' => new \PHPExiftool\Driver\Tag\NikonCustom\ExposureControlStepSize(),
                'ExposureCompStepSize' => new \PHPExiftool\Driver\Tag\NikonCustom\ExposureCompStepSize(),
                'EasyExposureCompensation' => new \PHPExiftool\Driver\Tag\NikonCustom\EasyExposureCompensation(),
                'CenterWeightedAreaSize' => new \PHPExiftool\Driver\Tag\NikonCustom\CenterWeightedAreaSize(),
                'FineTuneOptCenterWeighted' => new \PHPExiftool\Driver\Tag\NikonCustom\FineTuneOptCenterWeighted(),
                'FineTuneOptMatrixMetering' => new \PHPExiftool\Driver\Tag\NikonCustom\FineTuneOptMatrixMetering(),
                'FineTuneOptSpotMetering' => new \PHPExiftool\Driver\Tag\NikonCustom\FineTuneOptSpotMetering(),
                'MultiSelectorShootMode' => new \PHPExiftool\Driver\Tag\NikonCustom\MultiSelectorShootMode(),
                'MultiSelectorPlaybackMode' => new \PHPExiftool\Driver\Tag\NikonCustom\MultiSelectorPlaybackMode(),
                'InitialZoomSetting' => new \PHPExiftool\Driver\Tag\NikonCustom\InitialZoomSetting(),
                'MultiSelector' => new \PHPExiftool\Driver\Tag\NikonCustom\MultiSelector(),
                'ExposureDelayMode' => new \PHPExiftool\Driver\Tag\NikonCustom\ExposureDelayMode(),
                'CLModeShootingSpeed' => new \PHPExiftool\Driver\Tag\NikonCustom\CLModeShootingSpeed(),
                'CHModeShootingSpeed' => new \PHPExiftool\Driver\Tag\NikonCustom\CHModeShootingSpeed(),
                'MaxContinuousRelease' => new \PHPExiftool\Driver\Tag\NikonCustom\MaxContinuousRelease(),
                'ReverseIndicators' => new \PHPExiftool\Driver\Tag\NikonCustom\ReverseIndicators(),
                'FileNumberSequence' => new \PHPExiftool\Driver\Tag\NikonCustom\FileNumberSequence(),
                'RearDisplay' => new \PHPExiftool\Driver\Tag\NikonCustom\RearDisplay(),
                'ViewfinderDisplay' => new \PHPExiftool\Driver\Tag\NikonCustom\ViewfinderDisplay(),
                'BatteryOrder' => new \PHPExiftool\Driver\Tag\NikonCustom\BatteryOrder(),
                'MB-D10Batteries' => new \PHPExiftool\Driver\Tag\NikonCustom\MBD10Batteries(),
                'ScreenTips' => new \PHPExiftool\Driver\Tag\NikonCustom\ScreenTips(),
                'Beep' => new \PHPExiftool\Driver\Tag\NikonCustom\Beep(),
                'ShootingInfoDisplay' => new \PHPExiftool\Driver\Tag\NikonCustom\ShootingInfoDisplay(),
                'GridDisplay' => new \PHPExiftool\Driver\Tag\NikonCustom\GridDisplay(),
                'ViewfinderWarning' => new \PHPExiftool\Driver\Tag\NikonCustom\ViewfinderWarning(),
                'PreviewButton' => new \PHPExiftool\Driver\Tag\NikonCustom\PreviewButton(),
                'FuncButton' => new \PHPExiftool\Driver\Tag\NikonCustom\FuncButton(),
                'PreviewButtonPlusDials' => new \PHPExiftool\Driver\Tag\NikonCustom\PreviewButtonPlusDials(),
                'FuncButtonPlusDials' => new \PHPExiftool\Driver\Tag\NikonCustom\FuncButtonPlusDials(),
                'AELockButton' => new \PHPExiftool\Driver\Tag\NikonCustom\AELockButton(),
                'AELockButtonPlusDials' => new \PHPExiftool\Driver\Tag\NikonCustom\AELockButtonPlusDials(),
                'CommandDialsReverseRotation' => new \PHPExiftool\Driver\Tag\NikonCustom\CommandDialsReverseRotation(),
                'CommandDialsChangeMainSub' => new \PHPExiftool\Driver\Tag\NikonCustom\CommandDialsChangeMainSub(),
                'CommandDialsApertureSetting' => new \PHPExiftool\Driver\Tag\NikonCustom\CommandDialsApertureSetting(),
                'CommandDialsMenuAndPlayback' => new \PHPExiftool\Driver\Tag\NikonCustom\CommandDialsMenuAndPlayback(),
                'LCDIllumination' => new \PHPExiftool\Driver\Tag\NikonCustom\LCDIllumination(),
                'PhotoInfoPlayback' => new \PHPExiftool\Driver\Tag\NikonCustom\PhotoInfoPlayback(),
                'ShutterReleaseButtonAE-L' => new \PHPExiftool\Driver\Tag\NikonCustom\ShutterReleaseButtonAEL(),
                'ReleaseButtonToUseDial' => new \PHPExiftool\Driver\Tag\NikonCustom\ReleaseButtonToUseDial(),
                'SelfTimerTime' => new \PHPExiftool\Driver\Tag\NikonCustom\SelfTimerTime(),
                'MonitorOffTime' => new \PHPExiftool\Driver\Tag\NikonCustom\MonitorOffTime(),
                'FlashSyncSpeed' => new \PHPExiftool\Driver\Tag\NikonCustom\FlashSyncSpeed(),
                'FlashShutterSpeed' => new \PHPExiftool\Driver\Tag\NikonCustom\FlashShutterSpeed(),
                'AutoBracketSet' => new \PHPExiftool\Driver\Tag\NikonCustom\AutoBracketSet(),
                'AutoBracketModeM' => new \PHPExiftool\Driver\Tag\NikonCustom\AutoBracketModeM(),
                'AutoBracketOrder' => new \PHPExiftool\Driver\Tag\NikonCustom\AutoBracketOrder(),
                'ModelingFlash' => new \PHPExiftool\Driver\Tag\NikonCustom\ModelingFlash(),
                'NoMemoryCard' => new \PHPExiftool\Driver\Tag\NikonCustom\NoMemoryCard(),
                'MeteringTime' => new \PHPExiftool\Driver\Tag\NikonCustom\MeteringTime(),
                'InternalFlash' => new \PHPExiftool\Driver\Tag\NikonCustom\InternalFlash(),
                'ImageReview' => new \PHPExiftool\Driver\Tag\NikonCustom\ImageReview(),
                'AutoISO' => new \PHPExiftool\Driver\Tag\NikonCustom\AutoISO(),
                'AutoISOMax' => new \PHPExiftool\Driver\Tag\NikonCustom\AutoISOMax(),
                'AutoISOMinShutterSpeed' => new \PHPExiftool\Driver\Tag\NikonCustom\AutoISOMinShutterSpeed(),
                'ImageReviewTime' => new \PHPExiftool\Driver\Tag\NikonCustom\ImageReviewTime(),
                'RemoteOnDuration' => new \PHPExiftool\Driver\Tag\NikonCustom\RemoteOnDuration(),
                'AELock' => new \PHPExiftool\Driver\Tag\NikonCustom\AELock(),
                'ShootingModeSetting' => new \PHPExiftool\Driver\Tag\NikonCustom\ShootingModeSetting(),
                'TimerFunctionButton' => new \PHPExiftool\Driver\Tag\NikonCustom\TimerFunctionButton(),
                'Metering' => new \PHPExiftool\Driver\Tag\NikonCustom\Metering(),
                'ManualFlashOutput' => new \PHPExiftool\Driver\Tag\NikonCustom\ManualFlashOutput(),
                'FlashLevel' => new \PHPExiftool\Driver\Tag\NikonCustom\FlashLevel(),
                'FocusModeSetting' => new \PHPExiftool\Driver\Tag\NikonCustom\FocusModeSetting(),
                'AFAreaModeSetting' => new \PHPExiftool\Driver\Tag\NikonCustom\AFAreaModeSetting(),
                'ISODisplay' => new \PHPExiftool\Driver\Tag\NikonCustom\ISODisplay(),
                'RangeFinder' => new \PHPExiftool\Driver\Tag\NikonCustom\RangeFinder(),
                'DateImprint' => new \PHPExiftool\Driver\Tag\NikonCustom\DateImprint(),
                'EVStepSize' => new \PHPExiftool\Driver\Tag\NikonCustom\EVStepSize(),
                'SelfTimerShotCount' => new \PHPExiftool\Driver\Tag\NikonCustom\SelfTimerShotCount(),
                'PlaybackMenusTime' => new \PHPExiftool\Driver\Tag\NikonCustom\PlaybackMenusTime(),
                'LiveViewAF' => new \PHPExiftool\Driver\Tag\NikonCustom\LiveViewAF(),
                'PlaybackMonitorOffTime' => new \PHPExiftool\Driver\Tag\NikonCustom\PlaybackMonitorOffTime(),
                'MenuMonitorOffTime' => new \PHPExiftool\Driver\Tag\NikonCustom\MenuMonitorOffTime(),
                'ShootingInfoMonitorOffTime' => new \PHPExiftool\Driver\Tag\NikonCustom\ShootingInfoMonitorOffTime(),
                'MB-D10BatteryType' => new \PHPExiftool\Driver\Tag\NikonCustom\MBD10BatteryType(),
                'FlashControlBuilt-in' => new \PHPExiftool\Driver\Tag\NikonCustom\FlashControlBuiltIn(),
                'RepeatingFlashOutput' => new \PHPExiftool\Driver\Tag\NikonCustom\RepeatingFlashOutput(),
                'RepeatingFlashCount' => new \PHPExiftool\Driver\Tag\NikonCustom\RepeatingFlashCount(),
                'RepeatingFlashRate' => new \PHPExiftool\Driver\Tag\NikonCustom\RepeatingFlashRate(),
                'CommanderInternalTTLChannel' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLChannel(),
                'CommanderInternalTTLCompBuiltin' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLCompBuiltin(),
                'CommanderInternalTTLCompGroupA' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLCompGroupA(),
                'CommanderInternalTTLCompGroupB' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLCompGroupB(),
                'NumberOfFocusPoints' => new \PHPExiftool\Driver\Tag\NikonCustom\NumberOfFocusPoints(),
                'AF-OnForMB-D11' => new \PHPExiftool\Driver\Tag\NikonCustom\AFOnForMBD11(),
                'MB-D11BatteryType' => new \PHPExiftool\Driver\Tag\NikonCustom\MBD11BatteryType(),
                'BeepPitch' => new \PHPExiftool\Driver\Tag\NikonCustom\BeepPitch(),
                'BeepVolume' => new \PHPExiftool\Driver\Tag\NikonCustom\BeepVolume(),
                'ExposureControlStep' => new \PHPExiftool\Driver\Tag\NikonCustom\ExposureControlStep(),
                'ISOSensitivityStep' => new \PHPExiftool\Driver\Tag\NikonCustom\ISOSensitivityStep(),
                'OKButton' => new \PHPExiftool\Driver\Tag\NikonCustom\OKButton(),
                'SelfTimerInterval' => new \PHPExiftool\Driver\Tag\NikonCustom\SelfTimerInterval(),
                'LiveViewMonitorOffTime' => new \PHPExiftool\Driver\Tag\NikonCustom\LiveViewMonitorOffTime(),
                'FlashWarning' => new \PHPExiftool\Driver\Tag\NikonCustom\FlashWarning(),
                'LiveViewAFAreaMode' => new \PHPExiftool\Driver\Tag\NikonCustom\LiveViewAFAreaMode(),
                'LiveViewAFMode' => new \PHPExiftool\Driver\Tag\NikonCustom\LiveViewAFMode(),
                'Illumination' => new \PHPExiftool\Driver\Tag\NikonCustom\Illumination(),
                'MainDialExposureComp' => new \PHPExiftool\Driver\Tag\NikonCustom\MainDialExposureComp(),
                'CommandDials' => new \PHPExiftool\Driver\Tag\NikonCustom\CommandDials(),
                'FunctionButton' => new \PHPExiftool\Driver\Tag\NikonCustom\FunctionButton(),
                'MB-D80Batteries' => new \PHPExiftool\Driver\Tag\NikonCustom\MBD80Batteries(),
                'AutoFP' => new \PHPExiftool\Driver\Tag\NikonCustom\AutoFP(),
                'CommanderChannel' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderChannel(),
                'CommanderInternalFlash' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalFlash(),
                'CommanderGroupAMode' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupAMode(),
                'CommanderGroupBMode' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupBMode(),
                'CommanderInternalTTLComp' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLComp(),
                'CommanderInternalManualOutput' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalManualOutput(),
                'CommanderGroupA_TTL-AAComp' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupATTLAAComp(),
                'CommanderGroupAManualOutput' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupAManualOutput(),
                'CommanderGroupB_TTL-AAComp' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupBTTLAAComp(),
                'CommanderGroupBManualOutput' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupBManualOutput(),
                'CenterAFArea' => new \PHPExiftool\Driver\Tag\NikonCustom\CenterAFArea(),
                'FocusAreaSelection' => new \PHPExiftool\Driver\Tag\NikonCustom\FocusAreaSelection(),
                'AFAreaIllumination' => new \PHPExiftool\Driver\Tag\NikonCustom\AFAreaIllumination(),
                'LightSwitch' => new \PHPExiftool\Driver\Tag\NikonCustom\LightSwitch(),
                'CenterFocusPoint' => new \PHPExiftool\Driver\Tag\NikonCustom\CenterFocusPoint(),
                'AELockForMB-D80' => new \PHPExiftool\Driver\Tag\NikonCustom\AELockForMBD80(),
                'MB-D80BatteryType' => new \PHPExiftool\Driver\Tag\NikonCustom\MBD80BatteryType(),
                'EasyExposureComp' => new \PHPExiftool\Driver\Tag\NikonCustom\EasyExposureComp(),
                'CommanderGroupA_TTLComp' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupATTLComp(),
                'CommanderGroupB_TTLComp' => new \PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupBTTLComp(),
            );
        });
        $this['XML'] = $this->share(function(){
            return array(
                'AppVersion' => new \PHPExiftool\Driver\Tag\XML\AppVersion(),
                'Application' => new \PHPExiftool\Driver\Tag\XML\Application(),
                'Characters' => new \PHPExiftool\Driver\Tag\XML\Characters(),
                'CharactersWithSpaces' => new \PHPExiftool\Driver\Tag\XML\CharactersWithSpaces(),
                'CheckedBy' => new \PHPExiftool\Driver\Tag\XML\CheckedBy(),
                'Client' => new \PHPExiftool\Driver\Tag\XML\Client(),
                'Company' => new \PHPExiftool\Driver\Tag\XML\Company(),
                'DateCompleted' => new \PHPExiftool\Driver\Tag\XML\DateCompleted(),
                'Department' => new \PHPExiftool\Driver\Tag\XML\Department(),
                'Destination' => new \PHPExiftool\Driver\Tag\XML\Destination(),
                'Disposition' => new \PHPExiftool\Driver\Tag\XML\Disposition(),
                'Division' => new \PHPExiftool\Driver\Tag\XML\Division(),
                'DocSecurity' => new \PHPExiftool\Driver\Tag\XML\DocSecurity(),
                'DocumentNumber' => new \PHPExiftool\Driver\Tag\XML\DocumentNumber(),
                'Editor' => new \PHPExiftool\Driver\Tag\XML\Editor(),
                'ForwardTo' => new \PHPExiftool\Driver\Tag\XML\ForwardTo(),
                'Group' => new \PHPExiftool\Driver\Tag\XML\Group(),
                'HeadingPairs' => new \PHPExiftool\Driver\Tag\XML\HeadingPairs(),
                'HiddenSlides' => new \PHPExiftool\Driver\Tag\XML\HiddenSlides(),
                'HyperlinkBase' => new \PHPExiftool\Driver\Tag\XML\HyperlinkBase(),
                'HyperlinksChanged' => new \PHPExiftool\Driver\Tag\XML\HyperlinksChanged(),
                'Language' => new \PHPExiftool\Driver\Tag\XML\Language(),
                'Lines' => new \PHPExiftool\Driver\Tag\XML\Lines(),
                'LinksUpToDate' => new \PHPExiftool\Driver\Tag\XML\LinksUpToDate(),
                'MMClips' => new \PHPExiftool\Driver\Tag\XML\MMClips(),
                'Mailstop' => new \PHPExiftool\Driver\Tag\XML\Mailstop(),
                'Manager' => new \PHPExiftool\Driver\Tag\XML\Manager(),
                'Matter' => new \PHPExiftool\Driver\Tag\XML\Matter(),
                'Notes' => new \PHPExiftool\Driver\Tag\XML\Notes(),
                'Office' => new \PHPExiftool\Driver\Tag\XML\Office(),
                'Owner' => new \PHPExiftool\Driver\Tag\XML\Owner(),
                'Pages' => new \PHPExiftool\Driver\Tag\XML\Pages(),
                'Paragraphs' => new \PHPExiftool\Driver\Tag\XML\Paragraphs(),
                'PresentationFormat' => new \PHPExiftool\Driver\Tag\XML\PresentationFormat(),
                'Project' => new \PHPExiftool\Driver\Tag\XML\Project(),
                'Publisher' => new \PHPExiftool\Driver\Tag\XML\Publisher(),
                'Purpose' => new \PHPExiftool\Driver\Tag\XML\Purpose(),
                'ReceivedFrom' => new \PHPExiftool\Driver\Tag\XML\ReceivedFrom(),
                'RecordedBy' => new \PHPExiftool\Driver\Tag\XML\RecordedBy(),
                'RecordedDate' => new \PHPExiftool\Driver\Tag\XML\RecordedDate(),
                'Reference' => new \PHPExiftool\Driver\Tag\XML\Reference(),
                'ScaleCrop' => new \PHPExiftool\Driver\Tag\XML\ScaleCrop(),
                'SharedDoc' => new \PHPExiftool\Driver\Tag\XML\SharedDoc(),
                'Slides' => new \PHPExiftool\Driver\Tag\XML\Slides(),
                'Source' => new \PHPExiftool\Driver\Tag\XML\Source(),
                'Status' => new \PHPExiftool\Driver\Tag\XML\Status(),
                'TelephoneNumber' => new \PHPExiftool\Driver\Tag\XML\TelephoneNumber(),
                'Template' => new \PHPExiftool\Driver\Tag\XML\Template(),
                'TitlesOfParts' => new \PHPExiftool\Driver\Tag\XML\TitlesOfParts(),
                'TotalEditTime' => new \PHPExiftool\Driver\Tag\XML\TotalEditTime(),
                'Typist' => new \PHPExiftool\Driver\Tag\XML\Typist(),
                'Words' => new \PHPExiftool\Driver\Tag\XML\Words(),
                'Category' => new \PHPExiftool\Driver\Tag\XML\Category(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\XML\CreateDate(),
                'CreatedType' => new \PHPExiftool\Driver\Tag\XML\CreatedType(),
                'Keywords' => new \PHPExiftool\Driver\Tag\XML\Keywords(),
                'LastModifiedBy' => new \PHPExiftool\Driver\Tag\XML\LastModifiedBy(),
                'LastPrinted' => new \PHPExiftool\Driver\Tag\XML\LastPrinted(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\XML\ModifyDate(),
                'ModifiedType' => new \PHPExiftool\Driver\Tag\XML\ModifiedType(),
                'RevisionNumber' => new \PHPExiftool\Driver\Tag\XML\RevisionNumber(),
                'Author' => new \PHPExiftool\Driver\Tag\XML\Author(),
                'Comment' => new \PHPExiftool\Driver\Tag\XML\Comment(),
                'Copyright' => new \PHPExiftool\Driver\Tag\XML\Copyright(),
                'Projects' => new \PHPExiftool\Driver\Tag\XML\Projects(),
                'Title' => new \PHPExiftool\Driver\Tag\XML\Title(),
            );
        });
        $this['Olympus'] = $this->share(function(){
            return array(
                'Make' => new \PHPExiftool\Driver\Tag\Olympus\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\Olympus\Model(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Olympus\FNumber(),
                'DateTime1' => new \PHPExiftool\Driver\Tag\Olympus\DateTime1(),
                'DateTime2' => new \PHPExiftool\Driver\Tag\Olympus\DateTime2(),
                'CameraSettingsVersion' => new \PHPExiftool\Driver\Tag\Olympus\CameraSettingsVersion(),
                'PreviewImageValid' => new \PHPExiftool\Driver\Tag\Olympus\PreviewImageValid(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Olympus\PreviewImageStart(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Olympus\PreviewImageLength(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\Olympus\ExposureMode(),
                'AELock' => new \PHPExiftool\Driver\Tag\Olympus\AELock(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Olympus\MeteringMode(),
                'ExposureShift' => new \PHPExiftool\Driver\Tag\Olympus\ExposureShift(),
                'MacroMode' => new \PHPExiftool\Driver\Tag\Olympus\MacroMode(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Olympus\FocusMode(),
                'FocusProcess' => new \PHPExiftool\Driver\Tag\Olympus\FocusProcess(),
                'AFSearch' => new \PHPExiftool\Driver\Tag\Olympus\AFSearch(),
                'AFAreas' => new \PHPExiftool\Driver\Tag\Olympus\AFAreas(),
                'AFPointSelected' => new \PHPExiftool\Driver\Tag\Olympus\AFPointSelected(),
                'AFFineTune' => new \PHPExiftool\Driver\Tag\Olympus\AFFineTune(),
                'AFFineTuneAdj' => new \PHPExiftool\Driver\Tag\Olympus\AFFineTuneAdj(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Olympus\FlashMode(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\Olympus\FlashExposureComp(),
                'FlashRemoteControl' => new \PHPExiftool\Driver\Tag\Olympus\FlashRemoteControl(),
                'FlashControlMode' => new \PHPExiftool\Driver\Tag\Olympus\FlashControlMode(),
                'FlashIntensity' => new \PHPExiftool\Driver\Tag\Olympus\FlashIntensity(),
                'ManualFlashStrength' => new \PHPExiftool\Driver\Tag\Olympus\ManualFlashStrength(),
                'WhiteBalance2' => new \PHPExiftool\Driver\Tag\Olympus\WhiteBalance2(),
                'WhiteBalanceTemperature' => new \PHPExiftool\Driver\Tag\Olympus\WhiteBalanceTemperature(),
                'WhiteBalanceBracket' => new \PHPExiftool\Driver\Tag\Olympus\WhiteBalanceBracket(),
                'CustomSaturation' => new \PHPExiftool\Driver\Tag\Olympus\CustomSaturation(),
                'ModifiedSaturation' => new \PHPExiftool\Driver\Tag\Olympus\ModifiedSaturation(),
                'ContrastSetting' => new \PHPExiftool\Driver\Tag\Olympus\ContrastSetting(),
                'SharpnessSetting' => new \PHPExiftool\Driver\Tag\Olympus\SharpnessSetting(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Olympus\ColorSpace(),
                'SceneMode' => new \PHPExiftool\Driver\Tag\Olympus\SceneMode(),
                'NoiseReduction' => new \PHPExiftool\Driver\Tag\Olympus\NoiseReduction(),
                'DistortionCorrection' => new \PHPExiftool\Driver\Tag\Olympus\DistortionCorrection(),
                'ShadingCompensation' => new \PHPExiftool\Driver\Tag\Olympus\ShadingCompensation(),
                'CompressionFactor' => new \PHPExiftool\Driver\Tag\Olympus\CompressionFactor(),
                'Gradation' => new \PHPExiftool\Driver\Tag\Olympus\Gradation(),
                'PictureMode' => new \PHPExiftool\Driver\Tag\Olympus\PictureMode(),
                'PictureModeSaturation' => new \PHPExiftool\Driver\Tag\Olympus\PictureModeSaturation(),
                'PictureModeHue' => new \PHPExiftool\Driver\Tag\Olympus\PictureModeHue(),
                'PictureModeContrast' => new \PHPExiftool\Driver\Tag\Olympus\PictureModeContrast(),
                'PictureModeSharpness' => new \PHPExiftool\Driver\Tag\Olympus\PictureModeSharpness(),
                'PictureModeBWFilter' => new \PHPExiftool\Driver\Tag\Olympus\PictureModeBWFilter(),
                'PictureModeTone' => new \PHPExiftool\Driver\Tag\Olympus\PictureModeTone(),
                'NoiseFilter' => new \PHPExiftool\Driver\Tag\Olympus\NoiseFilter(),
                'ArtFilter' => new \PHPExiftool\Driver\Tag\Olympus\ArtFilter(),
                'MagicFilter' => new \PHPExiftool\Driver\Tag\Olympus\MagicFilter(),
                'PictureModeEffect' => new \PHPExiftool\Driver\Tag\Olympus\PictureModeEffect(),
                'ArtFilterEffect' => new \PHPExiftool\Driver\Tag\Olympus\ArtFilterEffect(),
                'DriveMode' => new \PHPExiftool\Driver\Tag\Olympus\DriveMode(),
                'PanoramaMode' => new \PHPExiftool\Driver\Tag\Olympus\PanoramaMode(),
                'ImageQuality2' => new \PHPExiftool\Driver\Tag\Olympus\ImageQuality2(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\Olympus\ImageStabilization(),
                'ManometerPressure' => new \PHPExiftool\Driver\Tag\Olympus\ManometerPressure(),
                'ManometerReading' => new \PHPExiftool\Driver\Tag\Olympus\ManometerReading(),
                'ExtendedWBDetect' => new \PHPExiftool\Driver\Tag\Olympus\ExtendedWBDetect(),
                'LevelGaugeRoll' => new \PHPExiftool\Driver\Tag\Olympus\LevelGaugeRoll(),
                'LevelGaugePitch' => new \PHPExiftool\Driver\Tag\Olympus\LevelGaugePitch(),
                'EquipmentVersion' => new \PHPExiftool\Driver\Tag\Olympus\EquipmentVersion(),
                'CameraType2' => new \PHPExiftool\Driver\Tag\Olympus\CameraType2(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Olympus\SerialNumber(),
                'InternalSerialNumber' => new \PHPExiftool\Driver\Tag\Olympus\InternalSerialNumber(),
                'FocalPlaneDiagonal' => new \PHPExiftool\Driver\Tag\Olympus\FocalPlaneDiagonal(),
                'BodyFirmwareVersion' => new \PHPExiftool\Driver\Tag\Olympus\BodyFirmwareVersion(),
                'LensType' => new \PHPExiftool\Driver\Tag\Olympus\LensType(),
                'LensSerialNumber' => new \PHPExiftool\Driver\Tag\Olympus\LensSerialNumber(),
                'LensModel' => new \PHPExiftool\Driver\Tag\Olympus\LensModel(),
                'LensFirmwareVersion' => new \PHPExiftool\Driver\Tag\Olympus\LensFirmwareVersion(),
                'MaxApertureAtMinFocal' => new \PHPExiftool\Driver\Tag\Olympus\MaxApertureAtMinFocal(),
                'MaxApertureAtMaxFocal' => new \PHPExiftool\Driver\Tag\Olympus\MaxApertureAtMaxFocal(),
                'MinFocalLength' => new \PHPExiftool\Driver\Tag\Olympus\MinFocalLength(),
                'MaxFocalLength' => new \PHPExiftool\Driver\Tag\Olympus\MaxFocalLength(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\Olympus\MaxAperture(),
                'LensProperties' => new \PHPExiftool\Driver\Tag\Olympus\LensProperties(),
                'Extender' => new \PHPExiftool\Driver\Tag\Olympus\Extender(),
                'ExtenderSerialNumber' => new \PHPExiftool\Driver\Tag\Olympus\ExtenderSerialNumber(),
                'ExtenderModel' => new \PHPExiftool\Driver\Tag\Olympus\ExtenderModel(),
                'ExtenderFirmwareVersion' => new \PHPExiftool\Driver\Tag\Olympus\ExtenderFirmwareVersion(),
                'ConversionLens' => new \PHPExiftool\Driver\Tag\Olympus\ConversionLens(),
                'FlashType' => new \PHPExiftool\Driver\Tag\Olympus\FlashType(),
                'FlashModel' => new \PHPExiftool\Driver\Tag\Olympus\FlashModel(),
                'FlashFirmwareVersion' => new \PHPExiftool\Driver\Tag\Olympus\FlashFirmwareVersion(),
                'FlashSerialNumber' => new \PHPExiftool\Driver\Tag\Olympus\FlashSerialNumber(),
                'FocusInfoVersion' => new \PHPExiftool\Driver\Tag\Olympus\FocusInfoVersion(),
                'AutoFocus' => new \PHPExiftool\Driver\Tag\Olympus\AutoFocus(),
                'SceneDetect' => new \PHPExiftool\Driver\Tag\Olympus\SceneDetect(),
                'SceneArea' => new \PHPExiftool\Driver\Tag\Olympus\SceneArea(),
                'SceneDetectData' => new \PHPExiftool\Driver\Tag\Olympus\SceneDetectData(),
                'ZoomStepCount' => new \PHPExiftool\Driver\Tag\Olympus\ZoomStepCount(),
                'FocusStepCount' => new \PHPExiftool\Driver\Tag\Olympus\FocusStepCount(),
                'FocusStepInfinity' => new \PHPExiftool\Driver\Tag\Olympus\FocusStepInfinity(),
                'FocusStepNear' => new \PHPExiftool\Driver\Tag\Olympus\FocusStepNear(),
                'FocusDistance' => new \PHPExiftool\Driver\Tag\Olympus\FocusDistance(),
                'AFPoint' => new \PHPExiftool\Driver\Tag\Olympus\AFPoint(),
                'ExternalFlash' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlash(),
                'ExternalFlashGuideNumber' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashGuideNumber(),
                'ExternalFlashBounce' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashBounce(),
                'ExternalFlashZoom' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashZoom(),
                'InternalFlash' => new \PHPExiftool\Driver\Tag\Olympus\InternalFlash(),
                'ManualFlash' => new \PHPExiftool\Driver\Tag\Olympus\ManualFlash(),
                'MacroLED' => new \PHPExiftool\Driver\Tag\Olympus\MacroLED(),
                'SensorTemperature' => new \PHPExiftool\Driver\Tag\Olympus\SensorTemperature(),
                'ImageProcessingVersion' => new \PHPExiftool\Driver\Tag\Olympus\ImageProcessingVersion(),
                'WB_RBLevels' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels(),
                'WB_RBLevels3000K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels3000K(),
                'WB_RBLevels3300K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels3300K(),
                'WB_RBLevels3600K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels3600K(),
                'WB_RBLevels3900K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels3900K(),
                'WB_RBLevels4000K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels4000K(),
                'WB_RBLevels4300K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels4300K(),
                'WB_RBLevels4500K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels4500K(),
                'WB_RBLevels4800K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels4800K(),
                'WB_RBLevels5300K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels5300K(),
                'WB_RBLevels6000K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels6000K(),
                'WB_RBLevels6600K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels6600K(),
                'WB_RBLevels7500K' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevels7500K(),
                'WB_RBLevelsCWB1' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCWB1(),
                'WB_RBLevelsCWB2' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCWB2(),
                'WB_RBLevelsCWB3' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCWB3(),
                'WB_RBLevelsCWB4' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCWB4(),
                'WB_GLevel3000K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel3000K(),
                'WB_GLevel3300K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel3300K(),
                'WB_GLevel3600K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel3600K(),
                'WB_GLevel3900K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel3900K(),
                'WB_GLevel4000K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel4000K(),
                'WB_GLevel4300K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel4300K(),
                'WB_GLevel4500K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel4500K(),
                'WB_GLevel4800K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel4800K(),
                'WB_GLevel5300K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel5300K(),
                'WB_GLevel6000K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel6000K(),
                'WB_GLevel6600K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel6600K(),
                'WB_GLevel7500K' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel7500K(),
                'WB_GLevel' => new \PHPExiftool\Driver\Tag\Olympus\WBGLevel(),
                'ColorMatrix' => new \PHPExiftool\Driver\Tag\Olympus\ColorMatrix(),
                'Enhancer' => new \PHPExiftool\Driver\Tag\Olympus\Enhancer(),
                'EnhancerValues' => new \PHPExiftool\Driver\Tag\Olympus\EnhancerValues(),
                'CoringFilter' => new \PHPExiftool\Driver\Tag\Olympus\CoringFilter(),
                'CoringValues' => new \PHPExiftool\Driver\Tag\Olympus\CoringValues(),
                'BlackLevel2' => new \PHPExiftool\Driver\Tag\Olympus\BlackLevel2(),
                'GainBase' => new \PHPExiftool\Driver\Tag\Olympus\GainBase(),
                'ValidBits' => new \PHPExiftool\Driver\Tag\Olympus\ValidBits(),
                'CropLeft' => new \PHPExiftool\Driver\Tag\Olympus\CropLeft(),
                'CropTop' => new \PHPExiftool\Driver\Tag\Olympus\CropTop(),
                'CropWidth' => new \PHPExiftool\Driver\Tag\Olympus\CropWidth(),
                'CropHeight' => new \PHPExiftool\Driver\Tag\Olympus\CropHeight(),
                'NoiseReduction2' => new \PHPExiftool\Driver\Tag\Olympus\NoiseReduction2(),
                'DistortionCorrection2' => new \PHPExiftool\Driver\Tag\Olympus\DistortionCorrection2(),
                'ShadingCompensation2' => new \PHPExiftool\Driver\Tag\Olympus\ShadingCompensation2(),
                'MultipleExposureMode' => new \PHPExiftool\Driver\Tag\Olympus\MultipleExposureMode(),
                'UnknownBlock' => new \PHPExiftool\Driver\Tag\Olympus\UnknownBlock(),
                'AspectRatio' => new \PHPExiftool\Driver\Tag\Olympus\AspectRatio(),
                'AspectFrame' => new \PHPExiftool\Driver\Tag\Olympus\AspectFrame(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Olympus\FacesDetected(),
                'FaceDetectArea' => new \PHPExiftool\Driver\Tag\Olympus\FaceDetectArea(),
                'MaxFaces' => new \PHPExiftool\Driver\Tag\Olympus\MaxFaces(),
                'FaceDetectFrameSize' => new \PHPExiftool\Driver\Tag\Olympus\FaceDetectFrameSize(),
                'FaceDetectFrameCrop' => new \PHPExiftool\Driver\Tag\Olympus\FaceDetectFrameCrop(),
                'ExposureUnknown' => new \PHPExiftool\Driver\Tag\Olympus\ExposureUnknown(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Olympus\ExposureCompensation(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Olympus\FocalLength(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Olympus\ExposureTime(),
                'ISO' => new \PHPExiftool\Driver\Tag\Olympus\ISO(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Olympus\MakerNoteVersion(),
                'CompressedImageSize' => new \PHPExiftool\Driver\Tag\Olympus\CompressedImageSize(),
                'PreviewImageData' => new \PHPExiftool\Driver\Tag\Olympus\PreviewImageData(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\Olympus\ThumbnailImage(),
                'SpecialMode' => new \PHPExiftool\Driver\Tag\Olympus\SpecialMode(),
                'Quality' => new \PHPExiftool\Driver\Tag\Olympus\Quality(),
                'Macro' => new \PHPExiftool\Driver\Tag\Olympus\Macro(),
                'BWMode' => new \PHPExiftool\Driver\Tag\Olympus\BWMode(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Olympus\DigitalZoom(),
                'LensDistortionParams' => new \PHPExiftool\Driver\Tag\Olympus\LensDistortionParams(),
                'CameraType' => new \PHPExiftool\Driver\Tag\Olympus\CameraType(),
                'CameraID' => new \PHPExiftool\Driver\Tag\Olympus\CameraID(),
                'EpsonImageWidth' => new \PHPExiftool\Driver\Tag\Olympus\EpsonImageWidth(),
                'EpsonImageHeight' => new \PHPExiftool\Driver\Tag\Olympus\EpsonImageHeight(),
                'EpsonSoftware' => new \PHPExiftool\Driver\Tag\Olympus\EpsonSoftware(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Olympus\PreviewImage(),
                'PreCaptureFrames' => new \PHPExiftool\Driver\Tag\Olympus\PreCaptureFrames(),
                'WhiteBoard' => new \PHPExiftool\Driver\Tag\Olympus\WhiteBoard(),
                'OneTouchWB' => new \PHPExiftool\Driver\Tag\Olympus\OneTouchWB(),
                'WhiteBalanceBias' => new \PHPExiftool\Driver\Tag\Olympus\WhiteBalanceBias(),
                'Firmware' => new \PHPExiftool\Driver\Tag\Olympus\Firmware(),
                'DataDump' => new \PHPExiftool\Driver\Tag\Olympus\DataDump(),
                'DataDump2' => new \PHPExiftool\Driver\Tag\Olympus\DataDump2(),
                'ZoomedPreviewStart' => new \PHPExiftool\Driver\Tag\Olympus\ZoomedPreviewStart(),
                'ZoomedPreviewLength' => new \PHPExiftool\Driver\Tag\Olympus\ZoomedPreviewLength(),
                'ZoomedPreviewSize' => new \PHPExiftool\Driver\Tag\Olympus\ZoomedPreviewSize(),
                'ShutterSpeedValue' => new \PHPExiftool\Driver\Tag\Olympus\ShutterSpeedValue(),
                'ISOValue' => new \PHPExiftool\Driver\Tag\Olympus\ISOValue(),
                'ApertureValue' => new \PHPExiftool\Driver\Tag\Olympus\ApertureValue(),
                'BrightnessValue' => new \PHPExiftool\Driver\Tag\Olympus\BrightnessValue(),
                'FlashDevice' => new \PHPExiftool\Driver\Tag\Olympus\FlashDevice(),
                'LensTemperature' => new \PHPExiftool\Driver\Tag\Olympus\LensTemperature(),
                'LightCondition' => new \PHPExiftool\Driver\Tag\Olympus\LightCondition(),
                'FocusRange' => new \PHPExiftool\Driver\Tag\Olympus\FocusRange(),
                'ManualFocusDistance' => new \PHPExiftool\Driver\Tag\Olympus\ManualFocusDistance(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Olympus\Sharpness(),
                'FlashChargeLevel' => new \PHPExiftool\Driver\Tag\Olympus\FlashChargeLevel(),
                'BlackLevel' => new \PHPExiftool\Driver\Tag\Olympus\BlackLevel(),
                'ColorTemperatureBG' => new \PHPExiftool\Driver\Tag\Olympus\ColorTemperatureBG(),
                'ColorTemperatureRG' => new \PHPExiftool\Driver\Tag\Olympus\ColorTemperatureRG(),
                'WBMode' => new \PHPExiftool\Driver\Tag\Olympus\WBMode(),
                'RedBalance' => new \PHPExiftool\Driver\Tag\Olympus\RedBalance(),
                'BlueBalance' => new \PHPExiftool\Driver\Tag\Olympus\BlueBalance(),
                'ColorMatrixNumber' => new \PHPExiftool\Driver\Tag\Olympus\ColorMatrixNumber(),
                'ExternalFlashAE1_0' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashAE10(),
                'ExternalFlashAE2_0' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashAE20(),
                'InternalFlashAE1_0' => new \PHPExiftool\Driver\Tag\Olympus\InternalFlashAE10(),
                'InternalFlashAE2_0' => new \PHPExiftool\Driver\Tag\Olympus\InternalFlashAE20(),
                'ExternalFlashAE1' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashAE1(),
                'ExternalFlashAE2' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashAE2(),
                'InternalFlashAE1' => new \PHPExiftool\Driver\Tag\Olympus\InternalFlashAE1(),
                'InternalFlashAE2' => new \PHPExiftool\Driver\Tag\Olympus\InternalFlashAE2(),
                'InternalFlashTable' => new \PHPExiftool\Driver\Tag\Olympus\InternalFlashTable(),
                'ExternalFlashGValue' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashGValue(),
                'ExternalFlashMode' => new \PHPExiftool\Driver\Tag\Olympus\ExternalFlashMode(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Olympus\Contrast(),
                'SharpnessFactor' => new \PHPExiftool\Driver\Tag\Olympus\SharpnessFactor(),
                'ColorControl' => new \PHPExiftool\Driver\Tag\Olympus\ColorControl(),
                'OlympusImageWidth' => new \PHPExiftool\Driver\Tag\Olympus\OlympusImageWidth(),
                'OlympusImageHeight' => new \PHPExiftool\Driver\Tag\Olympus\OlympusImageHeight(),
                'CompressionRatio' => new \PHPExiftool\Driver\Tag\Olympus\CompressionRatio(),
                'AFResult' => new \PHPExiftool\Driver\Tag\Olympus\AFResult(),
                'CCDScanMode' => new \PHPExiftool\Driver\Tag\Olympus\CCDScanMode(),
                'LightValueCenter' => new \PHPExiftool\Driver\Tag\Olympus\LightValueCenter(),
                'LightValuePeriphery' => new \PHPExiftool\Driver\Tag\Olympus\LightValuePeriphery(),
                'FieldCount' => new \PHPExiftool\Driver\Tag\Olympus\FieldCount(),
                'CameraParameters' => new \PHPExiftool\Driver\Tag\Olympus\CameraParameters(),
                'EncoderVersion' => new \PHPExiftool\Driver\Tag\Olympus\EncoderVersion(),
                'DecoderVersion' => new \PHPExiftool\Driver\Tag\Olympus\DecoderVersion(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\Olympus\DateTimeOriginal(),
                'ThumbnailWidth' => new \PHPExiftool\Driver\Tag\Olympus\ThumbnailWidth(),
                'ThumbnailHeight' => new \PHPExiftool\Driver\Tag\Olympus\ThumbnailHeight(),
                'RawDevVersion' => new \PHPExiftool\Driver\Tag\Olympus\RawDevVersion(),
                'RawDevExposureBiasValue' => new \PHPExiftool\Driver\Tag\Olympus\RawDevExposureBiasValue(),
                'RawDevWhiteBalanceValue' => new \PHPExiftool\Driver\Tag\Olympus\RawDevWhiteBalanceValue(),
                'RawDevWBFineAdjustment' => new \PHPExiftool\Driver\Tag\Olympus\RawDevWBFineAdjustment(),
                'RawDevGrayPoint' => new \PHPExiftool\Driver\Tag\Olympus\RawDevGrayPoint(),
                'RawDevSaturationEmphasis' => new \PHPExiftool\Driver\Tag\Olympus\RawDevSaturationEmphasis(),
                'RawDevMemoryColorEmphasis' => new \PHPExiftool\Driver\Tag\Olympus\RawDevMemoryColorEmphasis(),
                'RawDevContrastValue' => new \PHPExiftool\Driver\Tag\Olympus\RawDevContrastValue(),
                'RawDevSharpnessValue' => new \PHPExiftool\Driver\Tag\Olympus\RawDevSharpnessValue(),
                'RawDevColorSpace' => new \PHPExiftool\Driver\Tag\Olympus\RawDevColorSpace(),
                'RawDevEngine' => new \PHPExiftool\Driver\Tag\Olympus\RawDevEngine(),
                'RawDevNoiseReduction' => new \PHPExiftool\Driver\Tag\Olympus\RawDevNoiseReduction(),
                'RawDevEditStatus' => new \PHPExiftool\Driver\Tag\Olympus\RawDevEditStatus(),
                'RawDevSettings' => new \PHPExiftool\Driver\Tag\Olympus\RawDevSettings(),
                'RawDevWhiteBalance' => new \PHPExiftool\Driver\Tag\Olympus\RawDevWhiteBalance(),
                'RawDevPictureMode' => new \PHPExiftool\Driver\Tag\Olympus\RawDevPictureMode(),
                'RawDevPMSaturation' => new \PHPExiftool\Driver\Tag\Olympus\RawDevPMSaturation(),
                'RawDevPMContrast' => new \PHPExiftool\Driver\Tag\Olympus\RawDevPMContrast(),
                'RawDevPMSharpness' => new \PHPExiftool\Driver\Tag\Olympus\RawDevPMSharpness(),
                'RawDevPM_BWFilter' => new \PHPExiftool\Driver\Tag\Olympus\RawDevPMBWFilter(),
                'RawDevPMPictureTone' => new \PHPExiftool\Driver\Tag\Olympus\RawDevPMPictureTone(),
                'RawDevGradation' => new \PHPExiftool\Driver\Tag\Olympus\RawDevGradation(),
                'RawDevSaturation3' => new \PHPExiftool\Driver\Tag\Olympus\RawDevSaturation3(),
                'RawDevAutoGradation' => new \PHPExiftool\Driver\Tag\Olympus\RawDevAutoGradation(),
                'RawDevPMNoiseFilter' => new \PHPExiftool\Driver\Tag\Olympus\RawDevPMNoiseFilter(),
                'RawInfoVersion' => new \PHPExiftool\Driver\Tag\Olympus\RawInfoVersion(),
                'WB_RBLevelsUsed' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsUsed(),
                'WB_RBLevelsAuto' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsAuto(),
                'WB_RBLevelsShade' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsShade(),
                'WB_RBLevelsCloudy' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCloudy(),
                'WB_RBLevelsFineWeather' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsFineWeather(),
                'WB_RBLevelsTungsten' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsTungsten(),
                'WB_RBLevelsEveningSunlight' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsEveningSunlight(),
                'WB_RBLevelsDaylightFluor' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsDaylightFluor(),
                'WB_RBLevelsDayWhiteFluor' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsDayWhiteFluor(),
                'WB_RBLevelsCoolWhiteFluor' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCoolWhiteFluor(),
                'WB_RBLevelsWhiteFluorescent' => new \PHPExiftool\Driver\Tag\Olympus\WBRBLevelsWhiteFluorescent(),
                'ColorMatrix2' => new \PHPExiftool\Driver\Tag\Olympus\ColorMatrix2(),
                'YCbCrCoefficients' => new \PHPExiftool\Driver\Tag\Olympus\YCbCrCoefficients(),
                'ValidPixelDepth' => new \PHPExiftool\Driver\Tag\Olympus\ValidPixelDepth(),
                'LightSource' => new \PHPExiftool\Driver\Tag\Olympus\LightSource(),
                'WhiteBalanceComp' => new \PHPExiftool\Driver\Tag\Olympus\WhiteBalanceComp(),
                'SaturationSetting' => new \PHPExiftool\Driver\Tag\Olympus\SaturationSetting(),
                'HueSetting' => new \PHPExiftool\Driver\Tag\Olympus\HueSetting(),
                'CMExposureCompensation' => new \PHPExiftool\Driver\Tag\Olympus\CMExposureCompensation(),
                'CMWhiteBalance' => new \PHPExiftool\Driver\Tag\Olympus\CMWhiteBalance(),
                'CMWhiteBalanceComp' => new \PHPExiftool\Driver\Tag\Olympus\CMWhiteBalanceComp(),
                'CMWhiteBalanceGrayPoint' => new \PHPExiftool\Driver\Tag\Olympus\CMWhiteBalanceGrayPoint(),
                'CMSaturation' => new \PHPExiftool\Driver\Tag\Olympus\CMSaturation(),
                'CMHue' => new \PHPExiftool\Driver\Tag\Olympus\CMHue(),
                'CMContrast' => new \PHPExiftool\Driver\Tag\Olympus\CMContrast(),
                'CMSharpness' => new \PHPExiftool\Driver\Tag\Olympus\CMSharpness(),
                'Resolution' => new \PHPExiftool\Driver\Tag\Olympus\Resolution(),
                'ThumbnailLength' => new \PHPExiftool\Driver\Tag\Olympus\ThumbnailLength(),
                'ThumbnailOffset' => new \PHPExiftool\Driver\Tag\Olympus\ThumbnailOffset(),
                'FileNumber' => new \PHPExiftool\Driver\Tag\Olympus\FileNumber(),
                'DateTimeEnd' => new \PHPExiftool\Driver\Tag\Olympus\DateTimeEnd(),
                'RecordingTime' => new \PHPExiftool\Driver\Tag\Olympus\RecordingTime(),
                'Duration' => new \PHPExiftool\Driver\Tag\Olympus\Duration(),
                'Index01' => new \PHPExiftool\Driver\Tag\Olympus\Index01(),
                'Index02' => new \PHPExiftool\Driver\Tag\Olympus\Index02(),
                'Index03' => new \PHPExiftool\Driver\Tag\Olympus\Index03(),
                'Index04' => new \PHPExiftool\Driver\Tag\Olympus\Index04(),
                'Index05' => new \PHPExiftool\Driver\Tag\Olympus\Index05(),
                'Index06' => new \PHPExiftool\Driver\Tag\Olympus\Index06(),
                'Index07' => new \PHPExiftool\Driver\Tag\Olympus\Index07(),
                'Index08' => new \PHPExiftool\Driver\Tag\Olympus\Index08(),
                'Index09' => new \PHPExiftool\Driver\Tag\Olympus\Index09(),
                'Index10' => new \PHPExiftool\Driver\Tag\Olympus\Index10(),
                'Index11' => new \PHPExiftool\Driver\Tag\Olympus\Index11(),
                'Index12' => new \PHPExiftool\Driver\Tag\Olympus\Index12(),
                'Index13' => new \PHPExiftool\Driver\Tag\Olympus\Index13(),
                'Index14' => new \PHPExiftool\Driver\Tag\Olympus\Index14(),
                'Index15' => new \PHPExiftool\Driver\Tag\Olympus\Index15(),
                'Index16' => new \PHPExiftool\Driver\Tag\Olympus\Index16(),
            );
        });
        $this['OpenEXR'] = $this->share(function(){
            return array(
                'Layout' => new \PHPExiftool\Driver\Tag\OpenEXR\Layout(),
                'EXRVersion' => new \PHPExiftool\Driver\Tag\OpenEXR\EXRVersion(),
                'AdoptedNeutral' => new \PHPExiftool\Driver\Tag\OpenEXR\AdoptedNeutral(),
                'GPSAltitude' => new \PHPExiftool\Driver\Tag\OpenEXR\GPSAltitude(),
                'Aperture' => new \PHPExiftool\Driver\Tag\OpenEXR\Aperture(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\OpenEXR\DateTimeOriginal(),
                'Channels' => new \PHPExiftool\Driver\Tag\OpenEXR\Channels(),
                'Chromaticities' => new \PHPExiftool\Driver\Tag\OpenEXR\Chromaticities(),
                'Comments' => new \PHPExiftool\Driver\Tag\OpenEXR\Comments(),
                'Compression' => new \PHPExiftool\Driver\Tag\OpenEXR\Compression(),
                'DataWindow' => new \PHPExiftool\Driver\Tag\OpenEXR\DataWindow(),
                'DisplayWindow' => new \PHPExiftool\Driver\Tag\OpenEXR\DisplayWindow(),
                'EnvironmentMap' => new \PHPExiftool\Driver\Tag\OpenEXR\EnvironmentMap(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\OpenEXR\ExposureTime(),
                'FocusDistance' => new \PHPExiftool\Driver\Tag\OpenEXR\FocusDistance(),
                'FramesPerSecond' => new \PHPExiftool\Driver\Tag\OpenEXR\FramesPerSecond(),
                'ISO' => new \PHPExiftool\Driver\Tag\OpenEXR\ISO(),
                'KeyCode' => new \PHPExiftool\Driver\Tag\OpenEXR\KeyCode(),
                'GPSLatitude' => new \PHPExiftool\Driver\Tag\OpenEXR\GPSLatitude(),
                'LineOrder' => new \PHPExiftool\Driver\Tag\OpenEXR\LineOrder(),
                'GPSLongitude' => new \PHPExiftool\Driver\Tag\OpenEXR\GPSLongitude(),
                'LookModTransform' => new \PHPExiftool\Driver\Tag\OpenEXR\LookModTransform(),
                'MultiView' => new \PHPExiftool\Driver\Tag\OpenEXR\MultiView(),
                'Owner' => new \PHPExiftool\Driver\Tag\OpenEXR\Owner(),
                'PixelAspectRatio' => new \PHPExiftool\Driver\Tag\OpenEXR\PixelAspectRatio(),
                'Preview' => new \PHPExiftool\Driver\Tag\OpenEXR\Preview(),
                'RenderingTransform' => new \PHPExiftool\Driver\Tag\OpenEXR\RenderingTransform(),
                'ScreenWindowCenter' => new \PHPExiftool\Driver\Tag\OpenEXR\ScreenWindowCenter(),
                'ScreenWindowWidth' => new \PHPExiftool\Driver\Tag\OpenEXR\ScreenWindowWidth(),
                'Tiles' => new \PHPExiftool\Driver\Tag\OpenEXR\Tiles(),
                'TimeCode' => new \PHPExiftool\Driver\Tag\OpenEXR\TimeCode(),
                'TimeZone' => new \PHPExiftool\Driver\Tag\OpenEXR\TimeZone(),
                'WhiteLuminance' => new \PHPExiftool\Driver\Tag\OpenEXR\WhiteLuminance(),
                'WorldToCamera' => new \PHPExiftool\Driver\Tag\OpenEXR\WorldToCamera(),
                'WorldToNDC' => new \PHPExiftool\Driver\Tag\OpenEXR\WorldToNDC(),
                'WrapModes' => new \PHPExiftool\Driver\Tag\OpenEXR\WrapModes(),
                'XResolution' => new \PHPExiftool\Driver\Tag\OpenEXR\XResolution(),
            );
        });
        $this['PDF'] = $this->share(function(){
            return array(
                'ContainerVersion' => new \PHPExiftool\Driver\Tag\PDF\ContainerVersion(),
                'CreatorVersion' => new \PHPExiftool\Driver\Tag\PDF\CreatorVersion(),
                'RoundTripVersion' => new \PHPExiftool\Driver\Tag\PDF\RoundTripVersion(),
                'HasXFA' => new \PHPExiftool\Driver\Tag\PDF\HasXFA(),
                'Encryption' => new \PHPExiftool\Driver\Tag\PDF\Encryption(),
                'UserAccess' => new \PHPExiftool\Driver\Tag\PDF\UserAccess(),
                'AppleKeywords' => new \PHPExiftool\Driver\Tag\PDF\AppleKeywords(),
                'Author' => new \PHPExiftool\Driver\Tag\PDF\Author(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\PDF\CreateDate(),
                'Creator' => new \PHPExiftool\Driver\Tag\PDF\Creator(),
                'Keywords' => new \PHPExiftool\Driver\Tag\PDF\Keywords(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\PDF\ModifyDate(),
                'Producer' => new \PHPExiftool\Driver\Tag\PDF\Producer(),
                'Subject' => new \PHPExiftool\Driver\Tag\PDF\Subject(),
                'Title' => new \PHPExiftool\Driver\Tag\PDF\Title(),
                'Trapped' => new \PHPExiftool\Driver\Tag\PDF\Trapped(),
                'Linearized' => new \PHPExiftool\Driver\Tag\PDF\Linearized(),
                'TaggedPDF' => new \PHPExiftool\Driver\Tag\PDF\TaggedPDF(),
                'PageCount' => new \PHPExiftool\Driver\Tag\PDF\PageCount(),
                'Language' => new \PHPExiftool\Driver\Tag\PDF\Language(),
                'PageLayout' => new \PHPExiftool\Driver\Tag\PDF\PageLayout(),
                'PageMode' => new \PHPExiftool\Driver\Tag\PDF\PageMode(),
                'PDFVersion' => new \PHPExiftool\Driver\Tag\PDF\PDFVersion(),
                'SignerContactInfo' => new \PHPExiftool\Driver\Tag\PDF\SignerContactInfo(),
                'SigningLocation' => new \PHPExiftool\Driver\Tag\PDF\SigningLocation(),
                'SigningDate' => new \PHPExiftool\Driver\Tag\PDF\SigningDate(),
                'SigningAuthority' => new \PHPExiftool\Driver\Tag\PDF\SigningAuthority(),
                'AuthenticationTime' => new \PHPExiftool\Driver\Tag\PDF\AuthenticationTime(),
                'AuthenticationType' => new \PHPExiftool\Driver\Tag\PDF\AuthenticationType(),
                'SigningReason' => new \PHPExiftool\Driver\Tag\PDF\SigningReason(),
                'FieldPermissions' => new \PHPExiftool\Driver\Tag\PDF\FieldPermissions(),
                'AnnotationUsageRights' => new \PHPExiftool\Driver\Tag\PDF\AnnotationUsageRights(),
                'DocumentUsageRights' => new \PHPExiftool\Driver\Tag\PDF\DocumentUsageRights(),
                'EmbeddedFileUsageRights' => new \PHPExiftool\Driver\Tag\PDF\EmbeddedFileUsageRights(),
                'FormFields' => new \PHPExiftool\Driver\Tag\PDF\FormFields(),
                'FormUsageRights' => new \PHPExiftool\Driver\Tag\PDF\FormUsageRights(),
                'FormExtraUsageRights' => new \PHPExiftool\Driver\Tag\PDF\FormExtraUsageRights(),
                'UsageRightsMessage' => new \PHPExiftool\Driver\Tag\PDF\UsageRightsMessage(),
                'ModificationPermissions' => new \PHPExiftool\Driver\Tag\PDF\ModificationPermissions(),
                'SignatureUsageRights' => new \PHPExiftool\Driver\Tag\PDF\SignatureUsageRights(),
            );
        });
        $this['PICT'] = $this->share(function(){
            return array(
                'Nop' => new \PHPExiftool\Driver\Tag\PICT\Nop(),
                'ClipRgn' => new \PHPExiftool\Driver\Tag\PICT\ClipRgn(),
                'BkPat' => new \PHPExiftool\Driver\Tag\PICT\BkPat(),
                'TxFont' => new \PHPExiftool\Driver\Tag\PICT\TxFont(),
                'TxFace' => new \PHPExiftool\Driver\Tag\PICT\TxFace(),
                'TxMode' => new \PHPExiftool\Driver\Tag\PICT\TxMode(),
                'SpExtra' => new \PHPExiftool\Driver\Tag\PICT\SpExtra(),
                'PnSize' => new \PHPExiftool\Driver\Tag\PICT\PnSize(),
                'PnMode' => new \PHPExiftool\Driver\Tag\PICT\PnMode(),
                'PnPat' => new \PHPExiftool\Driver\Tag\PICT\PnPat(),
                'FillPat' => new \PHPExiftool\Driver\Tag\PICT\FillPat(),
                'OvSize' => new \PHPExiftool\Driver\Tag\PICT\OvSize(),
                'Origin' => new \PHPExiftool\Driver\Tag\PICT\Origin(),
                'TxSize' => new \PHPExiftool\Driver\Tag\PICT\TxSize(),
                'FgColor' => new \PHPExiftool\Driver\Tag\PICT\FgColor(),
                'BkColor' => new \PHPExiftool\Driver\Tag\PICT\BkColor(),
                'TxRatio' => new \PHPExiftool\Driver\Tag\PICT\TxRatio(),
                'VersionOp' => new \PHPExiftool\Driver\Tag\PICT\VersionOp(),
                'BkPixPat' => new \PHPExiftool\Driver\Tag\PICT\BkPixPat(),
                'PnPixPat' => new \PHPExiftool\Driver\Tag\PICT\PnPixPat(),
                'FillPixPat' => new \PHPExiftool\Driver\Tag\PICT\FillPixPat(),
                'PnLocHFrac' => new \PHPExiftool\Driver\Tag\PICT\PnLocHFrac(),
                'ChExtra' => new \PHPExiftool\Driver\Tag\PICT\ChExtra(),
                'RGBFgCol' => new \PHPExiftool\Driver\Tag\PICT\RGBFgCol(),
                'RGBBkCol' => new \PHPExiftool\Driver\Tag\PICT\RGBBkCol(),
                'HiliteMode' => new \PHPExiftool\Driver\Tag\PICT\HiliteMode(),
                'HiliteColor' => new \PHPExiftool\Driver\Tag\PICT\HiliteColor(),
                'DefHilite' => new \PHPExiftool\Driver\Tag\PICT\DefHilite(),
                'OpColor' => new \PHPExiftool\Driver\Tag\PICT\OpColor(),
                'Line' => new \PHPExiftool\Driver\Tag\PICT\Line(),
                'LineFrom' => new \PHPExiftool\Driver\Tag\PICT\LineFrom(),
                'ShortLine' => new \PHPExiftool\Driver\Tag\PICT\ShortLine(),
                'ShortLineFrom' => new \PHPExiftool\Driver\Tag\PICT\ShortLineFrom(),
                'LongText' => new \PHPExiftool\Driver\Tag\PICT\LongText(),
                'DHText' => new \PHPExiftool\Driver\Tag\PICT\DHText(),
                'DVText' => new \PHPExiftool\Driver\Tag\PICT\DVText(),
                'DHDVText' => new \PHPExiftool\Driver\Tag\PICT\DHDVText(),
                'FontName' => new \PHPExiftool\Driver\Tag\PICT\FontName(),
                'LineJustify' => new \PHPExiftool\Driver\Tag\PICT\LineJustify(),
                'GlyphState' => new \PHPExiftool\Driver\Tag\PICT\GlyphState(),
                'FrameRect' => new \PHPExiftool\Driver\Tag\PICT\FrameRect(),
                'PaintRect' => new \PHPExiftool\Driver\Tag\PICT\PaintRect(),
                'EraseRect' => new \PHPExiftool\Driver\Tag\PICT\EraseRect(),
                'InvertRect' => new \PHPExiftool\Driver\Tag\PICT\InvertRect(),
                'FillRect' => new \PHPExiftool\Driver\Tag\PICT\FillRect(),
                'FrameSameRect' => new \PHPExiftool\Driver\Tag\PICT\FrameSameRect(),
                'PaintSameRect' => new \PHPExiftool\Driver\Tag\PICT\PaintSameRect(),
                'EraseSameRect' => new \PHPExiftool\Driver\Tag\PICT\EraseSameRect(),
                'InvertSameRect' => new \PHPExiftool\Driver\Tag\PICT\InvertSameRect(),
                'FillSameRect' => new \PHPExiftool\Driver\Tag\PICT\FillSameRect(),
                'FrameRRect' => new \PHPExiftool\Driver\Tag\PICT\FrameRRect(),
                'PaintRRect' => new \PHPExiftool\Driver\Tag\PICT\PaintRRect(),
                'EraseRRect' => new \PHPExiftool\Driver\Tag\PICT\EraseRRect(),
                'InvertRRect' => new \PHPExiftool\Driver\Tag\PICT\InvertRRect(),
                'FillRRect' => new \PHPExiftool\Driver\Tag\PICT\FillRRect(),
                'FrameSameRRect' => new \PHPExiftool\Driver\Tag\PICT\FrameSameRRect(),
                'PaintSameRRect' => new \PHPExiftool\Driver\Tag\PICT\PaintSameRRect(),
                'EraseSameRRect' => new \PHPExiftool\Driver\Tag\PICT\EraseSameRRect(),
                'InvertSameRRect' => new \PHPExiftool\Driver\Tag\PICT\InvertSameRRect(),
                'FillSameRRect' => new \PHPExiftool\Driver\Tag\PICT\FillSameRRect(),
                'FrameOval' => new \PHPExiftool\Driver\Tag\PICT\FrameOval(),
                'PaintOval' => new \PHPExiftool\Driver\Tag\PICT\PaintOval(),
                'EraseOval' => new \PHPExiftool\Driver\Tag\PICT\EraseOval(),
                'InvertOval' => new \PHPExiftool\Driver\Tag\PICT\InvertOval(),
                'FillOval' => new \PHPExiftool\Driver\Tag\PICT\FillOval(),
                'FrameSameOval' => new \PHPExiftool\Driver\Tag\PICT\FrameSameOval(),
                'PaintSameOval' => new \PHPExiftool\Driver\Tag\PICT\PaintSameOval(),
                'EraseSameOval' => new \PHPExiftool\Driver\Tag\PICT\EraseSameOval(),
                'InvertSameOval' => new \PHPExiftool\Driver\Tag\PICT\InvertSameOval(),
                'FillSameOval' => new \PHPExiftool\Driver\Tag\PICT\FillSameOval(),
                'FrameArc' => new \PHPExiftool\Driver\Tag\PICT\FrameArc(),
                'PaintArc' => new \PHPExiftool\Driver\Tag\PICT\PaintArc(),
                'EraseArc' => new \PHPExiftool\Driver\Tag\PICT\EraseArc(),
                'InvertArc' => new \PHPExiftool\Driver\Tag\PICT\InvertArc(),
                'FillArc' => new \PHPExiftool\Driver\Tag\PICT\FillArc(),
                'FrameSameArc' => new \PHPExiftool\Driver\Tag\PICT\FrameSameArc(),
                'PaintSameArc' => new \PHPExiftool\Driver\Tag\PICT\PaintSameArc(),
                'EraseSameArc' => new \PHPExiftool\Driver\Tag\PICT\EraseSameArc(),
                'InvertSameArc' => new \PHPExiftool\Driver\Tag\PICT\InvertSameArc(),
                'FillSameArc' => new \PHPExiftool\Driver\Tag\PICT\FillSameArc(),
                'FramePoly' => new \PHPExiftool\Driver\Tag\PICT\FramePoly(),
                'PaintPoly' => new \PHPExiftool\Driver\Tag\PICT\PaintPoly(),
                'ErasePoly' => new \PHPExiftool\Driver\Tag\PICT\ErasePoly(),
                'InvertPoly' => new \PHPExiftool\Driver\Tag\PICT\InvertPoly(),
                'FillPoly' => new \PHPExiftool\Driver\Tag\PICT\FillPoly(),
                'FrameSamePoly' => new \PHPExiftool\Driver\Tag\PICT\FrameSamePoly(),
                'PaintSamePoly' => new \PHPExiftool\Driver\Tag\PICT\PaintSamePoly(),
                'EraseSamePoly' => new \PHPExiftool\Driver\Tag\PICT\EraseSamePoly(),
                'InvertSamePoly' => new \PHPExiftool\Driver\Tag\PICT\InvertSamePoly(),
                'FillSamePoly' => new \PHPExiftool\Driver\Tag\PICT\FillSamePoly(),
                'FrameRgn' => new \PHPExiftool\Driver\Tag\PICT\FrameRgn(),
                'PaintRgn' => new \PHPExiftool\Driver\Tag\PICT\PaintRgn(),
                'EraseRgn' => new \PHPExiftool\Driver\Tag\PICT\EraseRgn(),
                'InvertRgn' => new \PHPExiftool\Driver\Tag\PICT\InvertRgn(),
                'FillRgn' => new \PHPExiftool\Driver\Tag\PICT\FillRgn(),
                'FrameSameRgn' => new \PHPExiftool\Driver\Tag\PICT\FrameSameRgn(),
                'PaintSameRgn' => new \PHPExiftool\Driver\Tag\PICT\PaintSameRgn(),
                'EraseSameRgn' => new \PHPExiftool\Driver\Tag\PICT\EraseSameRgn(),
                'InvertSameRgn' => new \PHPExiftool\Driver\Tag\PICT\InvertSameRgn(),
                'FillSameRgn' => new \PHPExiftool\Driver\Tag\PICT\FillSameRgn(),
                'BitsRect' => new \PHPExiftool\Driver\Tag\PICT\BitsRect(),
                'BitsRgn' => new \PHPExiftool\Driver\Tag\PICT\BitsRgn(),
                'PackBitsRect' => new \PHPExiftool\Driver\Tag\PICT\PackBitsRect(),
                'PackBitsRgn' => new \PHPExiftool\Driver\Tag\PICT\PackBitsRgn(),
                'DirectBitsRect' => new \PHPExiftool\Driver\Tag\PICT\DirectBitsRect(),
                'DirectBitsRgn' => new \PHPExiftool\Driver\Tag\PICT\DirectBitsRgn(),
                'ShortComment' => new \PHPExiftool\Driver\Tag\PICT\ShortComment(),
                'OpEndPic' => new \PHPExiftool\Driver\Tag\PICT\OpEndPic(),
                'Version' => new \PHPExiftool\Driver\Tag\PICT\Version(),
                'HeaderOp' => new \PHPExiftool\Driver\Tag\PICT\HeaderOp(),
                'CompressedQuickTime' => new \PHPExiftool\Driver\Tag\PICT\CompressedQuickTime(),
                'UncompressedQuickTime' => new \PHPExiftool\Driver\Tag\PICT\UncompressedQuickTime(),
            );
        });
        $this['PNG'] = $this->share(function(){
            return array(
                'ImageWidth' => new \PHPExiftool\Driver\Tag\PNG\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\PNG\ImageHeight(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\PNG\BitDepth(),
                'ColorType' => new \PHPExiftool\Driver\Tag\PNG\ColorType(),
                'Compression' => new \PHPExiftool\Driver\Tag\PNG\Compression(),
                'Filter' => new \PHPExiftool\Driver\Tag\PNG\Filter(),
                'Interlace' => new \PHPExiftool\Driver\Tag\PNG\Interlace(),
                'Palette' => new \PHPExiftool\Driver\Tag\PNG\Palette(),
                'BackgroundColor' => new \PHPExiftool\Driver\Tag\PNG\BackgroundColor(),
                'DigitalSignature' => new \PHPExiftool\Driver\Tag\PNG\DigitalSignature(),
                'FractalParameters' => new \PHPExiftool\Driver\Tag\PNG\FractalParameters(),
                'Gamma' => new \PHPExiftool\Driver\Tag\PNG\Gamma(),
                'GIFGraphicControlExtension' => new \PHPExiftool\Driver\Tag\PNG\GIFGraphicControlExtension(),
                'GIFPlainTextExtension' => new \PHPExiftool\Driver\Tag\PNG\GIFPlainTextExtension(),
                'GIFApplicationExtension' => new \PHPExiftool\Driver\Tag\PNG\GIFApplicationExtension(),
                'PaletteHistogram' => new \PHPExiftool\Driver\Tag\PNG\PaletteHistogram(),
                'ImageOffset' => new \PHPExiftool\Driver\Tag\PNG\ImageOffset(),
                'PixelCalibration' => new \PHPExiftool\Driver\Tag\PNG\PixelCalibration(),
                'SignificantBits' => new \PHPExiftool\Driver\Tag\PNG\SignificantBits(),
                'SuggestedPalette' => new \PHPExiftool\Driver\Tag\PNG\SuggestedPalette(),
                'SRGBRendering' => new \PHPExiftool\Driver\Tag\PNG\SRGBRendering(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\PNG\ModifyDate(),
                'Transparency' => new \PHPExiftool\Driver\Tag\PNG\Transparency(),
                'PixelsPerUnitX' => new \PHPExiftool\Driver\Tag\PNG\PixelsPerUnitX(),
                'PixelsPerUnitY' => new \PHPExiftool\Driver\Tag\PNG\PixelsPerUnitY(),
                'PixelUnits' => new \PHPExiftool\Driver\Tag\PNG\PixelUnits(),
                'WhitePointX' => new \PHPExiftool\Driver\Tag\PNG\WhitePointX(),
                'WhitePointY' => new \PHPExiftool\Driver\Tag\PNG\WhitePointY(),
                'RedX' => new \PHPExiftool\Driver\Tag\PNG\RedX(),
                'RedY' => new \PHPExiftool\Driver\Tag\PNG\RedY(),
                'GreenX' => new \PHPExiftool\Driver\Tag\PNG\GreenX(),
                'GreenY' => new \PHPExiftool\Driver\Tag\PNG\GreenY(),
                'BlueX' => new \PHPExiftool\Driver\Tag\PNG\BlueX(),
                'BlueY' => new \PHPExiftool\Driver\Tag\PNG\BlueY(),
                'StereoMode' => new \PHPExiftool\Driver\Tag\PNG\StereoMode(),
                'SubjectUnits' => new \PHPExiftool\Driver\Tag\PNG\SubjectUnits(),
                'SubjectPixelWidth' => new \PHPExiftool\Driver\Tag\PNG\SubjectPixelWidth(),
                'SubjectPixelHeight' => new \PHPExiftool\Driver\Tag\PNG\SubjectPixelHeight(),
                'Artist' => new \PHPExiftool\Driver\Tag\PNG\Artist(),
                'Author' => new \PHPExiftool\Driver\Tag\PNG\Author(),
                'Comment' => new \PHPExiftool\Driver\Tag\PNG\Comment(),
                'Copyright' => new \PHPExiftool\Driver\Tag\PNG\Copyright(),
                'CreationTime' => new \PHPExiftool\Driver\Tag\PNG\CreationTime(),
                'Description' => new \PHPExiftool\Driver\Tag\PNG\Description(),
                'Disclaimer' => new \PHPExiftool\Driver\Tag\PNG\Disclaimer(),
                'Document' => new \PHPExiftool\Driver\Tag\PNG\Document(),
                'Label' => new \PHPExiftool\Driver\Tag\PNG\Label(),
                'Make' => new \PHPExiftool\Driver\Tag\PNG\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\PNG\Model(),
                'Software' => new \PHPExiftool\Driver\Tag\PNG\Software(),
                'Source' => new \PHPExiftool\Driver\Tag\PNG\Source(),
                'TimeStamp' => new \PHPExiftool\Driver\Tag\PNG\TimeStamp(),
                'Title' => new \PHPExiftool\Driver\Tag\PNG\Title(),
                'URL' => new \PHPExiftool\Driver\Tag\PNG\URL(),
                'PNGWarning' => new \PHPExiftool\Driver\Tag\PNG\PNGWarning(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\PNG\CreateDate(),
                'ModDate' => new \PHPExiftool\Driver\Tag\PNG\ModDate(),
                'VirtualImageWidth' => new \PHPExiftool\Driver\Tag\PNG\VirtualImageWidth(),
                'VirtualImageHeight' => new \PHPExiftool\Driver\Tag\PNG\VirtualImageHeight(),
                'VirtualPageUnits' => new \PHPExiftool\Driver\Tag\PNG\VirtualPageUnits(),
            );
        });
        $this['PSP'] = $this->share(function(){
            return array(
                'Title' => new \PHPExiftool\Driver\Tag\PSP\Title(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\PSP\CreateDate(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\PSP\ModifyDate(),
                'Artist' => new \PHPExiftool\Driver\Tag\PSP\Artist(),
                'Copyright' => new \PHPExiftool\Driver\Tag\PSP\Copyright(),
                'Description' => new \PHPExiftool\Driver\Tag\PSP\Description(),
                'CreatorAppID' => new \PHPExiftool\Driver\Tag\PSP\CreatorAppID(),
                'CreatorAppVersion' => new \PHPExiftool\Driver\Tag\PSP\CreatorAppVersion(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\PSP\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\PSP\ImageHeight(),
                'ImageResolution' => new \PHPExiftool\Driver\Tag\PSP\ImageResolution(),
                'ResolutionUnit' => new \PHPExiftool\Driver\Tag\PSP\ResolutionUnit(),
                'Compression' => new \PHPExiftool\Driver\Tag\PSP\Compression(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\PSP\BitsPerSample(),
                'Planes' => new \PHPExiftool\Driver\Tag\PSP\Planes(),
                'NumColors' => new \PHPExiftool\Driver\Tag\PSP\NumColors(),
                'FileVersion' => new \PHPExiftool\Driver\Tag\PSP\FileVersion(),
            );
        });
        $this['Leica'] = $this->share(function(){
            return array(
                'LensType' => new \PHPExiftool\Driver\Tag\Leica\LensType(),
                'Quality' => new \PHPExiftool\Driver\Tag\Leica\Quality(),
                'UserProfile' => new \PHPExiftool\Driver\Tag\Leica\UserProfile(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Leica\SerialNumber(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Leica\WhiteBalance(),
                'ExternalSensorBrightnessValue' => new \PHPExiftool\Driver\Tag\Leica\ExternalSensorBrightnessValue(),
                'MeasuredLV' => new \PHPExiftool\Driver\Tag\Leica\MeasuredLV(),
                'ApproximateFNumber' => new \PHPExiftool\Driver\Tag\Leica\ApproximateFNumber(),
                'CameraTemperature' => new \PHPExiftool\Driver\Tag\Leica\CameraTemperature(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\Leica\ColorTemperature(),
                'WBRedLevel' => new \PHPExiftool\Driver\Tag\Leica\WBRedLevel(),
                'WBGreenLevel' => new \PHPExiftool\Driver\Tag\Leica\WBGreenLevel(),
                'WBBlueLevel' => new \PHPExiftool\Driver\Tag\Leica\WBBlueLevel(),
                'UV-IRFilterCorrection' => new \PHPExiftool\Driver\Tag\Leica\UVIRFilterCorrection(),
                'CCDVersion' => new \PHPExiftool\Driver\Tag\Leica\CCDVersion(),
                'CCDBoardVersion' => new \PHPExiftool\Driver\Tag\Leica\CCDBoardVersion(),
                'ControllerBoardVersion' => new \PHPExiftool\Driver\Tag\Leica\ControllerBoardVersion(),
                'M16CVersion' => new \PHPExiftool\Driver\Tag\Leica\M16CVersion(),
                'ImageIDNumber' => new \PHPExiftool\Driver\Tag\Leica\ImageIDNumber(),
                'WB_RGBLevels' => new \PHPExiftool\Driver\Tag\Leica\WBRGBLevels(),
                'OriginalFileName' => new \PHPExiftool\Driver\Tag\Leica\OriginalFileName(),
                'OriginalDirectory' => new \PHPExiftool\Driver\Tag\Leica\OriginalDirectory(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\Leica\ExposureMode(),
                'FilmMode' => new \PHPExiftool\Driver\Tag\Leica\FilmMode(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Leica\PreviewImage(),
                'UnknownBlock' => new \PHPExiftool\Driver\Tag\Leica\UnknownBlock(),
                'FileIndex' => new \PHPExiftool\Driver\Tag\Leica\FileIndex(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Leica\Contrast(),
                'Sharpening' => new \PHPExiftool\Driver\Tag\Leica\Sharpening(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Leica\Saturation(),
                'JPEGQuality' => new \PHPExiftool\Driver\Tag\Leica\JPEGQuality(),
                'JPEGSize' => new \PHPExiftool\Driver\Tag\Leica\JPEGSize(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\Leica\FirmwareVersion(),
                'BaseISO' => new \PHPExiftool\Driver\Tag\Leica\BaseISO(),
                'SensorWidth' => new \PHPExiftool\Driver\Tag\Leica\SensorWidth(),
                'SensorHeight' => new \PHPExiftool\Driver\Tag\Leica\SensorHeight(),
                'SensorBitDepth' => new \PHPExiftool\Driver\Tag\Leica\SensorBitDepth(),
            );
        });
        $this['Panasonic'] = $this->share(function(){
            return array(
                'NumFacePositions' => new \PHPExiftool\Driver\Tag\Panasonic\NumFacePositions(),
                'Face1Position' => new \PHPExiftool\Driver\Tag\Panasonic\Face1Position(),
                'Face2Position' => new \PHPExiftool\Driver\Tag\Panasonic\Face2Position(),
                'Face3Position' => new \PHPExiftool\Driver\Tag\Panasonic\Face3Position(),
                'Face4Position' => new \PHPExiftool\Driver\Tag\Panasonic\Face4Position(),
                'Face5Position' => new \PHPExiftool\Driver\Tag\Panasonic\Face5Position(),
                'FacesRecognized' => new \PHPExiftool\Driver\Tag\Panasonic\FacesRecognized(),
                'RecognizedFace1Name' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace1Name(),
                'RecognizedFace1Position' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace1Position(),
                'RecognizedFace1Age' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace1Age(),
                'RecognizedFace2Name' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace2Name(),
                'RecognizedFace2Position' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace2Position(),
                'RecognizedFace2Age' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace2Age(),
                'RecognizedFace3Name' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace3Name(),
                'RecognizedFace3Position' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace3Position(),
                'RecognizedFace3Age' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFace3Age(),
                'ImageQuality' => new \PHPExiftool\Driver\Tag\Panasonic\ImageQuality(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\Panasonic\FirmwareVersion(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Panasonic\WhiteBalance(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Panasonic\FocusMode(),
                'AFAreaMode' => new \PHPExiftool\Driver\Tag\Panasonic\AFAreaMode(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\Panasonic\ImageStabilization(),
                'MacroMode' => new \PHPExiftool\Driver\Tag\Panasonic\MacroMode(),
                'ShootingMode' => new \PHPExiftool\Driver\Tag\Panasonic\ShootingMode(),
                'Audio' => new \PHPExiftool\Driver\Tag\Panasonic\Audio(),
                'DataDump' => new \PHPExiftool\Driver\Tag\Panasonic\DataDump(),
                'WhiteBalanceBias' => new \PHPExiftool\Driver\Tag\Panasonic\WhiteBalanceBias(),
                'FlashBias' => new \PHPExiftool\Driver\Tag\Panasonic\FlashBias(),
                'InternalSerialNumber' => new \PHPExiftool\Driver\Tag\Panasonic\InternalSerialNumber(),
                'PanasonicExifVersion' => new \PHPExiftool\Driver\Tag\Panasonic\PanasonicExifVersion(),
                'ColorEffect' => new \PHPExiftool\Driver\Tag\Panasonic\ColorEffect(),
                'TimeSincePowerOn' => new \PHPExiftool\Driver\Tag\Panasonic\TimeSincePowerOn(),
                'BurstMode' => new \PHPExiftool\Driver\Tag\Panasonic\BurstMode(),
                'SequenceNumber' => new \PHPExiftool\Driver\Tag\Panasonic\SequenceNumber(),
                'ContrastMode' => new \PHPExiftool\Driver\Tag\Panasonic\ContrastMode(),
                'NoiseReduction' => new \PHPExiftool\Driver\Tag\Panasonic\NoiseReduction(),
                'SelfTimer' => new \PHPExiftool\Driver\Tag\Panasonic\SelfTimer(),
                'Rotation' => new \PHPExiftool\Driver\Tag\Panasonic\Rotation(),
                'AFAssistLamp' => new \PHPExiftool\Driver\Tag\Panasonic\AFAssistLamp(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Panasonic\ColorMode(),
                'BabyAge' => new \PHPExiftool\Driver\Tag\Panasonic\BabyAge(),
                'OpticalZoomMode' => new \PHPExiftool\Driver\Tag\Panasonic\OpticalZoomMode(),
                'ConversionLens' => new \PHPExiftool\Driver\Tag\Panasonic\ConversionLens(),
                'TravelDay' => new \PHPExiftool\Driver\Tag\Panasonic\TravelDay(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Panasonic\Contrast(),
                'WorldTimeLocation' => new \PHPExiftool\Driver\Tag\Panasonic\WorldTimeLocation(),
                'TextStamp' => new \PHPExiftool\Driver\Tag\Panasonic\TextStamp(),
                'ProgramISO' => new \PHPExiftool\Driver\Tag\Panasonic\ProgramISO(),
                'AdvancedSceneType' => new \PHPExiftool\Driver\Tag\Panasonic\AdvancedSceneType(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Panasonic\FacesDetected(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Panasonic\Saturation(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Panasonic\Sharpness(),
                'FilmMode' => new \PHPExiftool\Driver\Tag\Panasonic\FilmMode(),
                'ColorTempKelvin' => new \PHPExiftool\Driver\Tag\Panasonic\ColorTempKelvin(),
                'WBShiftAB' => new \PHPExiftool\Driver\Tag\Panasonic\WBShiftAB(),
                'WBShiftGM' => new \PHPExiftool\Driver\Tag\Panasonic\WBShiftGM(),
                'PanasonicImageWidth' => new \PHPExiftool\Driver\Tag\Panasonic\PanasonicImageWidth(),
                'PanasonicImageHeight' => new \PHPExiftool\Driver\Tag\Panasonic\PanasonicImageHeight(),
                'AFPointPosition' => new \PHPExiftool\Driver\Tag\Panasonic\AFPointPosition(),
                'LensType' => new \PHPExiftool\Driver\Tag\Panasonic\LensType(),
                'LensSerialNumber' => new \PHPExiftool\Driver\Tag\Panasonic\LensSerialNumber(),
                'AccessoryType' => new \PHPExiftool\Driver\Tag\Panasonic\AccessoryType(),
                'Transform' => new \PHPExiftool\Driver\Tag\Panasonic\Transform(),
                'IntelligentExposure' => new \PHPExiftool\Driver\Tag\Panasonic\IntelligentExposure(),
                'FlashWarning' => new \PHPExiftool\Driver\Tag\Panasonic\FlashWarning(),
                'RecognizedFaceFlags' => new \PHPExiftool\Driver\Tag\Panasonic\RecognizedFaceFlags(),
                'Title' => new \PHPExiftool\Driver\Tag\Panasonic\Title(),
                'BabyName' => new \PHPExiftool\Driver\Tag\Panasonic\BabyName(),
                'Location' => new \PHPExiftool\Driver\Tag\Panasonic\Location(),
                'Country' => new \PHPExiftool\Driver\Tag\Panasonic\Country(),
                'State' => new \PHPExiftool\Driver\Tag\Panasonic\State(),
                'City' => new \PHPExiftool\Driver\Tag\Panasonic\City(),
                'Landmark' => new \PHPExiftool\Driver\Tag\Panasonic\Landmark(),
                'IntelligentResolution' => new \PHPExiftool\Driver\Tag\Panasonic\IntelligentResolution(),
                'IntelligentD-Range' => new \PHPExiftool\Driver\Tag\Panasonic\IntelligentDRange(),
                'ManometerPressure' => new \PHPExiftool\Driver\Tag\Panasonic\ManometerPressure(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Panasonic\MakerNoteVersion(),
                'SceneMode' => new \PHPExiftool\Driver\Tag\Panasonic\SceneMode(),
                'WBRedLevel' => new \PHPExiftool\Driver\Tag\Panasonic\WBRedLevel(),
                'WBGreenLevel' => new \PHPExiftool\Driver\Tag\Panasonic\WBGreenLevel(),
                'WBBlueLevel' => new \PHPExiftool\Driver\Tag\Panasonic\WBBlueLevel(),
                'FlashFired' => new \PHPExiftool\Driver\Tag\Panasonic\FlashFired(),
                'Model' => new \PHPExiftool\Driver\Tag\Panasonic\Model(),
                'ThumbnailWidth' => new \PHPExiftool\Driver\Tag\Panasonic\ThumbnailWidth(),
                'ThumbnailHeight' => new \PHPExiftool\Driver\Tag\Panasonic\ThumbnailHeight(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\Panasonic\ThumbnailImage(),
                'MakerNoteType' => new \PHPExiftool\Driver\Tag\Panasonic\MakerNoteType(),
                'Gain' => new \PHPExiftool\Driver\Tag\Panasonic\Gain(),
            );
        });
        $this['PanasonicRaw'] = $this->share(function(){
            return array(
                'DistortionParam02' => new \PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam02(),
                'DistortionParam04' => new \PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam04(),
                'DistortionScale' => new \PHPExiftool\Driver\Tag\PanasonicRaw\DistortionScale(),
                'DistortionCorrection' => new \PHPExiftool\Driver\Tag\PanasonicRaw\DistortionCorrection(),
                'DistortionParam08' => new \PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam08(),
                'DistortionParam09' => new \PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam09(),
                'DistortionParam11' => new \PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam11(),
                'DistortionN' => new \PHPExiftool\Driver\Tag\PanasonicRaw\DistortionN(),
            );
        });
        $this['Pentax'] = $this->share(function(){
            return array(
                'AEExposureTime' => new \PHPExiftool\Driver\Tag\Pentax\AEExposureTime(),
                'AEAperture' => new \PHPExiftool\Driver\Tag\Pentax\AEAperture(),
                'AE_ISO' => new \PHPExiftool\Driver\Tag\Pentax\AEISO(),
                'AEXv' => new \PHPExiftool\Driver\Tag\Pentax\AEXv(),
                'AEBXv' => new \PHPExiftool\Driver\Tag\Pentax\AEBXv(),
                'AEMinExposureTime' => new \PHPExiftool\Driver\Tag\Pentax\AEMinExposureTime(),
                'AEProgramMode' => new \PHPExiftool\Driver\Tag\Pentax\AEProgramMode(),
                'AEFlags' => new \PHPExiftool\Driver\Tag\Pentax\AEFlags(),
                'AEUnknown' => new \PHPExiftool\Driver\Tag\Pentax\AEUnknown(),
                'AEMaxAperture' => new \PHPExiftool\Driver\Tag\Pentax\AEMaxAperture(),
                'AEMaxAperture2' => new \PHPExiftool\Driver\Tag\Pentax\AEMaxAperture2(),
                'AEMinAperture' => new \PHPExiftool\Driver\Tag\Pentax\AEMinAperture(),
                'AEMeteringMode' => new \PHPExiftool\Driver\Tag\Pentax\AEMeteringMode(),
                'FlashExposureCompSet' => new \PHPExiftool\Driver\Tag\Pentax\FlashExposureCompSet(),
                'AFPointsUnknown1' => new \PHPExiftool\Driver\Tag\Pentax\AFPointsUnknown1(),
                'AFPointsUnknown2' => new \PHPExiftool\Driver\Tag\Pentax\AFPointsUnknown2(),
                'AFPredictor' => new \PHPExiftool\Driver\Tag\Pentax\AFPredictor(),
                'AFDefocus' => new \PHPExiftool\Driver\Tag\Pentax\AFDefocus(),
                'AFIntegrationTime' => new \PHPExiftool\Driver\Tag\Pentax\AFIntegrationTime(),
                'AFPointsInFocus' => new \PHPExiftool\Driver\Tag\Pentax\AFPointsInFocus(),
                'WhiteBalanceAutoAdjustment' => new \PHPExiftool\Driver\Tag\Pentax\WhiteBalanceAutoAdjustment(),
                'TungstenAWB' => new \PHPExiftool\Driver\Tag\Pentax\TungstenAWB(),
                'PowerSource' => new \PHPExiftool\Driver\Tag\Pentax\PowerSource(),
                'BodyBatteryState' => new \PHPExiftool\Driver\Tag\Pentax\BodyBatteryState(),
                'GripBatteryState' => new \PHPExiftool\Driver\Tag\Pentax\GripBatteryState(),
                'BodyBatteryADNoLoad' => new \PHPExiftool\Driver\Tag\Pentax\BodyBatteryADNoLoad(),
                'BodyBatteryVoltage1' => new \PHPExiftool\Driver\Tag\Pentax\BodyBatteryVoltage1(),
                'BodyBatteryADLoad' => new \PHPExiftool\Driver\Tag\Pentax\BodyBatteryADLoad(),
                'GripBatteryADNoLoad' => new \PHPExiftool\Driver\Tag\Pentax\GripBatteryADNoLoad(),
                'BodyBatteryVoltage2' => new \PHPExiftool\Driver\Tag\Pentax\BodyBatteryVoltage2(),
                'GripBatteryADLoad' => new \PHPExiftool\Driver\Tag\Pentax\GripBatteryADLoad(),
                'BodyBatteryVoltage3' => new \PHPExiftool\Driver\Tag\Pentax\BodyBatteryVoltage3(),
                'BodyBatteryVoltage4' => new \PHPExiftool\Driver\Tag\Pentax\BodyBatteryVoltage4(),
                'PentaxModelID' => new \PHPExiftool\Driver\Tag\Pentax\PentaxModelID(),
                'ManufactureDate' => new \PHPExiftool\Driver\Tag\Pentax\ManufactureDate(),
                'ProductionCode' => new \PHPExiftool\Driver\Tag\Pentax\ProductionCode(),
                'InternalSerialNumber' => new \PHPExiftool\Driver\Tag\Pentax\InternalSerialNumber(),
                'PictureMode2' => new \PHPExiftool\Driver\Tag\Pentax\PictureMode2(),
                'ProgramLine' => new \PHPExiftool\Driver\Tag\Pentax\ProgramLine(),
                'EVSteps' => new \PHPExiftool\Driver\Tag\Pentax\EVSteps(),
                'E-DialInProgram' => new \PHPExiftool\Driver\Tag\Pentax\EDialInProgram(),
                'ApertureRingUse' => new \PHPExiftool\Driver\Tag\Pentax\ApertureRingUse(),
                'FlashOptions' => new \PHPExiftool\Driver\Tag\Pentax\FlashOptions(),
                'MeteringMode2' => new \PHPExiftool\Driver\Tag\Pentax\MeteringMode2(),
                'AFPointMode' => new \PHPExiftool\Driver\Tag\Pentax\AFPointMode(),
                'FocusMode2' => new \PHPExiftool\Driver\Tag\Pentax\FocusMode2(),
                'AFPointSelected2' => new \PHPExiftool\Driver\Tag\Pentax\AFPointSelected2(),
                'ISOFloor' => new \PHPExiftool\Driver\Tag\Pentax\ISOFloor(),
                'DriveMode2' => new \PHPExiftool\Driver\Tag\Pentax\DriveMode2(),
                'ExposureBracketStepSize' => new \PHPExiftool\Driver\Tag\Pentax\ExposureBracketStepSize(),
                'BracketShotNumber' => new \PHPExiftool\Driver\Tag\Pentax\BracketShotNumber(),
                'WhiteBalanceSet' => new \PHPExiftool\Driver\Tag\Pentax\WhiteBalanceSet(),
                'MultipleExposureSet' => new \PHPExiftool\Driver\Tag\Pentax\MultipleExposureSet(),
                'RawAndJpgRecording' => new \PHPExiftool\Driver\Tag\Pentax\RawAndJpgRecording(),
                'JpgRecordedPixels' => new \PHPExiftool\Driver\Tag\Pentax\JpgRecordedPixels(),
                'LinkAEToAFPoint' => new \PHPExiftool\Driver\Tag\Pentax\LinkAEToAFPoint(),
                'SensitivitySteps' => new \PHPExiftool\Driver\Tag\Pentax\SensitivitySteps(),
                'ISOAuto' => new \PHPExiftool\Driver\Tag\Pentax\ISOAuto(),
                'FlashOptions2' => new \PHPExiftool\Driver\Tag\Pentax\FlashOptions2(),
                'MeteringMode3' => new \PHPExiftool\Driver\Tag\Pentax\MeteringMode3(),
                'SRActive' => new \PHPExiftool\Driver\Tag\Pentax\SRActive(),
                'Rotation' => new \PHPExiftool\Driver\Tag\Pentax\Rotation(),
                'ISOSetting' => new \PHPExiftool\Driver\Tag\Pentax\ISOSetting(),
                'TvExposureTimeSetting' => new \PHPExiftool\Driver\Tag\Pentax\TvExposureTimeSetting(),
                'AvApertureSetting' => new \PHPExiftool\Driver\Tag\Pentax\AvApertureSetting(),
                'SvISOSetting' => new \PHPExiftool\Driver\Tag\Pentax\SvISOSetting(),
                'BaseExposureCompensation' => new \PHPExiftool\Driver\Tag\Pentax\BaseExposureCompensation(),
                'WBShiftAB' => new \PHPExiftool\Driver\Tag\Pentax\WBShiftAB(),
                'WBShiftGM' => new \PHPExiftool\Driver\Tag\Pentax\WBShiftGM(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Pentax\FacesDetected(),
                'FacePosition' => new \PHPExiftool\Driver\Tag\Pentax\FacePosition(),
                'Face1Position' => new \PHPExiftool\Driver\Tag\Pentax\Face1Position(),
                'Face2Position' => new \PHPExiftool\Driver\Tag\Pentax\Face2Position(),
                'Face3Position' => new \PHPExiftool\Driver\Tag\Pentax\Face3Position(),
                'Face4Position' => new \PHPExiftool\Driver\Tag\Pentax\Face4Position(),
                'Face5Position' => new \PHPExiftool\Driver\Tag\Pentax\Face5Position(),
                'Face6Position' => new \PHPExiftool\Driver\Tag\Pentax\Face6Position(),
                'Face7Position' => new \PHPExiftool\Driver\Tag\Pentax\Face7Position(),
                'Face8Position' => new \PHPExiftool\Driver\Tag\Pentax\Face8Position(),
                'Face9Position' => new \PHPExiftool\Driver\Tag\Pentax\Face9Position(),
                'Face10Position' => new \PHPExiftool\Driver\Tag\Pentax\Face10Position(),
                'Face11Position' => new \PHPExiftool\Driver\Tag\Pentax\Face11Position(),
                'Face12Position' => new \PHPExiftool\Driver\Tag\Pentax\Face12Position(),
                'Face13Position' => new \PHPExiftool\Driver\Tag\Pentax\Face13Position(),
                'Face14Position' => new \PHPExiftool\Driver\Tag\Pentax\Face14Position(),
                'Face15Position' => new \PHPExiftool\Driver\Tag\Pentax\Face15Position(),
                'Face16Position' => new \PHPExiftool\Driver\Tag\Pentax\Face16Position(),
                'Face17Position' => new \PHPExiftool\Driver\Tag\Pentax\Face17Position(),
                'Face18Position' => new \PHPExiftool\Driver\Tag\Pentax\Face18Position(),
                'Face19Position' => new \PHPExiftool\Driver\Tag\Pentax\Face19Position(),
                'Face20Position' => new \PHPExiftool\Driver\Tag\Pentax\Face20Position(),
                'Face21Position' => new \PHPExiftool\Driver\Tag\Pentax\Face21Position(),
                'Face22Position' => new \PHPExiftool\Driver\Tag\Pentax\Face22Position(),
                'Face23Position' => new \PHPExiftool\Driver\Tag\Pentax\Face23Position(),
                'Face24Position' => new \PHPExiftool\Driver\Tag\Pentax\Face24Position(),
                'Face25Position' => new \PHPExiftool\Driver\Tag\Pentax\Face25Position(),
                'Face26Position' => new \PHPExiftool\Driver\Tag\Pentax\Face26Position(),
                'Face27Position' => new \PHPExiftool\Driver\Tag\Pentax\Face27Position(),
                'Face28Position' => new \PHPExiftool\Driver\Tag\Pentax\Face28Position(),
                'Face29Position' => new \PHPExiftool\Driver\Tag\Pentax\Face29Position(),
                'Face30Position' => new \PHPExiftool\Driver\Tag\Pentax\Face30Position(),
                'Face31Position' => new \PHPExiftool\Driver\Tag\Pentax\Face31Position(),
                'Face32Position' => new \PHPExiftool\Driver\Tag\Pentax\Face32Position(),
                'Face1Size' => new \PHPExiftool\Driver\Tag\Pentax\Face1Size(),
                'Face2Size' => new \PHPExiftool\Driver\Tag\Pentax\Face2Size(),
                'Face3Size' => new \PHPExiftool\Driver\Tag\Pentax\Face3Size(),
                'Face4Size' => new \PHPExiftool\Driver\Tag\Pentax\Face4Size(),
                'Face5Size' => new \PHPExiftool\Driver\Tag\Pentax\Face5Size(),
                'Face6Size' => new \PHPExiftool\Driver\Tag\Pentax\Face6Size(),
                'Face7Size' => new \PHPExiftool\Driver\Tag\Pentax\Face7Size(),
                'Face8Size' => new \PHPExiftool\Driver\Tag\Pentax\Face8Size(),
                'Face9Size' => new \PHPExiftool\Driver\Tag\Pentax\Face9Size(),
                'Face10Size' => new \PHPExiftool\Driver\Tag\Pentax\Face10Size(),
                'Face11Size' => new \PHPExiftool\Driver\Tag\Pentax\Face11Size(),
                'Face12Size' => new \PHPExiftool\Driver\Tag\Pentax\Face12Size(),
                'Face13Size' => new \PHPExiftool\Driver\Tag\Pentax\Face13Size(),
                'Face14Size' => new \PHPExiftool\Driver\Tag\Pentax\Face14Size(),
                'Face15Size' => new \PHPExiftool\Driver\Tag\Pentax\Face15Size(),
                'Face16Size' => new \PHPExiftool\Driver\Tag\Pentax\Face16Size(),
                'Face17Size' => new \PHPExiftool\Driver\Tag\Pentax\Face17Size(),
                'Face18Size' => new \PHPExiftool\Driver\Tag\Pentax\Face18Size(),
                'Face19Size' => new \PHPExiftool\Driver\Tag\Pentax\Face19Size(),
                'Face20Size' => new \PHPExiftool\Driver\Tag\Pentax\Face20Size(),
                'Face21Size' => new \PHPExiftool\Driver\Tag\Pentax\Face21Size(),
                'Face22Size' => new \PHPExiftool\Driver\Tag\Pentax\Face22Size(),
                'Face23Size' => new \PHPExiftool\Driver\Tag\Pentax\Face23Size(),
                'Face24Size' => new \PHPExiftool\Driver\Tag\Pentax\Face24Size(),
                'Face25Size' => new \PHPExiftool\Driver\Tag\Pentax\Face25Size(),
                'Face26Size' => new \PHPExiftool\Driver\Tag\Pentax\Face26Size(),
                'Face27Size' => new \PHPExiftool\Driver\Tag\Pentax\Face27Size(),
                'Face28Size' => new \PHPExiftool\Driver\Tag\Pentax\Face28Size(),
                'Face29Size' => new \PHPExiftool\Driver\Tag\Pentax\Face29Size(),
                'Face30Size' => new \PHPExiftool\Driver\Tag\Pentax\Face30Size(),
                'Face31Size' => new \PHPExiftool\Driver\Tag\Pentax\Face31Size(),
                'Face32Size' => new \PHPExiftool\Driver\Tag\Pentax\Face32Size(),
                'SourceDirectoryIndex' => new \PHPExiftool\Driver\Tag\Pentax\SourceDirectoryIndex(),
                'SourceFileIndex' => new \PHPExiftool\Driver\Tag\Pentax\SourceFileIndex(),
                'DigitalFilter01' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter01(),
                'DigitalFilter02' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter02(),
                'DigitalFilter03' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter03(),
                'DigitalFilter04' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter04(),
                'DigitalFilter05' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter05(),
                'DigitalFilter06' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter06(),
                'DigitalFilter07' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter07(),
                'DigitalFilter08' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter08(),
                'DigitalFilter09' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter09(),
                'DigitalFilter10' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter10(),
                'DigitalFilter11' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter11(),
                'DigitalFilter12' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter12(),
                'DigitalFilter13' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter13(),
                'DigitalFilter14' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter14(),
                'DigitalFilter15' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter15(),
                'DigitalFilter16' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter16(),
                'DigitalFilter17' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter17(),
                'DigitalFilter18' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter18(),
                'DigitalFilter19' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter19(),
                'DigitalFilter20' => new \PHPExiftool\Driver\Tag\Pentax\DigitalFilter20(),
                'FlashStatus' => new \PHPExiftool\Driver\Tag\Pentax\FlashStatus(),
                'InternalFlashMode' => new \PHPExiftool\Driver\Tag\Pentax\InternalFlashMode(),
                'ExternalFlashMode' => new \PHPExiftool\Driver\Tag\Pentax\ExternalFlashMode(),
                'InternalFlashStrength' => new \PHPExiftool\Driver\Tag\Pentax\InternalFlashStrength(),
                'TTL_DA_AUp' => new \PHPExiftool\Driver\Tag\Pentax\TTLDAAUp(),
                'TTL_DA_ADown' => new \PHPExiftool\Driver\Tag\Pentax\TTLDAADown(),
                'TTL_DA_BUp' => new \PHPExiftool\Driver\Tag\Pentax\TTLDABUp(),
                'TTL_DA_BDown' => new \PHPExiftool\Driver\Tag\Pentax\TTLDABDown(),
                'ExternalFlashGuideNumber' => new \PHPExiftool\Driver\Tag\Pentax\ExternalFlashGuideNumber(),
                'ExternalFlashExposureComp' => new \PHPExiftool\Driver\Tag\Pentax\ExternalFlashExposureComp(),
                'ExternalFlashBounce' => new \PHPExiftool\Driver\Tag\Pentax\ExternalFlashBounce(),
                'Model' => new \PHPExiftool\Driver\Tag\Pentax\Model(),
                'Make' => new \PHPExiftool\Driver\Tag\Pentax\Make(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Pentax\FNumber(),
                'DateTime1' => new \PHPExiftool\Driver\Tag\Pentax\DateTime1(),
                'DateTime2' => new \PHPExiftool\Driver\Tag\Pentax\DateTime2(),
                'ThumbnailWidth' => new \PHPExiftool\Driver\Tag\Pentax\ThumbnailWidth(),
                'ThumbnailHeight' => new \PHPExiftool\Driver\Tag\Pentax\ThumbnailHeight(),
                'ThumbnailLength' => new \PHPExiftool\Driver\Tag\Pentax\ThumbnailLength(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\Pentax\ThumbnailImage(),
                'DistortionCorrection' => new \PHPExiftool\Driver\Tag\Pentax\DistortionCorrection(),
                'ChromaticAberrationCorrection' => new \PHPExiftool\Driver\Tag\Pentax\ChromaticAberrationCorrection(),
                'AutoAperture' => new \PHPExiftool\Driver\Tag\Pentax\AutoAperture(),
                'MinAperture' => new \PHPExiftool\Driver\Tag\Pentax\MinAperture(),
                'LensFStops' => new \PHPExiftool\Driver\Tag\Pentax\LensFStops(),
                'LensKind' => new \PHPExiftool\Driver\Tag\Pentax\LensKind(),
                'LC1' => new \PHPExiftool\Driver\Tag\Pentax\LC1(),
                'LC2' => new \PHPExiftool\Driver\Tag\Pentax\LC2(),
                'LC3' => new \PHPExiftool\Driver\Tag\Pentax\LC3(),
                'LC4' => new \PHPExiftool\Driver\Tag\Pentax\LC4(),
                'LC5' => new \PHPExiftool\Driver\Tag\Pentax\LC5(),
                'LC6' => new \PHPExiftool\Driver\Tag\Pentax\LC6(),
                'LC7' => new \PHPExiftool\Driver\Tag\Pentax\LC7(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Pentax\FocalLength(),
                'NominalMaxAperture' => new \PHPExiftool\Driver\Tag\Pentax\NominalMaxAperture(),
                'NominalMinAperture' => new \PHPExiftool\Driver\Tag\Pentax\NominalMinAperture(),
                'LC10' => new \PHPExiftool\Driver\Tag\Pentax\LC10(),
                'LC11' => new \PHPExiftool\Driver\Tag\Pentax\LC11(),
                'LC12' => new \PHPExiftool\Driver\Tag\Pentax\LC12(),
                'MaxAperture' => new \PHPExiftool\Driver\Tag\Pentax\MaxAperture(),
                'LC14' => new \PHPExiftool\Driver\Tag\Pentax\LC14(),
                'LC15' => new \PHPExiftool\Driver\Tag\Pentax\LC15(),
                'LensType' => new \PHPExiftool\Driver\Tag\Pentax\LensType(),
                'LensModel' => new \PHPExiftool\Driver\Tag\Pentax\LensModel(),
                'LensInfo' => new \PHPExiftool\Driver\Tag\Pentax\LensInfo(),
                'LevelOrientation' => new \PHPExiftool\Driver\Tag\Pentax\LevelOrientation(),
                'CompositionAdjust' => new \PHPExiftool\Driver\Tag\Pentax\CompositionAdjust(),
                'RollAngle' => new \PHPExiftool\Driver\Tag\Pentax\RollAngle(),
                'PitchAngle' => new \PHPExiftool\Driver\Tag\Pentax\PitchAngle(),
                'CompositionAdjustX' => new \PHPExiftool\Driver\Tag\Pentax\CompositionAdjustX(),
                'CompositionAdjustY' => new \PHPExiftool\Driver\Tag\Pentax\CompositionAdjustY(),
                'CompositionAdjustRotation' => new \PHPExiftool\Driver\Tag\Pentax\CompositionAdjustRotation(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Pentax\ExposureTime(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Pentax\ExposureCompensation(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Pentax\WhiteBalance(),
                'ISO' => new \PHPExiftool\Driver\Tag\Pentax\ISO(),
                'PentaxVersion' => new \PHPExiftool\Driver\Tag\Pentax\PentaxVersion(),
                'PentaxModelType' => new \PHPExiftool\Driver\Tag\Pentax\PentaxModelType(),
                'PreviewImageSize' => new \PHPExiftool\Driver\Tag\Pentax\PreviewImageSize(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Pentax\PreviewImageLength(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Pentax\PreviewImageStart(),
                'Date' => new \PHPExiftool\Driver\Tag\Pentax\Date(),
                'Time' => new \PHPExiftool\Driver\Tag\Pentax\Time(),
                'Quality' => new \PHPExiftool\Driver\Tag\Pentax\Quality(),
                'PentaxImageSize' => new \PHPExiftool\Driver\Tag\Pentax\PentaxImageSize(),
                'PictureMode' => new \PHPExiftool\Driver\Tag\Pentax\PictureMode(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Pentax\FlashMode(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Pentax\FocusMode(),
                'AFPointSelected' => new \PHPExiftool\Driver\Tag\Pentax\AFPointSelected(),
                'FocusPosition' => new \PHPExiftool\Driver\Tag\Pentax\FocusPosition(),
                'LightReading' => new \PHPExiftool\Driver\Tag\Pentax\LightReading(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Pentax\MeteringMode(),
                'AutoBracketing' => new \PHPExiftool\Driver\Tag\Pentax\AutoBracketing(),
                'WhiteBalanceMode' => new \PHPExiftool\Driver\Tag\Pentax\WhiteBalanceMode(),
                'BlueBalance' => new \PHPExiftool\Driver\Tag\Pentax\BlueBalance(),
                'RedBalance' => new \PHPExiftool\Driver\Tag\Pentax\RedBalance(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Pentax\DigitalZoom(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Pentax\Saturation(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Pentax\Contrast(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Pentax\Sharpness(),
                'WorldTimeLocation' => new \PHPExiftool\Driver\Tag\Pentax\WorldTimeLocation(),
                'HometownCity' => new \PHPExiftool\Driver\Tag\Pentax\HometownCity(),
                'DestinationCity' => new \PHPExiftool\Driver\Tag\Pentax\DestinationCity(),
                'HometownDST' => new \PHPExiftool\Driver\Tag\Pentax\HometownDST(),
                'DestinationDST' => new \PHPExiftool\Driver\Tag\Pentax\DestinationDST(),
                'DSPFirmwareVersion' => new \PHPExiftool\Driver\Tag\Pentax\DSPFirmwareVersion(),
                'CPUFirmwareVersion' => new \PHPExiftool\Driver\Tag\Pentax\CPUFirmwareVersion(),
                'FrameNumber' => new \PHPExiftool\Driver\Tag\Pentax\FrameNumber(),
                'EffectiveLV' => new \PHPExiftool\Driver\Tag\Pentax\EffectiveLV(),
                'ImageEditing' => new \PHPExiftool\Driver\Tag\Pentax\ImageEditing(),
                'DriveMode' => new \PHPExiftool\Driver\Tag\Pentax\DriveMode(),
                'SensorSize' => new \PHPExiftool\Driver\Tag\Pentax\SensorSize(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Pentax\ColorSpace(),
                'ImageAreaOffset' => new \PHPExiftool\Driver\Tag\Pentax\ImageAreaOffset(),
                'RawImageSize' => new \PHPExiftool\Driver\Tag\Pentax\RawImageSize(),
                'PreviewImageBorders' => new \PHPExiftool\Driver\Tag\Pentax\PreviewImageBorders(),
                'SensitivityAdjust' => new \PHPExiftool\Driver\Tag\Pentax\SensitivityAdjust(),
                'ImageEditCount' => new \PHPExiftool\Driver\Tag\Pentax\ImageEditCount(),
                'CameraTemperature' => new \PHPExiftool\Driver\Tag\Pentax\CameraTemperature(),
                'AELock' => new \PHPExiftool\Driver\Tag\Pentax\AELock(),
                'NoiseReduction' => new \PHPExiftool\Driver\Tag\Pentax\NoiseReduction(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\Pentax\FlashExposureComp(),
                'ImageTone' => new \PHPExiftool\Driver\Tag\Pentax\ImageTone(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\Pentax\ColorTemperature(),
                'ShutterCount' => new \PHPExiftool\Driver\Tag\Pentax\ShutterCount(),
                'Hue' => new \PHPExiftool\Driver\Tag\Pentax\Hue(),
                'DynamicRangeExpansion' => new \PHPExiftool\Driver\Tag\Pentax\DynamicRangeExpansion(),
                'HighLowKeyAdj' => new \PHPExiftool\Driver\Tag\Pentax\HighLowKeyAdj(),
                'ContrastHighlight' => new \PHPExiftool\Driver\Tag\Pentax\ContrastHighlight(),
                'ContrastShadow' => new \PHPExiftool\Driver\Tag\Pentax\ContrastShadow(),
                'ContrastHighlightShadowAdj' => new \PHPExiftool\Driver\Tag\Pentax\ContrastHighlightShadowAdj(),
                'FineSharpness' => new \PHPExiftool\Driver\Tag\Pentax\FineSharpness(),
                'HighISONoiseReduction' => new \PHPExiftool\Driver\Tag\Pentax\HighISONoiseReduction(),
                'AFAdjustment' => new \PHPExiftool\Driver\Tag\Pentax\AFAdjustment(),
                'MonochromeFilterEffect' => new \PHPExiftool\Driver\Tag\Pentax\MonochromeFilterEffect(),
                'MonochromeToning' => new \PHPExiftool\Driver\Tag\Pentax\MonochromeToning(),
                'FaceDetect' => new \PHPExiftool\Driver\Tag\Pentax\FaceDetect(),
                'FaceDetectFrameSize' => new \PHPExiftool\Driver\Tag\Pentax\FaceDetectFrameSize(),
                'ShadowCompensation' => new \PHPExiftool\Driver\Tag\Pentax\ShadowCompensation(),
                'ISOAutoParameters' => new \PHPExiftool\Driver\Tag\Pentax\ISOAutoParameters(),
                'CrossProcess' => new \PHPExiftool\Driver\Tag\Pentax\CrossProcess(),
                'BleachBypassToning' => new \PHPExiftool\Driver\Tag\Pentax\BleachBypassToning(),
                'AspectRatio' => new \PHPExiftool\Driver\Tag\Pentax\AspectRatio(),
                'BlurControl' => new \PHPExiftool\Driver\Tag\Pentax\BlurControl(),
                'NeutralDensityFilter' => new \PHPExiftool\Driver\Tag\Pentax\NeutralDensityFilter(),
                'BlackPoint' => new \PHPExiftool\Driver\Tag\Pentax\BlackPoint(),
                'WhitePoint' => new \PHPExiftool\Driver\Tag\Pentax\WhitePoint(),
                'ColorMatrixA' => new \PHPExiftool\Driver\Tag\Pentax\ColorMatrixA(),
                'ColorMatrixB' => new \PHPExiftool\Driver\Tag\Pentax\ColorMatrixB(),
                'AEMeteringSegments' => new \PHPExiftool\Driver\Tag\Pentax\AEMeteringSegments(),
                'FlashMeteringSegments' => new \PHPExiftool\Driver\Tag\Pentax\FlashMeteringSegments(),
                'SlaveFlashMeteringSegments' => new \PHPExiftool\Driver\Tag\Pentax\SlaveFlashMeteringSegments(),
                'WB_RGGBLevelsDaylight' => new \PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsDaylight(),
                'WB_RGGBLevelsShade' => new \PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsShade(),
                'WB_RGGBLevelsCloudy' => new \PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsCloudy(),
                'WB_RGGBLevelsTungsten' => new \PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsTungsten(),
                'WB_RGGBLevelsFluorescentD' => new \PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsFluorescentD(),
                'WB_RGGBLevelsFluorescentN' => new \PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsFluorescentN(),
                'WB_RGGBLevelsFluorescentW' => new \PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsFluorescentW(),
                'WB_RGGBLevelsFlash' => new \PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsFlash(),
                'SaturationInfo' => new \PHPExiftool\Driver\Tag\Pentax\SaturationInfo(),
                'HuffmanTable' => new \PHPExiftool\Driver\Tag\Pentax\HuffmanTable(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Pentax\SerialNumber(),
                'Artist' => new \PHPExiftool\Driver\Tag\Pentax\Artist(),
                'Copyright' => new \PHPExiftool\Driver\Tag\Pentax\Copyright(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\Pentax\FirmwareVersion(),
                'ContrastDetectAFArea' => new \PHPExiftool\Driver\Tag\Pentax\ContrastDetectAFArea(),
                'CrossProcessParams' => new \PHPExiftool\Driver\Tag\Pentax\CrossProcessParams(),
                'DataDump' => new \PHPExiftool\Driver\Tag\Pentax\DataDump(),
                'ToneCurve' => new \PHPExiftool\Driver\Tag\Pentax\ToneCurve(),
                'ToneCurves' => new \PHPExiftool\Driver\Tag\Pentax\ToneCurves(),
                'AudioCodecID' => new \PHPExiftool\Driver\Tag\Pentax\AudioCodecID(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Pentax\PreviewImage(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Pentax\MakerNoteVersion(),
                'SRResult' => new \PHPExiftool\Driver\Tag\Pentax\SRResult(),
                'ShakeReduction' => new \PHPExiftool\Driver\Tag\Pentax\ShakeReduction(),
                'SRHalfPressTime' => new \PHPExiftool\Driver\Tag\Pentax\SRHalfPressTime(),
                'SRFocalLength' => new \PHPExiftool\Driver\Tag\Pentax\SRFocalLength(),
                'CameraOrientation' => new \PHPExiftool\Driver\Tag\Pentax\CameraOrientation(),
                'CameraTemperature2' => new \PHPExiftool\Driver\Tag\Pentax\CameraTemperature2(),
                'CameraTemperature3' => new \PHPExiftool\Driver\Tag\Pentax\CameraTemperature3(),
                'CameraTemperature4' => new \PHPExiftool\Driver\Tag\Pentax\CameraTemperature4(),
                'CameraTemperature5' => new \PHPExiftool\Driver\Tag\Pentax\CameraTemperature5(),
                'RecordingMode' => new \PHPExiftool\Driver\Tag\Pentax\RecordingMode(),
                'ColorFilter' => new \PHPExiftool\Driver\Tag\Pentax\ColorFilter(),
                'HometownCityCode' => new \PHPExiftool\Driver\Tag\Pentax\HometownCityCode(),
                'DestinationCityCode' => new \PHPExiftool\Driver\Tag\Pentax\DestinationCityCode(),
            );
        });
        $this['PhotoCD'] = $this->share(function(){
            return array(
                'SpecificationVersion' => new \PHPExiftool\Driver\Tag\PhotoCD\SpecificationVersion(),
                'AuthoringSoftwareRelease' => new \PHPExiftool\Driver\Tag\PhotoCD\AuthoringSoftwareRelease(),
                'ImageMagnificationDescriptor' => new \PHPExiftool\Driver\Tag\PhotoCD\ImageMagnificationDescriptor(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\PhotoCD\CreateDate(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\PhotoCD\ModifyDate(),
                'ImageMedium' => new \PHPExiftool\Driver\Tag\PhotoCD\ImageMedium(),
                'ProductType' => new \PHPExiftool\Driver\Tag\PhotoCD\ProductType(),
                'ScannerVendorID' => new \PHPExiftool\Driver\Tag\PhotoCD\ScannerVendorID(),
                'ScannerProductID' => new \PHPExiftool\Driver\Tag\PhotoCD\ScannerProductID(),
                'ScannerFirmwareVersion' => new \PHPExiftool\Driver\Tag\PhotoCD\ScannerFirmwareVersion(),
                'ScannerFirmwareDate' => new \PHPExiftool\Driver\Tag\PhotoCD\ScannerFirmwareDate(),
                'ScannerSerialNumber' => new \PHPExiftool\Driver\Tag\PhotoCD\ScannerSerialNumber(),
                'ScannerPixelSize' => new \PHPExiftool\Driver\Tag\PhotoCD\ScannerPixelSize(),
                'ImageWorkstationMake' => new \PHPExiftool\Driver\Tag\PhotoCD\ImageWorkstationMake(),
                'CharacterSet' => new \PHPExiftool\Driver\Tag\PhotoCD\CharacterSet(),
                'CharacterEscapeSequence' => new \PHPExiftool\Driver\Tag\PhotoCD\CharacterEscapeSequence(),
                'PhotoFinisherName' => new \PHPExiftool\Driver\Tag\PhotoCD\PhotoFinisherName(),
                'HasSBA' => new \PHPExiftool\Driver\Tag\PhotoCD\HasSBA(),
                'SceneBalanceAlgorithmRevision' => new \PHPExiftool\Driver\Tag\PhotoCD\SceneBalanceAlgorithmRevision(),
                'SceneBalanceAlgorithmCommand' => new \PHPExiftool\Driver\Tag\PhotoCD\SceneBalanceAlgorithmCommand(),
                'SceneBalanceAlgorithmFilmID' => new \PHPExiftool\Driver\Tag\PhotoCD\SceneBalanceAlgorithmFilmID(),
                'CopyrightStatus' => new \PHPExiftool\Driver\Tag\PhotoCD\CopyrightStatus(),
                'CopyrightFileName' => new \PHPExiftool\Driver\Tag\PhotoCD\CopyrightFileName(),
                'Orientation' => new \PHPExiftool\Driver\Tag\PhotoCD\Orientation(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\PhotoCD\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\PhotoCD\ImageHeight(),
                'CompressionClass' => new \PHPExiftool\Driver\Tag\PhotoCD\CompressionClass(),
            );
        });
        $this['PhotoMechanic'] = $this->share(function(){
            return array(
                'RawCropLeft' => new \PHPExiftool\Driver\Tag\PhotoMechanic\RawCropLeft(),
                'RawCropTop' => new \PHPExiftool\Driver\Tag\PhotoMechanic\RawCropTop(),
                'RawCropRight' => new \PHPExiftool\Driver\Tag\PhotoMechanic\RawCropRight(),
                'RawCropBottom' => new \PHPExiftool\Driver\Tag\PhotoMechanic\RawCropBottom(),
                'ConstrainedCropWidth' => new \PHPExiftool\Driver\Tag\PhotoMechanic\ConstrainedCropWidth(),
                'ConstrainedCropHeight' => new \PHPExiftool\Driver\Tag\PhotoMechanic\ConstrainedCropHeight(),
                'FrameNum' => new \PHPExiftool\Driver\Tag\PhotoMechanic\FrameNum(),
                'Rotation' => new \PHPExiftool\Driver\Tag\PhotoMechanic\Rotation(),
                'CropLeft' => new \PHPExiftool\Driver\Tag\PhotoMechanic\CropLeft(),
                'CropTop' => new \PHPExiftool\Driver\Tag\PhotoMechanic\CropTop(),
                'CropRight' => new \PHPExiftool\Driver\Tag\PhotoMechanic\CropRight(),
                'CropBottom' => new \PHPExiftool\Driver\Tag\PhotoMechanic\CropBottom(),
                'Tagged' => new \PHPExiftool\Driver\Tag\PhotoMechanic\Tagged(),
                'ColorClass' => new \PHPExiftool\Driver\Tag\PhotoMechanic\ColorClass(),
                'Rating' => new \PHPExiftool\Driver\Tag\PhotoMechanic\Rating(),
                'PreviewCropLeft' => new \PHPExiftool\Driver\Tag\PhotoMechanic\PreviewCropLeft(),
                'PreviewCropTop' => new \PHPExiftool\Driver\Tag\PhotoMechanic\PreviewCropTop(),
                'PreviewCropRight' => new \PHPExiftool\Driver\Tag\PhotoMechanic\PreviewCropRight(),
                'PreviewCropBottom' => new \PHPExiftool\Driver\Tag\PhotoMechanic\PreviewCropBottom(),
            );
        });
        $this['XMP-photomech'] = $this->share(function(){
            return array(
                'ColorClass' => new \PHPExiftool\Driver\Tag\XMPPhotomech\ColorClass(),
                'CountryCode' => new \PHPExiftool\Driver\Tag\XMPPhotomech\CountryCode(),
                'EditStatus' => new \PHPExiftool\Driver\Tag\XMPPhotomech\EditStatus(),
                'PMVersion' => new \PHPExiftool\Driver\Tag\XMPPhotomech\PMVersion(),
                'Prefs' => new \PHPExiftool\Driver\Tag\XMPPhotomech\Prefs(),
                'Tagged' => new \PHPExiftool\Driver\Tag\XMPPhotomech\Tagged(),
                'TimeCreated' => new \PHPExiftool\Driver\Tag\XMPPhotomech\TimeCreated(),
            );
        });
        $this['Photoshop'] = $this->share(function(){
            return array(
                'NumChannels' => new \PHPExiftool\Driver\Tag\Photoshop\NumChannels(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\Photoshop\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\Photoshop\ImageWidth(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\Photoshop\BitDepth(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Photoshop\ColorMode(),
                'PhotoshopQuality' => new \PHPExiftool\Driver\Tag\Photoshop\PhotoshopQuality(),
                'PhotoshopFormat' => new \PHPExiftool\Driver\Tag\Photoshop\PhotoshopFormat(),
                'ProgressiveScans' => new \PHPExiftool\Driver\Tag\Photoshop\ProgressiveScans(),
                'Photoshop2Info' => new \PHPExiftool\Driver\Tag\Photoshop\Photoshop2Info(),
                'MacintoshPrintInfo' => new \PHPExiftool\Driver\Tag\Photoshop\MacintoshPrintInfo(),
                'XMLData' => new \PHPExiftool\Driver\Tag\Photoshop\XMLData(),
                'Photoshop2ColorTable' => new \PHPExiftool\Driver\Tag\Photoshop\Photoshop2ColorTable(),
                'AlphaChannelsNames' => new \PHPExiftool\Driver\Tag\Photoshop\AlphaChannelsNames(),
                'DisplayInfo' => new \PHPExiftool\Driver\Tag\Photoshop\DisplayInfo(),
                'PStringCaption' => new \PHPExiftool\Driver\Tag\Photoshop\PStringCaption(),
                'BorderInformation' => new \PHPExiftool\Driver\Tag\Photoshop\BorderInformation(),
                'BackgroundColor' => new \PHPExiftool\Driver\Tag\Photoshop\BackgroundColor(),
                'PrintFlags' => new \PHPExiftool\Driver\Tag\Photoshop\PrintFlags(),
                'BW_HalftoningInfo' => new \PHPExiftool\Driver\Tag\Photoshop\BWHalftoningInfo(),
                'ColorHalftoningInfo' => new \PHPExiftool\Driver\Tag\Photoshop\ColorHalftoningInfo(),
                'DuotoneHalftoningInfo' => new \PHPExiftool\Driver\Tag\Photoshop\DuotoneHalftoningInfo(),
                'BW_TransferFunc' => new \PHPExiftool\Driver\Tag\Photoshop\BWTransferFunc(),
                'ColorTransferFuncs' => new \PHPExiftool\Driver\Tag\Photoshop\ColorTransferFuncs(),
                'DuotoneTransferFuncs' => new \PHPExiftool\Driver\Tag\Photoshop\DuotoneTransferFuncs(),
                'DuotoneImageInfo' => new \PHPExiftool\Driver\Tag\Photoshop\DuotoneImageInfo(),
                'EffectiveBW' => new \PHPExiftool\Driver\Tag\Photoshop\EffectiveBW(),
                'ObsoletePhotoshopTag1' => new \PHPExiftool\Driver\Tag\Photoshop\ObsoletePhotoshopTag1(),
                'EPSOptions' => new \PHPExiftool\Driver\Tag\Photoshop\EPSOptions(),
                'QuickMaskInfo' => new \PHPExiftool\Driver\Tag\Photoshop\QuickMaskInfo(),
                'ObsoletePhotoshopTag2' => new \PHPExiftool\Driver\Tag\Photoshop\ObsoletePhotoshopTag2(),
                'LayerStateInfo' => new \PHPExiftool\Driver\Tag\Photoshop\LayerStateInfo(),
                'WorkingPath' => new \PHPExiftool\Driver\Tag\Photoshop\WorkingPath(),
                'LayersGroupInfo' => new \PHPExiftool\Driver\Tag\Photoshop\LayersGroupInfo(),
                'ObsoletePhotoshopTag3' => new \PHPExiftool\Driver\Tag\Photoshop\ObsoletePhotoshopTag3(),
                'RawImageMode' => new \PHPExiftool\Driver\Tag\Photoshop\RawImageMode(),
                'GridGuidesInfo' => new \PHPExiftool\Driver\Tag\Photoshop\GridGuidesInfo(),
                'PhotoshopBGRThumbnail' => new \PHPExiftool\Driver\Tag\Photoshop\PhotoshopBGRThumbnail(),
                'CopyrightFlag' => new \PHPExiftool\Driver\Tag\Photoshop\CopyrightFlag(),
                'URL' => new \PHPExiftool\Driver\Tag\Photoshop\URL(),
                'PhotoshopThumbnail' => new \PHPExiftool\Driver\Tag\Photoshop\PhotoshopThumbnail(),
                'GlobalAngle' => new \PHPExiftool\Driver\Tag\Photoshop\GlobalAngle(),
                'ColorSamplersResource' => new \PHPExiftool\Driver\Tag\Photoshop\ColorSamplersResource(),
                'Watermark' => new \PHPExiftool\Driver\Tag\Photoshop\Watermark(),
                'ICC_Untagged' => new \PHPExiftool\Driver\Tag\Photoshop\ICCUntagged(),
                'EffectsVisible' => new \PHPExiftool\Driver\Tag\Photoshop\EffectsVisible(),
                'SpotHalftone' => new \PHPExiftool\Driver\Tag\Photoshop\SpotHalftone(),
                'IDsBaseValue' => new \PHPExiftool\Driver\Tag\Photoshop\IDsBaseValue(),
                'UnicodeAlphaNames' => new \PHPExiftool\Driver\Tag\Photoshop\UnicodeAlphaNames(),
                'IndexedColourTableCount' => new \PHPExiftool\Driver\Tag\Photoshop\IndexedColourTableCount(),
                'TransparentIndex' => new \PHPExiftool\Driver\Tag\Photoshop\TransparentIndex(),
                'GlobalAltitude' => new \PHPExiftool\Driver\Tag\Photoshop\GlobalAltitude(),
                'Slices' => new \PHPExiftool\Driver\Tag\Photoshop\Slices(),
                'WorkflowURL' => new \PHPExiftool\Driver\Tag\Photoshop\WorkflowURL(),
                'JumpToXPEP' => new \PHPExiftool\Driver\Tag\Photoshop\JumpToXPEP(),
                'AlphaIdentifiers' => new \PHPExiftool\Driver\Tag\Photoshop\AlphaIdentifiers(),
                'URL_List' => new \PHPExiftool\Driver\Tag\Photoshop\URLList(),
                'VersionInfo' => new \PHPExiftool\Driver\Tag\Photoshop\VersionInfo(),
                'ExifInfo2' => new \PHPExiftool\Driver\Tag\Photoshop\ExifInfo2(),
                'IPTCDigest' => new \PHPExiftool\Driver\Tag\Photoshop\IPTCDigest(),
                'PrintScale' => new \PHPExiftool\Driver\Tag\Photoshop\PrintScale(),
                'PixelAspectRatio' => new \PHPExiftool\Driver\Tag\Photoshop\PixelAspectRatio(),
                'LayerComps' => new \PHPExiftool\Driver\Tag\Photoshop\LayerComps(),
                'AlternateDuotoneColors' => new \PHPExiftool\Driver\Tag\Photoshop\AlternateDuotoneColors(),
                'AlternateSpotColors' => new \PHPExiftool\Driver\Tag\Photoshop\AlternateSpotColors(),
                'ClippingPathName' => new \PHPExiftool\Driver\Tag\Photoshop\ClippingPathName(),
                'PrintFlagsInfo' => new \PHPExiftool\Driver\Tag\Photoshop\PrintFlagsInfo(),
                'XResolution' => new \PHPExiftool\Driver\Tag\Photoshop\XResolution(),
                'DisplayedUnitsX' => new \PHPExiftool\Driver\Tag\Photoshop\DisplayedUnitsX(),
                'YResolution' => new \PHPExiftool\Driver\Tag\Photoshop\YResolution(),
                'DisplayedUnitsY' => new \PHPExiftool\Driver\Tag\Photoshop\DisplayedUnitsY(),
            );
        });
        $this['PostScript'] = $this->share(function(){
            return array(
                'Author' => new \PHPExiftool\Driver\Tag\PostScript\Author(),
                'BoundingBox' => new \PHPExiftool\Driver\Tag\PostScript\BoundingBox(),
                'Copyright' => new \PHPExiftool\Driver\Tag\PostScript\Copyright(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\PostScript\CreateDate(),
                'Creator' => new \PHPExiftool\Driver\Tag\PostScript\Creator(),
                'EmbeddedFileName' => new \PHPExiftool\Driver\Tag\PostScript\EmbeddedFileName(),
                'For' => new \PHPExiftool\Driver\Tag\PostScript\For0(),
                'ImageData' => new \PHPExiftool\Driver\Tag\PostScript\ImageData(),
                'Keywords' => new \PHPExiftool\Driver\Tag\PostScript\Keywords(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\PostScript\ModifyDate(),
                'Pages' => new \PHPExiftool\Driver\Tag\PostScript\Pages(),
                'Routing' => new \PHPExiftool\Driver\Tag\PostScript\Routing(),
                'Subject' => new \PHPExiftool\Driver\Tag\PostScript\Subject(),
                'TIFFPreview' => new \PHPExiftool\Driver\Tag\PostScript\TIFFPreview(),
                'Title' => new \PHPExiftool\Driver\Tag\PostScript\Title(),
                'Version' => new \PHPExiftool\Driver\Tag\PostScript\Version(),
            );
        });
        $this['PrintIM'] = $this->share(function(){
            return array(
                'PrintIMVersion' => new \PHPExiftool\Driver\Tag\PrintIM\PrintIMVersion(),
            );
        });
        $this['Qualcomm'] = $this->share(function(){
            return array(
                'HJREnable' => new \PHPExiftool\Driver\Tag\Qualcomm\HJREnable(),
                'HJRMaxNumFrames' => new \PHPExiftool\Driver\Tag\Qualcomm\HJRMaxNumFrames(),
                'HJR_NReductionFlat' => new \PHPExiftool\Driver\Tag\Qualcomm\HJRNReductionFlat(),
                'HJR_NReductionTexture' => new \PHPExiftool\Driver\Tag\Qualcomm\HJRNReductionTexture(),
                'HJROneToTwoOffset' => new \PHPExiftool\Driver\Tag\Qualcomm\HJROneToTwoOffset(),
                'HJRTextureThreshold' => new \PHPExiftool\Driver\Tag\Qualcomm\HJRTextureThreshold(),
                'AECAggressiveness' => new \PHPExiftool\Driver\Tag\Qualcomm\AECAggressiveness(),
                'AECCurrentExpIndex' => new \PHPExiftool\Driver\Tag\Qualcomm\AECCurrentExpIndex(),
                'AECCurrentSensorLuma' => new \PHPExiftool\Driver\Tag\Qualcomm\AECCurrentSensorLuma(),
                'AECEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\AECEnable(),
                'AECExposureIndexAdjStep' => new \PHPExiftool\Driver\Tag\Qualcomm\AECExposureIndexAdjStep(),
                'AECHighLumaRegionCount' => new \PHPExiftool\Driver\Tag\Qualcomm\AECHighLumaRegionCount(),
                'AECHighLumaRegionThreshold' => new \PHPExiftool\Driver\Tag\Qualcomm\AECHighLumaRegionThreshold(),
                'AECIndoorIdx' => new \PHPExiftool\Driver\Tag\Qualcomm\AECIndoorIdx(),
                'AECLumaTarget' => new \PHPExiftool\Driver\Tag\Qualcomm\AECLumaTarget(),
                'AECLumaTolerance' => new \PHPExiftool\Driver\Tag\Qualcomm\AECLumaTolerance(),
                'AECMode' => new \PHPExiftool\Driver\Tag\Qualcomm\AECMode(),
                'AECOdoorIdx' => new \PHPExiftool\Driver\Tag\Qualcomm\AECOdoorIdx(),
                'AECOutdoorBrightDiscarded' => new \PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightDiscarded(),
                'AECOutdoorBrightEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightEnable(),
                'AECOutdoorBrightReduction' => new \PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightReduction(),
                'AECOutdoorBrightThresholdHI' => new \PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightThresholdHI(),
                'AECOutdoorBrightThresholdLO' => new \PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightThresholdLO(),
                'AECOutdoorGammaIndex' => new \PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorGammaIndex(),
                'AECSnapshotDigitalGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AECSnapshotDigitalGain(),
                'AECSnapshotExposureTimeMs' => new \PHPExiftool\Driver\Tag\Qualcomm\AECSnapshotExposureTimeMs(),
                'AECSnapshotLineCount' => new \PHPExiftool\Driver\Tag\Qualcomm\AECSnapshotLineCount(),
                'AECSnapshotSensorGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AECSnapshotSensorGain(),
                'AECVfeLuma' => new \PHPExiftool\Driver\Tag\Qualcomm\AECVfeLuma(),
                'AFBoundary' => new \PHPExiftool\Driver\Tag\Qualcomm\AFBoundary(),
                'AFCollectEndStat' => new \PHPExiftool\Driver\Tag\Qualcomm\AFCollectEndStat(),
                'AFEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\AFEnable(),
                'AFFarEnd' => new \PHPExiftool\Driver\Tag\Qualcomm\AFFarEnd(),
                'AFFineSrchPoints' => new \PHPExiftool\Driver\Tag\Qualcomm\AFFineSrchPoints(),
                'AFFineStep' => new \PHPExiftool\Driver\Tag\Qualcomm\AFFineStep(),
                'AFFocusTime' => new \PHPExiftool\Driver\Tag\Qualcomm\AFFocusTime(),
                'AFGrossStep' => new \PHPExiftool\Driver\Tag\Qualcomm\AFGrossStep(),
                'AFMode' => new \PHPExiftool\Driver\Tag\Qualcomm\AFMode(),
                'AFNearEnd' => new \PHPExiftool\Driver\Tag\Qualcomm\AFNearEnd(),
                'AFPosDefMacro' => new \PHPExiftool\Driver\Tag\Qualcomm\AFPosDefMacro(),
                'AFPosDefNorm' => new \PHPExiftool\Driver\Tag\Qualcomm\AFPosDefNorm(),
                'AFPosition' => new \PHPExiftool\Driver\Tag\Qualcomm\AFPosition(),
                'AFProcess' => new \PHPExiftool\Driver\Tag\Qualcomm\AFProcess(),
                'AFResetLensAfterSnap' => new \PHPExiftool\Driver\Tag\Qualcomm\AFResetLensAfterSnap(),
                'AFStepsNearFar' => new \PHPExiftool\Driver\Tag\Qualcomm\AFStepsNearFar(),
                'AFStepsNearInfinity' => new \PHPExiftool\Driver\Tag\Qualcomm\AFStepsNearInfinity(),
                'AFTestMode' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTestMode(),
                'AFTracePositions00' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions00(),
                'AFTracePositions10' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions10(),
                'AFTracePositions11' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions11(),
                'AFTracePositions12' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions12(),
                'AFTracePositions13' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions13(),
                'AFTracePositions14' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions14(),
                'AFTracePositions15' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions15(),
                'AFTracePositions16' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions16(),
                'AFTracePositions17' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions17(),
                'AFTracePositions18' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions18(),
                'AFTracePositions19' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions19(),
                'AFTracePositions01' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions01(),
                'AFTracePositions20' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions20(),
                'AFTracePositions21' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions21(),
                'AFTracePositions22' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions22(),
                'AFTracePositions23' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions23(),
                'AFTracePositions24' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions24(),
                'AFTracePositions25' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions25(),
                'AFTracePositions26' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions26(),
                'AFTracePositions27' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions27(),
                'AFTracePositions28' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions28(),
                'AFTracePositions29' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions29(),
                'AFTracePositions02' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions02(),
                'AFTracePositions30' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions30(),
                'AFTracePositions31' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions31(),
                'AFTracePositions32' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions32(),
                'AFTracePositions33' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions33(),
                'AFTracePositions34' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions34(),
                'AFTracePositions35' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions35(),
                'AFTracePositions36' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions36(),
                'AFTracePositions37' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions37(),
                'AFTracePositions38' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions38(),
                'AFTracePositions39' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions39(),
                'AFTracePositions03' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions03(),
                'AFTracePositions40' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions40(),
                'AFTracePositions41' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions41(),
                'AFTracePositions42' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions42(),
                'AFTracePositions43' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions43(),
                'AFTracePositions44' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions44(),
                'AFTracePositions45' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions45(),
                'AFTracePositions46' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions46(),
                'AFTracePositions47' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions47(),
                'AFTracePositions48' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions48(),
                'AFTracePositions49' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions49(),
                'AFTracePositions04' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions04(),
                'AFTracePositions05' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions05(),
                'AFTracePositions06' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions06(),
                'AFTracePositions07' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions07(),
                'AFTracePositions08' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions08(),
                'AFTracePositions09' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions09(),
                'AFTraceStats00' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats00(),
                'AFTraceStats10' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats10(),
                'AFTraceStats11' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats11(),
                'AFTraceStats12' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats12(),
                'AFTraceStats13' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats13(),
                'AFTraceStats14' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats14(),
                'AFTraceStats15' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats15(),
                'AFTraceStats16' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats16(),
                'AFTraceStats17' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats17(),
                'AFTraceStats18' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats18(),
                'AFTraceStats19' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats19(),
                'AFTraceStats01' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats01(),
                'AFTraceStats20' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats20(),
                'AFTraceStats21' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats21(),
                'AFTraceStats22' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats22(),
                'AFTraceStats23' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats23(),
                'AFTraceStats24' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats24(),
                'AFTraceStats25' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats25(),
                'AFTraceStats26' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats26(),
                'AFTraceStats27' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats27(),
                'AFTraceStats28' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats28(),
                'AFTraceStats29' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats29(),
                'AFTraceStats02' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats02(),
                'AFTraceStats30' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats30(),
                'AFTraceStats31' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats31(),
                'AFTraceStats32' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats32(),
                'AFTraceStats33' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats33(),
                'AFTraceStats34' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats34(),
                'AFTraceStats35' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats35(),
                'AFTraceStats36' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats36(),
                'AFTraceStats37' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats37(),
                'AFTraceStats38' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats38(),
                'AFTraceStats39' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats39(),
                'AFTraceStats03' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats03(),
                'AFTraceStats40' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats40(),
                'AFTraceStats41' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats41(),
                'AFTraceStats42' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats42(),
                'AFTraceStats43' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats43(),
                'AFTraceStats44' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats44(),
                'AFTraceStats45' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats45(),
                'AFTraceStats46' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats46(),
                'AFTraceStats47' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats47(),
                'AFTraceStats48' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats48(),
                'AFTraceStats49' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats49(),
                'AFTraceStats04' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats04(),
                'AFTraceStats05' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats05(),
                'AFTraceStats06' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats06(),
                'AFTraceStats07' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats07(),
                'AFTraceStats08' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats08(),
                'AFTraceStats09' => new \PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats09(),
                'AFUndershootProtect' => new \PHPExiftool\Driver\Tag\Qualcomm\AFUndershootProtect(),
                'AFVfeHorzOffset' => new \PHPExiftool\Driver\Tag\Qualcomm\AFVfeHorzOffset(),
                'AFVfeHorzWidth' => new \PHPExiftool\Driver\Tag\Qualcomm\AFVfeHorzWidth(),
                'AFVfeMetricMax' => new \PHPExiftool\Driver\Tag\Qualcomm\AFVfeMetricMax(),
                'AFVfeVertHeight' => new \PHPExiftool\Driver\Tag\Qualcomm\AFVfeVertHeight(),
                'AFVfeVertOffset' => new \PHPExiftool\Driver\Tag\Qualcomm\AFVfeVertOffset(),
                'AFREnable' => new \PHPExiftool\Driver\Tag\Qualcomm\AFREnable(),
                'AFRFaster0ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster0ExpMod(),
                'AFRFaster0Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster0Trigger(),
                'AFRFaster1ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster1ExpMod(),
                'AFRFaster1Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster1Trigger(),
                'AFRFaster2ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster2ExpMod(),
                'AFRFaster2Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster2Trigger(),
                'AFRFaster3ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster3ExpMod(),
                'AFRFaster3Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster3Trigger(),
                'AFRFaster4ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster4ExpMod(),
                'AFRFaster4Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRFaster4Trigger(),
                'AFRPossibleFrameCnt' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRPossibleFrameCnt(),
                'AFRSlower0ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower0ExpMod(),
                'AFRSlower0Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower0Trigger(),
                'AFRSlower1ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower1ExpMod(),
                'AFRSlower1Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower1Trigger(),
                'AFRSlower2ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower2ExpMod(),
                'AFRSlower2Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower2Trigger(),
                'AFRSlower3ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower3ExpMod(),
                'AFRSlower3Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower3Trigger(),
                'AFRSlower4ExpMod' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower4ExpMod(),
                'AFRSlower4Trigger' => new \PHPExiftool\Driver\Tag\Qualcomm\AFRSlower4Trigger(),
                'AntiBadingPixelClk' => new \PHPExiftool\Driver\Tag\Qualcomm\AntiBadingPixelClk(),
                'AntiBadingPixelClkPerLine' => new \PHPExiftool\Driver\Tag\Qualcomm\AntiBadingPixelClkPerLine(),
                'AntibandingEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\AntibandingEnable(),
                'ASF3EdgeDetect' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeDetect(),
                'ASF3EdgeFilterA11' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA11(),
                'ASF3EdgeFilterA12' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA12(),
                'ASF3EdgeFilterA13' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA13(),
                'ASF3EdgeFilterA21' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA21(),
                'ASF3EdgeFilterA22' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA22(),
                'ASF3EdgeFilterA23' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA23(),
                'ASF3EdgeFilterA31' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA31(),
                'ASF3EdgeFilterA32' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA32(),
                'ASF3EdgeFilterA33' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA33(),
                'ASF3Enable' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3Enable(),
                'ASF3LowerThreshold' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3LowerThreshold(),
                'ASF3NoiseFilterA11' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA11(),
                'ASF3NoiseFilterA12' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA12(),
                'ASF3NoiseFilterA13' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA13(),
                'ASF3NoiseFilterA21' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA21(),
                'ASF3NoiseFilterA22' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA22(),
                'ASF3NoiseFilterA23' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA23(),
                'ASF3NoiseFilterA31' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA31(),
                'ASF3NoiseFilterA32' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA32(),
                'ASF3NoiseFilterA33' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA33(),
                'ASF3UpperThreshold' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF3UpperThreshold(),
                'ASF5BrtLoThres' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtLoThres(),
                'ASF5BrtShrpDegF1' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtShrpDegF1(),
                'ASF5BrtShrpDegF2' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtShrpDegF2(),
                'ASF5BrtSmthPercent' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtSmthPercent(),
                'ASF5BrtUpThres' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtUpThres(),
                'ASF5Enable' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Enable(),
                'ASF5ExposureIndex1' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5ExposureIndex1(),
                'ASF5ExposureIndex2' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5ExposureIndex2(),
                'ASF5Filter1A11' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A11(),
                'ASF5Filter1A12' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A12(),
                'ASF5Filter1A13' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A13(),
                'ASF5Filter1A14' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A14(),
                'ASF5Filter1A15' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A15(),
                'ASF5Filter1A21' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A21(),
                'ASF5Filter1A22' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A22(),
                'ASF5Filter1A23' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A23(),
                'ASF5Filter1A24' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A24(),
                'ASF5Filter1A25' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A25(),
                'ASF5Filter1A31' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A31(),
                'ASF5Filter1A32' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A32(),
                'ASF5Filter1A33' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A33(),
                'ASF5Filter1A34' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A34(),
                'ASF5Filter1A35' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A35(),
                'ASF5Filter1A41' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A41(),
                'ASF5Filter1A42' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A42(),
                'ASF5Filter1A43' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A43(),
                'ASF5Filter1A44' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A44(),
                'ASF5Filter1A45' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A45(),
                'ASF5Filter1A51' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A51(),
                'ASF5Filter1A52' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A52(),
                'ASF5Filter1A53' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A53(),
                'ASF5Filter1A54' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A54(),
                'ASF5Filter1A55' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A55(),
                'ASF5Filter2A11' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A11(),
                'ASF5Filter2A12' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A12(),
                'ASF5Filter2A13' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A13(),
                'ASF5Filter2A14' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A14(),
                'ASF5Filter2A15' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A15(),
                'ASF5Filter2A21' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A21(),
                'ASF5Filter2A22' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A22(),
                'ASF5Filter2A23' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A23(),
                'ASF5Filter2A24' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A24(),
                'ASF5Filter2A25' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A25(),
                'ASF5Filter2A31' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A31(),
                'ASF5Filter2A32' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A32(),
                'ASF5Filter2A33' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A33(),
                'ASF5Filter2A34' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A34(),
                'ASF5Filter2A35' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A35(),
                'ASF5Filter2A41' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A41(),
                'ASF5Filter2A42' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A42(),
                'ASF5Filter2A43' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A43(),
                'ASF5Filter2A44' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A44(),
                'ASF5Filter2A45' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A45(),
                'ASF5Filter2A51' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A51(),
                'ASF5Filter2A52' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A52(),
                'ASF5Filter2A53' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A53(),
                'ASF5Filter2A54' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A54(),
                'ASF5Filter2A55' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A55(),
                'ASF5FilterMode' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5FilterMode(),
                'ASF5LowLoThres' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LowLoThres(),
                'ASF5LowShrpDegF1' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LowShrpDegF1(),
                'ASF5LowShrpDegF2' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LowShrpDegF2(),
                'ASF5LowSmthPrcnt' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LowSmthPrcnt(),
                'ASF5LowUpThres' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LowUpThres(),
                'ASF5LumaFilter00' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter00(),
                'ASF5LumaFilter01' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter01(),
                'ASF5LumaFilter02' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter02(),
                'ASF5LumaFilter03' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter03(),
                'ASF5LumaFilter04' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter04(),
                'ASF5LumaFilter05' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter05(),
                'ASF5LumaFilter06' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter06(),
                'ASF5LumaFilter07' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter07(),
                'ASF5LumaFilter08' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter08(),
                'ASF5MaxExposureIndex' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5MaxExposureIndex(),
                'ASF5NrmLoThres' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmLoThres(),
                'ASF5NrmShrpDegF1' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmShrpDegF1(),
                'ASF5NrmShrpDegF2' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmShrpDegF2(),
                'ASF5NrmSmthPrcnt' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmSmthPrcnt(),
                'ASF5NrmUpThres' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmUpThres(),
                'ASF5NrmizeFactor1' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmizeFactor1(),
                'ASF5NrmizeFactor2' => new \PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmizeFactor2(),
                'AWBAggressiveness' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBAggressiveness(),
                'AWBAgwGridDist2Thresh' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBAgwGridDist2Thresh(),
                'AWBAlgorithm' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBAlgorithm(),
                'AWBAveBgRatio' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBAveBgRatio(),
                'AWBAveRgRatio' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBAveRgRatio(),
                'AWBBlueGainAdjRef1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef1(),
                'AWBBlueGainAdjRef2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef2(),
                'AWBBlueGainAdjRef3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef3(),
                'AWBBlueGainAdjRef4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef4(),
                'AWBBlueGainAdjRef5' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef5(),
                'AWBBlueGainAdjRef6' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef6(),
                'AWBBlueGainAdjRef7' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef7(),
                'AWBBlueGainAdjRef8' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef8(),
                'AWBBlueGainRef1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef1(),
                'AWBBlueGainRef2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef2(),
                'AWBBlueGainRef3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef3(),
                'AWBBlueGainRef4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef4(),
                'AWBBlueGainRef5' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef5(),
                'AWBBlueGainRef6' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef6(),
                'AWBBlueGainRef7' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef7(),
                'AWBBlueGainRef8' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef8(),
                'AWBCcBias' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBCcBias(),
                'AWBCompactClusterR2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBCompactClusterR2(),
                'AWBEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBEnable(),
                'AWBGreenOffsetBg' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBGreenOffsetBg(),
                'AWBGreenOffsetRg' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBGreenOffsetRg(),
                'AWBIndoorSampleInfluence' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBIndoorSampleInfluence(),
                'AWBLoVfeC1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeC1(),
                'AWBLoVfeC2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeC2(),
                'AWBLoVfeC3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeC3(),
                'AWBLoVfeC4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeC4(),
                'AWBLoVfeM1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeM1(),
                'AWBLoVfeM2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeM2(),
                'AWBLoVfeM3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeM3(),
                'AWBLoVfeM4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeM4(),
                'AWBLoVfeMaxY' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeMaxY(),
                'AWBLoVfeMinY' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeMinY(),
                'AWBLowLigColCorEna' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBLowLigColCorEna(),
                'AWBMaxBGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBMaxBGain(),
                'AWBMaxGGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBMaxGGain(),
                'AWBMaxRGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBMaxRGain(),
                'AWBMinBGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBMinBGain(),
                'AWBMinGGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBMinGGain(),
                'AWBMinRGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBMinRGain(),
                'AWBNormVfeC1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeC1(),
                'AWBNormVfeC2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeC2(),
                'AWBNormVfeC3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeC3(),
                'AWBNormVfeC4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeC4(),
                'AWBNormVfeM1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeM1(),
                'AWBNormVfeM2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeM2(),
                'AWBNormVfeM3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeM3(),
                'AWBNormVfeM4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeM4(),
                'AWBNormVfeMaxY' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeMaxY(),
                'AWBNormVfeMinY' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeMinY(),
                'AWBOudorVfeC1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeC1(),
                'AWBOudorVfeC2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeC2(),
                'AWBOudorVfeC3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeC3(),
                'AWBOudorVfeC4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeC4(),
                'AWBOudorVfeM1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeM1(),
                'AWBOudorVfeM2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeM2(),
                'AWBOudorVfeM3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeM3(),
                'AWBOudorVfeM4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeM4(),
                'AWBOudorVfeMaxY' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeMaxY(),
                'AWBOudorVfeMinY' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeMinY(),
                'AWBOutdoorSampleInfluence' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBOutdoorSampleInfluence(),
                'AWBPrevWbBgain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBPrevWbBgain(),
                'AWBPrevWbGgain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBPrevWbGgain(),
                'AWBPrevWbRgain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBPrevWbRgain(),
                'AWBRedGainAdjRef1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef1(),
                'AWBRedGainAdjRef2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef2(),
                'AWBRedGainAdjRef3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef3(),
                'AWBRedGainAdjRef4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef4(),
                'AWBRedGainAdjRef5' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef5(),
                'AWBRedGainAdjRef6' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef6(),
                'AWBRedGainAdjRef7' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef7(),
                'AWBRedGainAdjRef8' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef8(),
                'AWBRedGainRef1' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef1(),
                'AWBRedGainRef2' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef2(),
                'AWBRedGainRef3' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef3(),
                'AWBRedGainRef4' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef4(),
                'AWBRedGainRef5' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef5(),
                'AWBRedGainRef6' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef6(),
                'AWBRedGainRef7' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef7(),
                'AWBRedGainRef8' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef8(),
                'AWBSampleDecision' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBSampleDecision(),
                'AWBSnapshotBGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBSnapshotBGain(),
                'AWBSnapshotRGain' => new \PHPExiftool\Driver\Tag\Qualcomm\AWBSnapshotRGain(),
                'BlckLvlEvenCols' => new \PHPExiftool\Driver\Tag\Qualcomm\BlckLvlEvenCols(),
                'BlckLvlOddCols' => new \PHPExiftool\Driver\Tag\Qualcomm\BlckLvlOddCols(),
                'CamMclkHz' => new \PHPExiftool\Driver\Tag\Qualcomm\CamMclkHz(),
                'ChroSupChroThres1' => new \PHPExiftool\Driver\Tag\Qualcomm\ChroSupChroThres1(),
                'ChroSupChroThres2' => new \PHPExiftool\Driver\Tag\Qualcomm\ChroSupChroThres2(),
                'ChroSupLumaThres1' => new \PHPExiftool\Driver\Tag\Qualcomm\ChroSupLumaThres1(),
                'ChroSupLumaThres2' => new \PHPExiftool\Driver\Tag\Qualcomm\ChroSupLumaThres2(),
                'ChroSupLumaThres3' => new \PHPExiftool\Driver\Tag\Qualcomm\ChroSupLumaThres3(),
                'ChroSupLumaThres4' => new \PHPExiftool\Driver\Tag\Qualcomm\ChroSupLumaThres4(),
                'ChromSupress' => new \PHPExiftool\Driver\Tag\Qualcomm\ChromSupress(),
                'ClipToAfRato' => new \PHPExiftool\Driver\Tag\Qualcomm\ClipToAfRato(),
                'CurrResol' => new \PHPExiftool\Driver\Tag\Qualcomm\CurrResol(),
                'DayltConvChrmA_M' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmAM(),
                'DayltConvChrmA_P' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmAP(),
                'DayltConvChrmB_M' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmBM(),
                'DayltConvChrmB_P' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmBP(),
                'DayltConvChrmC_M' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmCM(),
                'DayltConvChrmC_P' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmCP(),
                'DayltConvChrmD_M' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmDM(),
                'DayltConvChrmD_P' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmDP(),
                'DayltConvChrmKCb' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmKCb(),
                'DayltConvChrmKCr' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmKCr(),
                'DayltConvLumaK' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvLumaK(),
                'DayltConvLumaV0' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvLumaV0(),
                'DayltConvLumaV1' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvLumaV1(),
                'DayltConvLumaV2' => new \PHPExiftool\Driver\Tag\Qualcomm\DayltConvLumaV2(),
                'DefConvChrmA_M' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmAM(),
                'DefConvChrmA_P' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmAP(),
                'DefConvChrmB_M' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmBM(),
                'DefConvChrmB_P' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmBP(),
                'DefConvChrmC_M' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmCM(),
                'DefConvChrmC_P' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmCP(),
                'DefConvChrmD_M' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmDM(),
                'DefConvChrmD_P' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmDP(),
                'DefConvChrmKCb' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmKCb(),
                'DefConvChrmKCr' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmKCr(),
                'DefConvLumaK' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvLumaK(),
                'DefConvLumaV0' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvLumaV0(),
                'DefConvLumaV1' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvLumaV1(),
                'DefConvLumaV2' => new \PHPExiftool\Driver\Tag\Qualcomm\DefConvLumaV2(),
                'DefCorC0' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC0(),
                'DefCorC1' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC1(),
                'DefCorC2' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC2(),
                'DefCorC3' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC3(),
                'DefCorC4' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC4(),
                'DefCorC5' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC5(),
                'DefCorC6' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC6(),
                'DefCorC7' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC7(),
                'DefCorC8' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorC8(),
                'DefCorK0' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorK0(),
                'DefCorK1' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorK1(),
                'DefCorK2' => new \PHPExiftool\Driver\Tag\Qualcomm\DefCorK2(),
                'DefLumaGammaMode' => new \PHPExiftool\Driver\Tag\Qualcomm\DefLumaGammaMode(),
                'DefRgbGammaMode' => new \PHPExiftool\Driver\Tag\Qualcomm\DefRgbGammaMode(),
                'DefectPixCorEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\DefectPixCorEnable(),
                'DefectPixMaxThresh' => new \PHPExiftool\Driver\Tag\Qualcomm\DefectPixMaxThresh(),
                'DefectPixMinThresh' => new \PHPExiftool\Driver\Tag\Qualcomm\DefectPixMinThresh(),
                'DiscardFrstFrm' => new \PHPExiftool\Driver\Tag\Qualcomm\DiscardFrstFrm(),
                'FrmSkipPttrn' => new \PHPExiftool\Driver\Tag\Qualcomm\FrmSkipPttrn(),
                'GammaEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\GammaEnable(),
                'IncandConvChrmA_M' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmAM(),
                'IncandConvChrmA_P' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmAP(),
                'IncandConvChrmB_M' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmBM(),
                'IncandConvChrmB_P' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmBP(),
                'IncandConvChrmC_M' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmCM(),
                'IncandConvChrmC_P' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmCP(),
                'IncandConvChrmD_M' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmDM(),
                'IncandConvChrmD_P' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmDP(),
                'IncandConvChrmKCb' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmKCb(),
                'IncandConvChrmKCr' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmKCr(),
                'IncandConvLumaK' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvLumaK(),
                'IncandConvLumaV0' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvLumaV0(),
                'IncandConvLumaV1' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvLumaV1(),
                'IncandConvLumaV2' => new \PHPExiftool\Driver\Tag\Qualcomm\IncandConvLumaV2(),
                'LADetect' => new \PHPExiftool\Driver\Tag\Qualcomm\LADetect(),
                'LAEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\LAEnable(),
                'MaxPrviewFps' => new \PHPExiftool\Driver\Tag\Qualcomm\MaxPrviewFps(),
                'MaxVideoFps' => new \PHPExiftool\Driver\Tag\Qualcomm\MaxVideoFps(),
                'NghtshtFps' => new \PHPExiftool\Driver\Tag\Qualcomm\NghtshtFps(),
                'NightshotMode' => new \PHPExiftool\Driver\Tag\Qualcomm\NightshotMode(),
                'OutlierDistance' => new \PHPExiftool\Driver\Tag\Qualcomm\OutlierDistance(),
                'PclkInvert' => new \PHPExiftool\Driver\Tag\Qualcomm\PclkInvert(),
                'PrviewFps' => new \PHPExiftool\Driver\Tag\Qualcomm\PrviewFps(),
                'PrviewResol' => new \PHPExiftool\Driver\Tag\Qualcomm\PrviewResol(),
                'R2ABlueCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl00(),
                'R2ABlueCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl10(),
                'R2ABlueCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl11(),
                'R2ABlueCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl12(),
                'R2ABlueCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl13(),
                'R2ABlueCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl14(),
                'R2ABlueCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl15(),
                'R2ABlueCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl16(),
                'R2ABlueCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl17(),
                'R2ABlueCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl18(),
                'R2ABlueCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl19(),
                'R2ABlueCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl01(),
                'R2ABlueCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl20(),
                'R2ABlueCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl21(),
                'R2ABlueCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl22(),
                'R2ABlueCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl23(),
                'R2ABlueCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl24(),
                'R2ABlueCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl25(),
                'R2ABlueCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl26(),
                'R2ABlueCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl27(),
                'R2ABlueCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl28(),
                'R2ABlueCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl29(),
                'R2ABlueCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl02(),
                'R2ABlueCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl30(),
                'R2ABlueCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl31(),
                'R2ABlueCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl03(),
                'R2ABlueCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl04(),
                'R2ABlueCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl05(),
                'R2ABlueCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl06(),
                'R2ABlueCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl07(),
                'R2ABlueCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl08(),
                'R2ABlueCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl09(),
                'R2ABlueStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl00(),
                'R2ABlueStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl10(),
                'R2ABlueStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl11(),
                'R2ABlueStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl12(),
                'R2ABlueStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl13(),
                'R2ABlueStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl14(),
                'R2ABlueStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl15(),
                'R2ABlueStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl16(),
                'R2ABlueStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl17(),
                'R2ABlueStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl18(),
                'R2ABlueStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl19(),
                'R2ABlueStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl01(),
                'R2ABlueStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl20(),
                'R2ABlueStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl21(),
                'R2ABlueStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl22(),
                'R2ABlueStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl23(),
                'R2ABlueStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl24(),
                'R2ABlueStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl25(),
                'R2ABlueStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl26(),
                'R2ABlueStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl27(),
                'R2ABlueStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl28(),
                'R2ABlueStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl29(),
                'R2ABlueStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl02(),
                'R2ABlueStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl30(),
                'R2ABlueStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl31(),
                'R2ABlueStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl03(),
                'R2ABlueStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl04(),
                'R2ABlueStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl05(),
                'R2ABlueStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl06(),
                'R2ABlueStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl07(),
                'R2ABlueStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl08(),
                'R2ABlueStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl09(),
                'R2ACx' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ACx(),
                'R2ACy' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ACy(),
                'R2AGreenCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl00(),
                'R2AGreenCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl10(),
                'R2AGreenCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl11(),
                'R2AGreenCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl12(),
                'R2AGreenCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl13(),
                'R2AGreenCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl14(),
                'R2AGreenCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl15(),
                'R2AGreenCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl16(),
                'R2AGreenCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl17(),
                'R2AGreenCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl18(),
                'R2AGreenCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl19(),
                'R2AGreenCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl01(),
                'R2AGreenCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl20(),
                'R2AGreenCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl21(),
                'R2AGreenCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl22(),
                'R2AGreenCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl23(),
                'R2AGreenCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl24(),
                'R2AGreenCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl25(),
                'R2AGreenCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl26(),
                'R2AGreenCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl27(),
                'R2AGreenCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl28(),
                'R2AGreenCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl29(),
                'R2AGreenCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl02(),
                'R2AGreenCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl30(),
                'R2AGreenCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl31(),
                'R2AGreenCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl03(),
                'R2AGreenCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl04(),
                'R2AGreenCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl05(),
                'R2AGreenCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl06(),
                'R2AGreenCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl07(),
                'R2AGreenCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl08(),
                'R2AGreenCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl09(),
                'R2AGreenStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl00(),
                'R2AGreenStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl10(),
                'R2AGreenStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl11(),
                'R2AGreenStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl12(),
                'R2AGreenStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl13(),
                'R2AGreenStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl14(),
                'R2AGreenStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl15(),
                'R2AGreenStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl16(),
                'R2AGreenStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl17(),
                'R2AGreenStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl18(),
                'R2AGreenStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl19(),
                'R2AGreenStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl01(),
                'R2AGreenStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl20(),
                'R2AGreenStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl21(),
                'R2AGreenStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl22(),
                'R2AGreenStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl23(),
                'R2AGreenStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl24(),
                'R2AGreenStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl25(),
                'R2AGreenStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl26(),
                'R2AGreenStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl27(),
                'R2AGreenStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl28(),
                'R2AGreenStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl29(),
                'R2AGreenStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl02(),
                'R2AGreenStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl30(),
                'R2AGreenStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl31(),
                'R2AGreenStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl03(),
                'R2AGreenStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl04(),
                'R2AGreenStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl05(),
                'R2AGreenStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl06(),
                'R2AGreenStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl07(),
                'R2AGreenStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl08(),
                'R2AGreenStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl09(),
                'R2AHeight' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AHeight(),
                'R2AIntervals' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AIntervals(),
                'R2ARedCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl00(),
                'R2ARedCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl10(),
                'R2ARedCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl11(),
                'R2ARedCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl12(),
                'R2ARedCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl13(),
                'R2ARedCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl14(),
                'R2ARedCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl15(),
                'R2ARedCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl16(),
                'R2ARedCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl17(),
                'R2ARedCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl18(),
                'R2ARedCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl19(),
                'R2ARedCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl01(),
                'R2ARedCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl20(),
                'R2ARedCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl21(),
                'R2ARedCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl22(),
                'R2ARedCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl23(),
                'R2ARedCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl24(),
                'R2ARedCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl25(),
                'R2ARedCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl26(),
                'R2ARedCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl27(),
                'R2ARedCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl28(),
                'R2ARedCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl29(),
                'R2ARedCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl02(),
                'R2ARedCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl30(),
                'R2ARedCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl31(),
                'R2ARedCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl03(),
                'R2ARedCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl04(),
                'R2ARedCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl05(),
                'R2ARedCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl06(),
                'R2ARedCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl07(),
                'R2ARedCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl08(),
                'R2ARedCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl09(),
                'R2ARedStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl00(),
                'R2ARedStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl10(),
                'R2ARedStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl11(),
                'R2ARedStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl12(),
                'R2ARedStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl13(),
                'R2ARedStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl14(),
                'R2ARedStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl15(),
                'R2ARedStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl16(),
                'R2ARedStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl17(),
                'R2ARedStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl18(),
                'R2ARedStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl19(),
                'R2ARedStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl01(),
                'R2ARedStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl20(),
                'R2ARedStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl21(),
                'R2ARedStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl22(),
                'R2ARedStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl23(),
                'R2ARedStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl24(),
                'R2ARedStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl25(),
                'R2ARedStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl26(),
                'R2ARedStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl27(),
                'R2ARedStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl28(),
                'R2ARedStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl29(),
                'R2ARedStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl02(),
                'R2ARedStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl30(),
                'R2ARedStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl31(),
                'R2ARedStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl03(),
                'R2ARedStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl04(),
                'R2ARedStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl05(),
                'R2ARedStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl06(),
                'R2ARedStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl07(),
                'R2ARedStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl08(),
                'R2ARedStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl09(),
                'R2ATbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl00(),
                'R2ATbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl10(),
                'R2ATbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl11(),
                'R2ATbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl12(),
                'R2ATbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl13(),
                'R2ATbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl14(),
                'R2ATbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl15(),
                'R2ATbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl16(),
                'R2ATbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl17(),
                'R2ATbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl18(),
                'R2ATbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl19(),
                'R2ATbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl01(),
                'R2ATbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl20(),
                'R2ATbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl21(),
                'R2ATbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl22(),
                'R2ATbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl23(),
                'R2ATbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl24(),
                'R2ATbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl25(),
                'R2ATbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl26(),
                'R2ATbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl27(),
                'R2ATbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl28(),
                'R2ATbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl29(),
                'R2ATbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl02(),
                'R2ATbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl30(),
                'R2ATbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl31(),
                'R2ATbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl03(),
                'R2ATbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl04(),
                'R2ATbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl05(),
                'R2ATbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl06(),
                'R2ATbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl07(),
                'R2ATbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl08(),
                'R2ATbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2ATbl09(),
                'R2AWidth' => new \PHPExiftool\Driver\Tag\Qualcomm\R2AWidth(),
                'R2D65BlueCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl00(),
                'R2D65BlueCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl10(),
                'R2D65BlueCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl11(),
                'R2D65BlueCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl12(),
                'R2D65BlueCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl13(),
                'R2D65BlueCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl14(),
                'R2D65BlueCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl15(),
                'R2D65BlueCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl16(),
                'R2D65BlueCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl17(),
                'R2D65BlueCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl18(),
                'R2D65BlueCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl19(),
                'R2D65BlueCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl01(),
                'R2D65BlueCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl20(),
                'R2D65BlueCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl21(),
                'R2D65BlueCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl22(),
                'R2D65BlueCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl23(),
                'R2D65BlueCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl24(),
                'R2D65BlueCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl25(),
                'R2D65BlueCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl26(),
                'R2D65BlueCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl27(),
                'R2D65BlueCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl28(),
                'R2D65BlueCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl29(),
                'R2D65BlueCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl02(),
                'R2D65BlueCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl30(),
                'R2D65BlueCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl31(),
                'R2D65BlueCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl03(),
                'R2D65BlueCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl04(),
                'R2D65BlueCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl05(),
                'R2D65BlueCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl06(),
                'R2D65BlueCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl07(),
                'R2D65BlueCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl08(),
                'R2D65BlueCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl09(),
                'R2D65BlueStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl00(),
                'R2D65BlueStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl10(),
                'R2D65BlueStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl11(),
                'R2D65BlueStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl12(),
                'R2D65BlueStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl13(),
                'R2D65BlueStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl14(),
                'R2D65BlueStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl15(),
                'R2D65BlueStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl16(),
                'R2D65BlueStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl17(),
                'R2D65BlueStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl18(),
                'R2D65BlueStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl19(),
                'R2D65BlueStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl01(),
                'R2D65BlueStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl20(),
                'R2D65BlueStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl21(),
                'R2D65BlueStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl22(),
                'R2D65BlueStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl23(),
                'R2D65BlueStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl24(),
                'R2D65BlueStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl25(),
                'R2D65BlueStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl26(),
                'R2D65BlueStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl27(),
                'R2D65BlueStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl28(),
                'R2D65BlueStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl29(),
                'R2D65BlueStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl02(),
                'R2D65BlueStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl30(),
                'R2D65BlueStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl31(),
                'R2D65BlueStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl03(),
                'R2D65BlueStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl04(),
                'R2D65BlueStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl05(),
                'R2D65BlueStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl06(),
                'R2D65BlueStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl07(),
                'R2D65BlueStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl08(),
                'R2D65BlueStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl09(),
                'R2D65Cx' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Cx(),
                'R2D65Cy' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Cy(),
                'R2D65GreenCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl00(),
                'R2D65GreenCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl10(),
                'R2D65GreenCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl11(),
                'R2D65GreenCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl12(),
                'R2D65GreenCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl13(),
                'R2D65GreenCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl14(),
                'R2D65GreenCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl15(),
                'R2D65GreenCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl16(),
                'R2D65GreenCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl17(),
                'R2D65GreenCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl18(),
                'R2D65GreenCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl19(),
                'R2D65GreenCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl01(),
                'R2D65GreenCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl20(),
                'R2D65GreenCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl21(),
                'R2D65GreenCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl22(),
                'R2D65GreenCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl23(),
                'R2D65GreenCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl24(),
                'R2D65GreenCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl25(),
                'R2D65GreenCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl26(),
                'R2D65GreenCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl27(),
                'R2D65GreenCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl28(),
                'R2D65GreenCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl29(),
                'R2D65GreenCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl02(),
                'R2D65GreenCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl30(),
                'R2D65GreenCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl31(),
                'R2D65GreenCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl03(),
                'R2D65GreenCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl04(),
                'R2D65GreenCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl05(),
                'R2D65GreenCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl06(),
                'R2D65GreenCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl07(),
                'R2D65GreenCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl08(),
                'R2D65GreenCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl09(),
                'R2D65GreenStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl00(),
                'R2D65GreenStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl10(),
                'R2D65GreenStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl11(),
                'R2D65GreenStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl12(),
                'R2D65GreenStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl13(),
                'R2D65GreenStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl14(),
                'R2D65GreenStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl15(),
                'R2D65GreenStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl16(),
                'R2D65GreenStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl17(),
                'R2D65GreenStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl18(),
                'R2D65GreenStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl19(),
                'R2D65GreenStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl01(),
                'R2D65GreenStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl20(),
                'R2D65GreenStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl21(),
                'R2D65GreenStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl22(),
                'R2D65GreenStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl23(),
                'R2D65GreenStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl24(),
                'R2D65GreenStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl25(),
                'R2D65GreenStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl26(),
                'R2D65GreenStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl27(),
                'R2D65GreenStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl28(),
                'R2D65GreenStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl29(),
                'R2D65GreenStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl02(),
                'R2D65GreenStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl30(),
                'R2D65GreenStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl31(),
                'R2D65GreenStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl03(),
                'R2D65GreenStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl04(),
                'R2D65GreenStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl05(),
                'R2D65GreenStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl06(),
                'R2D65GreenStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl07(),
                'R2D65GreenStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl08(),
                'R2D65GreenStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl09(),
                'R2D65Height' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Height(),
                'R2D65Intervals' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Intervals(),
                'R2D65RedCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl00(),
                'R2D65RedCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl10(),
                'R2D65RedCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl11(),
                'R2D65RedCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl12(),
                'R2D65RedCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl13(),
                'R2D65RedCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl14(),
                'R2D65RedCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl15(),
                'R2D65RedCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl16(),
                'R2D65RedCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl17(),
                'R2D65RedCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl18(),
                'R2D65RedCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl19(),
                'R2D65RedCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl01(),
                'R2D65RedCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl20(),
                'R2D65RedCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl21(),
                'R2D65RedCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl22(),
                'R2D65RedCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl23(),
                'R2D65RedCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl24(),
                'R2D65RedCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl25(),
                'R2D65RedCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl26(),
                'R2D65RedCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl27(),
                'R2D65RedCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl28(),
                'R2D65RedCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl29(),
                'R2D65RedCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl02(),
                'R2D65RedCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl30(),
                'R2D65RedCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl31(),
                'R2D65RedCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl03(),
                'R2D65RedCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl04(),
                'R2D65RedCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl05(),
                'R2D65RedCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl06(),
                'R2D65RedCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl07(),
                'R2D65RedCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl08(),
                'R2D65RedCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl09(),
                'R2D65RedStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl00(),
                'R2D65RedStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl10(),
                'R2D65RedStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl11(),
                'R2D65RedStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl12(),
                'R2D65RedStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl13(),
                'R2D65RedStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl14(),
                'R2D65RedStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl15(),
                'R2D65RedStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl16(),
                'R2D65RedStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl17(),
                'R2D65RedStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl18(),
                'R2D65RedStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl19(),
                'R2D65RedStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl01(),
                'R2D65RedStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl20(),
                'R2D65RedStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl21(),
                'R2D65RedStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl22(),
                'R2D65RedStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl23(),
                'R2D65RedStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl24(),
                'R2D65RedStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl25(),
                'R2D65RedStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl26(),
                'R2D65RedStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl27(),
                'R2D65RedStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl28(),
                'R2D65RedStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl29(),
                'R2D65RedStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl02(),
                'R2D65RedStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl30(),
                'R2D65RedStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl31(),
                'R2D65RedStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl03(),
                'R2D65RedStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl04(),
                'R2D65RedStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl05(),
                'R2D65RedStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl06(),
                'R2D65RedStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl07(),
                'R2D65RedStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl08(),
                'R2D65RedStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl09(),
                'R2D65Tbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl00(),
                'R2D65Tbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl10(),
                'R2D65Tbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl11(),
                'R2D65Tbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl12(),
                'R2D65Tbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl13(),
                'R2D65Tbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl14(),
                'R2D65Tbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl15(),
                'R2D65Tbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl16(),
                'R2D65Tbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl17(),
                'R2D65Tbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl18(),
                'R2D65Tbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl19(),
                'R2D65Tbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl01(),
                'R2D65Tbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl20(),
                'R2D65Tbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl21(),
                'R2D65Tbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl22(),
                'R2D65Tbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl23(),
                'R2D65Tbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl24(),
                'R2D65Tbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl25(),
                'R2D65Tbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl26(),
                'R2D65Tbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl27(),
                'R2D65Tbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl28(),
                'R2D65Tbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl29(),
                'R2D65Tbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl02(),
                'R2D65Tbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl30(),
                'R2D65Tbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl31(),
                'R2D65Tbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl03(),
                'R2D65Tbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl04(),
                'R2D65Tbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl05(),
                'R2D65Tbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl06(),
                'R2D65Tbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl07(),
                'R2D65Tbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl08(),
                'R2D65Tbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl09(),
                'R2D65Width' => new \PHPExiftool\Driver\Tag\Qualcomm\R2D65Width(),
                'R2TL84BlueCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl00(),
                'R2TL84BlueCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl10(),
                'R2TL84BlueCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl11(),
                'R2TL84BlueCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl12(),
                'R2TL84BlueCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl13(),
                'R2TL84BlueCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl14(),
                'R2TL84BlueCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl15(),
                'R2TL84BlueCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl16(),
                'R2TL84BlueCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl17(),
                'R2TL84BlueCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl18(),
                'R2TL84BlueCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl19(),
                'R2TL84BlueCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl01(),
                'R2TL84BlueCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl20(),
                'R2TL84BlueCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl21(),
                'R2TL84BlueCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl22(),
                'R2TL84BlueCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl23(),
                'R2TL84BlueCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl24(),
                'R2TL84BlueCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl25(),
                'R2TL84BlueCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl26(),
                'R2TL84BlueCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl27(),
                'R2TL84BlueCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl28(),
                'R2TL84BlueCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl29(),
                'R2TL84BlueCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl02(),
                'R2TL84BlueCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl30(),
                'R2TL84BlueCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl31(),
                'R2TL84BlueCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl03(),
                'R2TL84BlueCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl04(),
                'R2TL84BlueCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl05(),
                'R2TL84BlueCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl06(),
                'R2TL84BlueCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl07(),
                'R2TL84BlueCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl08(),
                'R2TL84BlueCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl09(),
                'R2TL84BlueStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl00(),
                'R2TL84BlueStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl10(),
                'R2TL84BlueStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl11(),
                'R2TL84BlueStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl12(),
                'R2TL84BlueStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl13(),
                'R2TL84BlueStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl14(),
                'R2TL84BlueStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl15(),
                'R2TL84BlueStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl16(),
                'R2TL84BlueStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl17(),
                'R2TL84BlueStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl18(),
                'R2TL84BlueStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl19(),
                'R2TL84BlueStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl01(),
                'R2TL84BlueStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl20(),
                'R2TL84BlueStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl21(),
                'R2TL84BlueStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl22(),
                'R2TL84BlueStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl23(),
                'R2TL84BlueStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl24(),
                'R2TL84BlueStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl25(),
                'R2TL84BlueStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl26(),
                'R2TL84BlueStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl27(),
                'R2TL84BlueStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl28(),
                'R2TL84BlueStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl29(),
                'R2TL84BlueStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl02(),
                'R2TL84BlueStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl30(),
                'R2TL84BlueStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl31(),
                'R2TL84BlueStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl03(),
                'R2TL84BlueStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl04(),
                'R2TL84BlueStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl05(),
                'R2TL84BlueStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl06(),
                'R2TL84BlueStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl07(),
                'R2TL84BlueStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl08(),
                'R2TL84BlueStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl09(),
                'R2TL84Cx' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Cx(),
                'R2TL84Cy' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Cy(),
                'R2TL84GreenCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl00(),
                'R2TL84GreenCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl10(),
                'R2TL84GreenCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl11(),
                'R2TL84GreenCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl12(),
                'R2TL84GreenCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl13(),
                'R2TL84GreenCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl14(),
                'R2TL84GreenCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl15(),
                'R2TL84GreenCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl16(),
                'R2TL84GreenCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl17(),
                'R2TL84GreenCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl18(),
                'R2TL84GreenCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl19(),
                'R2TL84GreenCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl01(),
                'R2TL84GreenCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl20(),
                'R2TL84GreenCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl21(),
                'R2TL84GreenCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl22(),
                'R2TL84GreenCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl23(),
                'R2TL84GreenCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl24(),
                'R2TL84GreenCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl25(),
                'R2TL84GreenCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl26(),
                'R2TL84GreenCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl27(),
                'R2TL84GreenCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl28(),
                'R2TL84GreenCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl29(),
                'R2TL84GreenCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl02(),
                'R2TL84GreenCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl30(),
                'R2TL84GreenCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl31(),
                'R2TL84GreenCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl03(),
                'R2TL84GreenCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl04(),
                'R2TL84GreenCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl05(),
                'R2TL84GreenCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl06(),
                'R2TL84GreenCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl07(),
                'R2TL84GreenCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl08(),
                'R2TL84GreenCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl09(),
                'R2TL84GreenStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl00(),
                'R2TL84GreenStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl10(),
                'R2TL84GreenStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl11(),
                'R2TL84GreenStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl12(),
                'R2TL84GreenStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl13(),
                'R2TL84GreenStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl14(),
                'R2TL84GreenStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl15(),
                'R2TL84GreenStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl16(),
                'R2TL84GreenStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl17(),
                'R2TL84GreenStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl18(),
                'R2TL84GreenStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl19(),
                'R2TL84GreenStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl01(),
                'R2TL84GreenStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl20(),
                'R2TL84GreenStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl21(),
                'R2TL84GreenStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl22(),
                'R2TL84GreenStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl23(),
                'R2TL84GreenStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl24(),
                'R2TL84GreenStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl25(),
                'R2TL84GreenStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl26(),
                'R2TL84GreenStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl27(),
                'R2TL84GreenStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl28(),
                'R2TL84GreenStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl29(),
                'R2TL84GreenStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl02(),
                'R2TL84GreenStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl30(),
                'R2TL84GreenStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl31(),
                'R2TL84GreenStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl03(),
                'R2TL84GreenStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl04(),
                'R2TL84GreenStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl05(),
                'R2TL84GreenStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl06(),
                'R2TL84GreenStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl07(),
                'R2TL84GreenStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl08(),
                'R2TL84GreenStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl09(),
                'R2TL84Height' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Height(),
                'R2TL84Intervals' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Intervals(),
                'R2TL84RedCtbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl00(),
                'R2TL84RedCtbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl10(),
                'R2TL84RedCtbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl11(),
                'R2TL84RedCtbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl12(),
                'R2TL84RedCtbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl13(),
                'R2TL84RedCtbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl14(),
                'R2TL84RedCtbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl15(),
                'R2TL84RedCtbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl16(),
                'R2TL84RedCtbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl17(),
                'R2TL84RedCtbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl18(),
                'R2TL84RedCtbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl19(),
                'R2TL84RedCtbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl01(),
                'R2TL84RedCtbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl20(),
                'R2TL84RedCtbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl21(),
                'R2TL84RedCtbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl22(),
                'R2TL84RedCtbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl23(),
                'R2TL84RedCtbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl24(),
                'R2TL84RedCtbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl25(),
                'R2TL84RedCtbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl26(),
                'R2TL84RedCtbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl27(),
                'R2TL84RedCtbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl28(),
                'R2TL84RedCtbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl29(),
                'R2TL84RedCtbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl02(),
                'R2TL84RedCtbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl30(),
                'R2TL84RedCtbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl31(),
                'R2TL84RedCtbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl03(),
                'R2TL84RedCtbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl04(),
                'R2TL84RedCtbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl05(),
                'R2TL84RedCtbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl06(),
                'R2TL84RedCtbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl07(),
                'R2TL84RedCtbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl08(),
                'R2TL84RedCtbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl09(),
                'R2TL84RedStbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl00(),
                'R2TL84RedStbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl10(),
                'R2TL84RedStbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl11(),
                'R2TL84RedStbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl12(),
                'R2TL84RedStbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl13(),
                'R2TL84RedStbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl14(),
                'R2TL84RedStbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl15(),
                'R2TL84RedStbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl16(),
                'R2TL84RedStbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl17(),
                'R2TL84RedStbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl18(),
                'R2TL84RedStbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl19(),
                'R2TL84RedStbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl01(),
                'R2TL84RedStbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl20(),
                'R2TL84RedStbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl21(),
                'R2TL84RedStbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl22(),
                'R2TL84RedStbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl23(),
                'R2TL84RedStbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl24(),
                'R2TL84RedStbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl25(),
                'R2TL84RedStbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl26(),
                'R2TL84RedStbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl27(),
                'R2TL84RedStbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl28(),
                'R2TL84RedStbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl29(),
                'R2TL84RedStbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl02(),
                'R2TL84RedStbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl30(),
                'R2TL84RedStbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl31(),
                'R2TL84RedStbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl03(),
                'R2TL84RedStbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl04(),
                'R2TL84RedStbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl05(),
                'R2TL84RedStbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl06(),
                'R2TL84RedStbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl07(),
                'R2TL84RedStbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl08(),
                'R2TL84RedStbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl09(),
                'R2TL84Tbl00' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl00(),
                'R2TL84Tbl10' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl10(),
                'R2TL84Tbl11' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl11(),
                'R2TL84Tbl12' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl12(),
                'R2TL84Tbl13' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl13(),
                'R2TL84Tbl14' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl14(),
                'R2TL84Tbl15' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl15(),
                'R2TL84Tbl16' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl16(),
                'R2TL84Tbl17' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl17(),
                'R2TL84Tbl18' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl18(),
                'R2TL84Tbl19' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl19(),
                'R2TL84Tbl01' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl01(),
                'R2TL84Tbl20' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl20(),
                'R2TL84Tbl21' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl21(),
                'R2TL84Tbl22' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl22(),
                'R2TL84Tbl23' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl23(),
                'R2TL84Tbl24' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl24(),
                'R2TL84Tbl25' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl25(),
                'R2TL84Tbl26' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl26(),
                'R2TL84Tbl27' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl27(),
                'R2TL84Tbl28' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl28(),
                'R2TL84Tbl29' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl29(),
                'R2TL84Tbl02' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl02(),
                'R2TL84Tbl30' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl30(),
                'R2TL84Tbl31' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl31(),
                'R2TL84Tbl03' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl03(),
                'R2TL84Tbl04' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl04(),
                'R2TL84Tbl05' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl05(),
                'R2TL84Tbl06' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl06(),
                'R2TL84Tbl07' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl07(),
                'R2TL84Tbl08' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl08(),
                'R2TL84Tbl09' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl09(),
                'R2TL84Width' => new \PHPExiftool\Driver\Tag\Qualcomm\R2TL84Width(),
                'RolloffEnable' => new \PHPExiftool\Driver\Tag\Qualcomm\RolloffEnable(),
                'SensorFmt' => new \PHPExiftool\Driver\Tag\Qualcomm\SensorFmt(),
                'SensorType' => new \PHPExiftool\Driver\Tag\Qualcomm\SensorType(),
                'SensrFulHght' => new \PHPExiftool\Driver\Tag\Qualcomm\SensrFulHght(),
                'SensrFulWdth' => new \PHPExiftool\Driver\Tag\Qualcomm\SensrFulWdth(),
                'SensrQtrHght' => new \PHPExiftool\Driver\Tag\Qualcomm\SensrQtrHght(),
                'SensrQtrWdth' => new \PHPExiftool\Driver\Tag\Qualcomm\SensrQtrWdth(),
                'SnapshotResol' => new \PHPExiftool\Driver\Tag\Qualcomm\SnapshotResol(),
                'TL84ConvChrmA_M' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmAM(),
                'TL84ConvChrmA_P' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmAP(),
                'TL84ConvChrmB_M' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmBM(),
                'TL84ConvChrmB_P' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmBP(),
                'TL84ConvChrmC_M' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmCM(),
                'TL84ConvChrmC_P' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmCP(),
                'TL84ConvChrmD_M' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmDM(),
                'TL84ConvChrmD_P' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmDP(),
                'TL84ConvChrmKCb' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmKCb(),
                'TL84ConvChrmKCr' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmKCr(),
                'TL84ConvLumaK' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvLumaK(),
                'TL84ConvLumaV0' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvLumaV0(),
                'TL84ConvLumaV1' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvLumaV1(),
                'TL84ConvLumaV2' => new \PHPExiftool\Driver\Tag\Qualcomm\TL84ConvLumaV2(),
                'VideoFps' => new \PHPExiftool\Driver\Tag\Qualcomm\VideoFps(),
                'YhiYloConvChrmA_M' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmAM(),
                'YhiYloConvChrmA_P' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmAP(),
                'YhiYloConvChrmB_M' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmBM(),
                'YhiYloConvChrmB_P' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmBP(),
                'YhiYloConvChrmC_M' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmCM(),
                'YhiYloConvChrmC_P' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmCP(),
                'YhiYloConvChrmD_M' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmDM(),
                'YhiYloConvChrmD_P' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmDP(),
                'YhiYloConvChrmKCb' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmKCb(),
                'YhiYloConvChrmKCr' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmKCr(),
                'YhiYloConvLumaK' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvLumaK(),
                'YhiYloConvLumaV0' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvLumaV0(),
                'YhiYloConvLumaV1' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvLumaV1(),
                'YhiYloConvLumaV2' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvLumaV2(),
                'YhiYloCorC0' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC0(),
                'YhiYloCorC1' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC1(),
                'YhiYloCorC2' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC2(),
                'YhiYloCorC3' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC3(),
                'YhiYloCorC4' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC4(),
                'YhiYloCorC5' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC5(),
                'YhiYloCorC6' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC6(),
                'YhiYloCorC7' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC7(),
                'YhiYloCorC8' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC8(),
                'YhiYloCorK0' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorK0(),
                'YhiYloCorK1' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorK1(),
                'YhiYloCorK2' => new \PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorK2(),
            );
        });
        $this['QuickTime'] = $this->share(function(){
            return array(
                'Balance' => new \PHPExiftool\Driver\Tag\QuickTime\Balance(),
                'AudioProfileVersion' => new \PHPExiftool\Driver\Tag\QuickTime\AudioProfileVersion(),
                'AudioTrackID' => new \PHPExiftool\Driver\Tag\QuickTime\AudioTrackID(),
                'AudioCodec' => new \PHPExiftool\Driver\Tag\QuickTime\AudioCodec(),
                'AudioCodecInfo' => new \PHPExiftool\Driver\Tag\QuickTime\AudioCodecInfo(),
                'AudioAttributes' => new \PHPExiftool\Driver\Tag\QuickTime\AudioAttributes(),
                'AudioAvgBitrate' => new \PHPExiftool\Driver\Tag\QuickTime\AudioAvgBitrate(),
                'AudioMaxBitrate' => new \PHPExiftool\Driver\Tag\QuickTime\AudioMaxBitrate(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\QuickTime\AudioSampleRate(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\QuickTime\AudioChannels(),
                'AudioFormat' => new \PHPExiftool\Driver\Tag\QuickTime\AudioFormat(),
                'AudioVendorID' => new \PHPExiftool\Driver\Tag\QuickTime\AudioVendorID(),
                'AudioBitsPerSample' => new \PHPExiftool\Driver\Tag\QuickTime\AudioBitsPerSample(),
                'Compression' => new \PHPExiftool\Driver\Tag\QuickTime\Compression(),
                'URL' => new \PHPExiftool\Driver\Tag\QuickTime\URL(),
                'URN' => new \PHPExiftool\Driver\Tag\QuickTime\URN(),
                'FileProfileVersion' => new \PHPExiftool\Driver\Tag\QuickTime\FileProfileVersion(),
                'FileFunctionFlags' => new \PHPExiftool\Driver\Tag\QuickTime\FileFunctionFlags(),
                'MajorBrand' => new \PHPExiftool\Driver\Tag\QuickTime\MajorBrand(),
                'MinorVersion' => new \PHPExiftool\Driver\Tag\QuickTime\MinorVersion(),
                'CompatibleBrands' => new \PHPExiftool\Driver\Tag\QuickTime\CompatibleBrands(),
                'Text' => new \PHPExiftool\Driver\Tag\QuickTime\Text(),
                'GenMediaVersion' => new \PHPExiftool\Driver\Tag\QuickTime\GenMediaVersion(),
                'GenFlags' => new \PHPExiftool\Driver\Tag\QuickTime\GenFlags(),
                'GenGraphicsMode' => new \PHPExiftool\Driver\Tag\QuickTime\GenGraphicsMode(),
                'GenOpColor' => new \PHPExiftool\Driver\Tag\QuickTime\GenOpColor(),
                'GenBalance' => new \PHPExiftool\Driver\Tag\QuickTime\GenBalance(),
                'HandlerClass' => new \PHPExiftool\Driver\Tag\QuickTime\HandlerClass(),
                'HandlerType' => new \PHPExiftool\Driver\Tag\QuickTime\HandlerType(),
                'HandlerVendorID' => new \PHPExiftool\Driver\Tag\QuickTime\HandlerVendorID(),
                'HandlerDescription' => new \PHPExiftool\Driver\Tag\QuickTime\HandlerDescription(),
                'MaxPDUSize' => new \PHPExiftool\Driver\Tag\QuickTime\MaxPDUSize(),
                'AvgPDUSize' => new \PHPExiftool\Driver\Tag\QuickTime\AvgPDUSize(),
                'MaxBitrate' => new \PHPExiftool\Driver\Tag\QuickTime\MaxBitrate(),
                'AvgBitrate' => new \PHPExiftool\Driver\Tag\QuickTime\AvgBitrate(),
                'RealtimeStreamingProtocol' => new \PHPExiftool\Driver\Tag\QuickTime\RealtimeStreamingProtocol(),
                'StreamingDataProtocol' => new \PHPExiftool\Driver\Tag\QuickTime\StreamingDataProtocol(),
                'HintFormat' => new \PHPExiftool\Driver\Tag\QuickTime\HintFormat(),
                'ImmediateDataBytes' => new \PHPExiftool\Driver\Tag\QuickTime\ImmediateDataBytes(),
                'LargestPacketDuration' => new \PHPExiftool\Driver\Tag\QuickTime\LargestPacketDuration(),
                'MediaTrackBytes' => new \PHPExiftool\Driver\Tag\QuickTime\MediaTrackBytes(),
                'RepeatedDataBytes' => new \PHPExiftool\Driver\Tag\QuickTime\RepeatedDataBytes(),
                'MaxDataRate' => new \PHPExiftool\Driver\Tag\QuickTime\MaxDataRate(),
                'NumPackets' => new \PHPExiftool\Driver\Tag\QuickTime\NumPackets(),
                'PayloadType' => new \PHPExiftool\Driver\Tag\QuickTime\PayloadType(),
                'LargestPacketSize' => new \PHPExiftool\Driver\Tag\QuickTime\LargestPacketSize(),
                'MaxTransmissionTime' => new \PHPExiftool\Driver\Tag\QuickTime\MaxTransmissionTime(),
                'MinTransmissionTime' => new \PHPExiftool\Driver\Tag\QuickTime\MinTransmissionTime(),
                'TotalBytes' => new \PHPExiftool\Driver\Tag\QuickTime\TotalBytes(),
                'TotalBytesNoRTPHeaders' => new \PHPExiftool\Driver\Tag\QuickTime\TotalBytesNoRTPHeaders(),
                'CompressorID' => new \PHPExiftool\Driver\Tag\QuickTime\CompressorID(),
                'VendorID' => new \PHPExiftool\Driver\Tag\QuickTime\VendorID(),
                'SourceImageWidth' => new \PHPExiftool\Driver\Tag\QuickTime\SourceImageWidth(),
                'SourceImageHeight' => new \PHPExiftool\Driver\Tag\QuickTime\SourceImageHeight(),
                'XResolution' => new \PHPExiftool\Driver\Tag\QuickTime\XResolution(),
                'YResolution' => new \PHPExiftool\Driver\Tag\QuickTime\YResolution(),
                'CompressorName' => new \PHPExiftool\Driver\Tag\QuickTime\CompressorName(),
                'BitDepth' => new \PHPExiftool\Driver\Tag\QuickTime\BitDepth(),
                'ImageData' => new \PHPExiftool\Driver\Tag\QuickTime\ImageData(),
                'AlbumArtist' => new \PHPExiftool\Driver\Tag\QuickTime\AlbumArtist(),
                'AppleStoreAccountType' => new \PHPExiftool\Driver\Tag\QuickTime\AppleStoreAccountType(),
                'Album' => new \PHPExiftool\Driver\Tag\QuickTime\Album(),
                'AppleStoreAccount' => new \PHPExiftool\Driver\Tag\QuickTime\AppleStoreAccount(),
                'AlbumTitleID' => new \PHPExiftool\Driver\Tag\QuickTime\AlbumTitleID(),
                'Author' => new \PHPExiftool\Driver\Tag\QuickTime\Author(),
                'Category' => new \PHPExiftool\Driver\Tag\QuickTime\Category(),
                'AppleStoreCatalogID' => new \PHPExiftool\Driver\Tag\QuickTime\AppleStoreCatalogID(),
                'CoverArt' => new \PHPExiftool\Driver\Tag\QuickTime\CoverArt(),
                'Compilation' => new \PHPExiftool\Driver\Tag\QuickTime\Compilation(),
                'Copyright' => new \PHPExiftool\Driver\Tag\QuickTime\Copyright(),
                'Description' => new \PHPExiftool\Driver\Tag\QuickTime\Description(),
                'DiskNumber' => new \PHPExiftool\Driver\Tag\QuickTime\DiskNumber(),
                'EpisodeGlobalUniqueID' => new \PHPExiftool\Driver\Tag\QuickTime\EpisodeGlobalUniqueID(),
                'GenreID' => new \PHPExiftool\Driver\Tag\QuickTime\GenreID(),
                'Genre' => new \PHPExiftool\Driver\Tag\QuickTime\Genre(),
                'Grouping' => new \PHPExiftool\Driver\Tag\QuickTime\Grouping(),
                'HDVideo' => new \PHPExiftool\Driver\Tag\QuickTime\HDVideo(),
                'iTunesU' => new \PHPExiftool\Driver\Tag\QuickTime\ITunesU(),
                'Keyword' => new \PHPExiftool\Driver\Tag\QuickTime\Keyword(),
                'LongDescription' => new \PHPExiftool\Driver\Tag\QuickTime\LongDescription(),
                'Podcast' => new \PHPExiftool\Driver\Tag\QuickTime\Podcast(),
                'Performer' => new \PHPExiftool\Driver\Tag\QuickTime\Performer(),
                'PlayGap' => new \PHPExiftool\Driver\Tag\QuickTime\PlayGap(),
                'PlayListID' => new \PHPExiftool\Driver\Tag\QuickTime\PlayListID(),
                'PurchaseDate' => new \PHPExiftool\Driver\Tag\QuickTime\PurchaseDate(),
                'PodcastURL' => new \PHPExiftool\Driver\Tag\QuickTime\PodcastURL(),
                'Rating' => new \PHPExiftool\Driver\Tag\QuickTime\Rating(),
                'AppleStoreCountry' => new \PHPExiftool\Driver\Tag\QuickTime\AppleStoreCountry(),
                'SortAlbumArtist' => new \PHPExiftool\Driver\Tag\QuickTime\SortAlbumArtist(),
                'SortAlbum' => new \PHPExiftool\Driver\Tag\QuickTime\SortAlbum(),
                'SortArtist' => new \PHPExiftool\Driver\Tag\QuickTime\SortArtist(),
                'SortComposer' => new \PHPExiftool\Driver\Tag\QuickTime\SortComposer(),
                'SortName' => new \PHPExiftool\Driver\Tag\QuickTime\SortName(),
                'SortShow' => new \PHPExiftool\Driver\Tag\QuickTime\SortShow(),
                'MediaType' => new \PHPExiftool\Driver\Tag\QuickTime\MediaType(),
                'Title' => new \PHPExiftool\Driver\Tag\QuickTime\Title(),
                'BeatsPerMinute' => new \PHPExiftool\Driver\Tag\QuickTime\BeatsPerMinute(),
                'TrackNumber' => new \PHPExiftool\Driver\Tag\QuickTime\TrackNumber(),
                'TVEpisodeID' => new \PHPExiftool\Driver\Tag\QuickTime\TVEpisodeID(),
                'TVEpisode' => new \PHPExiftool\Driver\Tag\QuickTime\TVEpisode(),
                'TVNetworkName' => new \PHPExiftool\Driver\Tag\QuickTime\TVNetworkName(),
                'TVShow' => new \PHPExiftool\Driver\Tag\QuickTime\TVShow(),
                'TVSeason' => new \PHPExiftool\Driver\Tag\QuickTime\TVSeason(),
                'Year' => new \PHPExiftool\Driver\Tag\QuickTime\Year(),
                'Artist' => new \PHPExiftool\Driver\Tag\QuickTime\Artist(),
                'Comment' => new \PHPExiftool\Driver\Tag\QuickTime\Comment(),
                'Composer' => new \PHPExiftool\Driver\Tag\QuickTime\Composer(),
                'EncodedBy' => new \PHPExiftool\Driver\Tag\QuickTime\EncodedBy(),
                'Lyrics' => new \PHPExiftool\Driver\Tag\QuickTime\Lyrics(),
                'Encoder' => new \PHPExiftool\Driver\Tag\QuickTime\Encoder(),
                'Track' => new \PHPExiftool\Driver\Tag\QuickTime\Track(),
                'EncodedWith' => new \PHPExiftool\Driver\Tag\QuickTime\EncodedWith(),
                'Artwork' => new \PHPExiftool\Driver\Tag\QuickTime\Artwork(),
                'FrameReadoutTime' => new \PHPExiftool\Driver\Tag\QuickTime\FrameReadoutTime(),
                'CameraIdentifier' => new \PHPExiftool\Driver\Tag\QuickTime\CameraIdentifier(),
                'CreationDate' => new \PHPExiftool\Driver\Tag\QuickTime\CreationDate(),
                'CameraDirection' => new \PHPExiftool\Driver\Tag\QuickTime\CameraDirection(),
                'CameraMotion' => new \PHPExiftool\Driver\Tag\QuickTime\CameraMotion(),
                'Director' => new \PHPExiftool\Driver\Tag\QuickTime\Director(),
                'Information' => new \PHPExiftool\Driver\Tag\QuickTime\Information(),
                'Keywords' => new \PHPExiftool\Driver\Tag\QuickTime\Keywords(),
                'GPSCoordinates' => new \PHPExiftool\Driver\Tag\QuickTime\GPSCoordinates(),
                'LocationBody' => new \PHPExiftool\Driver\Tag\QuickTime\LocationBody(),
                'LocationDate' => new \PHPExiftool\Driver\Tag\QuickTime\LocationDate(),
                'LocationName' => new \PHPExiftool\Driver\Tag\QuickTime\LocationName(),
                'LocationNote' => new \PHPExiftool\Driver\Tag\QuickTime\LocationNote(),
                'LocationRole' => new \PHPExiftool\Driver\Tag\QuickTime\LocationRole(),
                'Make' => new \PHPExiftool\Driver\Tag\QuickTime\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\QuickTime\Model(),
                'Bass' => new \PHPExiftool\Driver\Tag\QuickTime\Bass(),
                'AudioGain' => new \PHPExiftool\Driver\Tag\QuickTime\AudioGain(),
                'Mute' => new \PHPExiftool\Driver\Tag\QuickTime\Mute(),
                'PitchShift' => new \PHPExiftool\Driver\Tag\QuickTime\PitchShift(),
                'Trebel' => new \PHPExiftool\Driver\Tag\QuickTime\Trebel(),
                'Brightness' => new \PHPExiftool\Driver\Tag\QuickTime\Brightness(),
                'Color' => new \PHPExiftool\Driver\Tag\QuickTime\Color(),
                'Contrast' => new \PHPExiftool\Driver\Tag\QuickTime\Contrast(),
                'Tint' => new \PHPExiftool\Driver\Tag\QuickTime\Tint(),
                'PlayerVersion' => new \PHPExiftool\Driver\Tag\QuickTime\PlayerVersion(),
                'Publisher' => new \PHPExiftool\Driver\Tag\QuickTime\Publisher(),
                'UserRating' => new \PHPExiftool\Driver\Tag\QuickTime\UserRating(),
                'Software' => new \PHPExiftool\Driver\Tag\QuickTime\Software(),
                'Version' => new \PHPExiftool\Driver\Tag\QuickTime\Version(),
                'PreviewPICT' => new \PHPExiftool\Driver\Tag\QuickTime\PreviewPICT(),
                'Free' => new \PHPExiftool\Driver\Tag\QuickTime\Free(),
                'Junk' => new \PHPExiftool\Driver\Tag\QuickTime\Junk(),
                'MovieData' => new \PHPExiftool\Driver\Tag\QuickTime\MovieData(),
                'MovieDataSize' => new \PHPExiftool\Driver\Tag\QuickTime\MovieDataSize(),
                'Skip' => new \PHPExiftool\Driver\Tag\QuickTime\Skip(),
                'UUID-Unknown' => new \PHPExiftool\Driver\Tag\QuickTime\UUIDUnknown(),
                'Wide' => new \PHPExiftool\Driver\Tag\QuickTime\Wide(),
                'MediaHeaderVersion' => new \PHPExiftool\Driver\Tag\QuickTime\MediaHeaderVersion(),
                'MediaCreateDate' => new \PHPExiftool\Driver\Tag\QuickTime\MediaCreateDate(),
                'MediaModifyDate' => new \PHPExiftool\Driver\Tag\QuickTime\MediaModifyDate(),
                'MediaTimeScale' => new \PHPExiftool\Driver\Tag\QuickTime\MediaTimeScale(),
                'MediaDuration' => new \PHPExiftool\Driver\Tag\QuickTime\MediaDuration(),
                'MediaLanguageCode' => new \PHPExiftool\Driver\Tag\QuickTime\MediaLanguageCode(),
                'NullMediaHeader' => new \PHPExiftool\Driver\Tag\QuickTime\NullMediaHeader(),
                'BinaryXML' => new \PHPExiftool\Driver\Tag\QuickTime\BinaryXML(),
                'DataInformation' => new \PHPExiftool\Driver\Tag\QuickTime\DataInformation(),
                'ItemInformation' => new \PHPExiftool\Driver\Tag\QuickTime\ItemInformation(),
                'ItemLocation' => new \PHPExiftool\Driver\Tag\QuickTime\ItemLocation(),
                'IPMPControl' => new \PHPExiftool\Driver\Tag\QuickTime\IPMPControl(),
                'ItemProtection' => new \PHPExiftool\Driver\Tag\QuickTime\ItemProtection(),
                'PrimaryItemReference' => new \PHPExiftool\Driver\Tag\QuickTime\PrimaryItemReference(),
                'ProductionDate' => new \PHPExiftool\Driver\Tag\QuickTime\ProductionDate(),
                'Product' => new \PHPExiftool\Driver\Tag\QuickTime\Product(),
                'TrackProperty' => new \PHPExiftool\Driver\Tag\QuickTime\TrackProperty(),
                'TimeZone' => new \PHPExiftool\Driver\Tag\QuickTime\TimeZone(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\QuickTime\ModifyDate(),
                'InitialObjectDescriptor' => new \PHPExiftool\Driver\Tag\QuickTime\InitialObjectDescriptor(),
                'MovieHeaderVersion' => new \PHPExiftool\Driver\Tag\QuickTime\MovieHeaderVersion(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\QuickTime\CreateDate(),
                'TimeScale' => new \PHPExiftool\Driver\Tag\QuickTime\TimeScale(),
                'Duration' => new \PHPExiftool\Driver\Tag\QuickTime\Duration(),
                'PreferredRate' => new \PHPExiftool\Driver\Tag\QuickTime\PreferredRate(),
                'PreferredVolume' => new \PHPExiftool\Driver\Tag\QuickTime\PreferredVolume(),
                'MatrixStructure' => new \PHPExiftool\Driver\Tag\QuickTime\MatrixStructure(),
                'PreviewTime' => new \PHPExiftool\Driver\Tag\QuickTime\PreviewTime(),
                'PreviewDuration' => new \PHPExiftool\Driver\Tag\QuickTime\PreviewDuration(),
                'PosterTime' => new \PHPExiftool\Driver\Tag\QuickTime\PosterTime(),
                'SelectionTime' => new \PHPExiftool\Driver\Tag\QuickTime\SelectionTime(),
                'SelectionDuration' => new \PHPExiftool\Driver\Tag\QuickTime\SelectionDuration(),
                'CurrentTime' => new \PHPExiftool\Driver\Tag\QuickTime\CurrentTime(),
                'NextTrackID' => new \PHPExiftool\Driver\Tag\QuickTime\NextTrackID(),
                'OtherFormat' => new \PHPExiftool\Driver\Tag\QuickTime\OtherFormat(),
                'PreviewDate' => new \PHPExiftool\Driver\Tag\QuickTime\PreviewDate(),
                'PreviewVersion' => new \PHPExiftool\Driver\Tag\QuickTime\PreviewVersion(),
                'PreviewAtomType' => new \PHPExiftool\Driver\Tag\QuickTime\PreviewAtomType(),
                'PreviewAtomIndex' => new \PHPExiftool\Driver\Tag\QuickTime\PreviewAtomIndex(),
                'ChunkOffset64' => new \PHPExiftool\Driver\Tag\QuickTime\ChunkOffset64(),
                'CompositionToDecodeTimelineMapping' => new \PHPExiftool\Driver\Tag\QuickTime\CompositionToDecodeTimelineMapping(),
                'CompositionTimeToSample' => new \PHPExiftool\Driver\Tag\QuickTime\CompositionTimeToSample(),
                'SamplePaddingBits' => new \PHPExiftool\Driver\Tag\QuickTime\SamplePaddingBits(),
                'SampleToGroup' => new \PHPExiftool\Driver\Tag\QuickTime\SampleToGroup(),
                'IdependentAndDisposableSamples' => new \PHPExiftool\Driver\Tag\QuickTime\IdependentAndDisposableSamples(),
                'SampleGroupDescription' => new \PHPExiftool\Driver\Tag\QuickTime\SampleGroupDescription(),
                'ChunkOffset' => new \PHPExiftool\Driver\Tag\QuickTime\ChunkOffset(),
                'SampleDegradationPriority' => new \PHPExiftool\Driver\Tag\QuickTime\SampleDegradationPriority(),
                'SampleToChunk' => new \PHPExiftool\Driver\Tag\QuickTime\SampleToChunk(),
                'ShadowSyncSampleTable' => new \PHPExiftool\Driver\Tag\QuickTime\ShadowSyncSampleTable(),
                'SyncSampleTable' => new \PHPExiftool\Driver\Tag\QuickTime\SyncSampleTable(),
                'SampleSizes' => new \PHPExiftool\Driver\Tag\QuickTime\SampleSizes(),
                'VideoFrameRate' => new \PHPExiftool\Driver\Tag\QuickTime\VideoFrameRate(),
                'TimeToSampleTable' => new \PHPExiftool\Driver\Tag\QuickTime\TimeToSampleTable(),
                'CompactSampleSizes' => new \PHPExiftool\Driver\Tag\QuickTime\CompactSampleSizes(),
                'Sub-sampleInformation' => new \PHPExiftool\Driver\Tag\QuickTime\SubSampleInformation(),
                'TextFont' => new \PHPExiftool\Driver\Tag\QuickTime\TextFont(),
                'TextFace' => new \PHPExiftool\Driver\Tag\QuickTime\TextFace(),
                'TextSize' => new \PHPExiftool\Driver\Tag\QuickTime\TextSize(),
                'TextColor' => new \PHPExiftool\Driver\Tag\QuickTime\TextColor(),
                'BackgroundColor' => new \PHPExiftool\Driver\Tag\QuickTime\BackgroundColor(),
                'FontName' => new \PHPExiftool\Driver\Tag\QuickTime\FontName(),
                'CleanApertureDimensions' => new \PHPExiftool\Driver\Tag\QuickTime\CleanApertureDimensions(),
                'EncodedPixelsDimensions' => new \PHPExiftool\Driver\Tag\QuickTime\EncodedPixelsDimensions(),
                'ProductionApertureDimensions' => new \PHPExiftool\Driver\Tag\QuickTime\ProductionApertureDimensions(),
                'ChapterList' => new \PHPExiftool\Driver\Tag\QuickTime\ChapterList(),
                'TimeCode' => new \PHPExiftool\Driver\Tag\QuickTime\TimeCode(),
                'PlayAllFrames' => new \PHPExiftool\Driver\Tag\QuickTime\PlayAllFrames(),
                'CompressorVersion' => new \PHPExiftool\Driver\Tag\QuickTime\CompressorVersion(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\QuickTime\FirmwareVersion(),
                'LoopStyle' => new \PHPExiftool\Driver\Tag\QuickTime\LoopStyle(),
                'PlayMode' => new \PHPExiftool\Driver\Tag\QuickTime\PlayMode(),
                'PlaySelection' => new \PHPExiftool\Driver\Tag\QuickTime\PlaySelection(),
                'UnknownTags' => new \PHPExiftool\Driver\Tag\QuickTime\UnknownTags(),
                'WindowLocation' => new \PHPExiftool\Driver\Tag\QuickTime\WindowLocation(),
                'HintVersion' => new \PHPExiftool\Driver\Tag\QuickTime\HintVersion(),
                'Name' => new \PHPExiftool\Driver\Tag\QuickTime\Name(),
                'Vendor' => new \PHPExiftool\Driver\Tag\QuickTime\Vendor(),
                'Arranger' => new \PHPExiftool\Driver\Tag\QuickTime\Arranger(),
                'ArrangerKeywords' => new \PHPExiftool\Driver\Tag\QuickTime\ArrangerKeywords(),
                'ComposerKeywords' => new \PHPExiftool\Driver\Tag\QuickTime\ComposerKeywords(),
                'Edit1' => new \PHPExiftool\Driver\Tag\QuickTime\Edit1(),
                'Edit2' => new \PHPExiftool\Driver\Tag\QuickTime\Edit2(),
                'Edit3' => new \PHPExiftool\Driver\Tag\QuickTime\Edit3(),
                'Edit4' => new \PHPExiftool\Driver\Tag\QuickTime\Edit4(),
                'Edit5' => new \PHPExiftool\Driver\Tag\QuickTime\Edit5(),
                'Edit6' => new \PHPExiftool\Driver\Tag\QuickTime\Edit6(),
                'Edit7' => new \PHPExiftool\Driver\Tag\QuickTime\Edit7(),
                'Edit8' => new \PHPExiftool\Driver\Tag\QuickTime\Edit8(),
                'Edit9' => new \PHPExiftool\Driver\Tag\QuickTime\Edit9(),
                'Format' => new \PHPExiftool\Driver\Tag\QuickTime\Format(),
                'ISRCCode' => new \PHPExiftool\Driver\Tag\QuickTime\ISRCCode(),
                'RecordLabelName' => new \PHPExiftool\Driver\Tag\QuickTime\RecordLabelName(),
                'RecordLabelURL' => new \PHPExiftool\Driver\Tag\QuickTime\RecordLabelURL(),
                'MakerURL' => new \PHPExiftool\Driver\Tag\QuickTime\MakerURL(),
                'ProducerKeywords' => new \PHPExiftool\Driver\Tag\QuickTime\ProducerKeywords(),
                'RecordingCopyright' => new \PHPExiftool\Driver\Tag\QuickTime\RecordingCopyright(),
                'Producer' => new \PHPExiftool\Driver\Tag\QuickTime\Producer(),
                'Performers' => new \PHPExiftool\Driver\Tag\QuickTime\Performers(),
                'PerformerKeywords' => new \PHPExiftool\Driver\Tag\QuickTime\PerformerKeywords(),
                'PerformerURL' => new \PHPExiftool\Driver\Tag\QuickTime\PerformerURL(),
                'Requirements' => new \PHPExiftool\Driver\Tag\QuickTime\Requirements(),
                'SubtitleKeywords' => new \PHPExiftool\Driver\Tag\QuickTime\SubtitleKeywords(),
                'Subtitle' => new \PHPExiftool\Driver\Tag\QuickTime\Subtitle(),
                'SourceCredits' => new \PHPExiftool\Driver\Tag\QuickTime\SourceCredits(),
                'SongWriter' => new \PHPExiftool\Driver\Tag\QuickTime\SongWriter(),
                'SongWriterKeywords' => new \PHPExiftool\Driver\Tag\QuickTime\SongWriterKeywords(),
                'SoftwareVersion' => new \PHPExiftool\Driver\Tag\QuickTime\SoftwareVersion(),
                'DisplaySize' => new \PHPExiftool\Driver\Tag\QuickTime\DisplaySize(),
                'SlideShow' => new \PHPExiftool\Driver\Tag\QuickTime\SlideShow(),
                'GraphicsMode' => new \PHPExiftool\Driver\Tag\QuickTime\GraphicsMode(),
                'OpColor' => new \PHPExiftool\Driver\Tag\QuickTime\OpColor(),
                'VideoProfileVersion' => new \PHPExiftool\Driver\Tag\QuickTime\VideoProfileVersion(),
                'VideoTrackID' => new \PHPExiftool\Driver\Tag\QuickTime\VideoTrackID(),
                'VideoCodec' => new \PHPExiftool\Driver\Tag\QuickTime\VideoCodec(),
                'VideoCodecInfo' => new \PHPExiftool\Driver\Tag\QuickTime\VideoCodecInfo(),
                'VideoAttributes' => new \PHPExiftool\Driver\Tag\QuickTime\VideoAttributes(),
                'VideoAvgBitrate' => new \PHPExiftool\Driver\Tag\QuickTime\VideoAvgBitrate(),
                'VideoMaxBitrate' => new \PHPExiftool\Driver\Tag\QuickTime\VideoMaxBitrate(),
                'VideoAvgFrameRate' => new \PHPExiftool\Driver\Tag\QuickTime\VideoAvgFrameRate(),
                'VideoMaxFrameRate' => new \PHPExiftool\Driver\Tag\QuickTime\VideoMaxFrameRate(),
                'VideoSize' => new \PHPExiftool\Driver\Tag\QuickTime\VideoSize(),
                'PixelAspectRatio' => new \PHPExiftool\Driver\Tag\QuickTime\PixelAspectRatio(),
                'Data' => new \PHPExiftool\Driver\Tag\QuickTime\Data(),
                'Mean' => new \PHPExiftool\Driver\Tag\QuickTime\Mean(),
            );
        });
        $this['MakerNotes'] = $this->share(function(){
            return array(
                'PreviewImageWidth' => new \PHPExiftool\Driver\Tag\MakerNotes\PreviewImageWidth(),
                'PreviewImageHeight' => new \PHPExiftool\Driver\Tag\MakerNotes\PreviewImageHeight(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\MakerNotes\PreviewImageLength(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\MakerNotes\SerialNumber(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\MakerNotes\PreviewImage(),
            );
        });
        $this['Track#'] = $this->share(function(){
            return array(
                'TrackHeaderVersion' => new \PHPExiftool\Driver\Tag\Track\TrackHeaderVersion(),
                'TrackCreateDate' => new \PHPExiftool\Driver\Tag\Track\TrackCreateDate(),
                'TrackModifyDate' => new \PHPExiftool\Driver\Tag\Track\TrackModifyDate(),
                'TrackID' => new \PHPExiftool\Driver\Tag\Track\TrackID(),
                'TrackDuration' => new \PHPExiftool\Driver\Tag\Track\TrackDuration(),
                'TrackLayer' => new \PHPExiftool\Driver\Tag\Track\TrackLayer(),
                'TrackVolume' => new \PHPExiftool\Driver\Tag\Track\TrackVolume(),
                'MatrixStructure' => new \PHPExiftool\Driver\Tag\Track\MatrixStructure(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\Track\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\Track\ImageHeight(),
            );
        });
        $this['RIFF'] = $this->share(function(){
            return array(
                'FrameRate' => new \PHPExiftool\Driver\Tag\RIFF\FrameRate(),
                'MaxDataRate' => new \PHPExiftool\Driver\Tag\RIFF\MaxDataRate(),
                'FrameCount' => new \PHPExiftool\Driver\Tag\RIFF\FrameCount(),
                'StreamCount' => new \PHPExiftool\Driver\Tag\RIFF\StreamCount(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\RIFF\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\RIFF\ImageHeight(),
                'Encoding' => new \PHPExiftool\Driver\Tag\RIFF\Encoding(),
                'NumChannels' => new \PHPExiftool\Driver\Tag\RIFF\NumChannels(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\RIFF\SampleRate(),
                'AvgBytesPerSec' => new \PHPExiftool\Driver\Tag\RIFF\AvgBytesPerSec(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\RIFF\BitsPerSample(),
                'Description' => new \PHPExiftool\Driver\Tag\RIFF\Description(),
                'Originator' => new \PHPExiftool\Driver\Tag\RIFF\Originator(),
                'OriginatorReference' => new \PHPExiftool\Driver\Tag\RIFF\OriginatorReference(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\RIFF\DateTimeOriginal(),
                'TimeReference' => new \PHPExiftool\Driver\Tag\RIFF\TimeReference(),
                'BWFVersion' => new \PHPExiftool\Driver\Tag\RIFF\BWFVersion(),
                'CodingHistory' => new \PHPExiftool\Driver\Tag\RIFF\CodingHistory(),
                'Make' => new \PHPExiftool\Driver\Tag\RIFF\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\RIFF\Model(),
                'MakerNotes' => new \PHPExiftool\Driver\Tag\RIFF\MakerNotes(),
                'RelatedImageFile' => new \PHPExiftool\Driver\Tag\RIFF\RelatedImageFile(),
                'TimeCreated' => new \PHPExiftool\Driver\Tag\RIFF\TimeCreated(),
                'UserComment' => new \PHPExiftool\Driver\Tag\RIFF\UserComment(),
                'ExifVersion' => new \PHPExiftool\Driver\Tag\RIFF\ExifVersion(),
                'TotalFrameCount' => new \PHPExiftool\Driver\Tag\RIFF\TotalFrameCount(),
                'Timecode' => new \PHPExiftool\Driver\Tag\RIFF\Timecode(),
                'Rated' => new \PHPExiftool\Driver\Tag\RIFF\Rated(),
                'Comment' => new \PHPExiftool\Driver\Tag\RIFF\Comment(),
                'EncodedBy' => new \PHPExiftool\Driver\Tag\RIFF\EncodedBy(),
                'Comments' => new \PHPExiftool\Driver\Tag\RIFF\Comments(),
                'Directory' => new \PHPExiftool\Driver\Tag\RIFF\Directory(),
                'SoundSchemeTitle' => new \PHPExiftool\Driver\Tag\RIFF\SoundSchemeTitle(),
                'Genre' => new \PHPExiftool\Driver\Tag\RIFF\Genre(),
                'ArchivalLocation' => new \PHPExiftool\Driver\Tag\RIFF\ArchivalLocation(),
                'Artist' => new \PHPExiftool\Driver\Tag\RIFF\Artist(),
                'FirstLanguage' => new \PHPExiftool\Driver\Tag\RIFF\FirstLanguage(),
                'SecondLanguage' => new \PHPExiftool\Driver\Tag\RIFF\SecondLanguage(),
                'ThirdLanguage' => new \PHPExiftool\Driver\Tag\RIFF\ThirdLanguage(),
                'FourthLanguage' => new \PHPExiftool\Driver\Tag\RIFF\FourthLanguage(),
                'FifthLanguage' => new \PHPExiftool\Driver\Tag\RIFF\FifthLanguage(),
                'SixthLanguage' => new \PHPExiftool\Driver\Tag\RIFF\SixthLanguage(),
                'SeventhLanguage' => new \PHPExiftool\Driver\Tag\RIFF\SeventhLanguage(),
                'EighthLanguage' => new \PHPExiftool\Driver\Tag\RIFF\EighthLanguage(),
                'NinthLanguage' => new \PHPExiftool\Driver\Tag\RIFF\NinthLanguage(),
                'BaseURL' => new \PHPExiftool\Driver\Tag\RIFF\BaseURL(),
                'DefaultAudioStream' => new \PHPExiftool\Driver\Tag\RIFF\DefaultAudioStream(),
                'CostumeDesigner' => new \PHPExiftool\Driver\Tag\RIFF\CostumeDesigner(),
                'Commissioned' => new \PHPExiftool\Driver\Tag\RIFF\Commissioned(),
                'Cinematographer' => new \PHPExiftool\Driver\Tag\RIFF\Cinematographer(),
                'Country' => new \PHPExiftool\Driver\Tag\RIFF\Country(),
                'Copyright' => new \PHPExiftool\Driver\Tag\RIFF\Copyright(),
                'DateCreated' => new \PHPExiftool\Driver\Tag\RIFF\DateCreated(),
                'Cropped' => new \PHPExiftool\Driver\Tag\RIFF\Cropped(),
                'Dimensions' => new \PHPExiftool\Driver\Tag\RIFF\Dimensions(),
                'DotsPerInch' => new \PHPExiftool\Driver\Tag\RIFF\DotsPerInch(),
                'DistributedBy' => new \PHPExiftool\Driver\Tag\RIFF\DistributedBy(),
                'EditedBy' => new \PHPExiftool\Driver\Tag\RIFF\EditedBy(),
                'Engineer' => new \PHPExiftool\Driver\Tag\RIFF\Engineer(),
                'Keywords' => new \PHPExiftool\Driver\Tag\RIFF\Keywords(),
                'Lightness' => new \PHPExiftool\Driver\Tag\RIFF\Lightness(),
                'LogoURL' => new \PHPExiftool\Driver\Tag\RIFF\LogoURL(),
                'LogoIconURL' => new \PHPExiftool\Driver\Tag\RIFF\LogoIconURL(),
                'Language' => new \PHPExiftool\Driver\Tag\RIFF\Language(),
                'MoreInfoBannerImage' => new \PHPExiftool\Driver\Tag\RIFF\MoreInfoBannerImage(),
                'MoreInfoBannerURL' => new \PHPExiftool\Driver\Tag\RIFF\MoreInfoBannerURL(),
                'Medium' => new \PHPExiftool\Driver\Tag\RIFF\Medium(),
                'MoreInfoText' => new \PHPExiftool\Driver\Tag\RIFF\MoreInfoText(),
                'MoreInfoURL' => new \PHPExiftool\Driver\Tag\RIFF\MoreInfoURL(),
                'MusicBy' => new \PHPExiftool\Driver\Tag\RIFF\MusicBy(),
                'Title' => new \PHPExiftool\Driver\Tag\RIFF\Title(),
                'ProductionDesigner' => new \PHPExiftool\Driver\Tag\RIFF\ProductionDesigner(),
                'NumColors' => new \PHPExiftool\Driver\Tag\RIFF\NumColors(),
                'Product' => new \PHPExiftool\Driver\Tag\RIFF\Product(),
                'ProducedBy' => new \PHPExiftool\Driver\Tag\RIFF\ProducedBy(),
                'RippedBy' => new \PHPExiftool\Driver\Tag\RIFF\RippedBy(),
                'Rating' => new \PHPExiftool\Driver\Tag\RIFF\Rating(),
                'Subject' => new \PHPExiftool\Driver\Tag\RIFF\Subject(),
                'Software' => new \PHPExiftool\Driver\Tag\RIFF\Software(),
                'SecondaryGenre' => new \PHPExiftool\Driver\Tag\RIFF\SecondaryGenre(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\RIFF\Sharpness(),
                'Source' => new \PHPExiftool\Driver\Tag\RIFF\Source(),
                'SourceForm' => new \PHPExiftool\Driver\Tag\RIFF\SourceForm(),
                'ProductionStudio' => new \PHPExiftool\Driver\Tag\RIFF\ProductionStudio(),
                'Starring' => new \PHPExiftool\Driver\Tag\RIFF\Starring(),
                'Technician' => new \PHPExiftool\Driver\Tag\RIFF\Technician(),
                'WatermarkURL' => new \PHPExiftool\Driver\Tag\RIFF\WatermarkURL(),
                'WrittenBy' => new \PHPExiftool\Driver\Tag\RIFF\WrittenBy(),
                'Location' => new \PHPExiftool\Driver\Tag\RIFF\Location(),
                'Part' => new \PHPExiftool\Driver\Tag\RIFF\Part(),
                'NumberOfParts' => new \PHPExiftool\Driver\Tag\RIFF\NumberOfParts(),
                'Rate' => new \PHPExiftool\Driver\Tag\RIFF\Rate(),
                'Statistics' => new \PHPExiftool\Driver\Tag\RIFF\Statistics(),
                'TapeName' => new \PHPExiftool\Driver\Tag\RIFF\TapeName(),
                'EndTimecode' => new \PHPExiftool\Driver\Tag\RIFF\EndTimecode(),
                'StartTimecode' => new \PHPExiftool\Driver\Tag\RIFF\StartTimecode(),
                'Length' => new \PHPExiftool\Driver\Tag\RIFF\Length(),
                'Organization' => new \PHPExiftool\Driver\Tag\RIFF\Organization(),
                'TrackNumber' => new \PHPExiftool\Driver\Tag\RIFF\TrackNumber(),
                'URL' => new \PHPExiftool\Driver\Tag\RIFF\URL(),
                'Version' => new \PHPExiftool\Driver\Tag\RIFF\Version(),
                'VegasVersionMajor' => new \PHPExiftool\Driver\Tag\RIFF\VegasVersionMajor(),
                'VegasVersionMinor' => new \PHPExiftool\Driver\Tag\RIFF\VegasVersionMinor(),
                'Year' => new \PHPExiftool\Driver\Tag\RIFF\Year(),
                'TextJunk' => new \PHPExiftool\Driver\Tag\RIFF\TextJunk(),
                'OldXMP' => new \PHPExiftool\Driver\Tag\RIFF\OldXMP(),
                'StreamName' => new \PHPExiftool\Driver\Tag\RIFF\StreamName(),
                'VendorName' => new \PHPExiftool\Driver\Tag\RIFF\VendorName(),
                'UnknownData' => new \PHPExiftool\Driver\Tag\RIFF\UnknownData(),
                'StreamType' => new \PHPExiftool\Driver\Tag\RIFF\StreamType(),
                'AudioCodec' => new \PHPExiftool\Driver\Tag\RIFF\AudioCodec(),
                'VideoCodec' => new \PHPExiftool\Driver\Tag\RIFF\VideoCodec(),
                'Codec' => new \PHPExiftool\Driver\Tag\RIFF\Codec(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\RIFF\AudioSampleRate(),
                'VideoFrameRate' => new \PHPExiftool\Driver\Tag\RIFF\VideoFrameRate(),
                'StreamSampleRate' => new \PHPExiftool\Driver\Tag\RIFF\StreamSampleRate(),
                'AudioSampleCount' => new \PHPExiftool\Driver\Tag\RIFF\AudioSampleCount(),
                'VideoFrameCount' => new \PHPExiftool\Driver\Tag\RIFF\VideoFrameCount(),
                'StreamSampleCount' => new \PHPExiftool\Driver\Tag\RIFF\StreamSampleCount(),
                'Quality' => new \PHPExiftool\Driver\Tag\RIFF\Quality(),
                'SampleSize' => new \PHPExiftool\Driver\Tag\RIFF\SampleSize(),
                'VP8Version' => new \PHPExiftool\Driver\Tag\RIFF\VP8Version(),
                'HorizontalScale' => new \PHPExiftool\Driver\Tag\RIFF\HorizontalScale(),
                'VerticalScale' => new \PHPExiftool\Driver\Tag\RIFF\VerticalScale(),
            );
        });
        $this['RSRC'] = $this->share(function(){
            return array(
                'ApplicationMissingMsg' => new \PHPExiftool\Driver\Tag\RSRC\ApplicationMissingMsg(),
                'CreatorApplication' => new \PHPExiftool\Driver\Tag\RSRC\CreatorApplication(),
                'Keywords' => new \PHPExiftool\Driver\Tag\RSRC\Keywords(),
                'Description' => new \PHPExiftool\Driver\Tag\RSRC\Description(),
                'OpenWithApplication' => new \PHPExiftool\Driver\Tag\RSRC\OpenWithApplication(),
                'ApplicationVersion' => new \PHPExiftool\Driver\Tag\RSRC\ApplicationVersion(),
            );
        });
        $this['RTF'] = $this->share(function(){
            return array(
                'Author' => new \PHPExiftool\Driver\Tag\RTF\Author(),
                'BackupTime' => new \PHPExiftool\Driver\Tag\RTF\BackupTime(),
                'Category' => new \PHPExiftool\Driver\Tag\RTF\Category(),
                'Comment' => new \PHPExiftool\Driver\Tag\RTF\Comment(),
                'Company' => new \PHPExiftool\Driver\Tag\RTF\Company(),
                'Copyright' => new \PHPExiftool\Driver\Tag\RTF\Copyright(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\RTF\CreateDate(),
                'Comments' => new \PHPExiftool\Driver\Tag\RTF\Comments(),
                'TotalEditTime' => new \PHPExiftool\Driver\Tag\RTF\TotalEditTime(),
                'HyperlinkBase' => new \PHPExiftool\Driver\Tag\RTF\HyperlinkBase(),
                'InternalIDNumber' => new \PHPExiftool\Driver\Tag\RTF\InternalIDNumber(),
                'Keywords' => new \PHPExiftool\Driver\Tag\RTF\Keywords(),
                'Manager' => new \PHPExiftool\Driver\Tag\RTF\Manager(),
                'Characters' => new \PHPExiftool\Driver\Tag\RTF\Characters(),
                'CharactersWithSpaces' => new \PHPExiftool\Driver\Tag\RTF\CharactersWithSpaces(),
                'Pages' => new \PHPExiftool\Driver\Tag\RTF\Pages(),
                'Words' => new \PHPExiftool\Driver\Tag\RTF\Words(),
                'LastModifiedBy' => new \PHPExiftool\Driver\Tag\RTF\LastModifiedBy(),
                'LastPrinted' => new \PHPExiftool\Driver\Tag\RTF\LastPrinted(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\RTF\ModifyDate(),
                'Subject' => new \PHPExiftool\Driver\Tag\RTF\Subject(),
                'Title' => new \PHPExiftool\Driver\Tag\RTF\Title(),
                'InternalVersionNumber' => new \PHPExiftool\Driver\Tag\RTF\InternalVersionNumber(),
                'RevisionNumber' => new \PHPExiftool\Driver\Tag\RTF\RevisionNumber(),
            );
        });
        $this['Radiance'] = $this->share(function(){
            return array(
                'Command' => new \PHPExiftool\Driver\Tag\Radiance\Command(),
                'Orientation' => new \PHPExiftool\Driver\Tag\Radiance\Orientation(),
                'ColorCorrection' => new \PHPExiftool\Driver\Tag\Radiance\ColorCorrection(),
                'Exposure' => new \PHPExiftool\Driver\Tag\Radiance\Exposure(),
                'Format' => new \PHPExiftool\Driver\Tag\Radiance\Format(),
                'Gamma' => new \PHPExiftool\Driver\Tag\Radiance\Gamma(),
                'PixelAspectRatio' => new \PHPExiftool\Driver\Tag\Radiance\PixelAspectRatio(),
                'ColorPrimaries' => new \PHPExiftool\Driver\Tag\Radiance\ColorPrimaries(),
                'Software' => new \PHPExiftool\Driver\Tag\Radiance\Software(),
                'View' => new \PHPExiftool\Driver\Tag\Radiance\View(),
            );
        });
        $this['Rawzor'] = $this->share(function(){
            return array(
                'CompressionFactor' => new \PHPExiftool\Driver\Tag\Rawzor\CompressionFactor(),
                'OriginalFileSize' => new \PHPExiftool\Driver\Tag\Rawzor\OriginalFileSize(),
                'OriginalFileType' => new \PHPExiftool\Driver\Tag\Rawzor\OriginalFileType(),
                'RawzorCreatorVersion' => new \PHPExiftool\Driver\Tag\Rawzor\RawzorCreatorVersion(),
                'RawzorRequiredVersion' => new \PHPExiftool\Driver\Tag\Rawzor\RawzorRequiredVersion(),
            );
        });
        $this['Real-RA3'] = $this->share(function(){
            return array(
                'Channels' => new \PHPExiftool\Driver\Tag\RealRA3\Channels(),
                'Unknown' => new \PHPExiftool\Driver\Tag\RealRA3\Unknown(),
                'BytesPerMinute' => new \PHPExiftool\Driver\Tag\RealRA3\BytesPerMinute(),
                'AudioBytes' => new \PHPExiftool\Driver\Tag\RealRA3\AudioBytes(),
                'TitleLen' => new \PHPExiftool\Driver\Tag\RealRA3\TitleLen(),
                'Title' => new \PHPExiftool\Driver\Tag\RealRA3\Title(),
                'ArtistLen' => new \PHPExiftool\Driver\Tag\RealRA3\ArtistLen(),
                'Artist' => new \PHPExiftool\Driver\Tag\RealRA3\Artist(),
                'CopyrightLen' => new \PHPExiftool\Driver\Tag\RealRA3\CopyrightLen(),
                'Copyright' => new \PHPExiftool\Driver\Tag\RealRA3\Copyright(),
                'CommentLen' => new \PHPExiftool\Driver\Tag\RealRA3\CommentLen(),
                'Comment' => new \PHPExiftool\Driver\Tag\RealRA3\Comment(),
            );
        });
        $this['Real-RA4'] = $this->share(function(){
            return array(
                'FourCC1' => new \PHPExiftool\Driver\Tag\RealRA4\FourCC1(),
                'AudioFileSize' => new \PHPExiftool\Driver\Tag\RealRA4\AudioFileSize(),
                'Version2' => new \PHPExiftool\Driver\Tag\RealRA4\Version2(),
                'HeaderSize' => new \PHPExiftool\Driver\Tag\RealRA4\HeaderSize(),
                'CodecFlavorID' => new \PHPExiftool\Driver\Tag\RealRA4\CodecFlavorID(),
                'CodedFrameSize' => new \PHPExiftool\Driver\Tag\RealRA4\CodedFrameSize(),
                'AudioBytes' => new \PHPExiftool\Driver\Tag\RealRA4\AudioBytes(),
                'BytesPerMinute' => new \PHPExiftool\Driver\Tag\RealRA4\BytesPerMinute(),
                'Unknown' => new \PHPExiftool\Driver\Tag\RealRA4\Unknown(),
                'SubPacketH' => new \PHPExiftool\Driver\Tag\RealRA4\SubPacketH(),
                'AudioFrameSize' => new \PHPExiftool\Driver\Tag\RealRA4\AudioFrameSize(),
                'SubPacketSize' => new \PHPExiftool\Driver\Tag\RealRA4\SubPacketSize(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\RealRA4\SampleRate(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\RealRA4\BitsPerSample(),
                'Channels' => new \PHPExiftool\Driver\Tag\RealRA4\Channels(),
                'FourCC2Len' => new \PHPExiftool\Driver\Tag\RealRA4\FourCC2Len(),
                'FourCC2' => new \PHPExiftool\Driver\Tag\RealRA4\FourCC2(),
                'FourCC3Len' => new \PHPExiftool\Driver\Tag\RealRA4\FourCC3Len(),
                'FourCC3' => new \PHPExiftool\Driver\Tag\RealRA4\FourCC3(),
                'TitleLen' => new \PHPExiftool\Driver\Tag\RealRA4\TitleLen(),
                'Title' => new \PHPExiftool\Driver\Tag\RealRA4\Title(),
                'ArtistLen' => new \PHPExiftool\Driver\Tag\RealRA4\ArtistLen(),
                'Artist' => new \PHPExiftool\Driver\Tag\RealRA4\Artist(),
                'CopyrightLen' => new \PHPExiftool\Driver\Tag\RealRA4\CopyrightLen(),
                'Copyright' => new \PHPExiftool\Driver\Tag\RealRA4\Copyright(),
                'CommentLen' => new \PHPExiftool\Driver\Tag\RealRA4\CommentLen(),
                'Comment' => new \PHPExiftool\Driver\Tag\RealRA4\Comment(),
            );
        });
        $this['Real-RA5'] = $this->share(function(){
            return array(
                'FourCC1' => new \PHPExiftool\Driver\Tag\RealRA5\FourCC1(),
                'AudioFileSize' => new \PHPExiftool\Driver\Tag\RealRA5\AudioFileSize(),
                'Version2' => new \PHPExiftool\Driver\Tag\RealRA5\Version2(),
                'HeaderSize' => new \PHPExiftool\Driver\Tag\RealRA5\HeaderSize(),
                'CodecFlavorID' => new \PHPExiftool\Driver\Tag\RealRA5\CodecFlavorID(),
                'CodedFrameSize' => new \PHPExiftool\Driver\Tag\RealRA5\CodedFrameSize(),
                'AudioBytes' => new \PHPExiftool\Driver\Tag\RealRA5\AudioBytes(),
                'BytesPerMinute' => new \PHPExiftool\Driver\Tag\RealRA5\BytesPerMinute(),
                'Unknown' => new \PHPExiftool\Driver\Tag\RealRA5\Unknown(),
                'SubPacketH' => new \PHPExiftool\Driver\Tag\RealRA5\SubPacketH(),
                'FrameSize' => new \PHPExiftool\Driver\Tag\RealRA5\FrameSize(),
                'SubPacketSize' => new \PHPExiftool\Driver\Tag\RealRA5\SubPacketSize(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\RealRA5\SampleRate(),
                'SampleRate2' => new \PHPExiftool\Driver\Tag\RealRA5\SampleRate2(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\RealRA5\BitsPerSample(),
                'Channels' => new \PHPExiftool\Driver\Tag\RealRA5\Channels(),
                'Genr' => new \PHPExiftool\Driver\Tag\RealRA5\Genr(),
                'FourCC3' => new \PHPExiftool\Driver\Tag\RealRA5\FourCC3(),
            );
        });
        $this['Real-CONT'] = $this->share(function(){
            return array(
                'TitleLen' => new \PHPExiftool\Driver\Tag\RealCONT\TitleLen(),
                'Title' => new \PHPExiftool\Driver\Tag\RealCONT\Title(),
                'AuthorLen' => new \PHPExiftool\Driver\Tag\RealCONT\AuthorLen(),
                'Author' => new \PHPExiftool\Driver\Tag\RealCONT\Author(),
                'CopyrightLen' => new \PHPExiftool\Driver\Tag\RealCONT\CopyrightLen(),
                'Copyright' => new \PHPExiftool\Driver\Tag\RealCONT\Copyright(),
                'CommentLen' => new \PHPExiftool\Driver\Tag\RealCONT\CommentLen(),
                'Comment' => new \PHPExiftool\Driver\Tag\RealCONT\Comment(),
            );
        });
        $this['Real-MDPR'] = $this->share(function(){
            return array(
                'Audiences' => new \PHPExiftool\Driver\Tag\RealMDPR\Audiences(),
                'AudioFormat' => new \PHPExiftool\Driver\Tag\RealMDPR\AudioFormat(),
                'ContentRating' => new \PHPExiftool\Driver\Tag\RealMDPR\ContentRating(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\RealMDPR\CreateDate(),
                'Description' => new \PHPExiftool\Driver\Tag\RealMDPR\Description(),
                'FileID' => new \PHPExiftool\Driver\Tag\RealMDPR\FileID(),
                'Software' => new \PHPExiftool\Driver\Tag\RealMDPR\Software(),
                'Indexable' => new \PHPExiftool\Driver\Tag\RealMDPR\Indexable(),
                'Keywords' => new \PHPExiftool\Driver\Tag\RealMDPR\Keywords(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\RealMDPR\ModifyDate(),
                'TargetAudiences' => new \PHPExiftool\Driver\Tag\RealMDPR\TargetAudiences(),
                'VideoQuality' => new \PHPExiftool\Driver\Tag\RealMDPR\VideoQuality(),
                'AudioMode' => new \PHPExiftool\Driver\Tag\RealMDPR\AudioMode(),
                'VideoMode' => new \PHPExiftool\Driver\Tag\RealMDPR\VideoMode(),
                'StreamNumber' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamNumber(),
                'StreamMaxBitrate' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamMaxBitrate(),
                'StreamAvgBitrate' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamAvgBitrate(),
                'StreamMaxPacketSize' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamMaxPacketSize(),
                'StreamAvgPacketSize' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamAvgPacketSize(),
                'StreamStartTime' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamStartTime(),
                'StreamPreroll' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamPreroll(),
                'StreamDuration' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamDuration(),
                'StreamNameLen' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamNameLen(),
                'StreamName' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamName(),
                'StreamMimeLen' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamMimeLen(),
                'StreamMimeType' => new \PHPExiftool\Driver\Tag\RealMDPR\StreamMimeType(),
                'FileInfoLen' => new \PHPExiftool\Driver\Tag\RealMDPR\FileInfoLen(),
                'FileInfoLen2' => new \PHPExiftool\Driver\Tag\RealMDPR\FileInfoLen2(),
                'FileInfoVersion' => new \PHPExiftool\Driver\Tag\RealMDPR\FileInfoVersion(),
                'PhysicalStreams' => new \PHPExiftool\Driver\Tag\RealMDPR\PhysicalStreams(),
                'PhysicalStreamNumbers' => new \PHPExiftool\Driver\Tag\RealMDPR\PhysicalStreamNumbers(),
                'DataOffsets' => new \PHPExiftool\Driver\Tag\RealMDPR\DataOffsets(),
                'NumRules' => new \PHPExiftool\Driver\Tag\RealMDPR\NumRules(),
                'PhysicalStreamNumberMap' => new \PHPExiftool\Driver\Tag\RealMDPR\PhysicalStreamNumberMap(),
                'NumProperties' => new \PHPExiftool\Driver\Tag\RealMDPR\NumProperties(),
            );
        });
        $this['Real-RJMD'] = $this->share(function(){
            return array(
                'AlbumName' => new \PHPExiftool\Driver\Tag\RealRJMD\AlbumName(),
                'TrackCategory' => new \PHPExiftool\Driver\Tag\RealRJMD\TrackCategory(),
                'TrackComments' => new \PHPExiftool\Driver\Tag\RealRJMD\TrackComments(),
                'TrackLyrics' => new \PHPExiftool\Driver\Tag\RealRJMD\TrackLyrics(),
            );
        });
        $this['Real'] = $this->share(function(){
            return array(
                'Text' => new \PHPExiftool\Driver\Tag\Real\Text(),
                'URL' => new \PHPExiftool\Driver\Tag\Real\URL(),
            );
        });
        $this['Real-PROP'] = $this->share(function(){
            return array(
                'MaxBitrate' => new \PHPExiftool\Driver\Tag\RealPROP\MaxBitrate(),
                'AvgBitrate' => new \PHPExiftool\Driver\Tag\RealPROP\AvgBitrate(),
                'MaxPacketSize' => new \PHPExiftool\Driver\Tag\RealPROP\MaxPacketSize(),
                'AvgPacketSize' => new \PHPExiftool\Driver\Tag\RealPROP\AvgPacketSize(),
                'NumPackets' => new \PHPExiftool\Driver\Tag\RealPROP\NumPackets(),
                'Duration' => new \PHPExiftool\Driver\Tag\RealPROP\Duration(),
                'Preroll' => new \PHPExiftool\Driver\Tag\RealPROP\Preroll(),
                'IndexOffset' => new \PHPExiftool\Driver\Tag\RealPROP\IndexOffset(),
                'DataOffset' => new \PHPExiftool\Driver\Tag\RealPROP\DataOffset(),
                'NumStreams' => new \PHPExiftool\Driver\Tag\RealPROP\NumStreams(),
                'Flags' => new \PHPExiftool\Driver\Tag\RealPROP\Flags(),
            );
        });
        $this['Reconyx'] = $this->share(function(){
            return array(
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Reconyx\MakerNoteVersion(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\Reconyx\FirmwareVersion(),
                'FirmwareDate' => new \PHPExiftool\Driver\Tag\Reconyx\FirmwareDate(),
                'TriggerMode' => new \PHPExiftool\Driver\Tag\Reconyx\TriggerMode(),
                'Sequence' => new \PHPExiftool\Driver\Tag\Reconyx\Sequence(),
                'EventNumber' => new \PHPExiftool\Driver\Tag\Reconyx\EventNumber(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\Reconyx\DateTimeOriginal(),
                'MoonPhase' => new \PHPExiftool\Driver\Tag\Reconyx\MoonPhase(),
                'AmbientTemperatureFahrenheit' => new \PHPExiftool\Driver\Tag\Reconyx\AmbientTemperatureFahrenheit(),
                'AmbientTemperature' => new \PHPExiftool\Driver\Tag\Reconyx\AmbientTemperature(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Reconyx\SerialNumber(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Reconyx\Contrast(),
                'Brightness' => new \PHPExiftool\Driver\Tag\Reconyx\Brightness(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Reconyx\Sharpness(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Reconyx\Saturation(),
                'InfraredIlluminator' => new \PHPExiftool\Driver\Tag\Reconyx\InfraredIlluminator(),
                'MotionSensitivity' => new \PHPExiftool\Driver\Tag\Reconyx\MotionSensitivity(),
                'BatteryVoltage' => new \PHPExiftool\Driver\Tag\Reconyx\BatteryVoltage(),
                'UserLabel' => new \PHPExiftool\Driver\Tag\Reconyx\UserLabel(),
            );
        });
        $this['Ricoh'] = $this->share(function(){
            return array(
                'RicohRDC2' => new \PHPExiftool\Driver\Tag\Ricoh\RicohRDC2(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\Ricoh\ThumbnailImage(),
                'Comment' => new \PHPExiftool\Driver\Tag\Ricoh\Comment(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Ricoh\FacesDetected(),
                'FaceDetectFrameSize' => new \PHPExiftool\Driver\Tag\Ricoh\FaceDetectFrameSize(),
                'Face1Position' => new \PHPExiftool\Driver\Tag\Ricoh\Face1Position(),
                'Face2Position' => new \PHPExiftool\Driver\Tag\Ricoh\Face2Position(),
                'Face3Position' => new \PHPExiftool\Driver\Tag\Ricoh\Face3Position(),
                'Face4Position' => new \PHPExiftool\Driver\Tag\Ricoh\Face4Position(),
                'Face5Position' => new \PHPExiftool\Driver\Tag\Ricoh\Face5Position(),
                'Face6Position' => new \PHPExiftool\Driver\Tag\Ricoh\Face6Position(),
                'Face7Position' => new \PHPExiftool\Driver\Tag\Ricoh\Face7Position(),
                'Face8Position' => new \PHPExiftool\Driver\Tag\Ricoh\Face8Position(),
                'FirmwareRevision' => new \PHPExiftool\Driver\Tag\Ricoh\FirmwareRevision(),
                'FirmwareRevision2' => new \PHPExiftool\Driver\Tag\Ricoh\FirmwareRevision2(),
                'RicohImageWidth' => new \PHPExiftool\Driver\Tag\Ricoh\RicohImageWidth(),
                'RicohImageHeight' => new \PHPExiftool\Driver\Tag\Ricoh\RicohImageHeight(),
                'RicohDate' => new \PHPExiftool\Driver\Tag\Ricoh\RicohDate(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Ricoh\PreviewImageStart(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Ricoh\PreviewImageLength(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Ricoh\FlashMode(),
                'Macro' => new \PHPExiftool\Driver\Tag\Ricoh\Macro(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Ricoh\Sharpness(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Ricoh\WhiteBalance(),
                'ISOSetting' => new \PHPExiftool\Driver\Tag\Ricoh\ISOSetting(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Ricoh\Saturation(),
                'MakerNoteType' => new \PHPExiftool\Driver\Tag\Ricoh\MakerNoteType(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\Ricoh\FirmwareVersion(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Ricoh\SerialNumber(),
                'InternalSerialNumber' => new \PHPExiftool\Driver\Tag\Ricoh\InternalSerialNumber(),
                'BodyFirmware' => new \PHPExiftool\Driver\Tag\Ricoh\BodyFirmware(),
                'BodySerialNumber' => new \PHPExiftool\Driver\Tag\Ricoh\BodySerialNumber(),
                'LensFirmware' => new \PHPExiftool\Driver\Tag\Ricoh\LensFirmware(),
                'LensSerialNumber' => new \PHPExiftool\Driver\Tag\Ricoh\LensSerialNumber(),
                'ManufactureDate1' => new \PHPExiftool\Driver\Tag\Ricoh\ManufactureDate1(),
                'ManufactureDate2' => new \PHPExiftool\Driver\Tag\Ricoh\ManufactureDate2(),
                'NoiseReduction' => new \PHPExiftool\Driver\Tag\Ricoh\NoiseReduction(),
                'BlueGain' => new \PHPExiftool\Driver\Tag\Ricoh\BlueGain(),
                'GreenGain' => new \PHPExiftool\Driver\Tag\Ricoh\GreenGain(),
                'RedGain' => new \PHPExiftool\Driver\Tag\Ricoh\RedGain(),
            );
        });
        $this['RMETA'] = $this->share(function(){
            return array(
                'Azimuth' => new \PHPExiftool\Driver\Tag\RMETA\Azimuth(),
                'Condition' => new \PHPExiftool\Driver\Tag\RMETA\Condition(),
                'Lit' => new \PHPExiftool\Driver\Tag\RMETA\Lit(),
                'Location' => new \PHPExiftool\Driver\Tag\RMETA\Location(),
                'SignType' => new \PHPExiftool\Driver\Tag\RMETA\SignType(),
            );
        });
        $this['Samsung'] = $this->share(function(){
            return array(
                'Effect' => new \PHPExiftool\Driver\Tag\Samsung\Effect(),
                'Quality' => new \PHPExiftool\Driver\Tag\Samsung\Quality(),
                'Make' => new \PHPExiftool\Driver\Tag\Samsung\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\Samsung\Model(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Samsung\ExposureTime(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Samsung\FNumber(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Samsung\ExposureCompensation(),
                'ISO' => new \PHPExiftool\Driver\Tag\Samsung\ISO(),
                'Software' => new \PHPExiftool\Driver\Tag\Samsung\Software(),
                'PictureWizardMode' => new \PHPExiftool\Driver\Tag\Samsung\PictureWizardMode(),
                'PictureWizardColor' => new \PHPExiftool\Driver\Tag\Samsung\PictureWizardColor(),
                'PictureWizardSaturation' => new \PHPExiftool\Driver\Tag\Samsung\PictureWizardSaturation(),
                'PictureWizardSharpness' => new \PHPExiftool\Driver\Tag\Samsung\PictureWizardSharpness(),
                'PictureWizardContrast' => new \PHPExiftool\Driver\Tag\Samsung\PictureWizardContrast(),
                'ThumbnailWidth' => new \PHPExiftool\Driver\Tag\Samsung\ThumbnailWidth(),
                'ThumbnailHeight' => new \PHPExiftool\Driver\Tag\Samsung\ThumbnailHeight(),
                'ThumbnailLength' => new \PHPExiftool\Driver\Tag\Samsung\ThumbnailLength(),
                'ThumbnailOffset' => new \PHPExiftool\Driver\Tag\Samsung\ThumbnailOffset(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Samsung\MakerNoteVersion(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Samsung\PreviewImageStart(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Samsung\PreviewImageLength(),
                'PictureWizard' => new \PHPExiftool\Driver\Tag\Samsung\PictureWizard(),
                'LocalLocationName' => new \PHPExiftool\Driver\Tag\Samsung\LocalLocationName(),
                'LocationName' => new \PHPExiftool\Driver\Tag\Samsung\LocationName(),
                'CameraTemperature' => new \PHPExiftool\Driver\Tag\Samsung\CameraTemperature(),
                'FirmwareName' => new \PHPExiftool\Driver\Tag\Samsung\FirmwareName(),
                'LensType' => new \PHPExiftool\Driver\Tag\Samsung\LensType(),
                'LensFirmware' => new \PHPExiftool\Driver\Tag\Samsung\LensFirmware(),
                'SensorAreas' => new \PHPExiftool\Driver\Tag\Samsung\SensorAreas(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Samsung\ColorSpace(),
                'SmartRange' => new \PHPExiftool\Driver\Tag\Samsung\SmartRange(),
                'FocalLengthIn35mmFormat' => new \PHPExiftool\Driver\Tag\Samsung\FocalLengthIn35mmFormat(),
                'EncryptionKey' => new \PHPExiftool\Driver\Tag\Samsung\EncryptionKey(),
                'WB_RGGBLevelsUncorrected' => new \PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsUncorrected(),
                'WB_RGGBLevelsAuto' => new \PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsAuto(),
                'WB_RGGBLevelsIlluminator1' => new \PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsIlluminator1(),
                'WB_RGGBLevelsIlluminator2' => new \PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsIlluminator2(),
                'WB_RGGBLevelsBlack' => new \PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsBlack(),
                'ColorMatrix' => new \PHPExiftool\Driver\Tag\Samsung\ColorMatrix(),
                'ColorMatrixSRGB' => new \PHPExiftool\Driver\Tag\Samsung\ColorMatrixSRGB(),
                'ColorMatrixAdobeRGB' => new \PHPExiftool\Driver\Tag\Samsung\ColorMatrixAdobeRGB(),
                'Samsung_Type2_0xa033' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa033(),
                'Samsung_Type2_0xa034' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa034(),
                'Samsung_Type2_0xa035' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa035(),
                'Samsung_Type2_0xa036' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa036(),
                'ToneCurve1' => new \PHPExiftool\Driver\Tag\Samsung\ToneCurve1(),
                'ToneCurve2' => new \PHPExiftool\Driver\Tag\Samsung\ToneCurve2(),
                'ToneCurve3' => new \PHPExiftool\Driver\Tag\Samsung\ToneCurve3(),
                'ToneCurve4' => new \PHPExiftool\Driver\Tag\Samsung\ToneCurve4(),
                'Samsung_Type2_0xa048' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa048(),
                'Samsung_Type2_0xa050' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa050(),
                'Samsung_Type2_0xa051' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa051(),
                'Samsung_Type2_0xa052' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa052(),
                'Samsung_Type2_0xa053' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa053(),
                'Samsung_Type2_0xa054' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa054(),
                'Samsung_Type2_0xa055' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa055(),
                'Samsung_Type2_0xa056' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa056(),
                'Samsung_Type2_0xa057' => new \PHPExiftool\Driver\Tag\Samsung\SamsungType20xa057(),
            );
        });
        $this['Sanyo'] = $this->share(function(){
            return array(
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Sanyo\FacesDetected(),
                'FacePosition' => new \PHPExiftool\Driver\Tag\Sanyo\FacePosition(),
                'Make' => new \PHPExiftool\Driver\Tag\Sanyo\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\Sanyo\Model(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Sanyo\ExposureTime(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Sanyo\FNumber(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Sanyo\ExposureCompensation(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Sanyo\WhiteBalance(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Sanyo\FocalLength(),
                'ISO' => new \PHPExiftool\Driver\Tag\Sanyo\ISO(),
                'Software' => new \PHPExiftool\Driver\Tag\Sanyo\Software(),
                'MakerNoteOffset' => new \PHPExiftool\Driver\Tag\Sanyo\MakerNoteOffset(),
                'SanyoThumbnail' => new \PHPExiftool\Driver\Tag\Sanyo\SanyoThumbnail(),
                'SpecialMode' => new \PHPExiftool\Driver\Tag\Sanyo\SpecialMode(),
                'SanyoQuality' => new \PHPExiftool\Driver\Tag\Sanyo\SanyoQuality(),
                'Macro' => new \PHPExiftool\Driver\Tag\Sanyo\Macro(),
                'DigitalZoom' => new \PHPExiftool\Driver\Tag\Sanyo\DigitalZoom(),
                'SoftwareVersion' => new \PHPExiftool\Driver\Tag\Sanyo\SoftwareVersion(),
                'PictInfo' => new \PHPExiftool\Driver\Tag\Sanyo\PictInfo(),
                'CameraID' => new \PHPExiftool\Driver\Tag\Sanyo\CameraID(),
                'SequentialShot' => new \PHPExiftool\Driver\Tag\Sanyo\SequentialShot(),
                'WideRange' => new \PHPExiftool\Driver\Tag\Sanyo\WideRange(),
                'ColorAdjustmentMode' => new \PHPExiftool\Driver\Tag\Sanyo\ColorAdjustmentMode(),
                'QuickShot' => new \PHPExiftool\Driver\Tag\Sanyo\QuickShot(),
                'SelfTimer' => new \PHPExiftool\Driver\Tag\Sanyo\SelfTimer(),
                'VoiceMemo' => new \PHPExiftool\Driver\Tag\Sanyo\VoiceMemo(),
                'RecordShutterRelease' => new \PHPExiftool\Driver\Tag\Sanyo\RecordShutterRelease(),
                'FlickerReduce' => new \PHPExiftool\Driver\Tag\Sanyo\FlickerReduce(),
                'OpticalZoomOn' => new \PHPExiftool\Driver\Tag\Sanyo\OpticalZoomOn(),
                'DigitalZoomOn' => new \PHPExiftool\Driver\Tag\Sanyo\DigitalZoomOn(),
                'LightSourceSpecial' => new \PHPExiftool\Driver\Tag\Sanyo\LightSourceSpecial(),
                'Resaved' => new \PHPExiftool\Driver\Tag\Sanyo\Resaved(),
                'SceneSelect' => new \PHPExiftool\Driver\Tag\Sanyo\SceneSelect(),
                'ManualFocusDistance' => new \PHPExiftool\Driver\Tag\Sanyo\ManualFocusDistance(),
                'SequenceShotInterval' => new \PHPExiftool\Driver\Tag\Sanyo\SequenceShotInterval(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Sanyo\FlashMode(),
                'DataDump' => new \PHPExiftool\Driver\Tag\Sanyo\DataDump(),
                'ThumbnailWidth' => new \PHPExiftool\Driver\Tag\Sanyo\ThumbnailWidth(),
                'ThumbnailHeight' => new \PHPExiftool\Driver\Tag\Sanyo\ThumbnailHeight(),
                'ThumbnailLength' => new \PHPExiftool\Driver\Tag\Sanyo\ThumbnailLength(),
                'ThumbnailOffset' => new \PHPExiftool\Driver\Tag\Sanyo\ThumbnailOffset(),
            );
        });
        $this['Sigma'] = $this->share(function(){
            return array(
                'SerialNumber' => new \PHPExiftool\Driver\Tag\Sigma\SerialNumber(),
                'DriveMode' => new \PHPExiftool\Driver\Tag\Sigma\DriveMode(),
                'ResolutionMode' => new \PHPExiftool\Driver\Tag\Sigma\ResolutionMode(),
                'AFMode' => new \PHPExiftool\Driver\Tag\Sigma\AFMode(),
                'FocusSetting' => new \PHPExiftool\Driver\Tag\Sigma\FocusSetting(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Sigma\WhiteBalance(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\Sigma\ExposureMode(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Sigma\MeteringMode(),
                'LensFocalRange' => new \PHPExiftool\Driver\Tag\Sigma\LensFocalRange(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Sigma\ColorSpace(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Sigma\ExposureCompensation(),
                'ExposureAdjust' => new \PHPExiftool\Driver\Tag\Sigma\ExposureAdjust(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Sigma\Contrast(),
                'Shadow' => new \PHPExiftool\Driver\Tag\Sigma\Shadow(),
                'Highlight' => new \PHPExiftool\Driver\Tag\Sigma\Highlight(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Sigma\Saturation(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Sigma\Sharpness(),
                'X3FillLight' => new \PHPExiftool\Driver\Tag\Sigma\X3FillLight(),
                'ColorAdjustment' => new \PHPExiftool\Driver\Tag\Sigma\ColorAdjustment(),
                'AdjustmentMode' => new \PHPExiftool\Driver\Tag\Sigma\AdjustmentMode(),
                'Quality' => new \PHPExiftool\Driver\Tag\Sigma\Quality(),
                'Firmware' => new \PHPExiftool\Driver\Tag\Sigma\Firmware(),
                'Software' => new \PHPExiftool\Driver\Tag\Sigma\Software(),
                'AutoBracket' => new \PHPExiftool\Driver\Tag\Sigma\AutoBracket(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Sigma\PreviewImageStart(),
                'ChrominanceNoiseReduction' => new \PHPExiftool\Driver\Tag\Sigma\ChrominanceNoiseReduction(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Sigma\PreviewImageLength(),
                'LuminanceNoiseReduction' => new \PHPExiftool\Driver\Tag\Sigma\LuminanceNoiseReduction(),
                'PreviewImageSize' => new \PHPExiftool\Driver\Tag\Sigma\PreviewImageSize(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Sigma\MakerNoteVersion(),
                'AFPoint' => new \PHPExiftool\Driver\Tag\Sigma\AFPoint(),
                'FileFormat' => new \PHPExiftool\Driver\Tag\Sigma\FileFormat(),
                'Calibration' => new \PHPExiftool\Driver\Tag\Sigma\Calibration(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Sigma\ColorMode(),
                'LensApertureRange' => new \PHPExiftool\Driver\Tag\Sigma\LensApertureRange(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Sigma\FNumber(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Sigma\ExposureTime(),
                'ExposureTime2' => new \PHPExiftool\Driver\Tag\Sigma\ExposureTime2(),
                'BurstShot' => new \PHPExiftool\Driver\Tag\Sigma\BurstShot(),
                'SensorTemperature' => new \PHPExiftool\Driver\Tag\Sigma\SensorTemperature(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\Sigma\FlashExposureComp(),
                'PictureMode' => new \PHPExiftool\Driver\Tag\Sigma\PictureMode(),
                'DigitalFilter' => new \PHPExiftool\Driver\Tag\Sigma\DigitalFilter(),
            );
        });
        $this['SigmaRaw'] = $this->share(function(){
            return array(
                'FileVersion' => new \PHPExiftool\Driver\Tag\SigmaRaw\FileVersion(),
                'ImageUniqueID' => new \PHPExiftool\Driver\Tag\SigmaRaw\ImageUniqueID(),
                'MarkBits' => new \PHPExiftool\Driver\Tag\SigmaRaw\MarkBits(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\SigmaRaw\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\SigmaRaw\ImageHeight(),
                'Rotation' => new \PHPExiftool\Driver\Tag\SigmaRaw\Rotation(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\SigmaRaw\WhiteBalance(),
                'SceneCaptureType' => new \PHPExiftool\Driver\Tag\SigmaRaw\SceneCaptureType(),
                'Unused' => new \PHPExiftool\Driver\Tag\SigmaRaw\Unused(),
                'ExposureAdjust' => new \PHPExiftool\Driver\Tag\SigmaRaw\ExposureAdjust(),
                'Contrast' => new \PHPExiftool\Driver\Tag\SigmaRaw\Contrast(),
                'Shadow' => new \PHPExiftool\Driver\Tag\SigmaRaw\Shadow(),
                'Highlight' => new \PHPExiftool\Driver\Tag\SigmaRaw\Highlight(),
                'Saturation' => new \PHPExiftool\Driver\Tag\SigmaRaw\Saturation(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\SigmaRaw\Sharpness(),
                'RedAdjust' => new \PHPExiftool\Driver\Tag\SigmaRaw\RedAdjust(),
                'GreenAdjust' => new \PHPExiftool\Driver\Tag\SigmaRaw\GreenAdjust(),
                'BlueAdjust' => new \PHPExiftool\Driver\Tag\SigmaRaw\BlueAdjust(),
                'X3FillLight' => new \PHPExiftool\Driver\Tag\SigmaRaw\X3FillLight(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\SigmaRaw\PreviewImage(),
                'JpgFromRaw' => new \PHPExiftool\Driver\Tag\SigmaRaw\JpgFromRaw(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\SigmaRaw\MeteringMode(),
                'AFArea' => new \PHPExiftool\Driver\Tag\SigmaRaw\AFArea(),
                'AFInFocus' => new \PHPExiftool\Driver\Tag\SigmaRaw\AFInFocus(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\SigmaRaw\FocusMode(),
                'FNumber' => new \PHPExiftool\Driver\Tag\SigmaRaw\FNumber(),
                'ApertureDisplayed' => new \PHPExiftool\Driver\Tag\SigmaRaw\ApertureDisplayed(),
                'BracketShot' => new \PHPExiftool\Driver\Tag\SigmaRaw\BracketShot(),
                'BurstShot' => new \PHPExiftool\Driver\Tag\SigmaRaw\BurstShot(),
                'Make' => new \PHPExiftool\Driver\Tag\SigmaRaw\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\SigmaRaw\Model(),
                'CameraName' => new \PHPExiftool\Driver\Tag\SigmaRaw\CameraName(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\SigmaRaw\SerialNumber(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\SigmaRaw\ColorSpace(),
                'DriveMode' => new \PHPExiftool\Driver\Tag\SigmaRaw\DriveMode(),
                'EvalState' => new \PHPExiftool\Driver\Tag\SigmaRaw\EvalState(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\SigmaRaw\ExposureCompensation(),
                'NetExposureCompensation' => new \PHPExiftool\Driver\Tag\SigmaRaw\NetExposureCompensation(),
                'IntegrationTime' => new \PHPExiftool\Driver\Tag\SigmaRaw\IntegrationTime(),
                'FirmwareVersion' => new \PHPExiftool\Driver\Tag\SigmaRaw\FirmwareVersion(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\SigmaRaw\FlashMode(),
                'FlashExpComp' => new \PHPExiftool\Driver\Tag\SigmaRaw\FlashExpComp(),
                'FlashPower' => new \PHPExiftool\Driver\Tag\SigmaRaw\FlashPower(),
                'FlashTTLMode' => new \PHPExiftool\Driver\Tag\SigmaRaw\FlashTTLMode(),
                'FlashType' => new \PHPExiftool\Driver\Tag\SigmaRaw\FlashType(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\SigmaRaw\FocalLength(),
                'FocalLengthIn35mmFormat' => new \PHPExiftool\Driver\Tag\SigmaRaw\FocalLengthIn35mmFormat(),
                'Focus' => new \PHPExiftool\Driver\Tag\SigmaRaw\Focus(),
                'ImageBoardID' => new \PHPExiftool\Driver\Tag\SigmaRaw\ImageBoardID(),
                'ImagerBoardID' => new \PHPExiftool\Driver\Tag\SigmaRaw\ImagerBoardID(),
                'SensorTemperature' => new \PHPExiftool\Driver\Tag\SigmaRaw\SensorTemperature(),
                'ISO' => new \PHPExiftool\Driver\Tag\SigmaRaw\ISO(),
                'LensApertureRange' => new \PHPExiftool\Driver\Tag\SigmaRaw\LensApertureRange(),
                'LensFocalRange' => new \PHPExiftool\Driver\Tag\SigmaRaw\LensFocalRange(),
                'LensType' => new \PHPExiftool\Driver\Tag\SigmaRaw\LensType(),
                'ExposureProgram' => new \PHPExiftool\Driver\Tag\SigmaRaw\ExposureProgram(),
                'Quality' => new \PHPExiftool\Driver\Tag\SigmaRaw\Quality(),
                'SensorID' => new \PHPExiftool\Driver\Tag\SigmaRaw\SensorID(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\SigmaRaw\ExposureTime(),
                'ShutterSpeedDisplayed' => new \PHPExiftool\Driver\Tag\SigmaRaw\ShutterSpeedDisplayed(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\SigmaRaw\DateTimeOriginal(),
                'VersionBF' => new \PHPExiftool\Driver\Tag\SigmaRaw\VersionBF(),
            );
        });
        $this['Sony'] = $this->share(function(){
            return array(
                'LensSpec' => new \PHPExiftool\Driver\Tag\Sony\LensSpec(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\Sony\FocalLength(),
                'FocalLengthTeleZoom' => new \PHPExiftool\Driver\Tag\Sony\FocalLengthTeleZoom(),
                'FocusStatus' => new \PHPExiftool\Driver\Tag\Sony\FocusStatus(),
                'AFPointSelected' => new \PHPExiftool\Driver\Tag\Sony\AFPointSelected(),
                'FocusMode' => new \PHPExiftool\Driver\Tag\Sony\FocusMode(),
                'AFPoint' => new \PHPExiftool\Driver\Tag\Sony\AFPoint(),
                'AFMicroAdjValue' => new \PHPExiftool\Driver\Tag\Sony\AFMicroAdjValue(),
                'AFMicroAdjMode' => new \PHPExiftool\Driver\Tag\Sony\AFMicroAdjMode(),
                'AFMicroAdjRegisteredLenses' => new \PHPExiftool\Driver\Tag\Sony\AFMicroAdjRegisteredLenses(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\Sony\ExposureTime(),
                'FNumber' => new \PHPExiftool\Driver\Tag\Sony\FNumber(),
                'DriveMode' => new \PHPExiftool\Driver\Tag\Sony\DriveMode(),
                'WhiteBalanceFineTune' => new \PHPExiftool\Driver\Tag\Sony\WhiteBalanceFineTune(),
                'ColorTemperatureSetting' => new \PHPExiftool\Driver\Tag\Sony\ColorTemperatureSetting(),
                'ColorCompensationFilterSet' => new \PHPExiftool\Driver\Tag\Sony\ColorCompensationFilterSet(),
                'FocusModeSetting' => new \PHPExiftool\Driver\Tag\Sony\FocusModeSetting(),
                'AFAreaMode' => new \PHPExiftool\Driver\Tag\Sony\AFAreaMode(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\Sony\MeteringMode(),
                'ISOSetting' => new \PHPExiftool\Driver\Tag\Sony\ISOSetting(),
                'DynamicRangeOptimizerMode' => new \PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizerMode(),
                'DynamicRangeOptimizerLevel' => new \PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizerLevel(),
                'CreativeStyle' => new \PHPExiftool\Driver\Tag\Sony\CreativeStyle(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Sony\ColorSpace(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\Sony\Sharpness(),
                'Contrast' => new \PHPExiftool\Driver\Tag\Sony\Contrast(),
                'Saturation' => new \PHPExiftool\Driver\Tag\Sony\Saturation(),
                'ZoneMatchingValue' => new \PHPExiftool\Driver\Tag\Sony\ZoneMatchingValue(),
                'Brightness' => new \PHPExiftool\Driver\Tag\Sony\Brightness(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\Sony\FlashMode(),
                'PrioritySetupShutterRelease' => new \PHPExiftool\Driver\Tag\Sony\PrioritySetupShutterRelease(),
                'AFIlluminator' => new \PHPExiftool\Driver\Tag\Sony\AFIlluminator(),
                'AFWithShutter' => new \PHPExiftool\Driver\Tag\Sony\AFWithShutter(),
                'LongExposureNoiseReduction' => new \PHPExiftool\Driver\Tag\Sony\LongExposureNoiseReduction(),
                'HighISONoiseReduction' => new \PHPExiftool\Driver\Tag\Sony\HighISONoiseReduction(),
                'ImageStyle' => new \PHPExiftool\Driver\Tag\Sony\ImageStyle(),
                'FocusModeSwitch' => new \PHPExiftool\Driver\Tag\Sony\FocusModeSwitch(),
                'ShutterSpeedSetting' => new \PHPExiftool\Driver\Tag\Sony\ShutterSpeedSetting(),
                'ApertureSetting' => new \PHPExiftool\Driver\Tag\Sony\ApertureSetting(),
                'ExposureProgram' => new \PHPExiftool\Driver\Tag\Sony\ExposureProgram(),
                'ImageStabilizationSetting' => new \PHPExiftool\Driver\Tag\Sony\ImageStabilizationSetting(),
                'Rotation' => new \PHPExiftool\Driver\Tag\Sony\Rotation(),
                'BatteryLevel' => new \PHPExiftool\Driver\Tag\Sony\BatteryLevel(),
                'SonyImageSize' => new \PHPExiftool\Driver\Tag\Sony\SonyImageSize(),
                'AspectRatio' => new \PHPExiftool\Driver\Tag\Sony\AspectRatio(),
                'Quality' => new \PHPExiftool\Driver\Tag\Sony\Quality(),
                'ExposureLevelIncrements' => new \PHPExiftool\Driver\Tag\Sony\ExposureLevelIncrements(),
                'ImageNumber' => new \PHPExiftool\Driver\Tag\Sony\ImageNumber(),
                'ExposureCompensationSet' => new \PHPExiftool\Driver\Tag\Sony\ExposureCompensationSet(),
                'DriveModeSetting' => new \PHPExiftool\Driver\Tag\Sony\DriveModeSetting(),
                'DynamicRangeOptimizerSetting' => new \PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizerSetting(),
                'CreativeStyleSetting' => new \PHPExiftool\Driver\Tag\Sony\CreativeStyleSetting(),
                'ContrastSetting' => new \PHPExiftool\Driver\Tag\Sony\ContrastSetting(),
                'SaturationSetting' => new \PHPExiftool\Driver\Tag\Sony\SaturationSetting(),
                'SharpnessSetting' => new \PHPExiftool\Driver\Tag\Sony\SharpnessSetting(),
                'WhiteBalanceSetting' => new \PHPExiftool\Driver\Tag\Sony\WhiteBalanceSetting(),
                'CustomWB_RGBLevels' => new \PHPExiftool\Driver\Tag\Sony\CustomWBRGBLevels(),
                'FlashControl' => new \PHPExiftool\Driver\Tag\Sony\FlashControl(),
                'FlashExposureCompSet' => new \PHPExiftool\Driver\Tag\Sony\FlashExposureCompSet(),
                'SmileShutterMode' => new \PHPExiftool\Driver\Tag\Sony\SmileShutterMode(),
                'RedEyeReduction' => new \PHPExiftool\Driver\Tag\Sony\RedEyeReduction(),
                'HDRSetting' => new \PHPExiftool\Driver\Tag\Sony\HDRSetting(),
                'HDRLevel' => new \PHPExiftool\Driver\Tag\Sony\HDRLevel(),
                'ViewingMode' => new \PHPExiftool\Driver\Tag\Sony\ViewingMode(),
                'FaceDetection' => new \PHPExiftool\Driver\Tag\Sony\FaceDetection(),
                'SmileShutter' => new \PHPExiftool\Driver\Tag\Sony\SmileShutter(),
                'SweepPanoramaSize' => new \PHPExiftool\Driver\Tag\Sony\SweepPanoramaSize(),
                'SweepPanoramaDirection' => new \PHPExiftool\Driver\Tag\Sony\SweepPanoramaDirection(),
                'MultiFrameNoiseReduction' => new \PHPExiftool\Driver\Tag\Sony\MultiFrameNoiseReduction(),
                'LiveViewAFSetting' => new \PHPExiftool\Driver\Tag\Sony\LiveViewAFSetting(),
                'PanoramaSize3D' => new \PHPExiftool\Driver\Tag\Sony\PanoramaSize3D(),
                'AFButtonPressed' => new \PHPExiftool\Driver\Tag\Sony\AFButtonPressed(),
                'LiveViewMetering' => new \PHPExiftool\Driver\Tag\Sony\LiveViewMetering(),
                'ViewingMode2' => new \PHPExiftool\Driver\Tag\Sony\ViewingMode2(),
                'AELock' => new \PHPExiftool\Driver\Tag\Sony\AELock(),
                'FlashAction' => new \PHPExiftool\Driver\Tag\Sony\FlashAction(),
                'LiveViewFocusMode' => new \PHPExiftool\Driver\Tag\Sony\LiveViewFocusMode(),
                'SequenceNumber' => new \PHPExiftool\Driver\Tag\Sony\SequenceNumber(),
                'PreviewImageStart' => new \PHPExiftool\Driver\Tag\Sony\PreviewImageStart(),
                'PreviewImageLength' => new \PHPExiftool\Driver\Tag\Sony\PreviewImageLength(),
                'MakerNoteVersion' => new \PHPExiftool\Driver\Tag\Sony\MakerNoteVersion(),
                'BatteryTemperature' => new \PHPExiftool\Driver\Tag\Sony\BatteryTemperature(),
                'BatteryUnknown' => new \PHPExiftool\Driver\Tag\Sony\BatteryUnknown(),
                'BatteryVoltage' => new \PHPExiftool\Driver\Tag\Sony\BatteryVoltage(),
                'ImageStabilization2' => new \PHPExiftool\Driver\Tag\Sony\ImageStabilization2(),
                'ExtraInfoVersion' => new \PHPExiftool\Driver\Tag\Sony\ExtraInfoVersion(),
                'ImageStabilization' => new \PHPExiftool\Driver\Tag\Sony\ImageStabilization(),
                'BatteryVoltage1' => new \PHPExiftool\Driver\Tag\Sony\BatteryVoltage1(),
                'BatteryVoltage2' => new \PHPExiftool\Driver\Tag\Sony\BatteryVoltage2(),
                'BatteryState' => new \PHPExiftool\Driver\Tag\Sony\BatteryState(),
                'ModeDialPosition' => new \PHPExiftool\Driver\Tag\Sony\ModeDialPosition(),
                'MemoryCardConfiguration' => new \PHPExiftool\Driver\Tag\Sony\MemoryCardConfiguration(),
                'CameraOrientation' => new \PHPExiftool\Driver\Tag\Sony\CameraOrientation(),
                'FacesDetected' => new \PHPExiftool\Driver\Tag\Sony\FacesDetected(),
                'Face1Position' => new \PHPExiftool\Driver\Tag\Sony\Face1Position(),
                'Face2Position' => new \PHPExiftool\Driver\Tag\Sony\Face2Position(),
                'Face3Position' => new \PHPExiftool\Driver\Tag\Sony\Face3Position(),
                'Face4Position' => new \PHPExiftool\Driver\Tag\Sony\Face4Position(),
                'Face5Position' => new \PHPExiftool\Driver\Tag\Sony\Face5Position(),
                'Face6Position' => new \PHPExiftool\Driver\Tag\Sony\Face6Position(),
                'Face7Position' => new \PHPExiftool\Driver\Tag\Sony\Face7Position(),
                'Face8Position' => new \PHPExiftool\Driver\Tag\Sony\Face8Position(),
                'DriveMode2' => new \PHPExiftool\Driver\Tag\Sony\DriveMode2(),
                'BracketShotNumber' => new \PHPExiftool\Driver\Tag\Sony\BracketShotNumber(),
                'WhiteBalanceBracketing' => new \PHPExiftool\Driver\Tag\Sony\WhiteBalanceBracketing(),
                'BracketShotNumber2' => new \PHPExiftool\Driver\Tag\Sony\BracketShotNumber2(),
                'DynamicRangeOptimizerBracket' => new \PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizerBracket(),
                'ExposureBracketShotNumber' => new \PHPExiftool\Driver\Tag\Sony\ExposureBracketShotNumber(),
                'FocusPosition' => new \PHPExiftool\Driver\Tag\Sony\FocusPosition(),
                'FlashExposureComp' => new \PHPExiftool\Driver\Tag\Sony\FlashExposureComp(),
                'Teleconverter' => new \PHPExiftool\Driver\Tag\Sony\Teleconverter(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\Sony\WhiteBalance(),
                'MultiBurstMode' => new \PHPExiftool\Driver\Tag\Sony\MultiBurstMode(),
                'MultiBurstImageWidth' => new \PHPExiftool\Driver\Tag\Sony\MultiBurstImageWidth(),
                'MultiBurstImageHeight' => new \PHPExiftool\Driver\Tag\Sony\MultiBurstImageHeight(),
                'PreviewImage' => new \PHPExiftool\Driver\Tag\Sony\PreviewImage(),
                'Rating' => new \PHPExiftool\Driver\Tag\Sony\Rating(),
                'HDR' => new \PHPExiftool\Driver\Tag\Sony\HDR(),
                'PictureEffect' => new \PHPExiftool\Driver\Tag\Sony\PictureEffect(),
                'SoftSkinEffect' => new \PHPExiftool\Driver\Tag\Sony\SoftSkinEffect(),
                'Sony_0x2010' => new \PHPExiftool\Driver\Tag\Sony\Sony0x2010(),
                'VignettingCorrection' => new \PHPExiftool\Driver\Tag\Sony\VignettingCorrection(),
                'LateralChromaticAberration' => new \PHPExiftool\Driver\Tag\Sony\LateralChromaticAberration(),
                'DistortionCorrection' => new \PHPExiftool\Driver\Tag\Sony\DistortionCorrection(),
                'WBShiftAB_GM' => new \PHPExiftool\Driver\Tag\Sony\WBShiftABGM(),
                'AutoPortraitFramed' => new \PHPExiftool\Driver\Tag\Sony\AutoPortraitFramed(),
                'Sony_0x9400' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9400(),
                'Sony_0x9401' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9401(),
                'Sony_0x9402' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9402(),
                'Sony_0x9403' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9403(),
                'Sony_0x9404' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9404(),
                'Sony_0x9405' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9405(),
                'Sony_0x9406' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9406(),
                'Sony_0x9407' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9407(),
                'Sony_0x9408' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9408(),
                'Sony_0x9409' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9409(),
                'Sony_0x940a' => new \PHPExiftool\Driver\Tag\Sony\Sony0x940a(),
                'Sony_0x940b' => new \PHPExiftool\Driver\Tag\Sony\Sony0x940b(),
                'Sony_0x940c' => new \PHPExiftool\Driver\Tag\Sony\Sony0x940c(),
                'Sony_0x940d' => new \PHPExiftool\Driver\Tag\Sony\Sony0x940d(),
                'Sony_0x9411' => new \PHPExiftool\Driver\Tag\Sony\Sony0x9411(),
                'FileFormat' => new \PHPExiftool\Driver\Tag\Sony\FileFormat(),
                'SonyModelID' => new \PHPExiftool\Driver\Tag\Sony\SonyModelID(),
                'ColorReproduction' => new \PHPExiftool\Driver\Tag\Sony\ColorReproduction(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\Sony\ColorTemperature(),
                'ColorCompensationFilter' => new \PHPExiftool\Driver\Tag\Sony\ColorCompensationFilter(),
                'SceneMode' => new \PHPExiftool\Driver\Tag\Sony\SceneMode(),
                'ZoneMatching' => new \PHPExiftool\Driver\Tag\Sony\ZoneMatching(),
                'DynamicRangeOptimizer' => new \PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizer(),
                'LensType' => new \PHPExiftool\Driver\Tag\Sony\LensType(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\Sony\ColorMode(),
                'FullImageSize' => new \PHPExiftool\Driver\Tag\Sony\FullImageSize(),
                'PreviewImageSize' => new \PHPExiftool\Driver\Tag\Sony\PreviewImageSize(),
                'Macro' => new \PHPExiftool\Driver\Tag\Sony\Macro(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\Sony\ExposureMode(),
                'AFMode' => new \PHPExiftool\Driver\Tag\Sony\AFMode(),
                'FlashLevel' => new \PHPExiftool\Driver\Tag\Sony\FlashLevel(),
                'ReleaseMode' => new \PHPExiftool\Driver\Tag\Sony\ReleaseMode(),
                'Anti-Blur' => new \PHPExiftool\Driver\Tag\Sony\AntiBlur(),
                'HighISONoiseReduction2' => new \PHPExiftool\Driver\Tag\Sony\HighISONoiseReduction2(),
                'IntelligentAuto' => new \PHPExiftool\Driver\Tag\Sony\IntelligentAuto(),
                'TiffMeteringImage' => new \PHPExiftool\Driver\Tag\Sony\TiffMeteringImage(),
                'CustomWB_RBLevels' => new \PHPExiftool\Driver\Tag\Sony\CustomWBRBLevels(),
                'LiveViewAFMethod' => new \PHPExiftool\Driver\Tag\Sony\LiveViewAFMethod(),
                'ExposureCompensation2' => new \PHPExiftool\Driver\Tag\Sony\ExposureCompensation2(),
                'FlashExposureCompSet2' => new \PHPExiftool\Driver\Tag\Sony\FlashExposureCompSet2(),
                'Orientation2' => new \PHPExiftool\Driver\Tag\Sony\Orientation2(),
                'FlashAction2' => new \PHPExiftool\Driver\Tag\Sony\FlashAction2(),
                'FocusMode2' => new \PHPExiftool\Driver\Tag\Sony\FocusMode2(),
                'JpgFromRawStart' => new \PHPExiftool\Driver\Tag\Sony\JpgFromRawStart(),
                'JpgFromRawLength' => new \PHPExiftool\Driver\Tag\Sony\JpgFromRawLength(),
                'SonyImageWidth' => new \PHPExiftool\Driver\Tag\Sony\SonyImageWidth(),
                'SonyImageHeight' => new \PHPExiftool\Driver\Tag\Sony\SonyImageHeight(),
                'Orientation' => new \PHPExiftool\Driver\Tag\Sony\Orientation(),
                'ImageQuality' => new \PHPExiftool\Driver\Tag\Sony\ImageQuality(),
                'Comment' => new \PHPExiftool\Driver\Tag\Sony\Comment(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\Sony\DateTimeOriginal(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\Sony\ModifyDate(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\Sony\ExposureCompensation(),
                'Flash' => new \PHPExiftool\Driver\Tag\Sony\Flash(),
                'PanoramaFullWidth' => new \PHPExiftool\Driver\Tag\Sony\PanoramaFullWidth(),
                'PanoramaFullHeight' => new \PHPExiftool\Driver\Tag\Sony\PanoramaFullHeight(),
                'PanoramaDirection' => new \PHPExiftool\Driver\Tag\Sony\PanoramaDirection(),
                'PanoramaCropLeft' => new \PHPExiftool\Driver\Tag\Sony\PanoramaCropLeft(),
                'PanoramaCropTop' => new \PHPExiftool\Driver\Tag\Sony\PanoramaCropTop(),
                'PanoramaCropRight' => new \PHPExiftool\Driver\Tag\Sony\PanoramaCropRight(),
                'PanoramaCropBottom' => new \PHPExiftool\Driver\Tag\Sony\PanoramaCropBottom(),
                'PanoramaFrameWidth' => new \PHPExiftool\Driver\Tag\Sony\PanoramaFrameWidth(),
                'PanoramaFrameHeight' => new \PHPExiftool\Driver\Tag\Sony\PanoramaFrameHeight(),
                'PanoramaSourceWidth' => new \PHPExiftool\Driver\Tag\Sony\PanoramaSourceWidth(),
                'PanoramaSourceHeight' => new \PHPExiftool\Driver\Tag\Sony\PanoramaSourceHeight(),
                'FaceInfoOffset' => new \PHPExiftool\Driver\Tag\Sony\FaceInfoOffset(),
                'SonyDateTime' => new \PHPExiftool\Driver\Tag\Sony\SonyDateTime(),
                'FaceInfoLength' => new \PHPExiftool\Driver\Tag\Sony\FaceInfoLength(),
                'SequenceImageNumber' => new \PHPExiftool\Driver\Tag\Sony\SequenceImageNumber(),
                'SequenceFileNumber' => new \PHPExiftool\Driver\Tag\Sony\SequenceFileNumber(),
                'ReleaseMode2' => new \PHPExiftool\Driver\Tag\Sony\ReleaseMode2(),
                'ShotNumberSincePowerUp' => new \PHPExiftool\Driver\Tag\Sony\ShotNumberSincePowerUp(),
                'SequenceLength' => new \PHPExiftool\Driver\Tag\Sony\SequenceLength(),
                'Quality2' => new \PHPExiftool\Driver\Tag\Sony\Quality2(),
                'TempTest1' => new \PHPExiftool\Driver\Tag\Sony\TempTest1(),
                'AmbientTemperature' => new \PHPExiftool\Driver\Tag\Sony\AmbientTemperature(),
                'TempTest2' => new \PHPExiftool\Driver\Tag\Sony\TempTest2(),
                'CameraTemperature' => new \PHPExiftool\Driver\Tag\Sony\CameraTemperature(),
                'AFMicroAdj' => new \PHPExiftool\Driver\Tag\Sony\AFMicroAdj(),
            );
        });
        $this['SR2DataIFD'] = $this->share(function(){
            return array(
                'ColorMode' => new \PHPExiftool\Driver\Tag\SR2DataIFD\ColorMode(),
            );
        });
        $this['SR2'] = $this->share(function(){
            return array(
                'SR2SubIFDOffset' => new \PHPExiftool\Driver\Tag\SR2\SR2SubIFDOffset(),
                'SR2SubIFDLength' => new \PHPExiftool\Driver\Tag\SR2\SR2SubIFDLength(),
                'SR2SubIFDKey' => new \PHPExiftool\Driver\Tag\SR2\SR2SubIFDKey(),
            );
        });
        $this['SR2SubIFD'] = $this->share(function(){
            return array(
                'WB_GRBGLevels' => new \PHPExiftool\Driver\Tag\SR2SubIFD\WBGRBGLevels(),
                'WB_RGGBLevels' => new \PHPExiftool\Driver\Tag\SR2SubIFD\WBRGGBLevels(),
                'MaxApertureAtMaxFocal' => new \PHPExiftool\Driver\Tag\SR2SubIFD\MaxApertureAtMaxFocal(),
                'MaxApertureAtMinFocal' => new \PHPExiftool\Driver\Tag\SR2SubIFD\MaxApertureAtMinFocal(),
                'WB_RGBLevelsDaylight' => new \PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsDaylight(),
                'WB_RGBLevelsCloudy' => new \PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsCloudy(),
                'WB_RGBLevelsTungsten' => new \PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsTungsten(),
                'WB_RGBLevelsShade' => new \PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsShade(),
                'WB_RGBLevelsFluorescent' => new \PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsFluorescent(),
                'WB_RGBLevelsFlash' => new \PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsFlash(),
            );
        });
        $this['SRF#'] = $this->share(function(){
            return array(
                'SRF2Key' => new \PHPExiftool\Driver\Tag\SRF\SRF2Key(),
                'DataKey' => new \PHPExiftool\Driver\Tag\SRF\DataKey(),
                'SRF6Offset' => new \PHPExiftool\Driver\Tag\SRF\SRF6Offset(),
                'SRFDataOffset' => new \PHPExiftool\Driver\Tag\SRF\SRFDataOffset(),
                'RawDataOffset' => new \PHPExiftool\Driver\Tag\SRF\RawDataOffset(),
                'RawDataLength' => new \PHPExiftool\Driver\Tag\SRF\RawDataLength(),
            );
        });
        $this['SonyIDC'] = $this->share(function(){
            return array(
                'IDCPreviewStart' => new \PHPExiftool\Driver\Tag\SonyIDC\IDCPreviewStart(),
                'IDCPreviewLength' => new \PHPExiftool\Driver\Tag\SonyIDC\IDCPreviewLength(),
                'IDCCreativeStyle' => new \PHPExiftool\Driver\Tag\SonyIDC\IDCCreativeStyle(),
                'CreativeStyleWasChanged' => new \PHPExiftool\Driver\Tag\SonyIDC\CreativeStyleWasChanged(),
                'PresetWhiteBalance' => new \PHPExiftool\Driver\Tag\SonyIDC\PresetWhiteBalance(),
                'ColorTemperatureAdj' => new \PHPExiftool\Driver\Tag\SonyIDC\ColorTemperatureAdj(),
                'PresetWhiteBalanceAdj' => new \PHPExiftool\Driver\Tag\SonyIDC\PresetWhiteBalanceAdj(),
                'ColorCorrection' => new \PHPExiftool\Driver\Tag\SonyIDC\ColorCorrection(),
                'SaturationAdj' => new \PHPExiftool\Driver\Tag\SonyIDC\SaturationAdj(),
                'ContrastAdj' => new \PHPExiftool\Driver\Tag\SonyIDC\ContrastAdj(),
                'BrightnessAdj' => new \PHPExiftool\Driver\Tag\SonyIDC\BrightnessAdj(),
                'HueAdj' => new \PHPExiftool\Driver\Tag\SonyIDC\HueAdj(),
                'SharpnessAdj' => new \PHPExiftool\Driver\Tag\SonyIDC\SharpnessAdj(),
                'SharpnessOvershoot' => new \PHPExiftool\Driver\Tag\SonyIDC\SharpnessOvershoot(),
                'SharpnessUndershoot' => new \PHPExiftool\Driver\Tag\SonyIDC\SharpnessUndershoot(),
                'SharpnessThreshold' => new \PHPExiftool\Driver\Tag\SonyIDC\SharpnessThreshold(),
                'NoiseReductionMode' => new \PHPExiftool\Driver\Tag\SonyIDC\NoiseReductionMode(),
                'GrayPoint' => new \PHPExiftool\Driver\Tag\SonyIDC\GrayPoint(),
                'D-RangeOptimizerMode' => new \PHPExiftool\Driver\Tag\SonyIDC\DRangeOptimizerMode(),
                'D-RangeOptimizerValue' => new \PHPExiftool\Driver\Tag\SonyIDC\DRangeOptimizerValue(),
                'D-RangeOptimizerHighlight' => new \PHPExiftool\Driver\Tag\SonyIDC\DRangeOptimizerHighlight(),
                'HighlightColorDistortReduct' => new \PHPExiftool\Driver\Tag\SonyIDC\HighlightColorDistortReduct(),
                'NoiseReductionValue' => new \PHPExiftool\Driver\Tag\SonyIDC\NoiseReductionValue(),
                'EdgeNoiseReduction' => new \PHPExiftool\Driver\Tag\SonyIDC\EdgeNoiseReduction(),
                'ColorNoiseReduction' => new \PHPExiftool\Driver\Tag\SonyIDC\ColorNoiseReduction(),
                'D-RangeOptimizerShadow' => new \PHPExiftool\Driver\Tag\SonyIDC\DRangeOptimizerShadow(),
                'PeripheralIllumCentralRadius' => new \PHPExiftool\Driver\Tag\SonyIDC\PeripheralIllumCentralRadius(),
                'PeripheralIllumCentralValue' => new \PHPExiftool\Driver\Tag\SonyIDC\PeripheralIllumCentralValue(),
                'PeripheralIllumPeriphValue' => new \PHPExiftool\Driver\Tag\SonyIDC\PeripheralIllumPeriphValue(),
                'ToneCurveBrightnessX' => new \PHPExiftool\Driver\Tag\SonyIDC\ToneCurveBrightnessX(),
                'ToneCurveRedX' => new \PHPExiftool\Driver\Tag\SonyIDC\ToneCurveRedX(),
                'ToneCurveGreenX' => new \PHPExiftool\Driver\Tag\SonyIDC\ToneCurveGreenX(),
                'ToneCurveBlueX' => new \PHPExiftool\Driver\Tag\SonyIDC\ToneCurveBlueX(),
                'ToneCurveBrightnessY' => new \PHPExiftool\Driver\Tag\SonyIDC\ToneCurveBrightnessY(),
                'ToneCurveRedY' => new \PHPExiftool\Driver\Tag\SonyIDC\ToneCurveRedY(),
                'ToneCurveGreenY' => new \PHPExiftool\Driver\Tag\SonyIDC\ToneCurveGreenY(),
                'ToneCurveBlueY' => new \PHPExiftool\Driver\Tag\SonyIDC\ToneCurveBlueY(),
                'CurrentVersion' => new \PHPExiftool\Driver\Tag\SonyIDC\CurrentVersion(),
                'VersionCreateDate' => new \PHPExiftool\Driver\Tag\SonyIDC\VersionCreateDate(),
                'VersionModifyDate' => new \PHPExiftool\Driver\Tag\SonyIDC\VersionModifyDate(),
            );
        });
        $this['Stim'] = $this->share(function(){
            return array(
                'CropXCommonOffset' => new \PHPExiftool\Driver\Tag\Stim\CropXCommonOffset(),
                'CropXViewpointNumber' => new \PHPExiftool\Driver\Tag\Stim\CropXViewpointNumber(),
                'CropXOffset' => new \PHPExiftool\Driver\Tag\Stim\CropXOffset(),
                'CropXViewpointNumber2' => new \PHPExiftool\Driver\Tag\Stim\CropXViewpointNumber2(),
                'CropXOffset2' => new \PHPExiftool\Driver\Tag\Stim\CropXOffset2(),
                'CropYCommonOffset' => new \PHPExiftool\Driver\Tag\Stim\CropYCommonOffset(),
                'CropYViewpointNumber' => new \PHPExiftool\Driver\Tag\Stim\CropYViewpointNumber(),
                'CropYOffset' => new \PHPExiftool\Driver\Tag\Stim\CropYOffset(),
                'CropYViewpointNumber2' => new \PHPExiftool\Driver\Tag\Stim\CropYViewpointNumber2(),
                'CropYOffset2' => new \PHPExiftool\Driver\Tag\Stim\CropYOffset2(),
                'StimVersion' => new \PHPExiftool\Driver\Tag\Stim\StimVersion(),
                'ApplicationData' => new \PHPExiftool\Driver\Tag\Stim\ApplicationData(),
                'ImageArrangement' => new \PHPExiftool\Driver\Tag\Stim\ImageArrangement(),
                'ImageRotation' => new \PHPExiftool\Driver\Tag\Stim\ImageRotation(),
                'ScalingFactor' => new \PHPExiftool\Driver\Tag\Stim\ScalingFactor(),
                'CropXSize' => new \PHPExiftool\Driver\Tag\Stim\CropXSize(),
                'CropYSize' => new \PHPExiftool\Driver\Tag\Stim\CropYSize(),
                'ViewType' => new \PHPExiftool\Driver\Tag\Stim\ViewType(),
                'RepresentativeImage' => new \PHPExiftool\Driver\Tag\Stim\RepresentativeImage(),
                'ConvergenceBaseImage' => new \PHPExiftool\Driver\Tag\Stim\ConvergenceBaseImage(),
                'AssumedDisplaySize' => new \PHPExiftool\Driver\Tag\Stim\AssumedDisplaySize(),
                'AssumedDistanceView' => new \PHPExiftool\Driver\Tag\Stim\AssumedDistanceView(),
                'RepresentativeDisparityNear' => new \PHPExiftool\Driver\Tag\Stim\RepresentativeDisparityNear(),
                'RepresentativeDisparityFar' => new \PHPExiftool\Driver\Tag\Stim\RepresentativeDisparityFar(),
                'InitialDisplayEffect' => new \PHPExiftool\Driver\Tag\Stim\InitialDisplayEffect(),
                'ConvergenceDistance' => new \PHPExiftool\Driver\Tag\Stim\ConvergenceDistance(),
                'CameraArrangementInterval' => new \PHPExiftool\Driver\Tag\Stim\CameraArrangementInterval(),
                'ShootingCount' => new \PHPExiftool\Driver\Tag\Stim\ShootingCount(),
            );
        });
        $this['Theora'] = $this->share(function(){
            return array(
                'TheoraVersion' => new \PHPExiftool\Driver\Tag\Theora\TheoraVersion(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\Theora\ImageWidth(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\Theora\ImageHeight(),
                'XOffset' => new \PHPExiftool\Driver\Tag\Theora\XOffset(),
                'YOffset' => new \PHPExiftool\Driver\Tag\Theora\YOffset(),
                'FrameRate' => new \PHPExiftool\Driver\Tag\Theora\FrameRate(),
                'PixelAspectRatio' => new \PHPExiftool\Driver\Tag\Theora\PixelAspectRatio(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\Theora\ColorSpace(),
                'NominalVideoBitrate' => new \PHPExiftool\Driver\Tag\Theora\NominalVideoBitrate(),
                'Quality' => new \PHPExiftool\Driver\Tag\Theora\Quality(),
                'PixelFormat' => new \PHPExiftool\Driver\Tag\Theora\PixelFormat(),
            );
        });
        $this['Vorbis'] = $this->share(function(){
            return array(
                'Actor' => new \PHPExiftool\Driver\Tag\Vorbis\Actor(),
                'Album' => new \PHPExiftool\Driver\Tag\Vorbis\Album(),
                'Artist' => new \PHPExiftool\Driver\Tag\Vorbis\Artist(),
                'Comment' => new \PHPExiftool\Driver\Tag\Vorbis\Comment(),
                'Composer' => new \PHPExiftool\Driver\Tag\Vorbis\Composer(),
                'Contact' => new \PHPExiftool\Driver\Tag\Vorbis\Contact(),
                'Copyright' => new \PHPExiftool\Driver\Tag\Vorbis\Copyright(),
                'CoverArt' => new \PHPExiftool\Driver\Tag\Vorbis\CoverArt(),
                'CoverArtMIMEType' => new \PHPExiftool\Driver\Tag\Vorbis\CoverArtMIMEType(),
                'Date' => new \PHPExiftool\Driver\Tag\Vorbis\Date(),
                'Description' => new \PHPExiftool\Driver\Tag\Vorbis\Description(),
                'Director' => new \PHPExiftool\Driver\Tag\Vorbis\Director(),
                'EncodedBy' => new \PHPExiftool\Driver\Tag\Vorbis\EncodedBy(),
                'EncodedUsing' => new \PHPExiftool\Driver\Tag\Vorbis\EncodedUsing(),
                'Genre' => new \PHPExiftool\Driver\Tag\Vorbis\Genre(),
                'ISRCNumber' => new \PHPExiftool\Driver\Tag\Vorbis\ISRCNumber(),
                'License' => new \PHPExiftool\Driver\Tag\Vorbis\License(),
                'Location' => new \PHPExiftool\Driver\Tag\Vorbis\Location(),
                'Organization' => new \PHPExiftool\Driver\Tag\Vorbis\Organization(),
                'Performer' => new \PHPExiftool\Driver\Tag\Vorbis\Performer(),
                'Producer' => new \PHPExiftool\Driver\Tag\Vorbis\Producer(),
                'ReplayGainAlbumGain' => new \PHPExiftool\Driver\Tag\Vorbis\ReplayGainAlbumGain(),
                'ReplayGainAlbumPeak' => new \PHPExiftool\Driver\Tag\Vorbis\ReplayGainAlbumPeak(),
                'ReplayGainTrackGain' => new \PHPExiftool\Driver\Tag\Vorbis\ReplayGainTrackGain(),
                'ReplayGainTrackPeak' => new \PHPExiftool\Driver\Tag\Vorbis\ReplayGainTrackPeak(),
                'Title' => new \PHPExiftool\Driver\Tag\Vorbis\Title(),
                'TrackNumber' => new \PHPExiftool\Driver\Tag\Vorbis\TrackNumber(),
                'Version' => new \PHPExiftool\Driver\Tag\Vorbis\Version(),
                'Vendor' => new \PHPExiftool\Driver\Tag\Vorbis\Vendor(),
                'VorbisVersion' => new \PHPExiftool\Driver\Tag\Vorbis\VorbisVersion(),
                'AudioChannels' => new \PHPExiftool\Driver\Tag\Vorbis\AudioChannels(),
                'SampleRate' => new \PHPExiftool\Driver\Tag\Vorbis\SampleRate(),
                'MaximumBitrate' => new \PHPExiftool\Driver\Tag\Vorbis\MaximumBitrate(),
                'NominalBitrate' => new \PHPExiftool\Driver\Tag\Vorbis\NominalBitrate(),
                'MinimumBitrate' => new \PHPExiftool\Driver\Tag\Vorbis\MinimumBitrate(),
            );
        });
        $this['XMP-album'] = $this->share(function(){
            return array(
                'Notes' => new \PHPExiftool\Driver\Tag\XMPAlbum\Notes(),
            );
        });
        $this['XMP-DICOM'] = $this->share(function(){
            return array(
                'EquipmentInstitution' => new \PHPExiftool\Driver\Tag\XMPDICOM\EquipmentInstitution(),
                'EquipmentManufacturer' => new \PHPExiftool\Driver\Tag\XMPDICOM\EquipmentManufacturer(),
                'PatientBirthDate' => new \PHPExiftool\Driver\Tag\XMPDICOM\PatientBirthDate(),
                'PatientID' => new \PHPExiftool\Driver\Tag\XMPDICOM\PatientID(),
                'PatientName' => new \PHPExiftool\Driver\Tag\XMPDICOM\PatientName(),
                'PatientSex' => new \PHPExiftool\Driver\Tag\XMPDICOM\PatientSex(),
                'SeriesDateTime' => new \PHPExiftool\Driver\Tag\XMPDICOM\SeriesDateTime(),
                'SeriesDescription' => new \PHPExiftool\Driver\Tag\XMPDICOM\SeriesDescription(),
                'SeriesModality' => new \PHPExiftool\Driver\Tag\XMPDICOM\SeriesModality(),
                'SeriesNumber' => new \PHPExiftool\Driver\Tag\XMPDICOM\SeriesNumber(),
                'StudyDateTime' => new \PHPExiftool\Driver\Tag\XMPDICOM\StudyDateTime(),
                'StudyDescription' => new \PHPExiftool\Driver\Tag\XMPDICOM\StudyDescription(),
                'StudyID' => new \PHPExiftool\Driver\Tag\XMPDICOM\StudyID(),
                'StudyPhysician' => new \PHPExiftool\Driver\Tag\XMPDICOM\StudyPhysician(),
            );
        });
        $this['XMP-expressionmedia'] = $this->share(function(){
            return array(
                'CatalogSets' => new \PHPExiftool\Driver\Tag\XMPExpressionmedia\CatalogSets(),
            );
        });
        $this['XMP-GPano'] = $this->share(function(){
            return array(
                'CaptureSoftware' => new \PHPExiftool\Driver\Tag\XMPGPano\CaptureSoftware(),
                'CroppedAreaImageHeightPixels' => new \PHPExiftool\Driver\Tag\XMPGPano\CroppedAreaImageHeightPixels(),
                'CroppedAreaImageWidthPixels' => new \PHPExiftool\Driver\Tag\XMPGPano\CroppedAreaImageWidthPixels(),
                'CroppedAreaLeftPixels' => new \PHPExiftool\Driver\Tag\XMPGPano\CroppedAreaLeftPixels(),
                'CroppedAreaTopPixels' => new \PHPExiftool\Driver\Tag\XMPGPano\CroppedAreaTopPixels(),
                'ExposureLockUsed' => new \PHPExiftool\Driver\Tag\XMPGPano\ExposureLockUsed(),
                'FirstPhotoDate' => new \PHPExiftool\Driver\Tag\XMPGPano\FirstPhotoDate(),
                'FullPanoHeightPixels' => new \PHPExiftool\Driver\Tag\XMPGPano\FullPanoHeightPixels(),
                'FullPanoWidthPixels' => new \PHPExiftool\Driver\Tag\XMPGPano\FullPanoWidthPixels(),
                'InitialHorizontalFOVDegrees' => new \PHPExiftool\Driver\Tag\XMPGPano\InitialHorizontalFOVDegrees(),
                'InitialViewHeadingDegrees' => new \PHPExiftool\Driver\Tag\XMPGPano\InitialViewHeadingDegrees(),
                'InitialViewPitchDegrees' => new \PHPExiftool\Driver\Tag\XMPGPano\InitialViewPitchDegrees(),
                'InitialViewRollDegrees' => new \PHPExiftool\Driver\Tag\XMPGPano\InitialViewRollDegrees(),
                'LargestValidInteriorRectHeight' => new \PHPExiftool\Driver\Tag\XMPGPano\LargestValidInteriorRectHeight(),
                'LargestValidInteriorRectLeft' => new \PHPExiftool\Driver\Tag\XMPGPano\LargestValidInteriorRectLeft(),
                'LargestValidInteriorRectTop' => new \PHPExiftool\Driver\Tag\XMPGPano\LargestValidInteriorRectTop(),
                'LargestValidInteriorRectWidth' => new \PHPExiftool\Driver\Tag\XMPGPano\LargestValidInteriorRectWidth(),
                'LastPhotoDate' => new \PHPExiftool\Driver\Tag\XMPGPano\LastPhotoDate(),
                'PoseHeadingDegrees' => new \PHPExiftool\Driver\Tag\XMPGPano\PoseHeadingDegrees(),
                'PosePitchDegrees' => new \PHPExiftool\Driver\Tag\XMPGPano\PosePitchDegrees(),
                'PoseRollDegrees' => new \PHPExiftool\Driver\Tag\XMPGPano\PoseRollDegrees(),
                'ProjectionType' => new \PHPExiftool\Driver\Tag\XMPGPano\ProjectionType(),
                'SourcePhotosCount' => new \PHPExiftool\Driver\Tag\XMPGPano\SourcePhotosCount(),
                'StitchingSoftware' => new \PHPExiftool\Driver\Tag\XMPGPano\StitchingSoftware(),
                'UsePanoramaViewer' => new \PHPExiftool\Driver\Tag\XMPGPano\UsePanoramaViewer(),
            );
        });
        $this['XMP-lr'] = $this->share(function(){
            return array(
                'HierarchicalSubject' => new \PHPExiftool\Driver\Tag\XMPLr\HierarchicalSubject(),
                'PrivateRTKInfo' => new \PHPExiftool\Driver\Tag\XMPLr\PrivateRTKInfo(),
            );
        });
        $this['XMP-mediapro'] = $this->share(function(){
            return array(
                'CatalogSets' => new \PHPExiftool\Driver\Tag\XMPMediapro\CatalogSets(),
                'Event' => new \PHPExiftool\Driver\Tag\XMPMediapro\Event(),
                'Location' => new \PHPExiftool\Driver\Tag\XMPMediapro\Location(),
                'People' => new \PHPExiftool\Driver\Tag\XMPMediapro\People(),
                'Status' => new \PHPExiftool\Driver\Tag\XMPMediapro\Status(),
                'UserFields' => new \PHPExiftool\Driver\Tag\XMPMediapro\UserFields(),
            );
        });
        $this['XMP-PixelLive'] = $this->share(function(){
            return array(
                'Author' => new \PHPExiftool\Driver\Tag\XMPPixelLive\Author(),
                'Comments' => new \PHPExiftool\Driver\Tag\XMPPixelLive\Comments(),
                'Copyright' => new \PHPExiftool\Driver\Tag\XMPPixelLive\Copyright(),
                'Date' => new \PHPExiftool\Driver\Tag\XMPPixelLive\Date(),
                'Genre' => new \PHPExiftool\Driver\Tag\XMPPixelLive\Genre(),
                'Title' => new \PHPExiftool\Driver\Tag\XMPPixelLive\Title(),
            );
        });
        $this['SVG'] = $this->share(function(){
            return array(
                'ImageHeight' => new \PHPExiftool\Driver\Tag\SVG\ImageHeight(),
                'ID' => new \PHPExiftool\Driver\Tag\SVG\ID(),
                'MetadataID' => new \PHPExiftool\Driver\Tag\SVG\MetadataID(),
                'SVGVersion' => new \PHPExiftool\Driver\Tag\SVG\SVGVersion(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\SVG\ImageWidth(),
            );
        });
        $this['XMP-aas'] = $this->share(function(){
            return array(
                'AffineA' => new \PHPExiftool\Driver\Tag\XMPAas\AffineA(),
                'AffineB' => new \PHPExiftool\Driver\Tag\XMPAas\AffineB(),
                'AffineC' => new \PHPExiftool\Driver\Tag\XMPAas\AffineC(),
                'AffineD' => new \PHPExiftool\Driver\Tag\XMPAas\AffineD(),
                'AffineX' => new \PHPExiftool\Driver\Tag\XMPAas\AffineX(),
                'AffineY' => new \PHPExiftool\Driver\Tag\XMPAas\AffineY(),
                'CropH' => new \PHPExiftool\Driver\Tag\XMPAas\CropH(),
                'CropW' => new \PHPExiftool\Driver\Tag\XMPAas\CropW(),
                'CropX' => new \PHPExiftool\Driver\Tag\XMPAas\CropX(),
                'CropY' => new \PHPExiftool\Driver\Tag\XMPAas\CropY(),
                'Curve0x' => new \PHPExiftool\Driver\Tag\XMPAas\Curve0x(),
                'Curve0y' => new \PHPExiftool\Driver\Tag\XMPAas\Curve0y(),
                'Curve1x' => new \PHPExiftool\Driver\Tag\XMPAas\Curve1x(),
                'Curve1y' => new \PHPExiftool\Driver\Tag\XMPAas\Curve1y(),
                'Curve2x' => new \PHPExiftool\Driver\Tag\XMPAas\Curve2x(),
                'Curve2y' => new \PHPExiftool\Driver\Tag\XMPAas\Curve2y(),
                'Curve3x' => new \PHPExiftool\Driver\Tag\XMPAas\Curve3x(),
                'Curve3y' => new \PHPExiftool\Driver\Tag\XMPAas\Curve3y(),
                'Curve4x' => new \PHPExiftool\Driver\Tag\XMPAas\Curve4x(),
                'Curve4y' => new \PHPExiftool\Driver\Tag\XMPAas\Curve4y(),
                'Highlights' => new \PHPExiftool\Driver\Tag\XMPAas\Highlights(),
                'Shadows' => new \PHPExiftool\Driver\Tag\XMPAas\Shadows(),
                'Vibrance' => new \PHPExiftool\Driver\Tag\XMPAas\Vibrance(),
            );
        });
        $this['XMP-acdsee'] = $this->share(function(){
            return array(
                'Author' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Author(),
                'Caption' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Caption(),
                'Categories' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Categories(),
                'Datetime' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Datetime(),
                'DPP' => new \PHPExiftool\Driver\Tag\XMPAcdsee\DPP(),
                'Keywords' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Keywords(),
                'Notes' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Notes(),
                'Rating' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Rating(),
                'Rawrppused' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Rawrppused(),
                'RPP' => new \PHPExiftool\Driver\Tag\XMPAcdsee\RPP(),
                'Tagged' => new \PHPExiftool\Driver\Tag\XMPAcdsee\Tagged(),
            );
        });
        $this['XMP-apple-fi'] = $this->share(function(){
            return array(
                'AngleInfoRoll' => new \PHPExiftool\Driver\Tag\XMPAppleFi\AngleInfoRoll(),
                'ConfidenceLevel' => new \PHPExiftool\Driver\Tag\XMPAppleFi\ConfidenceLevel(),
                'FaceID' => new \PHPExiftool\Driver\Tag\XMPAppleFi\FaceID(),
                'TimeStamp' => new \PHPExiftool\Driver\Tag\XMPAppleFi\TimeStamp(),
            );
        });
        $this['XMP-aux'] = $this->share(function(){
            return array(
                'ApproximateFocusDistance' => new \PHPExiftool\Driver\Tag\XMPAux\ApproximateFocusDistance(),
                'Firmware' => new \PHPExiftool\Driver\Tag\XMPAux\Firmware(),
                'FlashCompensation' => new \PHPExiftool\Driver\Tag\XMPAux\FlashCompensation(),
                'ImageNumber' => new \PHPExiftool\Driver\Tag\XMPAux\ImageNumber(),
                'Lens' => new \PHPExiftool\Driver\Tag\XMPAux\Lens(),
                'LensID' => new \PHPExiftool\Driver\Tag\XMPAux\LensID(),
                'LensInfo' => new \PHPExiftool\Driver\Tag\XMPAux\LensInfo(),
                'OwnerName' => new \PHPExiftool\Driver\Tag\XMPAux\OwnerName(),
                'SerialNumber' => new \PHPExiftool\Driver\Tag\XMPAux\SerialNumber(),
            );
        });
        $this['XMP-cc'] = $this->share(function(){
            return array(
                'AttributionName' => new \PHPExiftool\Driver\Tag\XMPCc\AttributionName(),
                'AttributionURL' => new \PHPExiftool\Driver\Tag\XMPCc\AttributionURL(),
                'DeprecatedOn' => new \PHPExiftool\Driver\Tag\XMPCc\DeprecatedOn(),
                'Jurisdiction' => new \PHPExiftool\Driver\Tag\XMPCc\Jurisdiction(),
                'LegalCode' => new \PHPExiftool\Driver\Tag\XMPCc\LegalCode(),
                'License' => new \PHPExiftool\Driver\Tag\XMPCc\License(),
                'MorePermissions' => new \PHPExiftool\Driver\Tag\XMPCc\MorePermissions(),
                'Permits' => new \PHPExiftool\Driver\Tag\XMPCc\Permits(),
                'Prohibits' => new \PHPExiftool\Driver\Tag\XMPCc\Prohibits(),
                'Requires' => new \PHPExiftool\Driver\Tag\XMPCc\Requires(),
                'UseGuidelines' => new \PHPExiftool\Driver\Tag\XMPCc\UseGuidelines(),
            );
        });
        $this['XMP-cell'] = $this->share(function(){
            return array(
                'CellTowerID' => new \PHPExiftool\Driver\Tag\XMPCell\CellTowerID(),
                'CellGlobalID' => new \PHPExiftool\Driver\Tag\XMPCell\CellGlobalID(),
                'LocationAreaCode' => new \PHPExiftool\Driver\Tag\XMPCell\LocationAreaCode(),
                'MobileCountryCode' => new \PHPExiftool\Driver\Tag\XMPCell\MobileCountryCode(),
                'MobileNetworkCode' => new \PHPExiftool\Driver\Tag\XMPCell\MobileNetworkCode(),
                'CellR' => new \PHPExiftool\Driver\Tag\XMPCell\CellR(),
            );
        });
        $this['XMP-crs'] = $this->share(function(){
            return array(
                'AlreadyApplied' => new \PHPExiftool\Driver\Tag\XMPCrs\AlreadyApplied(),
                'AutoBrightness' => new \PHPExiftool\Driver\Tag\XMPCrs\AutoBrightness(),
                'AutoContrast' => new \PHPExiftool\Driver\Tag\XMPCrs\AutoContrast(),
                'AutoExposure' => new \PHPExiftool\Driver\Tag\XMPCrs\AutoExposure(),
                'AutoLateralCA' => new \PHPExiftool\Driver\Tag\XMPCrs\AutoLateralCA(),
                'AutoShadows' => new \PHPExiftool\Driver\Tag\XMPCrs\AutoShadows(),
                'Blacks2012' => new \PHPExiftool\Driver\Tag\XMPCrs\Blacks2012(),
                'BlueHue' => new \PHPExiftool\Driver\Tag\XMPCrs\BlueHue(),
                'BlueSaturation' => new \PHPExiftool\Driver\Tag\XMPCrs\BlueSaturation(),
                'Brightness' => new \PHPExiftool\Driver\Tag\XMPCrs\Brightness(),
                'CameraProfile' => new \PHPExiftool\Driver\Tag\XMPCrs\CameraProfile(),
                'CameraProfileDigest' => new \PHPExiftool\Driver\Tag\XMPCrs\CameraProfileDigest(),
                'ChromaticAberrationB' => new \PHPExiftool\Driver\Tag\XMPCrs\ChromaticAberrationB(),
                'ChromaticAberrationR' => new \PHPExiftool\Driver\Tag\XMPCrs\ChromaticAberrationR(),
                'Clarity' => new \PHPExiftool\Driver\Tag\XMPCrs\Clarity(),
                'Clarity2012' => new \PHPExiftool\Driver\Tag\XMPCrs\Clarity2012(),
                'ColorNoiseReduction' => new \PHPExiftool\Driver\Tag\XMPCrs\ColorNoiseReduction(),
                'ColorNoiseReductionDetail' => new \PHPExiftool\Driver\Tag\XMPCrs\ColorNoiseReductionDetail(),
                'Contrast' => new \PHPExiftool\Driver\Tag\XMPCrs\Contrast(),
                'Contrast2012' => new \PHPExiftool\Driver\Tag\XMPCrs\Contrast2012(),
                'Converter' => new \PHPExiftool\Driver\Tag\XMPCrs\Converter(),
                'ConvertToGrayscale' => new \PHPExiftool\Driver\Tag\XMPCrs\ConvertToGrayscale(),
                'CropAngle' => new \PHPExiftool\Driver\Tag\XMPCrs\CropAngle(),
                'CropBottom' => new \PHPExiftool\Driver\Tag\XMPCrs\CropBottom(),
                'CropConstrainToWarp' => new \PHPExiftool\Driver\Tag\XMPCrs\CropConstrainToWarp(),
                'CropHeight' => new \PHPExiftool\Driver\Tag\XMPCrs\CropHeight(),
                'CropLeft' => new \PHPExiftool\Driver\Tag\XMPCrs\CropLeft(),
                'CropRight' => new \PHPExiftool\Driver\Tag\XMPCrs\CropRight(),
                'CropTop' => new \PHPExiftool\Driver\Tag\XMPCrs\CropTop(),
                'CropUnit' => new \PHPExiftool\Driver\Tag\XMPCrs\CropUnit(),
                'CropUnits' => new \PHPExiftool\Driver\Tag\XMPCrs\CropUnits(),
                'CropWidth' => new \PHPExiftool\Driver\Tag\XMPCrs\CropWidth(),
                'Defringe' => new \PHPExiftool\Driver\Tag\XMPCrs\Defringe(),
                'DefringeGreenAmount' => new \PHPExiftool\Driver\Tag\XMPCrs\DefringeGreenAmount(),
                'DefringeGreenHueHi' => new \PHPExiftool\Driver\Tag\XMPCrs\DefringeGreenHueHi(),
                'DefringeGreenHueLo' => new \PHPExiftool\Driver\Tag\XMPCrs\DefringeGreenHueLo(),
                'DefringePurpleAmount' => new \PHPExiftool\Driver\Tag\XMPCrs\DefringePurpleAmount(),
                'DefringePurpleHueHi' => new \PHPExiftool\Driver\Tag\XMPCrs\DefringePurpleHueHi(),
                'DefringePurpleHueLo' => new \PHPExiftool\Driver\Tag\XMPCrs\DefringePurpleHueLo(),
                'Exposure' => new \PHPExiftool\Driver\Tag\XMPCrs\Exposure(),
                'Exposure2012' => new \PHPExiftool\Driver\Tag\XMPCrs\Exposure2012(),
                'FillLight' => new \PHPExiftool\Driver\Tag\XMPCrs\FillLight(),
                'GradientBasedCorrections' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrections(),
                'GradientBasedCorrActive' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrActive(),
                'GradientBasedCorrAmount' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrAmount(),
                'GradientBasedCorrMasks' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMasks(),
                'GradientBasedCorrMaskCenterWeight' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskCenterWeight(),
                'GradientBasedCorrMaskDabs' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskDabs(),
                'GradientBasedCorrMaskFlow' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskFlow(),
                'GradientBasedCorrMaskFullX' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskFullX(),
                'GradientBasedCorrMaskFullY' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskFullY(),
                'GradientBasedCorrMaskValue' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskValue(),
                'GradientBasedCorrMaskRadius' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskRadius(),
                'GradientBasedCorrMaskWhat' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskWhat(),
                'GradientBasedCorrMaskZeroX' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskZeroX(),
                'GradientBasedCorrMaskZeroY' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskZeroY(),
                'GradientBasedCorrBrightness' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrBrightness(),
                'GradientBasedCorrClarity' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrClarity(),
                'GradientBasedCorrClarity2012' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrClarity2012(),
                'GradientBasedCorrContrast' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrContrast(),
                'GradientBasedCorrContrast2012' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrContrast2012(),
                'GradientBasedCorrDefringe' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrDefringe(),
                'GradientBasedCorrExposure' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrExposure(),
                'GradientBasedCorrExposure2012' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrExposure2012(),
                'GradientBasedCorrHighlights2012' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrHighlights2012(),
                'GradientBasedCorrLuminanceNoise' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrLuminanceNoise(),
                'GradientBasedCorrMoire' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMoire(),
                'GradientBasedCorrSaturation' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrSaturation(),
                'GradientBasedCorrShadows2012' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrShadows2012(),
                'GradientBasedCorrSharpness' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrSharpness(),
                'GradientBasedCorrTemperature' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrTemperature(),
                'GradientBasedCorrTint' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrTint(),
                'GradientBasedCorrHue' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrHue(),
                'GradientBasedCorrWhat' => new \PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrWhat(),
                'GrainAmount' => new \PHPExiftool\Driver\Tag\XMPCrs\GrainAmount(),
                'GrainFrequency' => new \PHPExiftool\Driver\Tag\XMPCrs\GrainFrequency(),
                'GrainSize' => new \PHPExiftool\Driver\Tag\XMPCrs\GrainSize(),
                'GrayMixerAqua' => new \PHPExiftool\Driver\Tag\XMPCrs\GrayMixerAqua(),
                'GrayMixerBlue' => new \PHPExiftool\Driver\Tag\XMPCrs\GrayMixerBlue(),
                'GrayMixerGreen' => new \PHPExiftool\Driver\Tag\XMPCrs\GrayMixerGreen(),
                'GrayMixerMagenta' => new \PHPExiftool\Driver\Tag\XMPCrs\GrayMixerMagenta(),
                'GrayMixerOrange' => new \PHPExiftool\Driver\Tag\XMPCrs\GrayMixerOrange(),
                'GrayMixerPurple' => new \PHPExiftool\Driver\Tag\XMPCrs\GrayMixerPurple(),
                'GrayMixerRed' => new \PHPExiftool\Driver\Tag\XMPCrs\GrayMixerRed(),
                'GrayMixerYellow' => new \PHPExiftool\Driver\Tag\XMPCrs\GrayMixerYellow(),
                'GreenHue' => new \PHPExiftool\Driver\Tag\XMPCrs\GreenHue(),
                'GreenSaturation' => new \PHPExiftool\Driver\Tag\XMPCrs\GreenSaturation(),
                'HasCrop' => new \PHPExiftool\Driver\Tag\XMPCrs\HasCrop(),
                'HasSettings' => new \PHPExiftool\Driver\Tag\XMPCrs\HasSettings(),
                'HighlightRecovery' => new \PHPExiftool\Driver\Tag\XMPCrs\HighlightRecovery(),
                'Highlights2012' => new \PHPExiftool\Driver\Tag\XMPCrs\Highlights2012(),
                'HueAdjustmentAqua' => new \PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentAqua(),
                'HueAdjustmentBlue' => new \PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentBlue(),
                'HueAdjustmentGreen' => new \PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentGreen(),
                'HueAdjustmentMagenta' => new \PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentMagenta(),
                'HueAdjustmentOrange' => new \PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentOrange(),
                'HueAdjustmentPurple' => new \PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentPurple(),
                'HueAdjustmentRed' => new \PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentRed(),
                'HueAdjustmentYellow' => new \PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentYellow(),
                'IncrementalTemperature' => new \PHPExiftool\Driver\Tag\XMPCrs\IncrementalTemperature(),
                'IncrementalTint' => new \PHPExiftool\Driver\Tag\XMPCrs\IncrementalTint(),
                'LensManualDistortionAmount' => new \PHPExiftool\Driver\Tag\XMPCrs\LensManualDistortionAmount(),
                'LensProfileChromaticAberrationScale' => new \PHPExiftool\Driver\Tag\XMPCrs\LensProfileChromaticAberrationScale(),
                'LensProfileDigest' => new \PHPExiftool\Driver\Tag\XMPCrs\LensProfileDigest(),
                'LensProfileDistortionScale' => new \PHPExiftool\Driver\Tag\XMPCrs\LensProfileDistortionScale(),
                'LensProfileEnable' => new \PHPExiftool\Driver\Tag\XMPCrs\LensProfileEnable(),
                'LensProfileFilename' => new \PHPExiftool\Driver\Tag\XMPCrs\LensProfileFilename(),
                'LensProfileName' => new \PHPExiftool\Driver\Tag\XMPCrs\LensProfileName(),
                'LensProfileSetup' => new \PHPExiftool\Driver\Tag\XMPCrs\LensProfileSetup(),
                'LensProfileVignettingScale' => new \PHPExiftool\Driver\Tag\XMPCrs\LensProfileVignettingScale(),
                'LuminanceAdjustmentAqua' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentAqua(),
                'LuminanceAdjustmentBlue' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentBlue(),
                'LuminanceAdjustmentGreen' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentGreen(),
                'LuminanceAdjustmentMagenta' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentMagenta(),
                'LuminanceAdjustmentOrange' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentOrange(),
                'LuminanceAdjustmentPurple' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentPurple(),
                'LuminanceAdjustmentRed' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentRed(),
                'LuminanceAdjustmentYellow' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentYellow(),
                'LuminanceNoiseReductionContrast' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceNoiseReductionContrast(),
                'LuminanceNoiseReductionDetail' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceNoiseReductionDetail(),
                'LuminanceSmoothing' => new \PHPExiftool\Driver\Tag\XMPCrs\LuminanceSmoothing(),
                'MoireFilter' => new \PHPExiftool\Driver\Tag\XMPCrs\MoireFilter(),
                'PaintBasedCorrections' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintBasedCorrections(),
                'PaintCorrectionActive' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionActive(),
                'PaintCorrectionAmount' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionAmount(),
                'PaintBasedCorrectionMasks' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintBasedCorrectionMasks(),
                'PaintCorrectionMaskCenterWeight' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskCenterWeight(),
                'PaintCorrectionMaskDabs' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskDabs(),
                'PaintCorrectionMaskFlow' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskFlow(),
                'PaintCorrectionMaskFullX' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskFullX(),
                'PaintCorrectionMaskFullY' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskFullY(),
                'PaintCorrectionMaskValue' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskValue(),
                'PaintCorrectionMaskRadius' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskRadius(),
                'PaintCorrectionMaskWhat' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskWhat(),
                'PaintCorrectionMaskZeroX' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskZeroX(),
                'PaintCorrectionMaskZeroY' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskZeroY(),
                'PaintCorrectionBrightness' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionBrightness(),
                'PaintCorrectionClarity' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionClarity(),
                'PaintCorrectionClarity2012' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionClarity2012(),
                'PaintCorrectionContrast' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionContrast(),
                'PaintCorrectionContrast2012' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionContrast2012(),
                'PaintCorrectionDefringe' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionDefringe(),
                'PaintCorrectionExposure' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionExposure(),
                'PaintCorrectionExposure2012' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionExposure2012(),
                'PaintCorrectionHighlights2012' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionHighlights2012(),
                'PaintCorrectionLuminanceNoise' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionLuminanceNoise(),
                'PaintCorrectionMoire' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMoire(),
                'PaintCorrectionSaturation' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionSaturation(),
                'PaintCorrectionShadows2012' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionShadows2012(),
                'PaintCorrectionSharpness' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionSharpness(),
                'PaintCorrectionTemperature' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionTemperature(),
                'PaintCorrectionTint' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionTint(),
                'PaintCorrectionHue' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionHue(),
                'PaintCorrectionWhat' => new \PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionWhat(),
                'ParametricDarks' => new \PHPExiftool\Driver\Tag\XMPCrs\ParametricDarks(),
                'ParametricHighlights' => new \PHPExiftool\Driver\Tag\XMPCrs\ParametricHighlights(),
                'ParametricHighlightSplit' => new \PHPExiftool\Driver\Tag\XMPCrs\ParametricHighlightSplit(),
                'ParametricLights' => new \PHPExiftool\Driver\Tag\XMPCrs\ParametricLights(),
                'ParametricMidtoneSplit' => new \PHPExiftool\Driver\Tag\XMPCrs\ParametricMidtoneSplit(),
                'ParametricShadows' => new \PHPExiftool\Driver\Tag\XMPCrs\ParametricShadows(),
                'ParametricShadowSplit' => new \PHPExiftool\Driver\Tag\XMPCrs\ParametricShadowSplit(),
                'PerspectiveHorizontal' => new \PHPExiftool\Driver\Tag\XMPCrs\PerspectiveHorizontal(),
                'PerspectiveRotate' => new \PHPExiftool\Driver\Tag\XMPCrs\PerspectiveRotate(),
                'PerspectiveScale' => new \PHPExiftool\Driver\Tag\XMPCrs\PerspectiveScale(),
                'PerspectiveVertical' => new \PHPExiftool\Driver\Tag\XMPCrs\PerspectiveVertical(),
                'PostCropVignetteAmount' => new \PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteAmount(),
                'PostCropVignetteFeather' => new \PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteFeather(),
                'PostCropVignetteHighlightContrast' => new \PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteHighlightContrast(),
                'PostCropVignetteMidpoint' => new \PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteMidpoint(),
                'PostCropVignetteRoundness' => new \PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteRoundness(),
                'PostCropVignetteStyle' => new \PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteStyle(),
                'ProcessVersion' => new \PHPExiftool\Driver\Tag\XMPCrs\ProcessVersion(),
                'RawFileName' => new \PHPExiftool\Driver\Tag\XMPCrs\RawFileName(),
                'RedEyeInfo' => new \PHPExiftool\Driver\Tag\XMPCrs\RedEyeInfo(),
                'RedHue' => new \PHPExiftool\Driver\Tag\XMPCrs\RedHue(),
                'RedSaturation' => new \PHPExiftool\Driver\Tag\XMPCrs\RedSaturation(),
                'RetouchInfo' => new \PHPExiftool\Driver\Tag\XMPCrs\RetouchInfo(),
                'Saturation' => new \PHPExiftool\Driver\Tag\XMPCrs\Saturation(),
                'SaturationAdjustmentAqua' => new \PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentAqua(),
                'SaturationAdjustmentBlue' => new \PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentBlue(),
                'SaturationAdjustmentGreen' => new \PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentGreen(),
                'SaturationAdjustmentMagenta' => new \PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentMagenta(),
                'SaturationAdjustmentOrange' => new \PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentOrange(),
                'SaturationAdjustmentPurple' => new \PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentPurple(),
                'SaturationAdjustmentRed' => new \PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentRed(),
                'SaturationAdjustmentYellow' => new \PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentYellow(),
                'Shadows' => new \PHPExiftool\Driver\Tag\XMPCrs\Shadows(),
                'Shadows2012' => new \PHPExiftool\Driver\Tag\XMPCrs\Shadows2012(),
                'ShadowTint' => new \PHPExiftool\Driver\Tag\XMPCrs\ShadowTint(),
                'SharpenDetail' => new \PHPExiftool\Driver\Tag\XMPCrs\SharpenDetail(),
                'SharpenEdgeMasking' => new \PHPExiftool\Driver\Tag\XMPCrs\SharpenEdgeMasking(),
                'SharpenRadius' => new \PHPExiftool\Driver\Tag\XMPCrs\SharpenRadius(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\XMPCrs\Sharpness(),
                'Smoothness' => new \PHPExiftool\Driver\Tag\XMPCrs\Smoothness(),
                'SplitToningBalance' => new \PHPExiftool\Driver\Tag\XMPCrs\SplitToningBalance(),
                'SplitToningHighlightHue' => new \PHPExiftool\Driver\Tag\XMPCrs\SplitToningHighlightHue(),
                'SplitToningHighlightSaturation' => new \PHPExiftool\Driver\Tag\XMPCrs\SplitToningHighlightSaturation(),
                'SplitToningShadowHue' => new \PHPExiftool\Driver\Tag\XMPCrs\SplitToningShadowHue(),
                'SplitToningShadowSaturation' => new \PHPExiftool\Driver\Tag\XMPCrs\SplitToningShadowSaturation(),
                'ColorTemperature' => new \PHPExiftool\Driver\Tag\XMPCrs\ColorTemperature(),
                'Tint' => new \PHPExiftool\Driver\Tag\XMPCrs\Tint(),
                'ToneCurve' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurve(),
                'ToneCurveBlue' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurveBlue(),
                'ToneCurveGreen' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurveGreen(),
                'ToneCurveName' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurveName(),
                'ToneCurveName2012' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurveName2012(),
                'ToneCurvePV2012' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurvePV2012(),
                'ToneCurvePV2012Blue' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurvePV2012Blue(),
                'ToneCurvePV2012Green' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurvePV2012Green(),
                'ToneCurvePV2012Red' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurvePV2012Red(),
                'ToneCurveRed' => new \PHPExiftool\Driver\Tag\XMPCrs\ToneCurveRed(),
                'Version' => new \PHPExiftool\Driver\Tag\XMPCrs\Version(),
                'Vibrance' => new \PHPExiftool\Driver\Tag\XMPCrs\Vibrance(),
                'VignetteAmount' => new \PHPExiftool\Driver\Tag\XMPCrs\VignetteAmount(),
                'VignetteMidpoint' => new \PHPExiftool\Driver\Tag\XMPCrs\VignetteMidpoint(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\XMPCrs\WhiteBalance(),
                'Whites2012' => new \PHPExiftool\Driver\Tag\XMPCrs\Whites2012(),
            );
        });
        $this['XMP-dc'] = $this->share(function(){
            return array(
                'Contributor' => new \PHPExiftool\Driver\Tag\XMPDc\Contributor(),
                'Coverage' => new \PHPExiftool\Driver\Tag\XMPDc\Coverage(),
                'Creator' => new \PHPExiftool\Driver\Tag\XMPDc\Creator(),
                'Date' => new \PHPExiftool\Driver\Tag\XMPDc\Date(),
                'Description' => new \PHPExiftool\Driver\Tag\XMPDc\Description(),
                'Format' => new \PHPExiftool\Driver\Tag\XMPDc\Format(),
                'Identifier' => new \PHPExiftool\Driver\Tag\XMPDc\Identifier(),
                'Language' => new \PHPExiftool\Driver\Tag\XMPDc\Language(),
                'Publisher' => new \PHPExiftool\Driver\Tag\XMPDc\Publisher(),
                'Relation' => new \PHPExiftool\Driver\Tag\XMPDc\Relation(),
                'Rights' => new \PHPExiftool\Driver\Tag\XMPDc\Rights(),
                'Source' => new \PHPExiftool\Driver\Tag\XMPDc\Source(),
                'Subject' => new \PHPExiftool\Driver\Tag\XMPDc\Subject(),
                'Title' => new \PHPExiftool\Driver\Tag\XMPDc\Title(),
                'Type' => new \PHPExiftool\Driver\Tag\XMPDc\Type(),
            );
        });
        $this['XMP-dex'] = $this->share(function(){
            return array(
                'CRC32' => new \PHPExiftool\Driver\Tag\XMPDex\CRC32(),
                'FFID' => new \PHPExiftool\Driver\Tag\XMPDex\FFID(),
                'LicenseType' => new \PHPExiftool\Driver\Tag\XMPDex\LicenseType(),
                'OS' => new \PHPExiftool\Driver\Tag\XMPDex\OS(),
                'Rating' => new \PHPExiftool\Driver\Tag\XMPDex\Rating(),
                'Revision' => new \PHPExiftool\Driver\Tag\XMPDex\Revision(),
                'ShortDescription' => new \PHPExiftool\Driver\Tag\XMPDex\ShortDescription(),
                'Source' => new \PHPExiftool\Driver\Tag\XMPDex\Source(),
            );
        });
        $this['XMP-digiKam'] = $this->share(function(){
            return array(
                'CaptionsAuthorNames' => new \PHPExiftool\Driver\Tag\XMPDigiKam\CaptionsAuthorNames(),
                'CaptionsDateTimeStamps' => new \PHPExiftool\Driver\Tag\XMPDigiKam\CaptionsDateTimeStamps(),
                'ColorLabel' => new \PHPExiftool\Driver\Tag\XMPDigiKam\ColorLabel(),
                'PickLabel' => new \PHPExiftool\Driver\Tag\XMPDigiKam\PickLabel(),
                'TagsList' => new \PHPExiftool\Driver\Tag\XMPDigiKam\TagsList(),
            );
        });
        $this['XMP-exif'] = $this->share(function(){
            return array(
                'ApertureValue' => new \PHPExiftool\Driver\Tag\XMPExif\ApertureValue(),
                'BrightnessValue' => new \PHPExiftool\Driver\Tag\XMPExif\BrightnessValue(),
                'CFAPattern' => new \PHPExiftool\Driver\Tag\XMPExif\CFAPattern(),
                'CFAPatternColumns' => new \PHPExiftool\Driver\Tag\XMPExif\CFAPatternColumns(),
                'CFAPatternRows' => new \PHPExiftool\Driver\Tag\XMPExif\CFAPatternRows(),
                'CFAPatternValues' => new \PHPExiftool\Driver\Tag\XMPExif\CFAPatternValues(),
                'ColorSpace' => new \PHPExiftool\Driver\Tag\XMPExif\ColorSpace(),
                'ComponentsConfiguration' => new \PHPExiftool\Driver\Tag\XMPExif\ComponentsConfiguration(),
                'CompressedBitsPerPixel' => new \PHPExiftool\Driver\Tag\XMPExif\CompressedBitsPerPixel(),
                'Contrast' => new \PHPExiftool\Driver\Tag\XMPExif\Contrast(),
                'CustomRendered' => new \PHPExiftool\Driver\Tag\XMPExif\CustomRendered(),
                'DateTimeDigitized' => new \PHPExiftool\Driver\Tag\XMPExif\DateTimeDigitized(),
                'DateTimeOriginal' => new \PHPExiftool\Driver\Tag\XMPExif\DateTimeOriginal(),
                'DeviceSettingDescription' => new \PHPExiftool\Driver\Tag\XMPExif\DeviceSettingDescription(),
                'DeviceSettingDescriptionColumns' => new \PHPExiftool\Driver\Tag\XMPExif\DeviceSettingDescriptionColumns(),
                'DeviceSettingDescriptionRows' => new \PHPExiftool\Driver\Tag\XMPExif\DeviceSettingDescriptionRows(),
                'DeviceSettingDescriptionSettings' => new \PHPExiftool\Driver\Tag\XMPExif\DeviceSettingDescriptionSettings(),
                'DigitalZoomRatio' => new \PHPExiftool\Driver\Tag\XMPExif\DigitalZoomRatio(),
                'ExifVersion' => new \PHPExiftool\Driver\Tag\XMPExif\ExifVersion(),
                'ExposureCompensation' => new \PHPExiftool\Driver\Tag\XMPExif\ExposureCompensation(),
                'ExposureIndex' => new \PHPExiftool\Driver\Tag\XMPExif\ExposureIndex(),
                'ExposureMode' => new \PHPExiftool\Driver\Tag\XMPExif\ExposureMode(),
                'ExposureProgram' => new \PHPExiftool\Driver\Tag\XMPExif\ExposureProgram(),
                'ExposureTime' => new \PHPExiftool\Driver\Tag\XMPExif\ExposureTime(),
                'FileSource' => new \PHPExiftool\Driver\Tag\XMPExif\FileSource(),
                'Flash' => new \PHPExiftool\Driver\Tag\XMPExif\Flash(),
                'FlashEnergy' => new \PHPExiftool\Driver\Tag\XMPExif\FlashEnergy(),
                'FlashFired' => new \PHPExiftool\Driver\Tag\XMPExif\FlashFired(),
                'FlashFunction' => new \PHPExiftool\Driver\Tag\XMPExif\FlashFunction(),
                'FlashMode' => new \PHPExiftool\Driver\Tag\XMPExif\FlashMode(),
                'FlashpixVersion' => new \PHPExiftool\Driver\Tag\XMPExif\FlashpixVersion(),
                'FlashRedEyeMode' => new \PHPExiftool\Driver\Tag\XMPExif\FlashRedEyeMode(),
                'FlashReturn' => new \PHPExiftool\Driver\Tag\XMPExif\FlashReturn(),
                'FNumber' => new \PHPExiftool\Driver\Tag\XMPExif\FNumber(),
                'FocalLength' => new \PHPExiftool\Driver\Tag\XMPExif\FocalLength(),
                'FocalLengthIn35mmFormat' => new \PHPExiftool\Driver\Tag\XMPExif\FocalLengthIn35mmFormat(),
                'FocalPlaneResolutionUnit' => new \PHPExiftool\Driver\Tag\XMPExif\FocalPlaneResolutionUnit(),
                'FocalPlaneXResolution' => new \PHPExiftool\Driver\Tag\XMPExif\FocalPlaneXResolution(),
                'FocalPlaneYResolution' => new \PHPExiftool\Driver\Tag\XMPExif\FocalPlaneYResolution(),
                'GainControl' => new \PHPExiftool\Driver\Tag\XMPExif\GainControl(),
                'GPSAltitude' => new \PHPExiftool\Driver\Tag\XMPExif\GPSAltitude(),
                'GPSAltitudeRef' => new \PHPExiftool\Driver\Tag\XMPExif\GPSAltitudeRef(),
                'GPSAreaInformation' => new \PHPExiftool\Driver\Tag\XMPExif\GPSAreaInformation(),
                'GPSDestBearing' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDestBearing(),
                'GPSDestBearingRef' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDestBearingRef(),
                'GPSDestDistance' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDestDistance(),
                'GPSDestDistanceRef' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDestDistanceRef(),
                'GPSDestLatitude' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDestLatitude(),
                'GPSDestLongitude' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDestLongitude(),
                'GPSDifferential' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDifferential(),
                'GPSDOP' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDOP(),
                'GPSImgDirection' => new \PHPExiftool\Driver\Tag\XMPExif\GPSImgDirection(),
                'GPSImgDirectionRef' => new \PHPExiftool\Driver\Tag\XMPExif\GPSImgDirectionRef(),
                'GPSLatitude' => new \PHPExiftool\Driver\Tag\XMPExif\GPSLatitude(),
                'GPSLongitude' => new \PHPExiftool\Driver\Tag\XMPExif\GPSLongitude(),
                'GPSMapDatum' => new \PHPExiftool\Driver\Tag\XMPExif\GPSMapDatum(),
                'GPSMeasureMode' => new \PHPExiftool\Driver\Tag\XMPExif\GPSMeasureMode(),
                'GPSProcessingMethod' => new \PHPExiftool\Driver\Tag\XMPExif\GPSProcessingMethod(),
                'GPSSatellites' => new \PHPExiftool\Driver\Tag\XMPExif\GPSSatellites(),
                'GPSSpeed' => new \PHPExiftool\Driver\Tag\XMPExif\GPSSpeed(),
                'GPSSpeedRef' => new \PHPExiftool\Driver\Tag\XMPExif\GPSSpeedRef(),
                'GPSStatus' => new \PHPExiftool\Driver\Tag\XMPExif\GPSStatus(),
                'GPSDateTime' => new \PHPExiftool\Driver\Tag\XMPExif\GPSDateTime(),
                'GPSTrack' => new \PHPExiftool\Driver\Tag\XMPExif\GPSTrack(),
                'GPSTrackRef' => new \PHPExiftool\Driver\Tag\XMPExif\GPSTrackRef(),
                'GPSVersionID' => new \PHPExiftool\Driver\Tag\XMPExif\GPSVersionID(),
                'ImageUniqueID' => new \PHPExiftool\Driver\Tag\XMPExif\ImageUniqueID(),
                'ISO' => new \PHPExiftool\Driver\Tag\XMPExif\ISO(),
                'LightSource' => new \PHPExiftool\Driver\Tag\XMPExif\LightSource(),
                'MakerNote' => new \PHPExiftool\Driver\Tag\XMPExif\MakerNote(),
                'MaxApertureValue' => new \PHPExiftool\Driver\Tag\XMPExif\MaxApertureValue(),
                'MeteringMode' => new \PHPExiftool\Driver\Tag\XMPExif\MeteringMode(),
                'NativeDigest' => new \PHPExiftool\Driver\Tag\XMPExif\NativeDigest(),
                'Opto-ElectricConvFactor' => new \PHPExiftool\Driver\Tag\XMPExif\OptoElectricConvFactor(),
                'OECFColumns' => new \PHPExiftool\Driver\Tag\XMPExif\OECFColumns(),
                'OECFNames' => new \PHPExiftool\Driver\Tag\XMPExif\OECFNames(),
                'OECFRows' => new \PHPExiftool\Driver\Tag\XMPExif\OECFRows(),
                'OECFValues' => new \PHPExiftool\Driver\Tag\XMPExif\OECFValues(),
                'ExifImageWidth' => new \PHPExiftool\Driver\Tag\XMPExif\ExifImageWidth(),
                'ExifImageHeight' => new \PHPExiftool\Driver\Tag\XMPExif\ExifImageHeight(),
                'RelatedSoundFile' => new \PHPExiftool\Driver\Tag\XMPExif\RelatedSoundFile(),
                'Saturation' => new \PHPExiftool\Driver\Tag\XMPExif\Saturation(),
                'SceneCaptureType' => new \PHPExiftool\Driver\Tag\XMPExif\SceneCaptureType(),
                'SceneType' => new \PHPExiftool\Driver\Tag\XMPExif\SceneType(),
                'SensingMethod' => new \PHPExiftool\Driver\Tag\XMPExif\SensingMethod(),
                'Sharpness' => new \PHPExiftool\Driver\Tag\XMPExif\Sharpness(),
                'ShutterSpeedValue' => new \PHPExiftool\Driver\Tag\XMPExif\ShutterSpeedValue(),
                'SpatialFrequencyResponse' => new \PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponse(),
                'SpatialFrequencyResponseColumns' => new \PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponseColumns(),
                'SpatialFrequencyResponseNames' => new \PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponseNames(),
                'SpatialFrequencyResponseRows' => new \PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponseRows(),
                'SpatialFrequencyResponseValues' => new \PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponseValues(),
                'SpectralSensitivity' => new \PHPExiftool\Driver\Tag\XMPExif\SpectralSensitivity(),
                'SubjectArea' => new \PHPExiftool\Driver\Tag\XMPExif\SubjectArea(),
                'SubjectDistance' => new \PHPExiftool\Driver\Tag\XMPExif\SubjectDistance(),
                'SubjectDistanceRange' => new \PHPExiftool\Driver\Tag\XMPExif\SubjectDistanceRange(),
                'SubjectLocation' => new \PHPExiftool\Driver\Tag\XMPExif\SubjectLocation(),
                'UserComment' => new \PHPExiftool\Driver\Tag\XMPExif\UserComment(),
                'WhiteBalance' => new \PHPExiftool\Driver\Tag\XMPExif\WhiteBalance(),
            );
        });
        $this['XMP-extensis'] = $this->share(function(){
            return array(
                'Approved' => new \PHPExiftool\Driver\Tag\XMPExtensis\Approved(),
                'ApprovedBy' => new \PHPExiftool\Driver\Tag\XMPExtensis\ApprovedBy(),
                'ClientName' => new \PHPExiftool\Driver\Tag\XMPExtensis\ClientName(),
                'JobName' => new \PHPExiftool\Driver\Tag\XMPExtensis\JobName(),
                'JobStatus' => new \PHPExiftool\Driver\Tag\XMPExtensis\JobStatus(),
                'RoutedTo' => new \PHPExiftool\Driver\Tag\XMPExtensis\RoutedTo(),
                'RoutingNotes' => new \PHPExiftool\Driver\Tag\XMPExtensis\RoutingNotes(),
                'WorkToDo' => new \PHPExiftool\Driver\Tag\XMPExtensis\WorkToDo(),
            );
        });
        $this['XMP-fpv'] = $this->share(function(){
            return array(
                'RichTextComment' => new \PHPExiftool\Driver\Tag\XMPFpv\RichTextComment(),
            );
        });
        $this['XMP-ics'] = $this->share(function(){
            return array(
                'ImageRef' => new \PHPExiftool\Driver\Tag\XMPIcs\ImageRef(),
                'SubVersions' => new \PHPExiftool\Driver\Tag\XMPIcs\SubVersions(),
                'SubVersionFileName' => new \PHPExiftool\Driver\Tag\XMPIcs\SubVersionFileName(),
                'SubVersionReference' => new \PHPExiftool\Driver\Tag\XMPIcs\SubVersionReference(),
                'TagStructure' => new \PHPExiftool\Driver\Tag\XMPIcs\TagStructure(),
                'LabelName1' => new \PHPExiftool\Driver\Tag\XMPIcs\LabelName1(),
                'ParentReference1' => new \PHPExiftool\Driver\Tag\XMPIcs\ParentReference1(),
                'Reference1' => new \PHPExiftool\Driver\Tag\XMPIcs\Reference1(),
                'SubLables1' => new \PHPExiftool\Driver\Tag\XMPIcs\SubLables1(),
                'LabelName2' => new \PHPExiftool\Driver\Tag\XMPIcs\LabelName2(),
                'ParentReference2' => new \PHPExiftool\Driver\Tag\XMPIcs\ParentReference2(),
                'Reference2' => new \PHPExiftool\Driver\Tag\XMPIcs\Reference2(),
                'SubLables2' => new \PHPExiftool\Driver\Tag\XMPIcs\SubLables2(),
                'LabelName3' => new \PHPExiftool\Driver\Tag\XMPIcs\LabelName3(),
                'ParentReference3' => new \PHPExiftool\Driver\Tag\XMPIcs\ParentReference3(),
                'Reference3' => new \PHPExiftool\Driver\Tag\XMPIcs\Reference3(),
                'SubLables3' => new \PHPExiftool\Driver\Tag\XMPIcs\SubLables3(),
                'LabelName4' => new \PHPExiftool\Driver\Tag\XMPIcs\LabelName4(),
                'ParentReference4' => new \PHPExiftool\Driver\Tag\XMPIcs\ParentReference4(),
                'Reference4' => new \PHPExiftool\Driver\Tag\XMPIcs\Reference4(),
                'SubLabels4' => new \PHPExiftool\Driver\Tag\XMPIcs\SubLabels4(),
                'LabelName5' => new \PHPExiftool\Driver\Tag\XMPIcs\LabelName5(),
                'ParentReference5' => new \PHPExiftool\Driver\Tag\XMPIcs\ParentReference5(),
                'Reference5' => new \PHPExiftool\Driver\Tag\XMPIcs\Reference5(),
                'SubLabels5' => new \PHPExiftool\Driver\Tag\XMPIcs\SubLabels5(),
                'LabelName6' => new \PHPExiftool\Driver\Tag\XMPIcs\LabelName6(),
                'ParentReference6' => new \PHPExiftool\Driver\Tag\XMPIcs\ParentReference6(),
                'Reference6' => new \PHPExiftool\Driver\Tag\XMPIcs\Reference6(),
            );
        });
        $this['XMP-iptcCore'] = $this->share(function(){
            return array(
                'CountryCode' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CountryCode(),
                'CreatorContactInfo' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorContactInfo(),
                'CreatorCity' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorCity(),
                'CreatorCountry' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorCountry(),
                'CreatorAddress' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorAddress(),
                'CreatorPostalCode' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorPostalCode(),
                'CreatorRegion' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorRegion(),
                'CreatorWorkEmail' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorWorkEmail(),
                'CreatorWorkTelephone' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorWorkTelephone(),
                'CreatorWorkURL' => new \PHPExiftool\Driver\Tag\XMPIptcCore\CreatorWorkURL(),
                'IntellectualGenre' => new \PHPExiftool\Driver\Tag\XMPIptcCore\IntellectualGenre(),
                'Location' => new \PHPExiftool\Driver\Tag\XMPIptcCore\Location(),
                'Scene' => new \PHPExiftool\Driver\Tag\XMPIptcCore\Scene(),
                'SubjectCode' => new \PHPExiftool\Driver\Tag\XMPIptcCore\SubjectCode(),
            );
        });
        $this['XMP-iptcExt'] = $this->share(function(){
            return array(
                'AdditionalModelInformation' => new \PHPExiftool\Driver\Tag\XMPIptcExt\AdditionalModelInformation(),
                'ArtworkOrObject' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkOrObject(),
                'ArtworkCopyrightNotice' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkCopyrightNotice(),
                'ArtworkCreator' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkCreator(),
                'ArtworkDateCreated' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkDateCreated(),
                'ArtworkSource' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkSource(),
                'ArtworkSourceInventoryNo' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkSourceInventoryNo(),
                'ArtworkTitle' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkTitle(),
                'ControlledVocabularyTerm' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ControlledVocabularyTerm(),
                'DigitalImageGUID' => new \PHPExiftool\Driver\Tag\XMPIptcExt\DigitalImageGUID(),
                'DigitalSourceFileType' => new \PHPExiftool\Driver\Tag\XMPIptcExt\DigitalSourceFileType(),
                'DigitalSourceType' => new \PHPExiftool\Driver\Tag\XMPIptcExt\DigitalSourceType(),
                'Event' => new \PHPExiftool\Driver\Tag\XMPIptcExt\Event(),
                'IPTCLastEdited' => new \PHPExiftool\Driver\Tag\XMPIptcExt\IPTCLastEdited(),
                'LocationCreated' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreated(),
                'LocationCreatedCity' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedCity(),
                'LocationCreatedCountryCode' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedCountryCode(),
                'LocationCreatedCountryName' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedCountryName(),
                'LocationCreatedProvinceState' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedProvinceState(),
                'LocationCreatedSublocation' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedSublocation(),
                'LocationCreatedWorldRegion' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedWorldRegion(),
                'LocationShown' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationShown(),
                'LocationShownCity' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownCity(),
                'LocationShownCountryCode' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownCountryCode(),
                'LocationShownCountryName' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownCountryName(),
                'LocationShownProvinceState' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownProvinceState(),
                'LocationShownSublocation' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownSublocation(),
                'LocationShownWorldRegion' => new \PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownWorldRegion(),
                'MaxAvailHeight' => new \PHPExiftool\Driver\Tag\XMPIptcExt\MaxAvailHeight(),
                'MaxAvailWidth' => new \PHPExiftool\Driver\Tag\XMPIptcExt\MaxAvailWidth(),
                'ModelAge' => new \PHPExiftool\Driver\Tag\XMPIptcExt\ModelAge(),
                'OrganisationInImageCode' => new \PHPExiftool\Driver\Tag\XMPIptcExt\OrganisationInImageCode(),
                'OrganisationInImageName' => new \PHPExiftool\Driver\Tag\XMPIptcExt\OrganisationInImageName(),
                'PersonInImage' => new \PHPExiftool\Driver\Tag\XMPIptcExt\PersonInImage(),
                'RegistryID' => new \PHPExiftool\Driver\Tag\XMPIptcExt\RegistryID(),
                'RegistryItemID' => new \PHPExiftool\Driver\Tag\XMPIptcExt\RegistryItemID(),
                'RegistryOrganisationID' => new \PHPExiftool\Driver\Tag\XMPIptcExt\RegistryOrganisationID(),
            );
        });
        $this['XMP-mwg-coll'] = $this->share(function(){
            return array(
                'Collections' => new \PHPExiftool\Driver\Tag\XMPMwgColl\Collections(),
                'CollectionName' => new \PHPExiftool\Driver\Tag\XMPMwgColl\CollectionName(),
                'CollectionURI' => new \PHPExiftool\Driver\Tag\XMPMwgColl\CollectionURI(),
            );
        });
        $this['XMP-mwg-kw'] = $this->share(function(){
            return array(
                'KeywordInfo' => new \PHPExiftool\Driver\Tag\XMPMwgKw\KeywordInfo(),
                'HierarchicalKeywords' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords(),
                'HierarchicalKeywords1Applied' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords1Applied(),
                'HierarchicalKeywords1Children' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords1Children(),
                'HierarchicalKeywords2Applied' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords2Applied(),
                'HierarchicalKeywords2Children' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords2Children(),
                'HierarchicalKeywords3Applied' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords3Applied(),
                'HierarchicalKeywords3Children' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords3Children(),
                'HierarchicalKeywords4Applied' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords4Applied(),
                'HierarchicalKeywords4Children' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords4Children(),
                'HierarchicalKeywords5Applied' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords5Applied(),
                'HierarchicalKeywords5Children' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords5Children(),
                'HierarchicalKeywords6Applied' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords6Applied(),
                'HierarchicalKeywords6' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords6(),
                'HierarchicalKeywords5' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords5(),
                'HierarchicalKeywords4' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords4(),
                'HierarchicalKeywords3' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords3(),
                'HierarchicalKeywords2' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords2(),
                'HierarchicalKeywords1' => new \PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords1(),
            );
        });
        $this['XMP-mwg-rs'] = $this->share(function(){
            return array(
                'RegionInfo' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionInfo(),
                'RegionAppliedToDimensions' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAppliedToDimensions(),
                'RegionAppliedToDimensionsH' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAppliedToDimensionsH(),
                'RegionAppliedToDimensionsUnit' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAppliedToDimensionsUnit(),
                'RegionAppliedToDimensionsW' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAppliedToDimensionsW(),
                'RegionList' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionList(),
                'RegionArea' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionArea(),
                'RegionAreaD' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaD(),
                'RegionAreaH' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaH(),
                'RegionAreaUnit' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaUnit(),
                'RegionAreaW' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaW(),
                'RegionAreaX' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaX(),
                'RegionAreaY' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaY(),
                'RegionBarCodeValue' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionBarCodeValue(),
                'RegionDescription' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionDescription(),
                'RegionExtensions' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionExtensions(),
                'RegionFocusUsage' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionFocusUsage(),
                'RegionName' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionName(),
                'RegionSeeAlso' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionSeeAlso(),
                'RegionType' => new \PHPExiftool\Driver\Tag\XMPMwgRs\RegionType(),
            );
        });
        $this['XMP-pdf'] = $this->share(function(){
            return array(
                'Author' => new \PHPExiftool\Driver\Tag\XMPPdf\Author(),
                'Copyright' => new \PHPExiftool\Driver\Tag\XMPPdf\Copyright(),
                'CreationDate' => new \PHPExiftool\Driver\Tag\XMPPdf\CreationDate(),
                'Creator' => new \PHPExiftool\Driver\Tag\XMPPdf\Creator(),
                'Keywords' => new \PHPExiftool\Driver\Tag\XMPPdf\Keywords(),
                'Marked' => new \PHPExiftool\Driver\Tag\XMPPdf\Marked(),
                'ModDate' => new \PHPExiftool\Driver\Tag\XMPPdf\ModDate(),
                'PDFVersion' => new \PHPExiftool\Driver\Tag\XMPPdf\PDFVersion(),
                'Producer' => new \PHPExiftool\Driver\Tag\XMPPdf\Producer(),
                'Subject' => new \PHPExiftool\Driver\Tag\XMPPdf\Subject(),
                'Title' => new \PHPExiftool\Driver\Tag\XMPPdf\Title(),
                'Trapped' => new \PHPExiftool\Driver\Tag\XMPPdf\Trapped(),
            );
        });
        $this['XMP-photoshop'] = $this->share(function(){
            return array(
                'AuthorsPosition' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\AuthorsPosition(),
                'CaptionWriter' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\CaptionWriter(),
                'Category' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\Category(),
                'City' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\City(),
                'ColorMode' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\ColorMode(),
                'Country' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\Country(),
                'Credit' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\Credit(),
                'DateCreated' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\DateCreated(),
                'DocumentAncestors' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\DocumentAncestors(),
                'DocumentAncestorID' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\DocumentAncestorID(),
                'Headline' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\Headline(),
                'History' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\History(),
                'ICCProfileName' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\ICCProfileName(),
                'Instructions' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\Instructions(),
                'LegacyIPTCDigest' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\LegacyIPTCDigest(),
                'SidecarForExtension' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\SidecarForExtension(),
                'Source' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\Source(),
                'State' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\State(),
                'SupplementalCategories' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\SupplementalCategories(),
                'TextLayers' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\TextLayers(),
                'TextLayerName' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\TextLayerName(),
                'TextLayerText' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\TextLayerText(),
                'TransmissionReference' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\TransmissionReference(),
                'Urgency' => new \PHPExiftool\Driver\Tag\XMPPhotoshop\Urgency(),
            );
        });
        $this['XMP-plus'] = $this->share(function(){
            return array(
                'AdultContentWarning' => new \PHPExiftool\Driver\Tag\XMPPlus\AdultContentWarning(),
                'CopyrightOwner' => new \PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwner(),
                'CopyrightOwnerID' => new \PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerID(),
                'CopyrightOwnerName' => new \PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerName(),
                'CopyrightOwnerImageID' => new \PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerImageID(),
                'CopyrightRegistrationNumber' => new \PHPExiftool\Driver\Tag\XMPPlus\CopyrightRegistrationNumber(),
                'CopyrightStatus' => new \PHPExiftool\Driver\Tag\XMPPlus\CopyrightStatus(),
                'CreditLineRequired' => new \PHPExiftool\Driver\Tag\XMPPlus\CreditLineRequired(),
                'Custom1' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom1(),
                'Custom10' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom10(),
                'Custom2' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom2(),
                'Custom3' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom3(),
                'Custom4' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom4(),
                'Custom5' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom5(),
                'Custom6' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom6(),
                'Custom7' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom7(),
                'Custom8' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom8(),
                'Custom9' => new \PHPExiftool\Driver\Tag\XMPPlus\Custom9(),
                'EndUser' => new \PHPExiftool\Driver\Tag\XMPPlus\EndUser(),
                'EndUserID' => new \PHPExiftool\Driver\Tag\XMPPlus\EndUserID(),
                'EndUserName' => new \PHPExiftool\Driver\Tag\XMPPlus\EndUserName(),
                'FileNameAsDelivered' => new \PHPExiftool\Driver\Tag\XMPPlus\FileNameAsDelivered(),
                'FirstPublicationDate' => new \PHPExiftool\Driver\Tag\XMPPlus\FirstPublicationDate(),
                'ImageAlterationConstraints' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageAlterationConstraints(),
                'ImageCreator' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageCreator(),
                'ImageCreatorID' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorID(),
                'ImageCreatorName' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorName(),
                'ImageCreatorImageID' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorImageID(),
                'ImageDuplicationConstraints' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageDuplicationConstraints(),
                'ImageFileConstraints' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageFileConstraints(),
                'ImageFileFormatAsDelivered' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageFileFormatAsDelivered(),
                'ImageFileSizeAsDelivered' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageFileSizeAsDelivered(),
                'ImageSupplier' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageSupplier(),
                'ImageSupplierImageID' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageSupplierImageID(),
                'ImageSupplierID' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageSupplierID(),
                'ImageSupplierName' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageSupplierName(),
                'ImageType' => new \PHPExiftool\Driver\Tag\XMPPlus\ImageType(),
                'Licensee' => new \PHPExiftool\Driver\Tag\XMPPlus\Licensee(),
                'LicenseeImageID' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseeImageID(),
                'LicenseeImageNotes' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseeImageNotes(),
                'LicenseeID' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseeID(),
                'LicenseeName' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseeName(),
                'LicenseEndDate' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseEndDate(),
                'LicenseeProjectReference' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseeProjectReference(),
                'LicenseeTransactionID' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseeTransactionID(),
                'LicenseID' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseID(),
                'LicenseStartDate' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseStartDate(),
                'LicenseTransactionDate' => new \PHPExiftool\Driver\Tag\XMPPlus\LicenseTransactionDate(),
                'Licensor' => new \PHPExiftool\Driver\Tag\XMPPlus\Licensor(),
                'LicensorImageID' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorImageID(),
                'LicensorCity' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorCity(),
                'LicensorCountry' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorCountry(),
                'LicensorEmail' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorEmail(),
                'LicensorExtendedAddress' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorExtendedAddress(),
                'LicensorID' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorID(),
                'LicensorName' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorName(),
                'LicensorPostalCode' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorPostalCode(),
                'LicensorRegion' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorRegion(),
                'LicensorStreetAddress' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorStreetAddress(),
                'LicensorTelephone1' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorTelephone1(),
                'LicensorTelephone2' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorTelephone2(),
                'LicensorTelephoneType1' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorTelephoneType1(),
                'LicensorTelephoneType2' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorTelephoneType2(),
                'LicensorURL' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorURL(),
                'LicensorNotes' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorNotes(),
                'LicensorTransactionID' => new \PHPExiftool\Driver\Tag\XMPPlus\LicensorTransactionID(),
                'MediaConstraints' => new \PHPExiftool\Driver\Tag\XMPPlus\MediaConstraints(),
                'MediaSummaryCode' => new \PHPExiftool\Driver\Tag\XMPPlus\MediaSummaryCode(),
                'MinorModelAgeDisclosure' => new \PHPExiftool\Driver\Tag\XMPPlus\MinorModelAgeDisclosure(),
                'ModelReleaseID' => new \PHPExiftool\Driver\Tag\XMPPlus\ModelReleaseID(),
                'ModelReleaseStatus' => new \PHPExiftool\Driver\Tag\XMPPlus\ModelReleaseStatus(),
                'OtherConditions' => new \PHPExiftool\Driver\Tag\XMPPlus\OtherConditions(),
                'OtherConstraints' => new \PHPExiftool\Driver\Tag\XMPPlus\OtherConstraints(),
                'OtherImageInfo' => new \PHPExiftool\Driver\Tag\XMPPlus\OtherImageInfo(),
                'OtherLicenseDocuments' => new \PHPExiftool\Driver\Tag\XMPPlus\OtherLicenseDocuments(),
                'OtherLicenseInfo' => new \PHPExiftool\Driver\Tag\XMPPlus\OtherLicenseInfo(),
                'OtherLicenseRequirements' => new \PHPExiftool\Driver\Tag\XMPPlus\OtherLicenseRequirements(),
                'ProductOrServiceConstraints' => new \PHPExiftool\Driver\Tag\XMPPlus\ProductOrServiceConstraints(),
                'PropertyReleaseID' => new \PHPExiftool\Driver\Tag\XMPPlus\PropertyReleaseID(),
                'PropertyReleaseStatus' => new \PHPExiftool\Driver\Tag\XMPPlus\PropertyReleaseStatus(),
                'RegionConstraints' => new \PHPExiftool\Driver\Tag\XMPPlus\RegionConstraints(),
                'Reuse' => new \PHPExiftool\Driver\Tag\XMPPlus\Reuse(),
                'TermsAndConditionsText' => new \PHPExiftool\Driver\Tag\XMPPlus\TermsAndConditionsText(),
                'TermsAndConditionsURL' => new \PHPExiftool\Driver\Tag\XMPPlus\TermsAndConditionsURL(),
                'PLUSVersion' => new \PHPExiftool\Driver\Tag\XMPPlus\PLUSVersion(),
            );
        });
        $this['XMP-prism'] = $this->share(function(){
            return array(
                'AggregationType' => new \PHPExiftool\Driver\Tag\XMPPrism\AggregationType(),
                'AlternateTitle' => new \PHPExiftool\Driver\Tag\XMPPrism\AlternateTitle(),
                'ByteCount' => new \PHPExiftool\Driver\Tag\XMPPrism\ByteCount(),
                'Channel' => new \PHPExiftool\Driver\Tag\XMPPrism\Channel(),
                'ComplianceProfile' => new \PHPExiftool\Driver\Tag\XMPPrism\ComplianceProfile(),
                'Copyright' => new \PHPExiftool\Driver\Tag\XMPPrism\Copyright(),
                'CorporateEntity' => new \PHPExiftool\Driver\Tag\XMPPrism\CorporateEntity(),
                'CoverDate' => new \PHPExiftool\Driver\Tag\XMPPrism\CoverDate(),
                'CoverDisplayDate' => new \PHPExiftool\Driver\Tag\XMPPrism\CoverDisplayDate(),
                'CreationDate' => new \PHPExiftool\Driver\Tag\XMPPrism\CreationDate(),
                'DateRecieved' => new \PHPExiftool\Driver\Tag\XMPPrism\DateRecieved(),
                'Distributor' => new \PHPExiftool\Driver\Tag\XMPPrism\Distributor(),
                'DOI' => new \PHPExiftool\Driver\Tag\XMPPrism\DOI(),
                'Edition' => new \PHPExiftool\Driver\Tag\XMPPrism\Edition(),
                'EIssn' => new \PHPExiftool\Driver\Tag\XMPPrism\EIssn(),
                'EmbargoDate' => new \PHPExiftool\Driver\Tag\XMPPrism\EmbargoDate(),
                'EndingPage' => new \PHPExiftool\Driver\Tag\XMPPrism\EndingPage(),
                'Event' => new \PHPExiftool\Driver\Tag\XMPPrism\Event(),
                'ExpirationDate' => new \PHPExiftool\Driver\Tag\XMPPrism\ExpirationDate(),
                'Genre' => new \PHPExiftool\Driver\Tag\XMPPrism\Genre(),
                'HasAlternative' => new \PHPExiftool\Driver\Tag\XMPPrism\HasAlternative(),
                'HasCorrection' => new \PHPExiftool\Driver\Tag\XMPPrism\HasCorrection(),
                'HasPreviousVersion' => new \PHPExiftool\Driver\Tag\XMPPrism\HasPreviousVersion(),
                'HasTranslation' => new \PHPExiftool\Driver\Tag\XMPPrism\HasTranslation(),
                'Industry' => new \PHPExiftool\Driver\Tag\XMPPrism\Industry(),
                'ISBN' => new \PHPExiftool\Driver\Tag\XMPPrism\ISBN(),
                'IsCorrectionOf' => new \PHPExiftool\Driver\Tag\XMPPrism\IsCorrectionOf(),
                'ISSN' => new \PHPExiftool\Driver\Tag\XMPPrism\ISSN(),
                'IssueIdentifier' => new \PHPExiftool\Driver\Tag\XMPPrism\IssueIdentifier(),
                'IssueName' => new \PHPExiftool\Driver\Tag\XMPPrism\IssueName(),
                'IsTranslationOf' => new \PHPExiftool\Driver\Tag\XMPPrism\IsTranslationOf(),
                'Keyword' => new \PHPExiftool\Driver\Tag\XMPPrism\Keyword(),
                'KillDate' => new \PHPExiftool\Driver\Tag\XMPPrism\KillDate(),
                'Location' => new \PHPExiftool\Driver\Tag\XMPPrism\Location(),
                'ModificationDate' => new \PHPExiftool\Driver\Tag\XMPPrism\ModificationDate(),
                'Number' => new \PHPExiftool\Driver\Tag\XMPPrism\Number(),
                'Object' => new \PHPExiftool\Driver\Tag\XMPPrism\Object(),
                'Organization' => new \PHPExiftool\Driver\Tag\XMPPrism\Organization(),
                'OriginPlatform' => new \PHPExiftool\Driver\Tag\XMPPrism\OriginPlatform(),
                'PageRange' => new \PHPExiftool\Driver\Tag\XMPPrism\PageRange(),
                'Person' => new \PHPExiftool\Driver\Tag\XMPPrism\Person(),
                'PublicationDate' => new \PHPExiftool\Driver\Tag\XMPPrism\PublicationDate(),
                'PublicationName' => new \PHPExiftool\Driver\Tag\XMPPrism\PublicationName(),
                'RightsAgent' => new \PHPExiftool\Driver\Tag\XMPPrism\RightsAgent(),
                'Section' => new \PHPExiftool\Driver\Tag\XMPPrism\Section(),
                'StartingPage' => new \PHPExiftool\Driver\Tag\XMPPrism\StartingPage(),
                'Subsection1' => new \PHPExiftool\Driver\Tag\XMPPrism\Subsection1(),
                'Subsection2' => new \PHPExiftool\Driver\Tag\XMPPrism\Subsection2(),
                'Subsection3' => new \PHPExiftool\Driver\Tag\XMPPrism\Subsection3(),
                'Subsection4' => new \PHPExiftool\Driver\Tag\XMPPrism\Subsection4(),
                'Teaser' => new \PHPExiftool\Driver\Tag\XMPPrism\Teaser(),
                'Ticker' => new \PHPExiftool\Driver\Tag\XMPPrism\Ticker(),
                'TimePeriod' => new \PHPExiftool\Driver\Tag\XMPPrism\TimePeriod(),
                'URL' => new \PHPExiftool\Driver\Tag\XMPPrism\URL(),
                'VersionIdentifier' => new \PHPExiftool\Driver\Tag\XMPPrism\VersionIdentifier(),
                'Volume' => new \PHPExiftool\Driver\Tag\XMPPrism\Volume(),
                'WordCount' => new \PHPExiftool\Driver\Tag\XMPPrism\WordCount(),
            );
        });
        $this['XMP-prl'] = $this->share(function(){
            return array(
                'Geography' => new \PHPExiftool\Driver\Tag\XMPPrl\Geography(),
                'Industry' => new \PHPExiftool\Driver\Tag\XMPPrl\Industry(),
                'Usage' => new \PHPExiftool\Driver\Tag\XMPPrl\Usage(),
            );
        });
        $this['XMP-pur'] = $this->share(function(){
            return array(
                'AdultContentWarning' => new \PHPExiftool\Driver\Tag\XMPPur\AdultContentWarning(),
                'Agreement' => new \PHPExiftool\Driver\Tag\XMPPur\Agreement(),
                'Copyright' => new \PHPExiftool\Driver\Tag\XMPPur\Copyright(),
                'CreditLine' => new \PHPExiftool\Driver\Tag\XMPPur\CreditLine(),
                'EmbargoDate' => new \PHPExiftool\Driver\Tag\XMPPur\EmbargoDate(),
                'ExclusivityEndDate' => new \PHPExiftool\Driver\Tag\XMPPur\ExclusivityEndDate(),
                'ExpirationDate' => new \PHPExiftool\Driver\Tag\XMPPur\ExpirationDate(),
                'ImageSizeRestriction' => new \PHPExiftool\Driver\Tag\XMPPur\ImageSizeRestriction(),
                'OptionEndDate' => new \PHPExiftool\Driver\Tag\XMPPur\OptionEndDate(),
                'Permissions' => new \PHPExiftool\Driver\Tag\XMPPur\Permissions(),
                'Restrictions' => new \PHPExiftool\Driver\Tag\XMPPur\Restrictions(),
                'ReuseProhibited' => new \PHPExiftool\Driver\Tag\XMPPur\ReuseProhibited(),
                'RightsAgent' => new \PHPExiftool\Driver\Tag\XMPPur\RightsAgent(),
                'RightsOwner' => new \PHPExiftool\Driver\Tag\XMPPur\RightsOwner(),
                'UsageFee' => new \PHPExiftool\Driver\Tag\XMPPur\UsageFee(),
            );
        });
        $this['XMP-rdf'] = $this->share(function(){
            return array(
                'About' => new \PHPExiftool\Driver\Tag\XMPRdf\About(),
            );
        });
        $this['XMP-swf'] = $this->share(function(){
            return array(
                'BackgroundAlpha' => new \PHPExiftool\Driver\Tag\XMPSwf\BackgroundAlpha(),
                'ForwardLock' => new \PHPExiftool\Driver\Tag\XMPSwf\ForwardLock(),
                'MaxStorage' => new \PHPExiftool\Driver\Tag\XMPSwf\MaxStorage(),
                'Type' => new \PHPExiftool\Driver\Tag\XMPSwf\Type(),
            );
        });
        $this['XMP-tiff'] = $this->share(function(){
            return array(
                'Artist' => new \PHPExiftool\Driver\Tag\XMPTiff\Artist(),
                'BitsPerSample' => new \PHPExiftool\Driver\Tag\XMPTiff\BitsPerSample(),
                'Compression' => new \PHPExiftool\Driver\Tag\XMPTiff\Compression(),
                'Copyright' => new \PHPExiftool\Driver\Tag\XMPTiff\Copyright(),
                'DateTime' => new \PHPExiftool\Driver\Tag\XMPTiff\DateTime(),
                'ImageDescription' => new \PHPExiftool\Driver\Tag\XMPTiff\ImageDescription(),
                'ImageHeight' => new \PHPExiftool\Driver\Tag\XMPTiff\ImageHeight(),
                'ImageWidth' => new \PHPExiftool\Driver\Tag\XMPTiff\ImageWidth(),
                'Make' => new \PHPExiftool\Driver\Tag\XMPTiff\Make(),
                'Model' => new \PHPExiftool\Driver\Tag\XMPTiff\Model(),
                'NativeDigest' => new \PHPExiftool\Driver\Tag\XMPTiff\NativeDigest(),
                'Orientation' => new \PHPExiftool\Driver\Tag\XMPTiff\Orientation(),
                'PhotometricInterpretation' => new \PHPExiftool\Driver\Tag\XMPTiff\PhotometricInterpretation(),
                'PlanarConfiguration' => new \PHPExiftool\Driver\Tag\XMPTiff\PlanarConfiguration(),
                'PrimaryChromaticities' => new \PHPExiftool\Driver\Tag\XMPTiff\PrimaryChromaticities(),
                'ReferenceBlackWhite' => new \PHPExiftool\Driver\Tag\XMPTiff\ReferenceBlackWhite(),
                'ResolutionUnit' => new \PHPExiftool\Driver\Tag\XMPTiff\ResolutionUnit(),
                'SamplesPerPixel' => new \PHPExiftool\Driver\Tag\XMPTiff\SamplesPerPixel(),
                'Software' => new \PHPExiftool\Driver\Tag\XMPTiff\Software(),
                'TransferFunction' => new \PHPExiftool\Driver\Tag\XMPTiff\TransferFunction(),
                'WhitePoint' => new \PHPExiftool\Driver\Tag\XMPTiff\WhitePoint(),
                'XResolution' => new \PHPExiftool\Driver\Tag\XMPTiff\XResolution(),
                'YCbCrCoefficients' => new \PHPExiftool\Driver\Tag\XMPTiff\YCbCrCoefficients(),
                'YCbCrPositioning' => new \PHPExiftool\Driver\Tag\XMPTiff\YCbCrPositioning(),
                'YCbCrSubSampling' => new \PHPExiftool\Driver\Tag\XMPTiff\YCbCrSubSampling(),
                'YResolution' => new \PHPExiftool\Driver\Tag\XMPTiff\YResolution(),
            );
        });
        $this['XMP-x'] = $this->share(function(){
            return array(
                'XMPToolkit' => new \PHPExiftool\Driver\Tag\XMPX\XMPToolkit(),
            );
        });
        $this['XMP-xmp'] = $this->share(function(){
            return array(
                'Advisory' => new \PHPExiftool\Driver\Tag\XMPXmp\Advisory(),
                'Author' => new \PHPExiftool\Driver\Tag\XMPXmp\Author(),
                'BaseURL' => new \PHPExiftool\Driver\Tag\XMPXmp\BaseURL(),
                'CreateDate' => new \PHPExiftool\Driver\Tag\XMPXmp\CreateDate(),
                'CreatorTool' => new \PHPExiftool\Driver\Tag\XMPXmp\CreatorTool(),
                'Description' => new \PHPExiftool\Driver\Tag\XMPXmp\Description(),
                'Format' => new \PHPExiftool\Driver\Tag\XMPXmp\Format(),
                'Identifier' => new \PHPExiftool\Driver\Tag\XMPXmp\Identifier(),
                'Keywords' => new \PHPExiftool\Driver\Tag\XMPXmp\Keywords(),
                'Label' => new \PHPExiftool\Driver\Tag\XMPXmp\Label(),
                'MetadataDate' => new \PHPExiftool\Driver\Tag\XMPXmp\MetadataDate(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\XMPXmp\ModifyDate(),
                'Nickname' => new \PHPExiftool\Driver\Tag\XMPXmp\Nickname(),
                'PageInfo' => new \PHPExiftool\Driver\Tag\XMPXmp\PageInfo(),
                'PageImageFormat' => new \PHPExiftool\Driver\Tag\XMPXmp\PageImageFormat(),
                'PageImageHeight' => new \PHPExiftool\Driver\Tag\XMPXmp\PageImageHeight(),
                'PageImage' => new \PHPExiftool\Driver\Tag\XMPXmp\PageImage(),
                'PageImagePageNumber' => new \PHPExiftool\Driver\Tag\XMPXmp\PageImagePageNumber(),
                'PageImageWidth' => new \PHPExiftool\Driver\Tag\XMPXmp\PageImageWidth(),
                'Rating' => new \PHPExiftool\Driver\Tag\XMPXmp\Rating(),
                'Thumbnails' => new \PHPExiftool\Driver\Tag\XMPXmp\Thumbnails(),
                'ThumbnailFormat' => new \PHPExiftool\Driver\Tag\XMPXmp\ThumbnailFormat(),
                'ThumbnailHeight' => new \PHPExiftool\Driver\Tag\XMPXmp\ThumbnailHeight(),
                'ThumbnailImage' => new \PHPExiftool\Driver\Tag\XMPXmp\ThumbnailImage(),
                'ThumbnailWidth' => new \PHPExiftool\Driver\Tag\XMPXmp\ThumbnailWidth(),
                'Title' => new \PHPExiftool\Driver\Tag\XMPXmp\Title(),
            );
        });
        $this['XMP-xmpBJ'] = $this->share(function(){
            return array(
                'JobRef' => new \PHPExiftool\Driver\Tag\XMPXmpBJ\JobRef(),
                'JobRefId' => new \PHPExiftool\Driver\Tag\XMPXmpBJ\JobRefId(),
                'JobRefName' => new \PHPExiftool\Driver\Tag\XMPXmpBJ\JobRefName(),
                'JobRefUrl' => new \PHPExiftool\Driver\Tag\XMPXmpBJ\JobRefUrl(),
            );
        });
        $this['XMP-xmpDM'] = $this->share(function(){
            return array(
                'AbsPeakAudioFilePath' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AbsPeakAudioFilePath(),
                'Album' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Album(),
                'AltTapeName' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AltTapeName(),
                'AltTimecode' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AltTimecode(),
                'AltTimecodeTimeFormat' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AltTimecodeTimeFormat(),
                'AltTimecodeTimeValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AltTimecodeTimeValue(),
                'AltTimecodeValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AltTimecodeValue(),
                'Artist' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Artist(),
                'AudioChannelType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AudioChannelType(),
                'AudioCompressor' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AudioCompressor(),
                'AudioModDate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AudioModDate(),
                'AudioSampleRate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AudioSampleRate(),
                'AudioSampleType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\AudioSampleType(),
                'BeatSpliceParams' => new \PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParams(),
                'BeatSpliceParamsRiseInDecibel' => new \PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsRiseInDecibel(),
                'BeatSpliceParamsRiseInTimeDuration' => new \PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsRiseInTimeDuration(),
                'BeatSpliceParamsRiseInTimeDurationScale' => new \PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsRiseInTimeDurationScale(),
                'BeatSpliceParamsRiseInTimeDurationValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsRiseInTimeDurationValue(),
                'BeatSpliceParamsUseFileBeatsMarker' => new \PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsUseFileBeatsMarker(),
                'CameraAngle' => new \PHPExiftool\Driver\Tag\XMPXmpDM\CameraAngle(),
                'CameraLabel' => new \PHPExiftool\Driver\Tag\XMPXmpDM\CameraLabel(),
                'CameraModel' => new \PHPExiftool\Driver\Tag\XMPXmpDM\CameraModel(),
                'CameraMove' => new \PHPExiftool\Driver\Tag\XMPXmpDM\CameraMove(),
                'Client' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Client(),
                'DMComment' => new \PHPExiftool\Driver\Tag\XMPXmpDM\DMComment(),
                'Composer' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Composer(),
                'ContributedMedia' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMedia(),
                'ContributedMediaDuration' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaDuration(),
                'ContributedMediaDurationScale' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaDurationScale(),
                'ContributedMediaDurationValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaDurationValue(),
                'ContributedMediaManaged' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaManaged(),
                'ContributedMediaPath' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaPath(),
                'ContributedMediaStartTime' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaStartTime(),
                'ContributedMediaStartTimeScale' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaStartTimeScale(),
                'ContributedMediaStartTimeValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaStartTimeValue(),
                'ContributedMediaTrack' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaTrack(),
                'ContributedMediaWebStatement' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaWebStatement(),
                'Copyright' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Copyright(),
                'Director' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Director(),
                'DirectorPhotography' => new \PHPExiftool\Driver\Tag\XMPXmpDM\DirectorPhotography(),
                'Duration' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Duration(),
                'DurationScale' => new \PHPExiftool\Driver\Tag\XMPXmpDM\DurationScale(),
                'DurationValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\DurationValue(),
                'Engineer' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Engineer(),
                'FileDataRate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\FileDataRate(),
                'Genre' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Genre(),
                'Good' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Good(),
                'Instrument' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Instrument(),
                'IntroTime' => new \PHPExiftool\Driver\Tag\XMPXmpDM\IntroTime(),
                'IntroTimeScale' => new \PHPExiftool\Driver\Tag\XMPXmpDM\IntroTimeScale(),
                'IntroTimeValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\IntroTimeValue(),
                'Key' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Key(),
                'LogComment' => new \PHPExiftool\Driver\Tag\XMPXmpDM\LogComment(),
                'Loop' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Loop(),
                'Markers' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Markers(),
                'MarkersComment' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersComment(),
                'MarkersCuePointParams' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersCuePointParams(),
                'MarkersCuePointParamsKey' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersCuePointParamsKey(),
                'MarkersCuePointParamsValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersCuePointParamsValue(),
                'MarkersCuePointType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersCuePointType(),
                'MarkersDuration' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersDuration(),
                'MarkersLocation' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersLocation(),
                'MarkersName' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersName(),
                'MarkersProbability' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersProbability(),
                'MarkersSpeaker' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersSpeaker(),
                'MarkersStartTime' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersStartTime(),
                'MarkersTarget' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersTarget(),
                'MarkersType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MarkersType(),
                'MetadataModDate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\MetadataModDate(),
                'NumberOfBeats' => new \PHPExiftool\Driver\Tag\XMPXmpDM\NumberOfBeats(),
                'OutCue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\OutCue(),
                'OutCueScale' => new \PHPExiftool\Driver\Tag\XMPXmpDM\OutCueScale(),
                'OutCueValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\OutCueValue(),
                'ProjectName' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ProjectName(),
                'ProjectRef' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ProjectRef(),
                'ProjectRefPath' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ProjectRefPath(),
                'ProjectRefType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ProjectRefType(),
                'PullDown' => new \PHPExiftool\Driver\Tag\XMPXmpDM\PullDown(),
                'RelativePeakAudioFilePath' => new \PHPExiftool\Driver\Tag\XMPXmpDM\RelativePeakAudioFilePath(),
                'RelativeTimestamp' => new \PHPExiftool\Driver\Tag\XMPXmpDM\RelativeTimestamp(),
                'RelativeTimestampScale' => new \PHPExiftool\Driver\Tag\XMPXmpDM\RelativeTimestampScale(),
                'RelativeTimestampValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\RelativeTimestampValue(),
                'ReleaseDate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ReleaseDate(),
                'ResampleParams' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ResampleParams(),
                'ResampleParamsQuality' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ResampleParamsQuality(),
                'ScaleType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ScaleType(),
                'Scene' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Scene(),
                'ShotDate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ShotDate(),
                'ShotDay' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ShotDay(),
                'ShotLocation' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ShotLocation(),
                'ShotName' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ShotName(),
                'ShotNumber' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ShotNumber(),
                'ShotSize' => new \PHPExiftool\Driver\Tag\XMPXmpDM\ShotSize(),
                'SpeakerPlacement' => new \PHPExiftool\Driver\Tag\XMPXmpDM\SpeakerPlacement(),
                'StartTimecode' => new \PHPExiftool\Driver\Tag\XMPXmpDM\StartTimecode(),
                'StartTimecodeTimeFormat' => new \PHPExiftool\Driver\Tag\XMPXmpDM\StartTimecodeTimeFormat(),
                'StartTimecodeTimeValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\StartTimecodeTimeValue(),
                'StartTimecodeValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\StartTimecodeValue(),
                'StretchMode' => new \PHPExiftool\Driver\Tag\XMPXmpDM\StretchMode(),
                'TakeNumber' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TakeNumber(),
                'TapeName' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TapeName(),
                'Tempo' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Tempo(),
                'TimeScaleParams' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TimeScaleParams(),
                'TimeScaleParamsFrameOverlappingPercentage' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TimeScaleParamsFrameOverlappingPercentage(),
                'TimeScaleParamsFrameSize' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TimeScaleParamsFrameSize(),
                'TimeScaleParamsQuality' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TimeScaleParamsQuality(),
                'TimeSignature' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TimeSignature(),
                'TrackNumber' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TrackNumber(),
                'Tracks' => new \PHPExiftool\Driver\Tag\XMPXmpDM\Tracks(),
                'TracksFrameRate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksFrameRate(),
                'TracksMarkers' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkers(),
                'TracksMarkersComment' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersComment(),
                'TracksMarkersCuePointParams' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersCuePointParams(),
                'TracksMarkersCuePointParamsKey' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersCuePointParamsKey(),
                'TracksMarkersCuePointParamsValue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersCuePointParamsValue(),
                'TracksMarkersCuePointType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersCuePointType(),
                'TracksMarkersDuration' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersDuration(),
                'TracksMarkersLocation' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersLocation(),
                'TracksMarkersName' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersName(),
                'TracksMarkersProbability' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersProbability(),
                'TracksMarkersSpeaker' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersSpeaker(),
                'TracksMarkersStartTime' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersStartTime(),
                'TracksMarkersTarget' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersTarget(),
                'TracksMarkersType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersType(),
                'TracksTrackName' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksTrackName(),
                'TracksTrackType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\TracksTrackType(),
                'VideoAlphaMode' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaMode(),
                'VideoAlphaPremultipleColor' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColor(),
                'VideoAlphaPremultipleColorA' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorA(),
                'VideoAlphaPremultipleColorB' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorB(),
                'VideoAlphaPremultipleColorBlack' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorBlack(),
                'VideoAlphaPremultipleColorBlue' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorBlue(),
                'VideoAlphaPremultipleColorCyan' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorCyan(),
                'VideoAlphaPremultipleColorGreen' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorGreen(),
                'VideoAlphaPremultipleColorL' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorL(),
                'VideoAlphaPremultipleColorMagenta' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorMagenta(),
                'VideoAlphaPremultipleColorMode' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorMode(),
                'VideoAlphaPremultipleColorRed' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorRed(),
                'VideoAlphaPremultipleColorSwatchName' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorSwatchName(),
                'VideoAlphaPremultipleColorTint' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorTint(),
                'VideoAlphaPremultipleColorType' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorType(),
                'VideoAlphaPremultipleColorYellow' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorYellow(),
                'VideoAlphaUnityIsTransparent' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaUnityIsTransparent(),
                'VideoColorSpace' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoColorSpace(),
                'VideoCompressor' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoCompressor(),
                'VideoFieldOrder' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoFieldOrder(),
                'VideoFrameRate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameRate(),
                'VideoFrameSize' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameSize(),
                'VideoFrameSizeH' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameSizeH(),
                'VideoFrameSizeUnit' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameSizeUnit(),
                'VideoFrameSizeW' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameSizeW(),
                'VideoModDate' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoModDate(),
                'VideoPixelAspectRatio' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoPixelAspectRatio(),
                'VideoPixelDepth' => new \PHPExiftool\Driver\Tag\XMPXmpDM\VideoPixelDepth(),
            );
        });
        $this['XMP-xmpMM'] = $this->share(function(){
            return array(
                'DerivedFrom' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFrom(),
                'DerivedFromAlternatePaths' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromAlternatePaths(),
                'DerivedFromDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromDocumentID(),
                'DerivedFromFilePath' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromFilePath(),
                'DerivedFromFromPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromFromPart(),
                'DerivedFromInstanceID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromInstanceID(),
                'DerivedFromLastModifyDate' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromLastModifyDate(),
                'DerivedFromManager' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromManager(),
                'DerivedFromManagerVariant' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromManagerVariant(),
                'DerivedFromManageTo' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromManageTo(),
                'DerivedFromManageUI' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromManageUI(),
                'DerivedFromMaskMarkers' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromMaskMarkers(),
                'DerivedFromOriginalDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromOriginalDocumentID(),
                'DerivedFromPartMapping' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromPartMapping(),
                'DerivedFromRenditionClass' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromRenditionClass(),
                'DerivedFromRenditionParams' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromRenditionParams(),
                'DerivedFromToPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromToPart(),
                'DerivedFromVersionID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromVersionID(),
                'DocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\DocumentID(),
                'History' => new \PHPExiftool\Driver\Tag\XMPXmpMM\History(),
                'HistoryAction' => new \PHPExiftool\Driver\Tag\XMPXmpMM\HistoryAction(),
                'HistoryChanged' => new \PHPExiftool\Driver\Tag\XMPXmpMM\HistoryChanged(),
                'HistoryInstanceID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\HistoryInstanceID(),
                'HistoryParameters' => new \PHPExiftool\Driver\Tag\XMPXmpMM\HistoryParameters(),
                'HistorySoftwareAgent' => new \PHPExiftool\Driver\Tag\XMPXmpMM\HistorySoftwareAgent(),
                'HistoryWhen' => new \PHPExiftool\Driver\Tag\XMPXmpMM\HistoryWhen(),
                'Ingredients' => new \PHPExiftool\Driver\Tag\XMPXmpMM\Ingredients(),
                'IngredientsAlternatePaths' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsAlternatePaths(),
                'IngredientsDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsDocumentID(),
                'IngredientsFilePath' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsFilePath(),
                'IngredientsFromPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsFromPart(),
                'IngredientsInstanceID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsInstanceID(),
                'IngredientsLastModifyDate' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsLastModifyDate(),
                'IngredientsManager' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsManager(),
                'IngredientsManagerVariant' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsManagerVariant(),
                'IngredientsManageTo' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsManageTo(),
                'IngredientsManageUI' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsManageUI(),
                'IngredientsMaskMarkers' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsMaskMarkers(),
                'IngredientsOriginalDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsOriginalDocumentID(),
                'IngredientsPartMapping' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsPartMapping(),
                'IngredientsRenditionClass' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsRenditionClass(),
                'IngredientsRenditionParams' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsRenditionParams(),
                'IngredientsToPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsToPart(),
                'IngredientsVersionID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsVersionID(),
                'InstanceID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\InstanceID(),
                'LastURL' => new \PHPExiftool\Driver\Tag\XMPXmpMM\LastURL(),
                'ManagedFrom' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFrom(),
                'ManagedFromAlternatePaths' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromAlternatePaths(),
                'ManagedFromDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromDocumentID(),
                'ManagedFromFilePath' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromFilePath(),
                'ManagedFromFromPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromFromPart(),
                'ManagedFromInstanceID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromInstanceID(),
                'ManagedFromLastModifyDate' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromLastModifyDate(),
                'ManagedFromManager' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromManager(),
                'ManagedFromManagerVariant' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromManagerVariant(),
                'ManagedFromManageTo' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromManageTo(),
                'ManagedFromManageUI' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromManageUI(),
                'ManagedFromMaskMarkers' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromMaskMarkers(),
                'ManagedFromOriginalDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromOriginalDocumentID(),
                'ManagedFromPartMapping' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromPartMapping(),
                'ManagedFromRenditionClass' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromRenditionClass(),
                'ManagedFromRenditionParams' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromRenditionParams(),
                'ManagedFromToPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromToPart(),
                'ManagedFromVersionID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromVersionID(),
                'Manager' => new \PHPExiftool\Driver\Tag\XMPXmpMM\Manager(),
                'ManagerVariant' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManagerVariant(),
                'ManageTo' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManageTo(),
                'ManageUI' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManageUI(),
                'Manifest' => new \PHPExiftool\Driver\Tag\XMPXmpMM\Manifest(),
                'ManifestLinkForm' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestLinkForm(),
                'ManifestPlacedResolutionUnit' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestPlacedResolutionUnit(),
                'ManifestPlacedXResolution' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestPlacedXResolution(),
                'ManifestPlacedYResolution' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestPlacedYResolution(),
                'ManifestReference' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReference(),
                'ManifestReferenceAlternatePaths' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceAlternatePaths(),
                'ManifestReferenceDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceDocumentID(),
                'ManifestReferenceFilePath' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceFilePath(),
                'ManifestReferenceFromPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceFromPart(),
                'ManifestReferenceInstanceID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceInstanceID(),
                'ManifestReferenceLastModifyDate' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceLastModifyDate(),
                'ManifestReferenceManager' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceManager(),
                'ManifestReferenceManagerVariant' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceManagerVariant(),
                'ManifestReferenceManageTo' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceManageTo(),
                'ManifestReferenceManageUI' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceManageUI(),
                'ManifestReferenceMaskMarkers' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceMaskMarkers(),
                'ManifestReferenceOriginalDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceOriginalDocumentID(),
                'ManifestReferencePartMapping' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferencePartMapping(),
                'ManifestReferenceRenditionClass' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceRenditionClass(),
                'ManifestReferenceRenditionParams' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceRenditionParams(),
                'ManifestReferenceToPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceToPart(),
                'ManifestReferenceVersionID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceVersionID(),
                'OriginalDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\OriginalDocumentID(),
                'Pantry' => new \PHPExiftool\Driver\Tag\XMPXmpMM\Pantry(),
                'PreservedFileName' => new \PHPExiftool\Driver\Tag\XMPXmpMM\PreservedFileName(),
                'RenditionClass' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionClass(),
                'RenditionOf' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOf(),
                'RenditionOfAlternatePaths' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfAlternatePaths(),
                'RenditionOfDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfDocumentID(),
                'RenditionOfFilePath' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfFilePath(),
                'RenditionOfFromPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfFromPart(),
                'RenditionOfInstanceID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfInstanceID(),
                'RenditionOfLastModifyDate' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfLastModifyDate(),
                'RenditionOfManager' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfManager(),
                'RenditionOfManagerVariant' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfManagerVariant(),
                'RenditionOfManageTo' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfManageTo(),
                'RenditionOfManageUI' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfManageUI(),
                'RenditionOfMaskMarkers' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfMaskMarkers(),
                'RenditionOfOriginalDocumentID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfOriginalDocumentID(),
                'RenditionOfPartMapping' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfPartMapping(),
                'RenditionOfRenditionClass' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfRenditionClass(),
                'RenditionOfRenditionParams' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfRenditionParams(),
                'RenditionOfToPart' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfToPart(),
                'RenditionOfVersionID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfVersionID(),
                'RenditionParams' => new \PHPExiftool\Driver\Tag\XMPXmpMM\RenditionParams(),
                'SaveID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\SaveID(),
                'Subject' => new \PHPExiftool\Driver\Tag\XMPXmpMM\Subject(),
                'VersionID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionID(),
                'Versions' => new \PHPExiftool\Driver\Tag\XMPXmpMM\Versions(),
                'VersionsComments' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsComments(),
                'VersionsEvent' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEvent(),
                'VersionsEventAction' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventAction(),
                'VersionsEventChanged' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventChanged(),
                'VersionsEventInstanceID' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventInstanceID(),
                'VersionsEventParameters' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventParameters(),
                'VersionsEventSoftwareAgent' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventSoftwareAgent(),
                'VersionsEventWhen' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventWhen(),
                'VersionsModifier' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsModifier(),
                'VersionsModifyDate' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsModifyDate(),
                'VersionsVersion' => new \PHPExiftool\Driver\Tag\XMPXmpMM\VersionsVersion(),
            );
        });
        $this['XMP-xmpNote'] = $this->share(function(){
            return array(
                'HasExtendedXMP' => new \PHPExiftool\Driver\Tag\XMPXmpNote\HasExtendedXMP(),
            );
        });
        $this['XMP-xmpPLUS'] = $this->share(function(){
            return array(
                'CreditLineReq' => new \PHPExiftool\Driver\Tag\XMPXmpPLUS\CreditLineReq(),
                'ReuseAllowed' => new \PHPExiftool\Driver\Tag\XMPXmpPLUS\ReuseAllowed(),
            );
        });
        $this['XMP-xmpRights'] = $this->share(function(){
            return array(
                'Certificate' => new \PHPExiftool\Driver\Tag\XMPXmpRights\Certificate(),
                'Marked' => new \PHPExiftool\Driver\Tag\XMPXmpRights\Marked(),
                'Owner' => new \PHPExiftool\Driver\Tag\XMPXmpRights\Owner(),
                'UsageTerms' => new \PHPExiftool\Driver\Tag\XMPXmpRights\UsageTerms(),
                'WebStatement' => new \PHPExiftool\Driver\Tag\XMPXmpRights\WebStatement(),
            );
        });
        $this['XMP-xmpTPg'] = $this->share(function(){
            return array(
                'Colorants' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\Colorants(),
                'ColorantA' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantA(),
                'ColorantB' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantB(),
                'ColorantBlack' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantBlack(),
                'ColorantBlue' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantBlue(),
                'ColorantCyan' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantCyan(),
                'ColorantGreen' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantGreen(),
                'ColorantL' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantL(),
                'ColorantMagenta' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantMagenta(),
                'ColorantMode' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantMode(),
                'ColorantRed' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantRed(),
                'ColorantSwatchName' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantSwatchName(),
                'ColorantTint' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantTint(),
                'ColorantType' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantType(),
                'ColorantYellow' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantYellow(),
                'Fonts' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\Fonts(),
                'ChildFontFiles' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\ChildFontFiles(),
                'FontComposite' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\FontComposite(),
                'FontFace' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\FontFace(),
                'FontFamily' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\FontFamily(),
                'FontFileName' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\FontFileName(),
                'FontName' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\FontName(),
                'FontType' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\FontType(),
                'FontVersion' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\FontVersion(),
                'MaxPageSize' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\MaxPageSize(),
                'MaxPageSizeH' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\MaxPageSizeH(),
                'MaxPageSizeUnit' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\MaxPageSizeUnit(),
                'MaxPageSizeW' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\MaxPageSizeW(),
                'NPages' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\NPages(),
                'PlateNames' => new \PHPExiftool\Driver\Tag\XMPXmpTPg\PlateNames(),
            );
        });
        $this['ZIP'] = $this->share(function(){
            return array(
                'Compression' => new \PHPExiftool\Driver\Tag\ZIP\Compression(),
                'Flags' => new \PHPExiftool\Driver\Tag\ZIP\Flags(),
                'ModifyDate' => new \PHPExiftool\Driver\Tag\ZIP\ModifyDate(),
                'ExtraFlags' => new \PHPExiftool\Driver\Tag\ZIP\ExtraFlags(),
                'OperatingSystem' => new \PHPExiftool\Driver\Tag\ZIP\OperatingSystem(),
                'ArchivedFileName' => new \PHPExiftool\Driver\Tag\ZIP\ArchivedFileName(),
                'Comment' => new \PHPExiftool\Driver\Tag\ZIP\Comment(),
                'ZipRequiredVersion' => new \PHPExiftool\Driver\Tag\ZIP\ZipRequiredVersion(),
                'ZipBitFlag' => new \PHPExiftool\Driver\Tag\ZIP\ZipBitFlag(),
                'ZipCompression' => new \PHPExiftool\Driver\Tag\ZIP\ZipCompression(),
                'ZipModifyDate' => new \PHPExiftool\Driver\Tag\ZIP\ZipModifyDate(),
                'ZipCRC' => new \PHPExiftool\Driver\Tag\ZIP\ZipCRC(),
                'ZipCompressedSize' => new \PHPExiftool\Driver\Tag\ZIP\ZipCompressedSize(),
                'ZipUncompressedSize' => new \PHPExiftool\Driver\Tag\ZIP\ZipUncompressedSize(),
                'ZipFileNameLength' => new \PHPExiftool\Driver\Tag\ZIP\ZipFileNameLength(),
                'ZipFileName' => new \PHPExiftool\Driver\Tag\ZIP\ZipFileName(),
                'CompressedSize' => new \PHPExiftool\Driver\Tag\ZIP\CompressedSize(),
                'UncompressedSize' => new \PHPExiftool\Driver\Tag\ZIP\UncompressedSize(),
                'PackingMethod' => new \PHPExiftool\Driver\Tag\ZIP\PackingMethod(),
                'FileNameLength' => new \PHPExiftool\Driver\Tag\ZIP\FileNameLength(),
            );
        });

    }

    public function getAll()
    {
        return array(
            'AFCP' => $this['AFCP'],
            'AIFF' => $this['AIFF'],
            'APE' => $this['APE'],
            'MAC' => $this['MAC'],
            'Ducky' => $this['Ducky'],
            'PictureInfo' => $this['PictureInfo'],
            'ASF' => $this['ASF'],
            'File' => $this['File'],
            'Canon' => $this['Canon'],
            'CanonCustom' => $this['CanonCustom'],
            'CanonRaw' => $this['CanonRaw'],
            'CanonVRD' => $this['CanonVRD'],
            'Casio' => $this['Casio'],
            'Composite' => $this['Composite'],
            'DICOM' => $this['DICOM'],
            'ExifIFD' => $this['ExifIFD'],
            'DNG' => $this['DNG'],
            'DV' => $this['DV'],
            'DjVu' => $this['DjVu'],
            'DjVu-Meta' => $this['DjVu-Meta'],
            'EXE' => $this['EXE'],
            'InteropIFD' => $this['InteropIFD'],
            'IFD0' => $this['IFD0'],
            'SubIFD1' => $this['SubIFD1'],
            'SubIFD2' => $this['SubIFD2'],
            'IFD1' => $this['IFD1'],
            'SubIFD' => $this['SubIFD'],
            'IFD2' => $this['IFD2'],
            'Adobe' => $this['Adobe'],
            'System' => $this['System'],
            'EXIF' => $this['EXIF'],
            'ExifTool' => $this['ExifTool'],
            'ICC_Profile' => $this['ICC_Profile'],
            'IPTC' => $this['IPTC'],
            'XMP' => $this['XMP'],
            'FLAC' => $this['FLAC'],
            'Flash' => $this['Flash'],
            'FlashPix' => $this['FlashPix'],
            'Font' => $this['Font'],
            'FotoStation' => $this['FotoStation'],
            'FujiFilm' => $this['FujiFilm'],
            'FujiIFD' => $this['FujiIFD'],
            'RAF2' => $this['RAF2'],
            'RAF' => $this['RAF'],
            'GE' => $this['GE'],
            'GIF' => $this['GIF'],
            'GIMP' => $this['GIMP'],
            'GPS' => $this['GPS'],
            'GeoTiff' => $this['GeoTiff'],
            'H264' => $this['H264'],
            'HP' => $this['HP'],
            'HTML' => $this['HTML'],
            'HTML-office' => $this['HTML-office'],
            'HTML-dc' => $this['HTML-dc'],
            'HTTP-equiv' => $this['HTTP-equiv'],
            'HTML-ncc' => $this['HTML-ncc'],
            'HTML-prod' => $this['HTML-prod'],
            'HTML-vw96' => $this['HTML-vw96'],
            'ICC-chrm' => $this['ICC-chrm'],
            'ICC-clrt' => $this['ICC-clrt'],
            'ICC-header' => $this['ICC-header'],
            'ICC-meas' => $this['ICC-meas'],
            'ICC-meta' => $this['ICC-meta'],
            'ICC-view' => $this['ICC-view'],
            'ID3' => $this['ID3'],
            'ID3v1' => $this['ID3v1'],
            'ID3v1_Enh' => $this['ID3v1_Enh'],
            'ID3v2_2' => $this['ID3v2_2'],
            'ID3v2_3' => $this['ID3v2_3'],
            'ID3v2_4' => $this['ID3v2_4'],
            'ITC' => $this['ITC'],
            'JFIF' => $this['JFIF'],
            'AVI1' => $this['AVI1'],
            'AdobeCM' => $this['AdobeCM'],
            'EPPIM' => $this['EPPIM'],
            'GraphConv' => $this['GraphConv'],
            'JPEG' => $this['JPEG'],
            'NITF' => $this['NITF'],
            'Ocad' => $this['Ocad'],
            'SPIFF' => $this['SPIFF'],
            'Scalado' => $this['Scalado'],
            'JVC' => $this['JVC'],
            'Jpeg2000' => $this['Jpeg2000'],
            'KodakBordersIFD' => $this['KodakBordersIFD'],
            'Kodak' => $this['Kodak'],
            'KodakIFD' => $this['KodakIFD'],
            'KDC_IFD' => $this['KDC_IFD'],
            'MetaIFD' => $this['MetaIFD'],
            'KodakEffectsIFD' => $this['KodakEffectsIFD'],
            'KyoceraRaw' => $this['KyoceraRaw'],
            'LNK' => $this['LNK'],
            'Leaf' => $this['Leaf'],
            'AC3' => $this['AC3'],
            'M2TS' => $this['M2TS'],
            'MIE-Audio' => $this['MIE-Audio'],
            'MIE-Camera' => $this['MIE-Camera'],
            'MIE-Doc' => $this['MIE-Doc'],
            'MIE-Extender' => $this['MIE-Extender'],
            'MIE-Flash' => $this['MIE-Flash'],
            'MIE-GPS' => $this['MIE-GPS'],
            'MIE-Geo' => $this['MIE-Geo'],
            'MIE-Image' => $this['MIE-Image'],
            'MIE-Lens' => $this['MIE-Lens'],
            'MIE-Main' => $this['MIE-Main'],
            'MIE-Orient' => $this['MIE-Orient'],
            'MIE-Preview' => $this['MIE-Preview'],
            'MIE-Thumbnail' => $this['MIE-Thumbnail'],
            'MIE-UTM' => $this['MIE-UTM'],
            'MIE-Video' => $this['MIE-Video'],
            'MIFF' => $this['MIFF'],
            'MNG' => $this['MNG'],
            'MPC' => $this['MPC'],
            'MPEG' => $this['MPEG'],
            'MPImage' => $this['MPImage'],
            'MPF0' => $this['MPF0'],
            'MXF' => $this['MXF'],
            'Matroska' => $this['Matroska'],
            'XMP-MP' => $this['XMP-MP'],
            'XMP-MP1' => $this['XMP-MP1'],
            'Microsoft' => $this['Microsoft'],
            'XMP-microsoft' => $this['XMP-microsoft'],
            'Minolta' => $this['Minolta'],
            'MinoltaRaw' => $this['MinoltaRaw'],
            'Nikon' => $this['Nikon'],
            'NikonScan' => $this['NikonScan'],
            'PreviewIFD' => $this['PreviewIFD'],
            'NikonCapture' => $this['NikonCapture'],
            'NikonCustom' => $this['NikonCustom'],
            'XML' => $this['XML'],
            'Olympus' => $this['Olympus'],
            'OpenEXR' => $this['OpenEXR'],
            'PDF' => $this['PDF'],
            'PICT' => $this['PICT'],
            'PNG' => $this['PNG'],
            'PSP' => $this['PSP'],
            'Leica' => $this['Leica'],
            'Panasonic' => $this['Panasonic'],
            'PanasonicRaw' => $this['PanasonicRaw'],
            'Pentax' => $this['Pentax'],
            'PhotoCD' => $this['PhotoCD'],
            'PhotoMechanic' => $this['PhotoMechanic'],
            'XMP-photomech' => $this['XMP-photomech'],
            'Photoshop' => $this['Photoshop'],
            'PostScript' => $this['PostScript'],
            'PrintIM' => $this['PrintIM'],
            'Qualcomm' => $this['Qualcomm'],
            'QuickTime' => $this['QuickTime'],
            'MakerNotes' => $this['MakerNotes'],
            'Track#' => $this['Track#'],
            'RIFF' => $this['RIFF'],
            'RSRC' => $this['RSRC'],
            'RTF' => $this['RTF'],
            'Radiance' => $this['Radiance'],
            'Rawzor' => $this['Rawzor'],
            'Real-RA3' => $this['Real-RA3'],
            'Real-RA4' => $this['Real-RA4'],
            'Real-RA5' => $this['Real-RA5'],
            'Real-CONT' => $this['Real-CONT'],
            'Real-MDPR' => $this['Real-MDPR'],
            'Real-RJMD' => $this['Real-RJMD'],
            'Real' => $this['Real'],
            'Real-PROP' => $this['Real-PROP'],
            'Reconyx' => $this['Reconyx'],
            'Ricoh' => $this['Ricoh'],
            'RMETA' => $this['RMETA'],
            'Samsung' => $this['Samsung'],
            'Sanyo' => $this['Sanyo'],
            'Sigma' => $this['Sigma'],
            'SigmaRaw' => $this['SigmaRaw'],
            'Sony' => $this['Sony'],
            'SR2DataIFD' => $this['SR2DataIFD'],
            'SR2' => $this['SR2'],
            'SR2SubIFD' => $this['SR2SubIFD'],
            'SRF#' => $this['SRF#'],
            'SonyIDC' => $this['SonyIDC'],
            'Stim' => $this['Stim'],
            'Theora' => $this['Theora'],
            'Vorbis' => $this['Vorbis'],
            'XMP-album' => $this['XMP-album'],
            'XMP-DICOM' => $this['XMP-DICOM'],
            'XMP-expressionmedia' => $this['XMP-expressionmedia'],
            'XMP-GPano' => $this['XMP-GPano'],
            'XMP-lr' => $this['XMP-lr'],
            'XMP-mediapro' => $this['XMP-mediapro'],
            'XMP-PixelLive' => $this['XMP-PixelLive'],
            'SVG' => $this['SVG'],
            'XMP-aas' => $this['XMP-aas'],
            'XMP-acdsee' => $this['XMP-acdsee'],
            'XMP-apple-fi' => $this['XMP-apple-fi'],
            'XMP-aux' => $this['XMP-aux'],
            'XMP-cc' => $this['XMP-cc'],
            'XMP-cell' => $this['XMP-cell'],
            'XMP-crs' => $this['XMP-crs'],
            'XMP-dc' => $this['XMP-dc'],
            'XMP-dex' => $this['XMP-dex'],
            'XMP-digiKam' => $this['XMP-digiKam'],
            'XMP-exif' => $this['XMP-exif'],
            'XMP-extensis' => $this['XMP-extensis'],
            'XMP-fpv' => $this['XMP-fpv'],
            'XMP-ics' => $this['XMP-ics'],
            'XMP-iptcCore' => $this['XMP-iptcCore'],
            'XMP-iptcExt' => $this['XMP-iptcExt'],
            'XMP-mwg-coll' => $this['XMP-mwg-coll'],
            'XMP-mwg-kw' => $this['XMP-mwg-kw'],
            'XMP-mwg-rs' => $this['XMP-mwg-rs'],
            'XMP-pdf' => $this['XMP-pdf'],
            'XMP-photoshop' => $this['XMP-photoshop'],
            'XMP-plus' => $this['XMP-plus'],
            'XMP-prism' => $this['XMP-prism'],
            'XMP-prl' => $this['XMP-prl'],
            'XMP-pur' => $this['XMP-pur'],
            'XMP-rdf' => $this['XMP-rdf'],
            'XMP-swf' => $this['XMP-swf'],
            'XMP-tiff' => $this['XMP-tiff'],
            'XMP-x' => $this['XMP-x'],
            'XMP-xmp' => $this['XMP-xmp'],
            'XMP-xmpBJ' => $this['XMP-xmpBJ'],
            'XMP-xmpDM' => $this['XMP-xmpDM'],
            'XMP-xmpMM' => $this['XMP-xmpMM'],
            'XMP-xmpNote' => $this['XMP-xmpNote'],
            'XMP-xmpPLUS' => $this['XMP-xmpPLUS'],
            'XMP-xmpRights' => $this['XMP-xmpRights'],
            'XMP-xmpTPg' => $this['XMP-xmpTPg'],
            'ZIP' => $this['ZIP'],

        );

    }

    public function getLookupTable()
    {
        return array(
            'afcp' => array(
                'thumbnailimage' => array(
                    'namespace' => 'AFCP',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\AFCP\ThumbnailImage',
                ),
                'previewimage' => array(
                    'namespace' => 'AFCP',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\AFCP\PreviewImage',
                ),
                'text' => array(
                    'namespace' => 'AFCP',
                    'tagname' => 'Text',
                    'classname' => 'PHPExiftool\Driver\Tag\AFCP\Text',
                ),

            ),
            'aiff' => array(
                'commenttime' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'CommentTime',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\CommentTime',
                ),
                'markerid' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'MarkerID',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\MarkerID',
                ),
                'comment' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\Comment',
                ),
                'numchannels' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'NumChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\NumChannels',
                ),
                'numsampleframes' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'NumSampleFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\NumSampleFrames',
                ),
                'samplesize' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'SampleSize',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\SampleSize',
                ),
                'samplerate' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\SampleRate',
                ),
                'compressiontype' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'CompressionType',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\CompressionType',
                ),
                'compressorname' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'CompressorName',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\CompressorName',
                ),
                'formatversiontime' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'FormatVersionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\FormatVersionTime',
                ),
                'copyright' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\Copyright',
                ),
                'annotation' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'Annotation',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\Annotation',
                ),
                'author' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\Author',
                ),
                'name' => array(
                    'namespace' => 'AIFF',
                    'tagname' => 'Name',
                    'classname' => 'PHPExiftool\Driver\Tag\AIFF\Name',
                ),

            ),
            'ape' => array(
                'album' => array(
                    'namespace' => 'APE',
                    'tagname' => 'Album',
                    'classname' => 'PHPExiftool\Driver\Tag\APE\Album',
                ),
                'artist' => array(
                    'namespace' => 'APE',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\APE\Artist',
                ),
                'genre' => array(
                    'namespace' => 'APE',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\APE\Genre',
                ),
                'title' => array(
                    'namespace' => 'APE',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\APE\Title',
                ),
                'toolname' => array(
                    'namespace' => 'APE',
                    'tagname' => 'ToolName',
                    'classname' => 'PHPExiftool\Driver\Tag\APE\ToolName',
                ),
                'toolversion' => array(
                    'namespace' => 'APE',
                    'tagname' => 'ToolVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\APE\ToolVersion',
                ),
                'track' => array(
                    'namespace' => 'APE',
                    'tagname' => 'Track',
                    'classname' => 'PHPExiftool\Driver\Tag\APE\Track',
                ),
                'year' => array(
                    'namespace' => 'APE',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\APE\Year',
                ),

            ),
            'mac' => array(
                'compressionlevel' => array(
                    'namespace' => 'MAC',
                    'tagname' => 'CompressionLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\MAC\CompressionLevel',
                ),
                'blocksperframe' => array(
                    'namespace' => 'MAC',
                    'tagname' => 'BlocksPerFrame',
                    'classname' => 'PHPExiftool\Driver\Tag\MAC\BlocksPerFrame',
                ),
                'finalframeblocks' => array(
                    'namespace' => 'MAC',
                    'tagname' => 'FinalFrameBlocks',
                    'classname' => 'PHPExiftool\Driver\Tag\MAC\FinalFrameBlocks',
                ),
                'totalframes' => array(
                    'namespace' => 'MAC',
                    'tagname' => 'TotalFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\MAC\TotalFrames',
                ),
                'bitspersample' => array(
                    'namespace' => 'MAC',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\MAC\BitsPerSample',
                ),
                'channels' => array(
                    'namespace' => 'MAC',
                    'tagname' => 'Channels',
                    'classname' => 'PHPExiftool\Driver\Tag\MAC\Channels',
                ),
                'samplerate' => array(
                    'namespace' => 'MAC',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MAC\SampleRate',
                ),
                'apeversion' => array(
                    'namespace' => 'MAC',
                    'tagname' => 'APEVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MAC\APEVersion',
                ),

            ),
            'ducky' => array(
                'quality' => array(
                    'namespace' => 'Ducky',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Ducky\Quality',
                ),
                'comment' => array(
                    'namespace' => 'Ducky',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\Ducky\Comment',
                ),
                'copyright' => array(
                    'namespace' => 'Ducky',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\Ducky\Copyright',
                ),

            ),
            'pictureinfo' => array(
                'aperture' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'Aperture',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\Aperture',
                ),
                'colormode' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\ColorMode',
                ),
                'contake' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'ConTake',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\ConTake',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\ExposureCompensation',
                ),
                'fnumber' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\FNumber',
                ),
                'firmwareversion' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\FirmwareVersion',
                ),
                'flash' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\Flash',
                ),
                'focusmode' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\FocusMode',
                ),
                'focuspos' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'FocusPos',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\FocusPos',
                ),
                'id' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'ID',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\ID',
                ),
                'imagesize' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'ImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\ImageSize',
                ),
                'lights' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'LightS',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\LightS',
                ),
                'macro' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'Macro',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\Macro',
                ),
                'protect' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'Protect',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\Protect',
                ),
                'quality' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\Quality',
                ),
                'resolution' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'Resolution',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\Resolution',
                ),
                'serialnumber' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\SerialNumber',
                ),
                'exposuretime' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\ExposureTime',
                ),
                'strobetime' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'StrobeTime',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\StrobeTime',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\DateTimeOriginal',
                ),
                'cameratype' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'CameraType',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\CameraType',
                ),
                'version' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\Version',
                ),
                'ytarget' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'YTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\YTarget',
                ),
                'zoom' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'Zoom',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\Zoom',
                ),
                'zoompos' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'ZoomPos',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\ZoomPos',
                ),
                'ylevel' => array(
                    'namespace' => 'PictureInfo',
                    'tagname' => 'YLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\PictureInfo\YLevel',
                ),

            ),
            'asf' => array(
                'audiocodecdescription' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AudioCodecDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AudioCodecDescription',
                ),
                'audiocodecname' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AudioCodecName',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AudioCodecName',
                ),
                'othercodecdescription' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OtherCodecDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OtherCodecDescription',
                ),
                'othercodecname' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OtherCodecName',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OtherCodecName',
                ),
                'videocodecdescription' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'VideoCodecDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\VideoCodecDescription',
                ),
                'videocodecname' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'VideoCodecName',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\VideoCodecName',
                ),
                'bannerimagetype' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'BannerImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\BannerImageType',
                ),
                'bannerimage' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'BannerImage',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\BannerImage',
                ),
                'bannerimageurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'BannerImageURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\BannerImageURL',
                ),
                'copyrighturl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'CopyrightURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\CopyrightURL',
                ),
                'title' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Title',
                ),
                'author' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Author',
                ),
                'copyright' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Copyright',
                ),
                'description' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Description',
                ),
                'rating' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Rating',
                ),
                'asfleakybucketpairs' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ASFLeakyBucketPairs',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ASFLeakyBucketPairs',
                ),
                'asfpacketcount' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ASFPacketCount',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ASFPacketCount',
                ),
                'asfsecurityobjectssize' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ASFSecurityObjectsSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ASFSecurityObjectsSize',
                ),
                'albumartist' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AlbumArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AlbumArtist',
                ),
                'albumcoverurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AlbumCoverURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AlbumCoverURL',
                ),
                'albumtitle' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AlbumTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AlbumTitle',
                ),
                'aspectratiox' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AspectRatioX',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AspectRatioX',
                ),
                'aspectratioy' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AspectRatioY',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AspectRatioY',
                ),
                'audiofileurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AudioFileURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AudioFileURL',
                ),
                'audiosourceurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AudioSourceURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AudioSourceURL',
                ),
                'authorurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AuthorURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AuthorURL',
                ),
                'averagelevel' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AverageLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AverageLevel',
                ),
                'bannerimagedata' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'BannerImageData',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\BannerImageData',
                ),
                'beatsperminute' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'BeatsPerMinute',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\BeatsPerMinute',
                ),
                'bitrate' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Bitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Bitrate',
                ),
                'broadcast' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Broadcast',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Broadcast',
                ),
                'bufferaverage' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'BufferAverage',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\BufferAverage',
                ),
                'can_skip_backward' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Can_Skip_Backward',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\CanSkipBackward',
                ),
                'can_skip_forward' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Can_Skip_Forward',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\CanSkipForward',
                ),
                'category' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Category',
                ),
                'codec' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Codec',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Codec',
                ),
                'composer' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Composer',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Composer',
                ),
                'conductor' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Conductor',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Conductor',
                ),
                'containerformat' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ContainerFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ContainerFormat',
                ),
                'contentdistributor' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ContentDistributor',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ContentDistributor',
                ),
                'contentgroupdescription' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ContentGroupDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ContentGroupDescription',
                ),
                'currentbitrate' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'CurrentBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\CurrentBitrate',
                ),
                'drm' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRM',
                ),
                'drm_contentid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_ContentID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMContentID',
                ),
                'drm_drmheader' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_DRMHeader',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMDRMHeader',
                ),
                'drm_drmheader_contentdistributor' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_DRMHeader_ContentDistributor',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderContentDistributor',
                ),
                'drm_drmheader_contentid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_DRMHeader_ContentID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderContentID',
                ),
                'drm_drmheader_individualizedversion' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_DRMHeader_IndividualizedVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderIndividualizedVersion',
                ),
                'drm_drmheader_keyid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_DRMHeader_KeyID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderKeyID',
                ),
                'drm_drmheader_licenseacqurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_DRMHeader_LicenseAcqURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderLicenseAcqURL',
                ),
                'drm_drmheader_subscriptioncontentid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_DRMHeader_SubscriptionContentID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMDRMHeaderSubscriptionContentID',
                ),
                'drm_individualizedversion' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_IndividualizedVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMIndividualizedVersion',
                ),
                'drm_keyid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_KeyID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMKeyID',
                ),
                'drm_lasignaturecert' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_LASignatureCert',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMLASignatureCert',
                ),
                'drm_lasignaturelicsrvcert' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_LASignatureLicSrvCert',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMLASignatureLicSrvCert',
                ),
                'drm_lasignatureprivkey' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_LASignaturePrivKey',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMLASignaturePrivKey',
                ),
                'drm_lasignaturerootcert' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_LASignatureRootCert',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMLASignatureRootCert',
                ),
                'drm_licenseacqurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_LicenseAcqURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMLicenseAcqURL',
                ),
                'drm_v1licenseacqurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DRM_V1LicenseAcqURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DRMV1LicenseAcqURL',
                ),
                'dvdid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DVDID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DVDID',
                ),
                'director' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Director',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Director',
                ),
                'duration' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Duration',
                ),
                'encodedby' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'EncodedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\EncodedBy',
                ),
                'encodingsettings' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'EncodingSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\EncodingSettings',
                ),
                'encodingtime' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'EncodingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\EncodingTime',
                ),
                'filesize' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'FileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\FileSize',
                ),
                'genre' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Genre',
                ),
                'genreid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'GenreID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\GenreID',
                ),
                'hasarbitrarydatastream' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'HasArbitraryDataStream',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\HasArbitraryDataStream',
                ),
                'hasattachedimages' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'HasAttachedImages',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\HasAttachedImages',
                ),
                'hasaudio' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'HasAudio',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\HasAudio',
                ),
                'hasfiletransferstream' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'HasFileTransferStream',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\HasFileTransferStream',
                ),
                'hasimage' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'HasImage',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\HasImage',
                ),
                'hasscript' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'HasScript',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\HasScript',
                ),
                'hasvideo' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'HasVideo',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\HasVideo',
                ),
                'isrc' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ISRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ISRC',
                ),
                'initialkey' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'InitialKey',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\InitialKey',
                ),
                'isvbr' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'IsVBR',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\IsVBR',
                ),
                'is_protected' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Is_Protected',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\IsProtected',
                ),
                'is_trusted' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Is_Trusted',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\IsTrusted',
                ),
                'language' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Language',
                ),
                'lyrics' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Lyrics',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Lyrics',
                ),
                'lyrics_synchronised' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Lyrics_Synchronised',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\LyricsSynchronised',
                ),
                'mcdi' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MCDI',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MCDI',
                ),
                'mediaclassprimaryid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaClassPrimaryID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaClassPrimaryID',
                ),
                'mediaclasssecondaryid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaClassSecondaryID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaClassSecondaryID',
                ),
                'mediacredits' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaCredits',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaCredits',
                ),
                'mediaisdelay' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsDelay',
                ),
                'mediaisfinale' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsFinale',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsFinale',
                ),
                'mediaislive' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsLive',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsLive',
                ),
                'mediaispremiere' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsPremiere',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsPremiere',
                ),
                'mediaisrepeat' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsRepeat',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsRepeat',
                ),
                'mediaissap' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsSAP',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsSAP',
                ),
                'mediaisstereo' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsStereo',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsStereo',
                ),
                'mediaissubtitled' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsSubtitled',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsSubtitled',
                ),
                'mediaistape' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIsTape',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIsTape',
                ),
                'medianetworkaffiliation' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaNetworkAffiliation',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaNetworkAffiliation',
                ),
                'mediaoriginalbroadcastdatetime' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaOriginalBroadcastDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaOriginalBroadcastDateTime',
                ),
                'mediaoriginalchannel' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaOriginalChannel',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaOriginalChannel',
                ),
                'mediastationcallsign' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaStationCallSign',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaStationCallSign',
                ),
                'mediastationname' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaStationName',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaStationName',
                ),
                'modifiedby' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ModifiedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ModifiedBy',
                ),
                'mood' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Mood',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Mood',
                ),
                'nsc_address' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'NSC_Address',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\NSCAddress',
                ),
                'nsc_description' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'NSC_Description',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\NSCDescription',
                ),
                'nsc_email' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'NSC_Email',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\NSCEmail',
                ),
                'nsc_name' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'NSC_Name',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\NSCName',
                ),
                'nsc_phone' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'NSC_Phone',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\NSCPhone',
                ),
                'numberofframes' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'NumberOfFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\NumberOfFrames',
                ),
                'optimalbitrate' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OptimalBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OptimalBitrate',
                ),
                'originalalbumtitle' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OriginalAlbumTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OriginalAlbumTitle',
                ),
                'originalartist' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OriginalArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OriginalArtist',
                ),
                'originalfilename' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OriginalFilename',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OriginalFilename',
                ),
                'originallyricist' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OriginalLyricist',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OriginalLyricist',
                ),
                'originalreleasetime' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OriginalReleaseTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OriginalReleaseTime',
                ),
                'originalreleaseyear' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'OriginalReleaseYear',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\OriginalReleaseYear',
                ),
                'parentalrating' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ParentalRating',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ParentalRating',
                ),
                'parentalratingreason' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ParentalRatingReason',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ParentalRatingReason',
                ),
                'partofset' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PartOfSet',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PartOfSet',
                ),
                'peakbitrate' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PeakBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PeakBitrate',
                ),
                'peakvalue' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PeakValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PeakValue',
                ),
                'period' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Period',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Period',
                ),
                'playlistdelay' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PlaylistDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PlaylistDelay',
                ),
                'producer' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Producer',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Producer',
                ),
                'promotionurl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PromotionURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PromotionURL',
                ),
                'protectiontype' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ProtectionType',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ProtectionType',
                ),
                'provider' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Provider',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Provider',
                ),
                'providercopyright' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ProviderCopyright',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ProviderCopyright',
                ),
                'providerrating' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ProviderRating',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ProviderRating',
                ),
                'providerstyle' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ProviderStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ProviderStyle',
                ),
                'publisher' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Publisher',
                ),
                'radiostationname' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'RadioStationName',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\RadioStationName',
                ),
                'radiostationowner' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'RadioStationOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\RadioStationOwner',
                ),
                'seekable' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Seekable',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Seekable',
                ),
                'shareduserrating' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'SharedUserRating',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\SharedUserRating',
                ),
                'signature_name' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Signature_Name',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\SignatureName',
                ),
                'streamtypeinfo' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'StreamTypeInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\StreamTypeInfo',
                ),
                'stridable' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Stridable',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Stridable',
                ),
                'subtitle' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'SubTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\SubTitle',
                ),
                'subtitledescription' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'SubTitleDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\SubTitleDescription',
                ),
                'subscriptioncontentid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'SubscriptionContentID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\SubscriptionContentID',
                ),
                'text' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Text',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Text',
                ),
                'toolname' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ToolName',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ToolName',
                ),
                'toolversion' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ToolVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ToolVersion',
                ),
                'track' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Track',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Track',
                ),
                'tracknumber' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'TrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\TrackNumber',
                ),
                'uniquefileidentifier' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'UniqueFileIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\UniqueFileIdentifier',
                ),
                'userweburl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'UserWebURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\UserWebURL',
                ),
                'vbrpeak' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'VBRPeak',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\VBRPeak',
                ),
                'videoclosedcaptioning' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'VideoClosedCaptioning',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\VideoClosedCaptioning',
                ),
                'videoframerate' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'VideoFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\VideoFrameRate',
                ),
                'videoheight' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'VideoHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\VideoHeight',
                ),
                'videowidth' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'VideoWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\VideoWidth',
                ),
                'wmadrcaveragereference' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'WMADRCAverageReference',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\WMADRCAverageReference',
                ),
                'wmadrcaveragetarget' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'WMADRCAverageTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\WMADRCAverageTarget',
                ),
                'wmadrcpeakreference' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'WMADRCPeakReference',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\WMADRCPeakReference',
                ),
                'wmadrcpeaktarget' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'WMADRCPeakTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\WMADRCPeakTarget',
                ),
                'wmcollectiongroupid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'WMCollectionGroupID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\WMCollectionGroupID',
                ),
                'wmcollectionid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'WMCollectionID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\WMCollectionID',
                ),
                'wmcontentid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'WMContentID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\WMContentID',
                ),
                'writer' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Writer',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Writer',
                ),
                'year' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Year',
                ),
                'fileid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'FileID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\FileID',
                ),
                'filelength' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'FileLength',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\FileLength',
                ),
                'creationdate' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'CreationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\CreationDate',
                ),
                'datapackets' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DataPackets',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DataPackets',
                ),
                'playduration' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PlayDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PlayDuration',
                ),
                'sendduration' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'SendDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\SendDuration',
                ),
                'preroll' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Preroll',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Preroll',
                ),
                'flags' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Flags',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Flags',
                ),
                'minpacketsize' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MinPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MinPacketSize',
                ),
                'maxpacketsize' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MaxPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MaxPacketSize',
                ),
                'maxbitrate' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MaxBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MaxBitrate',
                ),
                'padding' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Padding',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Padding',
                ),
                'scriptcommand' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ScriptCommand',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ScriptCommand',
                ),
                'contentencryption' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ContentEncryption',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ContentEncryption',
                ),
                'digitalsignature' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'DigitalSignature',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\DigitalSignature',
                ),
                'extendedcontentencryption' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ExtendedContentEncryption',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ExtendedContentEncryption',
                ),
                'errorcorrection' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ErrorCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ErrorCorrection',
                ),
                'streambitrateprops' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'StreamBitrateProps',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\StreamBitrateProps',
                ),
                'bitratemutualexclusion' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'BitrateMutualExclusion',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\BitrateMutualExclusion',
                ),
                'marker' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Marker',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Marker',
                ),
                'extendedstreamprops' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ExtendedStreamProps',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ExtendedStreamProps',
                ),
                'advancedcontentencryption' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AdvancedContentEncryption',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AdvancedContentEncryption',
                ),
                'timecodeindexparms' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'TimecodeIndexParms',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\TimecodeIndexParms',
                ),
                'compatibility' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Compatibility',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Compatibility',
                ),
                'languagelist' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'LanguageList',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\LanguageList',
                ),
                'advancedmutualexcl' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AdvancedMutualExcl',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AdvancedMutualExcl',
                ),
                'bandwidthsharing' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'BandwidthSharing',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\BandwidthSharing',
                ),
                'reserved1' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Reserved1',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Reserved1',
                ),
                'groupmutualexclusion' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'GroupMutualExclusion',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\GroupMutualExclusion',
                ),
                'streamprioritization' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'StreamPrioritization',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\StreamPrioritization',
                ),
                'indexparameters' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'IndexParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\IndexParameters',
                ),
                'simpleindex' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'SimpleIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\SimpleIndex',
                ),
                'timecodeindex' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'TimecodeIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\TimecodeIndex',
                ),
                'data' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Data',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Data',
                ),
                'index' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Index',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Index',
                ),
                'mediaindex' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'MediaIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\MediaIndex',
                ),
                'picturetype' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PictureType',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PictureType',
                ),
                'picturemimetype' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PictureMimeType',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PictureMimeType',
                ),
                'picturedescription' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'PictureDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\PictureDescription',
                ),
                'picture' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'Picture',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\Picture',
                ),
                'streamtype' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'StreamType',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\StreamType',
                ),
                'errorcorrectiontype' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ErrorCorrectionType',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ErrorCorrectionType',
                ),
                'timeoffset' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'TimeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\TimeOffset',
                ),
                'streamnumber' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'StreamNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\StreamNumber',
                ),
                'audiocodecid' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AudioCodecID',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AudioCodecID',
                ),
                'imagewidth' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ImageWidth',
                ),
                'audiochannels' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AudioChannels',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\AudioSampleRate',
                ),
                'imageheight' => array(
                    'namespace' => 'ASF',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\ASF\ImageHeight',
                ),

            ),
            'file' => array(
                'imagewidth' => array(
                    'namespace' => 'File',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\File\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'File',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\File\ImageHeight',
                ),
                'planes' => array(
                    'namespace' => 'File',
                    'tagname' => 'Planes',
                    'classname' => 'PHPExiftool\Driver\Tag\File\Planes',
                ),
                'bitdepth' => array(
                    'namespace' => 'File',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\File\BitDepth',
                ),
                'compression' => array(
                    'namespace' => 'File',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\File\Compression',
                ),
                'imagelength' => array(
                    'namespace' => 'File',
                    'tagname' => 'ImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\File\ImageLength',
                ),
                'pixelspermeterx' => array(
                    'namespace' => 'File',
                    'tagname' => 'PixelsPerMeterX',
                    'classname' => 'PHPExiftool\Driver\Tag\File\PixelsPerMeterX',
                ),
                'pixelspermetery' => array(
                    'namespace' => 'File',
                    'tagname' => 'PixelsPerMeterY',
                    'classname' => 'PHPExiftool\Driver\Tag\File\PixelsPerMeterY',
                ),
                'numcolors' => array(
                    'namespace' => 'File',
                    'tagname' => 'NumColors',
                    'classname' => 'PHPExiftool\Driver\Tag\File\NumColors',
                ),
                'numimportantcolors' => array(
                    'namespace' => 'File',
                    'tagname' => 'NumImportantColors',
                    'classname' => 'PHPExiftool\Driver\Tag\File\NumImportantColors',
                ),
                'comment' => array(
                    'namespace' => 'File',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\File\Comment',
                ),
                'currentiptcdigest' => array(
                    'namespace' => 'File',
                    'tagname' => 'CurrentIPTCDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\File\CurrentIPTCDigest',
                ),
                'exifbyteorder' => array(
                    'namespace' => 'File',
                    'tagname' => 'ExifByteOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\File\ExifByteOrder',
                ),
                'exifunicodebyteorder' => array(
                    'namespace' => 'File',
                    'tagname' => 'ExifUnicodeByteOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\File\ExifUnicodeByteOrder',
                ),
                'filetype' => array(
                    'namespace' => 'File',
                    'tagname' => 'FileType',
                    'classname' => 'PHPExiftool\Driver\Tag\File\FileType',
                ),
                'geosync' => array(
                    'namespace' => 'File',
                    'tagname' => 'Geosync',
                    'classname' => 'PHPExiftool\Driver\Tag\File\Geosync',
                ),
                'geotag' => array(
                    'namespace' => 'File',
                    'tagname' => 'Geotag',
                    'classname' => 'PHPExiftool\Driver\Tag\File\Geotag',
                ),
                'geotime' => array(
                    'namespace' => 'File',
                    'tagname' => 'Geotime',
                    'classname' => 'PHPExiftool\Driver\Tag\File\Geotime',
                ),
                'id3size' => array(
                    'namespace' => 'File',
                    'tagname' => 'ID3Size',
                    'classname' => 'PHPExiftool\Driver\Tag\File\ID3Size',
                ),
                'jpegdigest' => array(
                    'namespace' => 'File',
                    'tagname' => 'JPEGDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\File\JPEGDigest',
                ),
                'mimetype' => array(
                    'namespace' => 'File',
                    'tagname' => 'MIMEType',
                    'classname' => 'PHPExiftool\Driver\Tag\File\MIMEType',
                ),
                'maxval' => array(
                    'namespace' => 'File',
                    'tagname' => 'MaxVal',
                    'classname' => 'PHPExiftool\Driver\Tag\File\MaxVal',
                ),
                'previewimage' => array(
                    'namespace' => 'File',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\File\PreviewImage',
                ),
                'previewpng' => array(
                    'namespace' => 'File',
                    'tagname' => 'PreviewPNG',
                    'classname' => 'PHPExiftool\Driver\Tag\File\PreviewPNG',
                ),
                'previewwmf' => array(
                    'namespace' => 'File',
                    'tagname' => 'PreviewWMF',
                    'classname' => 'PHPExiftool\Driver\Tag\File\PreviewWMF',
                ),
                'rafversion' => array(
                    'namespace' => 'File',
                    'tagname' => 'RAFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\File\RAFVersion',
                ),
                'xresolution' => array(
                    'namespace' => 'File',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\File\XResolution',
                ),
                'yresolution' => array(
                    'namespace' => 'File',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\File\YResolution',
                ),
                'bitspersample' => array(
                    'namespace' => 'File',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\File\BitsPerSample',
                ),
                'colorcomponents' => array(
                    'namespace' => 'File',
                    'tagname' => 'ColorComponents',
                    'classname' => 'PHPExiftool\Driver\Tag\File\ColorComponents',
                ),
                'encodingprocess' => array(
                    'namespace' => 'File',
                    'tagname' => 'EncodingProcess',
                    'classname' => 'PHPExiftool\Driver\Tag\File\EncodingProcess',
                ),
                'ycbcrsubsampling' => array(
                    'namespace' => 'File',
                    'tagname' => 'YCbCrSubSampling',
                    'classname' => 'PHPExiftool\Driver\Tag\File\YCbCrSubSampling',
                ),
                'pgfversion' => array(
                    'namespace' => 'File',
                    'tagname' => 'PGFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\File\PGFVersion',
                ),
                'pyramidlevels' => array(
                    'namespace' => 'File',
                    'tagname' => 'PyramidLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\File\PyramidLevels',
                ),
                'quality' => array(
                    'namespace' => 'File',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\File\Quality',
                ),
                'bitsperpixel' => array(
                    'namespace' => 'File',
                    'tagname' => 'BitsPerPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\File\BitsPerPixel',
                ),
                'colormode' => array(
                    'namespace' => 'File',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\File\ColorMode',
                ),
                'backgroundcolor' => array(
                    'namespace' => 'File',
                    'tagname' => 'BackgroundColor',
                    'classname' => 'PHPExiftool\Driver\Tag\File\BackgroundColor',
                ),

            ),
            'canon' => array(
                'numafpoints' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'NumAFPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\NumAFPoints',
                ),
                'validafpoints' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ValidAFPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ValidAFPoints',
                ),
                'canonimagewidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonImageWidth',
                ),
                'canonimageheight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonImageHeight',
                ),
                'afimagewidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFImageWidth',
                ),
                'afimageheight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFImageHeight',
                ),
                'afareawidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFAreaWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFAreaWidth',
                ),
                'afareaheight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFAreaHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFAreaHeight',
                ),
                'afareaxpositions' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFAreaXPositions',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFAreaXPositions',
                ),
                'afareaypositions' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFAreaYPositions',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFAreaYPositions',
                ),
                'afpointsinfocus' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFPointsInFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFPointsInFocus',
                ),
                'primaryafpoint' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PrimaryAFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PrimaryAFPoint',
                ),
                'canon_afinfo_0x000b' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Canon_AFInfo_0x000b',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonAFInfo0x000b',
                ),
                'afinfosize' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFInfoSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFInfoSize',
                ),
                'afareamode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFAreaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFAreaMode',
                ),
                'afareawidths' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFAreaWidths',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFAreaWidths',
                ),
                'afareaheights' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFAreaHeights',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFAreaHeights',
                ),
                'afpointsselected' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFPointsSelected',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFPointsSelected',
                ),
                'canon_afinfo2_0x000d' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Canon_AFInfo2_0x000d',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonAFInfo20x000d',
                ),
                'afmicroadjmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFMicroAdjMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFMicroAdjMode',
                ),
                'afmicroadjvalue' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFMicroAdjValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFMicroAdjValue',
                ),
                'ambienceselection' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AmbienceSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AmbienceSelection',
                ),
                'aspectratio' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AspectRatio',
                ),
                'croppedimagewidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CroppedImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CroppedImageWidth',
                ),
                'croppedimageheight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CroppedImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CroppedImageHeight',
                ),
                'croppedimageleft' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CroppedImageLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CroppedImageLeft',
                ),
                'croppedimagetop' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CroppedImageTop',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CroppedImageTop',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ThumbnailImage',
                ),
                'fnumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FNumber',
                ),
                'exposuretime' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ExposureTime',
                ),
                'iso' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ISO',
                ),
                'flashmeteringmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FlashMeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FlashMeteringMode',
                ),
                'cameratemperature' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraTemperature',
                ),
                'macromagnification' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MacroMagnification',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MacroMagnification',
                ),
                'focallength' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocalLength',
                ),
                'cameraorientation' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraOrientation',
                ),
                'focusdistanceupper' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocusDistanceUpper',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocusDistanceUpper',
                ),
                'focusdistancelower' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocusDistanceLower',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocusDistanceLower',
                ),
                'whitebalance' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WhiteBalance',
                ),
                'colortemperature' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTemperature',
                ),
                'lenstype' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\LensType',
                ),
                'minfocallength' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MinFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MinFocalLength',
                ),
                'maxfocallength' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MaxFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MaxFocalLength',
                ),
                'firmwareversion' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FirmwareVersion',
                ),
                'directoryindex' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'DirectoryIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\DirectoryIndex',
                ),
                'fileindex' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FileIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FileIndex',
                ),
                'lensmodel' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'LensModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\LensModel',
                ),
                'sharpnessfrequency' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessFrequency',
                ),
                'sharpness' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Sharpness',
                ),
                'picturestyle' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PictureStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PictureStyle',
                ),
                'firmwareversionlookahead' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FirmwareVersionLookAhead',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FirmwareVersionLookAhead',
                ),
                'focaltype' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocalType',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocalType',
                ),
                'canonimagesize' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonImageSize',
                ),
                'jpegquality' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'JPEGQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\JPEGQuality',
                ),
                'saturation' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Saturation',
                ),
                'colortone' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTone',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTone',
                ),
                'contrast' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Contrast',
                ),
                'shuttercount' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ShutterCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ShutterCount',
                ),
                'timestamp1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'TimeStamp1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\TimeStamp1',
                ),
                'timestamp' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'TimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\TimeStamp',
                ),
                'highlighttonepriority' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'HighlightTonePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\HighlightTonePriority',
                ),
                'measuredev2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MeasuredEV2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MeasuredEV2',
                ),
                'measuredev3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MeasuredEV3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MeasuredEV3',
                ),
                'ownername' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'OwnerName',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\OwnerName',
                ),
                'highisonoisereduction' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'HighISONoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\HighISONoiseReduction',
                ),
                'autolightingoptimizer' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AutoLightingOptimizer',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AutoLightingOptimizer',
                ),
                'afpointsinfocus5d' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFPointsInFocus5D',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFPointsInFocus5D',
                ),
                'firmwarerevision' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FirmwareRevision',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FirmwareRevision',
                ),
                'shortownername' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ShortOwnerName',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ShortOwnerName',
                ),
                'contraststandard' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastStandard',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastStandard',
                ),
                'contrastportrait' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastPortrait',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastPortrait',
                ),
                'contrastlandscape' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastLandscape',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastLandscape',
                ),
                'contrastneutral' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastNeutral',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastNeutral',
                ),
                'contrastfaithful' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastFaithful',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastFaithful',
                ),
                'contrastmonochrome' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastMonochrome',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastMonochrome',
                ),
                'contrastuserdef1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastUserDef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastUserDef1',
                ),
                'contrastuserdef2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastUserDef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastUserDef2',
                ),
                'contrastuserdef3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastUserDef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastUserDef3',
                ),
                'sharpnessstandard' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessStandard',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessStandard',
                ),
                'sharpnessportrait' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessPortrait',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessPortrait',
                ),
                'sharpnesslandscape' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessLandscape',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessLandscape',
                ),
                'sharpnessneutral' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessNeutral',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessNeutral',
                ),
                'sharpnessfaithful' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessFaithful',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessFaithful',
                ),
                'sharpnessmonochrome' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessMonochrome',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessMonochrome',
                ),
                'sharpnessuserdef1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessUserDef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessUserDef1',
                ),
                'sharpnessuserdef2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessUserDef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessUserDef2',
                ),
                'sharpnessuserdef3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessUserDef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessUserDef3',
                ),
                'saturationstandard' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationStandard',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationStandard',
                ),
                'saturationportrait' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationPortrait',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationPortrait',
                ),
                'saturationlandscape' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationLandscape',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationLandscape',
                ),
                'saturationneutral' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationNeutral',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationNeutral',
                ),
                'saturationfaithful' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationFaithful',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationFaithful',
                ),
                'filtereffectmonochrome' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectMonochrome',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectMonochrome',
                ),
                'saturationuserdef1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationUserDef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationUserDef1',
                ),
                'saturationuserdef2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationUserDef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationUserDef2',
                ),
                'saturationuserdef3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationUserDef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationUserDef3',
                ),
                'colortonestandard' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneStandard',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneStandard',
                ),
                'colortoneportrait' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTonePortrait',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTonePortrait',
                ),
                'colortonelandscape' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneLandscape',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneLandscape',
                ),
                'colortoneneutral' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneNeutral',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneNeutral',
                ),
                'colortonefaithful' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneFaithful',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneFaithful',
                ),
                'toningeffectmonochrome' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectMonochrome',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectMonochrome',
                ),
                'colortoneuserdef1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneUserDef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneUserDef1',
                ),
                'colortoneuserdef2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneUserDef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneUserDef2',
                ),
                'colortoneuserdef3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneUserDef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneUserDef3',
                ),
                'userdef1picturestyle' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'UserDef1PictureStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\UserDef1PictureStyle',
                ),
                'userdef2picturestyle' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'UserDef2PictureStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\UserDef2PictureStyle',
                ),
                'userdef3picturestyle' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'UserDef3PictureStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\UserDef3PictureStyle',
                ),
                'fileindex2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FileIndex2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FileIndex2',
                ),
                'directoryindex2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'DirectoryIndex2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\DirectoryIndex2',
                ),
                'measuredev' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MeasuredEV',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MeasuredEV',
                ),
                'rotation' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Rotation',
                ),
                'macromode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MacroMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MacroMode',
                ),
                'selftimer' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SelfTimer',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SelfTimer',
                ),
                'quality' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Quality',
                ),
                'canonflashmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonFlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonFlashMode',
                ),
                'continuousdrive' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContinuousDrive',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContinuousDrive',
                ),
                'focusmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocusMode',
                ),
                'recordmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'RecordMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\RecordMode',
                ),
                'easymode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'EasyMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\EasyMode',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\DigitalZoom',
                ),
                'cameraiso' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraISO',
                ),
                'meteringmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MeteringMode',
                ),
                'focusrange' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocusRange',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocusRange',
                ),
                'afpoint' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFPoint',
                ),
                'canonexposuremode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonExposureMode',
                ),
                'focalunits' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocalUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocalUnits',
                ),
                'maxaperture' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MaxAperture',
                ),
                'minaperture' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MinAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MinAperture',
                ),
                'flashactivity' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FlashActivity',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FlashActivity',
                ),
                'flashbits' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FlashBits',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FlashBits',
                ),
                'focuscontinuous' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocusContinuous',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocusContinuous',
                ),
                'aesetting' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AESetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AESetting',
                ),
                'imagestabilization' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ImageStabilization',
                ),
                'displayaperture' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'DisplayAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\DisplayAperture',
                ),
                'zoomsourcewidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ZoomSourceWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ZoomSourceWidth',
                ),
                'zoomtargetwidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ZoomTargetWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ZoomTargetWidth',
                ),
                'spotmeteringmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SpotMeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SpotMeteringMode',
                ),
                'photoeffect' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PhotoEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PhotoEffect',
                ),
                'manualflashoutput' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ManualFlashOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ManualFlashOutput',
                ),
                'srawquality' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SRAWQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SRAWQuality',
                ),
                'wb_rggblevelsauto' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsAuto',
                ),
                'wb_rggblevelsdaylight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsDaylight',
                ),
                'wb_rggblevelsshade' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsShade',
                ),
                'wb_rggblevelscloudy' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsCloudy',
                ),
                'wb_rggblevelstungsten' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsTungsten',
                ),
                'wb_rggblevelsfluorescent' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsFluorescent',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsFluorescent',
                ),
                'wb_rggblevelsflash' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsFlash',
                ),
                'wb_rggblevelscustom' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsCustom',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsCustom',
                ),
                'wb_rggblevelskelvin' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsKelvin',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsKelvin',
                ),
                'cameracolorcalibration01' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration01',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration01',
                ),
                'cameracolorcalibration02' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration02',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration02',
                ),
                'cameracolorcalibration03' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration03',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration03',
                ),
                'cameracolorcalibration04' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration04',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration04',
                ),
                'cameracolorcalibration05' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration05',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration05',
                ),
                'cameracolorcalibration06' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration06',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration06',
                ),
                'cameracolorcalibration07' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration07',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration07',
                ),
                'cameracolorcalibration08' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration08',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration08',
                ),
                'cameracolorcalibration09' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration09',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration09',
                ),
                'cameracolorcalibration10' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration10',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration10',
                ),
                'cameracolorcalibration11' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration11',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration11',
                ),
                'cameracolorcalibration12' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration12',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration12',
                ),
                'cameracolorcalibration13' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration13',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration13',
                ),
                'cameracolorcalibration14' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration14',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration14',
                ),
                'cameracolorcalibration15' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraColorCalibration15',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraColorCalibration15',
                ),
                'wb_rggblevelsasshot' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsAsShot',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsAsShot',
                ),
                'colortempasshot' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempAsShot',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempAsShot',
                ),
                'colortempauto' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempAuto',
                ),
                'wb_rggblevelsmeasured' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsMeasured',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsMeasured',
                ),
                'colortempmeasured' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempMeasured',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempMeasured',
                ),
                'wb_rggblevelsunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown',
                ),
                'colortempunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown',
                ),
                'colortempdaylight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempDaylight',
                ),
                'colortempshade' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempShade',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempShade',
                ),
                'colortempcloudy' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempCloudy',
                ),
                'colortemptungsten' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempTungsten',
                ),
                'colortempfluorescent' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempFluorescent',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempFluorescent',
                ),
                'colortempkelvin' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempKelvin',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempKelvin',
                ),
                'colortempflash' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempFlash',
                ),
                'wb_rggblevelsunknown2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown2',
                ),
                'colortempunknown2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown2',
                ),
                'wb_rggblevelsunknown3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown3',
                ),
                'colortempunknown3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown3',
                ),
                'wb_rggblevelsunknown4' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown4',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown4',
                ),
                'colortempunknown4' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown4',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown4',
                ),
                'wb_rggblevelsunknown5' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown5',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown5',
                ),
                'colortempunknown5' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown5',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown5',
                ),
                'wb_rggblevelsunknown6' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown6',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown6',
                ),
                'colortempunknown6' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown6',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown6',
                ),
                'wb_rggblevelsunknown7' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown7',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown7',
                ),
                'colortempunknown7' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown7',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown7',
                ),
                'wb_rggblevelsunknown8' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown8',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown8',
                ),
                'colortempunknown8' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown8',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown8',
                ),
                'wb_rggblevelsunknown9' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown9',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown9',
                ),
                'colortempunknown9' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown9',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown9',
                ),
                'wb_rggblevelsunknown10' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown10',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown10',
                ),
                'colortempunknown10' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown10',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown10',
                ),
                'wb_rggblevelsunknown11' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown11',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown11',
                ),
                'colortempunknown11' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown11',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown11',
                ),
                'wb_rggblevelsunknown12' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown12',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown12',
                ),
                'colortempunknown12' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown12',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown12',
                ),
                'wb_rggblevelsunknown13' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown13',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown13',
                ),
                'colortempunknown13' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown13',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown13',
                ),
                'wb_rggblevelscustom1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsCustom1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsCustom1',
                ),
                'colortempcustom1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempCustom1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempCustom1',
                ),
                'wb_rggblevelscustom2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsCustom2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsCustom2',
                ),
                'colortempcustom2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempCustom2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempCustom2',
                ),
                'wb_rggblevelsunknown14' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown14',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown14',
                ),
                'colortempunknown14' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown14',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown14',
                ),
                'wb_rggblevelsunknown15' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown15',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown15',
                ),
                'colortempunknown15' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown15',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown15',
                ),
                'wb_rggblevelspc1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsPC1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsPC1',
                ),
                'colortemppc1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempPC1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempPC1',
                ),
                'wb_rggblevelspc2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsPC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsPC2',
                ),
                'colortemppc2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempPC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempPC2',
                ),
                'wb_rggblevelspc3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsPC3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsPC3',
                ),
                'colortemppc3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempPC3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempPC3',
                ),
                'wb_rggblevelsunknown16' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown16',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown16',
                ),
                'colortempunknown16' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown16',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown16',
                ),
                'rawmeasuredrggb' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'RawMeasuredRGGB',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\RawMeasuredRGGB',
                ),
                'colordataversion' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorDataVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorDataVersion',
                ),
                'colortempcustom' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempCustom',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempCustom',
                ),
                'flashoutput' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FlashOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FlashOutput',
                ),
                'flashbatterylevel' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FlashBatteryLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FlashBatteryLevel',
                ),
                'colortempflashdata' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempFlashData',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempFlashData',
                ),
                'measuredrggbdata' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MeasuredRGGBData',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MeasuredRGGBData',
                ),
                'wb_rggblevelsunknown17' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown17',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown17',
                ),
                'colortempunknown17' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown17',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown17',
                ),
                'wb_rggblevelsunknown18' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown18',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown18',
                ),
                'colortempunknown18' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown18',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown18',
                ),
                'wb_rggblevelsunknown19' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown19',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown19',
                ),
                'colortempunknown19' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown19',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown19',
                ),
                'wb_rggblevelsunknown20' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WB_RGGBLevelsUnknown20',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBRGGBLevelsUnknown20',
                ),
                'colortempunknown20' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorTempUnknown20',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorTempUnknown20',
                ),
                'colorspace' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorSpace',
                ),
                'intelligentcontrast' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'IntelligentContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\IntelligentContrast',
                ),
                'cropleftmargin' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CropLeftMargin',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CropLeftMargin',
                ),
                'croprightmargin' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CropRightMargin',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CropRightMargin',
                ),
                'croptopmargin' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CropTopMargin',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CropTopMargin',
                ),
                'cropbottommargin' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CropBottomMargin',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CropBottomMargin',
                ),
                'facesdetected' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FacesDetected',
                ),
                'facedetectframesize' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FaceDetectFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FaceDetectFrameSize',
                ),
                'face1position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face1Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face1Position',
                ),
                'face2position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face2Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face2Position',
                ),
                'face3position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face3Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face3Position',
                ),
                'face4position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face4Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face4Position',
                ),
                'face5position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face5Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face5Position',
                ),
                'face6position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face6Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face6Position',
                ),
                'face7position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face7Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face7Position',
                ),
                'face8position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face8Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face8Position',
                ),
                'face9position' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Face9Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Face9Position',
                ),
                'facewidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FaceWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FaceWidth',
                ),
                'filenumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FileNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FileNumber',
                ),
                'bracketmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BracketMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BracketMode',
                ),
                'bracketvalue' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BracketValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BracketValue',
                ),
                'bracketshotnumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BracketShotNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BracketShotNumber',
                ),
                'rawjpgquality' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'RawJpgQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\RawJpgQuality',
                ),
                'rawjpgsize' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'RawJpgSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\RawJpgSize',
                ),
                'longexposurenoisereduction2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'LongExposureNoiseReduction2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\LongExposureNoiseReduction2',
                ),
                'wbbracketmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WBBracketMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBBracketMode',
                ),
                'wbbracketvalueab' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WBBracketValueAB',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBBracketValueAB',
                ),
                'wbbracketvaluegm' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WBBracketValueGM',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBBracketValueGM',
                ),
                'filtereffect' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffect',
                ),
                'toningeffect' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffect',
                ),
                'liveviewshooting' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'LiveViewShooting',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\LiveViewShooting',
                ),
                'flashexposurelock' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FlashExposureLock',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FlashExposureLock',
                ),
                'grainybwfilter' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'GrainyBWFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\GrainyBWFilter',
                ),
                'softfocusfilter' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SoftFocusFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SoftFocusFilter',
                ),
                'toycamerafilter' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToyCameraFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToyCameraFilter',
                ),
                'miniaturefilter' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MiniatureFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MiniatureFilter',
                ),
                'miniaturefilterorientation' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MiniatureFilterOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MiniatureFilterOrientation',
                ),
                'miniaturefilterposition' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MiniatureFilterPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MiniatureFilterPosition',
                ),
                'modifiedparamflag' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedParamFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedParamFlag',
                ),
                'focalplanexsize' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocalPlaneXSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocalPlaneXSize',
                ),
                'focalplanexunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocalPlaneXUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocalPlaneXUnknown',
                ),
                'focalplaneysize' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocalPlaneYSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocalPlaneYSize',
                ),
                'focalplaneyunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FocalPlaneYUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FocalPlaneYUnknown',
                ),
                'lensserialnumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'LensSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\LensSerialNumber',
                ),
                'canonflashinfo' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonFlashInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonFlashInfo',
                ),
                'canonimagetype' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonImageType',
                ),
                'canonfirmwareversion' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonFirmwareVersion',
                ),
                'serialnumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SerialNumber',
                ),
                'canonfilelength' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonFileLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonFileLength',
                ),
                'canonmodelid' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CanonModelID',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CanonModelID',
                ),
                'thumbnailimagevalidarea' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ThumbnailImageValidArea',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ThumbnailImageValidArea',
                ),
                'serialnumberformat' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SerialNumberFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SerialNumberFormat',
                ),
                'supermacro' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SuperMacro',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SuperMacro',
                ),
                'datestampmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'DateStampMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\DateStampMode',
                ),
                'categories' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Categories',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Categories',
                ),
                'imageuniqueid' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ImageUniqueID',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ImageUniqueID',
                ),
                'rawdataoffset' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'RawDataOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\RawDataOffset',
                ),
                'originaldecisiondataoffset' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'OriginalDecisionDataOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\OriginalDecisionDataOffset',
                ),
                'afpointsinfocus1d' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AFPointsInFocus1D',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AFPointsInFocus1D',
                ),
                'internalserialnumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'InternalSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\InternalSerialNumber',
                ),
                'dustremovaldata' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'DustRemovalData',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\DustRemovalData',
                ),
                'tonecurvetable' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToneCurveTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToneCurveTable',
                ),
                'sharpnesstable' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessTable',
                ),
                'sharpnessfreqtable' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessFreqTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessFreqTable',
                ),
                'whitebalancetable' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WhiteBalanceTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WhiteBalanceTable',
                ),
                'tonecurvematching' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToneCurveMatching',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToneCurveMatching',
                ),
                'whitebalancematching' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WhiteBalanceMatching',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WhiteBalanceMatching',
                ),
                'vrdoffset' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'VRDOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\VRDOffset',
                ),
                'crwparam' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CRWParam',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CRWParam',
                ),
                'flavor' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Flavor',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Flavor',
                ),
                'blacklevel' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BlackLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BlackLevel',
                ),
                'custompicturestylefilename' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CustomPictureStyleFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CustomPictureStyleFileName',
                ),
                'measuredrggb' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MeasuredRGGB',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MeasuredRGGB',
                ),
                'modifiedtonecurve' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedToneCurve',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedToneCurve',
                ),
                'modifiedsharpness' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedSharpness',
                ),
                'modifiedsharpnessfreq' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedSharpnessFreq',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedSharpnessFreq',
                ),
                'modifiedsensorredlevel' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedSensorRedLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedSensorRedLevel',
                ),
                'modifiedsensorbluelevel' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedSensorBlueLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedSensorBlueLevel',
                ),
                'modifiedwhitebalancered' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedWhiteBalanceRed',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedWhiteBalanceRed',
                ),
                'modifiedwhitebalanceblue' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedWhiteBalanceBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedWhiteBalanceBlue',
                ),
                'modifiedwhitebalance' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedWhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedWhiteBalance',
                ),
                'modifiedcolortemp' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedColorTemp',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedColorTemp',
                ),
                'modifiedpicturestyle' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedPictureStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedPictureStyle',
                ),
                'modifieddigitalgain' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ModifiedDigitalGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ModifiedDigitalGain',
                ),
                'framerate' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FrameRate',
                ),
                'framecount' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FrameCount',
                ),
                'duration' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\Duration',
                ),
                'audiobitrate' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AudioBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AudioBitrate',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AudioSampleRate',
                ),
                'audiochannels' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AudioChannels',
                ),
                'videocodec' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'VideoCodec',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\VideoCodec',
                ),
                'mycolormode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'MyColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\MyColorMode',
                ),
                'filtereffectstandard' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectStandard',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectStandard',
                ),
                'toningeffectstandard' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectStandard',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectStandard',
                ),
                'filtereffectportrait' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectPortrait',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectPortrait',
                ),
                'toningeffectportrait' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectPortrait',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectPortrait',
                ),
                'filtereffectlandscape' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectLandscape',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectLandscape',
                ),
                'toningeffectlandscape' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectLandscape',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectLandscape',
                ),
                'filtereffectneutral' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectNeutral',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectNeutral',
                ),
                'toningeffectneutral' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectNeutral',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectNeutral',
                ),
                'filtereffectfaithful' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectFaithful',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectFaithful',
                ),
                'toningeffectfaithful' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectFaithful',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectFaithful',
                ),
                'saturationmonochrome' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationMonochrome',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationMonochrome',
                ),
                'colortonemonochrome' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneMonochrome',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneMonochrome',
                ),
                'filtereffectuserdef1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectUserDef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectUserDef1',
                ),
                'toningeffectuserdef1' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectUserDef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectUserDef1',
                ),
                'filtereffectuserdef2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectUserDef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectUserDef2',
                ),
                'toningeffectuserdef2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectUserDef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectUserDef2',
                ),
                'filtereffectuserdef3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectUserDef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectUserDef3',
                ),
                'toningeffectuserdef3' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectUserDef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectUserDef3',
                ),
                'contrastunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ContrastUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ContrastUnknown',
                ),
                'sharpnessunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SharpnessUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SharpnessUnknown',
                ),
                'saturationunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SaturationUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SaturationUnknown',
                ),
                'colortoneunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ColorToneUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ColorToneUnknown',
                ),
                'filtereffectunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FilterEffectUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FilterEffectUnknown',
                ),
                'toningeffectunknown' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToningEffectUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToningEffectUnknown',
                ),
                'panoramaframenumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PanoramaFrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PanoramaFrameNumber',
                ),
                'panoramadirection' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PanoramaDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PanoramaDirection',
                ),
                'previewquality' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PreviewQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PreviewQuality',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PreviewImageLength',
                ),
                'previewimagewidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PreviewImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PreviewImageWidth',
                ),
                'previewimageheight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PreviewImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PreviewImageHeight',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PreviewImageStart',
                ),
                'tonecurve' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ToneCurve',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ToneCurve',
                ),
                'sensorredlevel' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SensorRedLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SensorRedLevel',
                ),
                'sensorbluelevel' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SensorBlueLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SensorBlueLevel',
                ),
                'whitebalancered' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WhiteBalanceRed',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WhiteBalanceRed',
                ),
                'whitebalanceblue' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WhiteBalanceBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WhiteBalanceBlue',
                ),
                'digitalgain' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'DigitalGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\DigitalGain',
                ),
                'wbshiftab' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WBShiftAB',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBShiftAB',
                ),
                'wbshiftgm' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'WBShiftGM',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\WBShiftGM',
                ),
                'sensorwidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SensorWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SensorWidth',
                ),
                'sensorheight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SensorHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SensorHeight',
                ),
                'sensorleftborder' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SensorLeftBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SensorLeftBorder',
                ),
                'sensortopborder' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SensorTopBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SensorTopBorder',
                ),
                'sensorrightborder' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SensorRightBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SensorRightBorder',
                ),
                'sensorbottomborder' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SensorBottomBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SensorBottomBorder',
                ),
                'blackmaskleftborder' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BlackMaskLeftBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BlackMaskLeftBorder',
                ),
                'blackmasktopborder' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BlackMaskTopBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BlackMaskTopBorder',
                ),
                'blackmaskrightborder' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BlackMaskRightBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BlackMaskRightBorder',
                ),
                'blackmaskbottomborder' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BlackMaskBottomBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BlackMaskBottomBorder',
                ),
                'autoiso' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AutoISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AutoISO',
                ),
                'baseiso' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BaseISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BaseISO',
                ),
                'targetaperture' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'TargetAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\TargetAperture',
                ),
                'targetexposuretime' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'TargetExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\TargetExposureTime',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ExposureCompensation',
                ),
                'slowshutter' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SlowShutter',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SlowShutter',
                ),
                'sequencenumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SequenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SequenceNumber',
                ),
                'opticalzoomcode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'OpticalZoomCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\OpticalZoomCode',
                ),
                'flashguidenumber' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FlashGuideNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FlashGuideNumber',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\FlashExposureComp',
                ),
                'autoexposurebracketing' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AutoExposureBracketing',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AutoExposureBracketing',
                ),
                'aebbracketvalue' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AEBBracketValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AEBBracketValue',
                ),
                'controlmode' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'ControlMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\ControlMode',
                ),
                'bulbduration' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'BulbDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\BulbDuration',
                ),
                'cameratype' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'CameraType',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\CameraType',
                ),
                'autorotate' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'AutoRotate',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\AutoRotate',
                ),
                'ndfilter' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'NDFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\NDFilter',
                ),
                'selftimer2' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'SelfTimer2',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\SelfTimer2',
                ),
                'unknown_cndb' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'Unknown_CNDB',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\UnknownCNDB',
                ),
                'timezone' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'TimeZone',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\TimeZone',
                ),
                'timezonecity' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'TimeZoneCity',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\TimeZoneCity',
                ),
                'daylightsavings' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'DaylightSavings',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\DaylightSavings',
                ),
                'peripherallighting' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PeripheralLighting',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PeripheralLighting',
                ),
                'peripherallightingvalue' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PeripheralLightingValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PeripheralLightingValue',
                ),
                'originalimagewidth' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'OriginalImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\OriginalImageWidth',
                ),
                'originalimageheight' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'OriginalImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\OriginalImageHeight',
                ),
                'peripherallightingsetting' => array(
                    'namespace' => 'Canon',
                    'tagname' => 'PeripheralLightingSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Canon\PeripheralLightingSetting',
                ),

            ),
            'canoncustom' => array(
                'setbuttonwhenshooting' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SetButtonWhenShooting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SetButtonWhenShooting',
                ),
                'shutterreleasenocfcard' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ShutterReleaseNoCFCard',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ShutterReleaseNoCFCard',
                ),
                'flashsyncspeedav' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'FlashSyncSpeedAv',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\FlashSyncSpeedAv',
                ),
                'shutter-aelock' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'Shutter-AELock',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ShutterAELock',
                ),
                'afassist' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFAssist',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFAssist',
                ),
                'exposurelevelincrements' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ExposureLevelIncrements',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ExposureLevelIncrements',
                ),
                'afpointregistration' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointRegistration',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointRegistration',
                ),
                'rawandjpgrecording' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'RawAndJpgRecording',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\RawAndJpgRecording',
                ),
                'aebsequenceautocancel' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AEBSequenceAutoCancel',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AEBSequenceAutoCancel',
                ),
                'superimposeddisplay' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SuperimposedDisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SuperimposedDisplay',
                ),
                'menubuttondisplayposition' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'MenuButtonDisplayPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\MenuButtonDisplayPosition',
                ),
                'mirrorlockup' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'MirrorLockup',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\MirrorLockup',
                ),
                'assistbuttonfunction' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AssistButtonFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AssistButtonFunction',
                ),
                'fillflashautoreduction' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'FillFlashAutoReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\FillFlashAutoReduction',
                ),
                'shuttercurtainsync' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ShutterCurtainSync',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ShutterCurtainSync',
                ),
                'safetyshiftinavortv' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SafetyShiftInAvOrTv',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SafetyShiftInAvOrTv',
                ),
                'lensafstopbutton' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LensAFStopButton',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LensAFStopButton',
                ),
                'focusingscreen' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'FocusingScreen',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\FocusingScreen',
                ),
                'finderdisplayduringexposure' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'FinderDisplayDuringExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\FinderDisplayDuringExposure',
                ),
                'isospeedexpansion' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ISOSpeedExpansion',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ISOSpeedExpansion',
                ),
                'shutteraelbutton' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ShutterAELButton',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ShutterAELButton',
                ),
                'manualtv' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ManualTv',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ManualTv',
                ),
                'usmlenselectronicmf' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'USMLensElectronicMF',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\USMLensElectronicMF',
                ),
                'lcdpanels' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LCDPanels',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LCDPanels',
                ),
                'afpointillumination' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointIllumination',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointIllumination',
                ),
                'afpointselection' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointSelection',
                ),
                'afpointspotmetering' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointSpotMetering',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointSpotMetering',
                ),
                'afpointactivationarea' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointActivationArea',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointActivationArea',
                ),
                'switchtoregisteredafpoint' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SwitchToRegisteredAFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SwitchToRegisteredAFPoint',
                ),
                'aiservotrackingsensitivity' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AIServoTrackingSensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AIServoTrackingSensitivity',
                ),
                'aiservocontinuousshooting' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AIServoContinuousShooting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AIServoContinuousShooting',
                ),
                'isospeedincrements' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ISOSpeedIncrements',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ISOSpeedIncrements',
                ),
                'isospeedrange' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ISOSpeedRange',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ISOSpeedRange',
                ),
                'isoexpansion' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ISOExpansion',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ISOExpansion',
                ),
                'aebautocancel' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AEBAutoCancel',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AEBAutoCancel',
                ),
                'aebsequence' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AEBSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AEBSequence',
                ),
                'aebshotcount' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AEBShotCount',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AEBShotCount',
                ),
                'spotmeterlinktoafpoint' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SpotMeterLinkToAFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SpotMeterLinkToAFPoint',
                ),
                'safetyshift' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SafetyShift',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SafetyShift',
                ),
                'usableshootingmodes' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'UsableShootingModes',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\UsableShootingModes',
                ),
                'usablemeteringmodes' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'UsableMeteringModes',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\UsableMeteringModes',
                ),
                'exposuremodeinmanual' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ExposureModeInManual',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ExposureModeInManual',
                ),
                'shutterspeedrange' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ShutterSpeedRange',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ShutterSpeedRange',
                ),
                'aperturerange' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ApertureRange',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ApertureRange',
                ),
                'applyshootingmeteringmode' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ApplyShootingMeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ApplyShootingMeteringMode',
                ),
                'femicroadjustment' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'FEMicroadjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\FEMicroadjustment',
                ),
                'aemicroadjustment' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AEMicroadjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AEMicroadjustment',
                ),
                'longexposurenoisereduction' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LongExposureNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LongExposureNoiseReduction',
                ),
                'highisonoisereduction' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'HighISONoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\HighISONoiseReduction',
                ),
                'highlighttonepriority' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'HighlightTonePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\HighlightTonePriority',
                ),
                'autolightingoptimizer' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AutoLightingOptimizer',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AutoLightingOptimizer',
                ),
                'ettlii' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ETTLII',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ETTLII',
                ),
                'flashfiring' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'FlashFiring',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\FlashFiring',
                ),
                'viewinfoduringexposure' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ViewInfoDuringExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ViewInfoDuringExposure',
                ),
                'lcdilluminationduringbulb' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LCDIlluminationDuringBulb',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LCDIlluminationDuringBulb',
                ),
                'infobuttonwhenshooting' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'InfoButtonWhenShooting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\InfoButtonWhenShooting',
                ),
                'viewfinderwarnings' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ViewfinderWarnings',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ViewfinderWarnings',
                ),
                'lvshootingareadisplay' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LVShootingAreaDisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LVShootingAreaDisplay',
                ),
                'aiservoimagepriority' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AIServoImagePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AIServoImagePriority',
                ),
                'aiservotrackingmethod' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AIServoTrackingMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AIServoTrackingMethod',
                ),
                'lensdrivenoaf' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LensDriveNoAF',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LensDriveNoAF',
                ),
                'afmicroadjustment' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFMicroadjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFMicroadjustment',
                ),
                'afpointareaexpansion' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointAreaExpansion',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointAreaExpansion',
                ),
                'selectableafpoint' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SelectableAFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SelectableAFPoint',
                ),
                'afpointautoselection' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointAutoSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointAutoSelection',
                ),
                'afpointdisplayduringfocus' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointDisplayDuringFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointDisplayDuringFocus',
                ),
                'afpointbrightness' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointBrightness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointBrightness',
                ),
                'afassistbeam' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFAssistBeam',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFAssistBeam',
                ),
                'afpointselectionmethod' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFPointSelectionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFPointSelectionMethod',
                ),
                'vfdisplayillumination' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'VFDisplayIllumination',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\VFDisplayIllumination',
                ),
                'afduringliveview' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFDuringLiveView',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFDuringLiveView',
                ),
                'selectafareaselectmode' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SelectAFAreaSelectMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SelectAFAreaSelectMode',
                ),
                'manualafpointselectpattern' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ManualAFPointSelectPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ManualAFPointSelectPattern',
                ),
                'displayallafpoints' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'DisplayAllAFPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\DisplayAllAFPoints',
                ),
                'focusdisplayaiservoandmf' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'FocusDisplayAIServoAndMF',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\FocusDisplayAIServoAndMF',
                ),
                'orientationlinkedafpoint' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'OrientationLinkedAFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\OrientationLinkedAFPoint',
                ),
                'multicontrollerwhilemetering' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'MultiControllerWhileMetering',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\MultiControllerWhileMetering',
                ),
                'accelerationtracking' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AccelerationTracking',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AccelerationTracking',
                ),
                'aiservofirstimagepriority' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AIServoFirstImagePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AIServoFirstImagePriority',
                ),
                'aiservosecondimagepriority' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AIServoSecondImagePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AIServoSecondImagePriority',
                ),
                'continuousshootingspeed' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ContinuousShootingSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ContinuousShootingSpeed',
                ),
                'continuousshotlimit' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ContinuousShotLimit',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ContinuousShotLimit',
                ),
                'afandmeteringbuttons' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFAndMeteringButtons',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFAndMeteringButtons',
                ),
                'shutterbuttonafonbutton' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ShutterButtonAFOnButton',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ShutterButtonAFOnButton',
                ),
                'afonaelockbuttonswitch' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AFOnAELockButtonSwitch',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AFOnAELockButtonSwitch',
                ),
                'quickcontroldialinmeter' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'QuickControlDialInMeter',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\QuickControlDialInMeter',
                ),
                'dialdirectiontvav' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'DialDirectionTvAv',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\DialDirectionTvAv',
                ),
                'avsettingwithoutlens' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AvSettingWithoutLens',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AvSettingWithoutLens',
                ),
                'wbmediaimagesizesetting' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'WBMediaImageSizeSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\WBMediaImageSizeSetting',
                ),
                'lockmicrophonebutton' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LockMicrophoneButton',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LockMicrophoneButton',
                ),
                'buttonfunctioncontroloff' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ButtonFunctionControlOff',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ButtonFunctionControlOff',
                ),
                'assignfuncbutton' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AssignFuncButton',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AssignFuncButton',
                ),
                'customcontrols' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'CustomControls',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\CustomControls',
                ),
                'startmovieshooting' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'StartMovieShooting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\StartMovieShooting',
                ),
                'flashbuttonfunction' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'FlashButtonFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\FlashButtonFunction',
                ),
                'multifunctionlock' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'MultiFunctionLock',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\MultiFunctionLock',
                ),
                'timerlength' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'TimerLength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\TimerLength',
                ),
                'shortreleasetimelag' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'ShortReleaseTimeLag',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\ShortReleaseTimeLag',
                ),
                'addaspectratioinfo' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AddAspectRatioInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AddAspectRatioInfo',
                ),
                'addoriginaldecisiondata' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'AddOriginalDecisionData',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\AddOriginalDecisionData',
                ),
                'liveviewexposuresimulation' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LiveViewExposureSimulation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LiveViewExposureSimulation',
                ),
                'lcddisplayatpoweron' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LCDDisplayAtPowerOn',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LCDDisplayAtPowerOn',
                ),
                'defaulteraseoption' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'DefaultEraseOption',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\DefaultEraseOption',
                ),
                'setfunctionwhenshooting' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SetFunctionWhenShooting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SetFunctionWhenShooting',
                ),
                'magnifiedview' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'MagnifiedView',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\MagnifiedView',
                ),
                'setbuttoncrosskeysfunc' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SetButtonCrossKeysFunc',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SetButtonCrossKeysFunc',
                ),
                'lcddisplayreturntoshoot' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'LCDDisplayReturnToShoot',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\LCDDisplayReturnToShoot',
                ),
                'menubuttonreturn' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'MenuButtonReturn',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\MenuButtonReturn',
                ),
                'sensorcleaning' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'SensorCleaning',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\SensorCleaning',
                ),
                'pf1value' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF1Value',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF1Value',
                ),
                'pf2value' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF2Value',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF2Value',
                ),
                'pf3value' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF3Value',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF3Value',
                ),
                'pf4exposuretimemin' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF4ExposureTimeMin',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF4ExposureTimeMin',
                ),
                'pf4exposuretimemax' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF4ExposureTimeMax',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF4ExposureTimeMax',
                ),
                'pf5aperturemin' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF5ApertureMin',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF5ApertureMin',
                ),
                'pf5aperturemax' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF5ApertureMax',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF5ApertureMax',
                ),
                'pf8bracketshots' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF8BracketShots',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF8BracketShots',
                ),
                'pf19shootingspeedlow' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF19ShootingSpeedLow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF19ShootingSpeedLow',
                ),
                'pf19shootingspeedhigh' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF19ShootingSpeedHigh',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF19ShootingSpeedHigh',
                ),
                'pf20maxcontinousshots' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF20MaxContinousShots',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF20MaxContinousShots',
                ),
                'pf23shutterbuttontime' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF23ShutterButtonTime',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF23ShutterButtonTime',
                ),
                'pf23felocktime' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF23FELockTime',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF23FELockTime',
                ),
                'pf23postreleasetime' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF23PostReleaseTime',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF23PostReleaseTime',
                ),
                'pf25aemode' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25AEMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25AEMode',
                ),
                'pf25meteringmode' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25MeteringMode',
                ),
                'pf25drivemode' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25DriveMode',
                ),
                'pf25afmode' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25AFMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25AFMode',
                ),
                'pf25afpointsel' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25AFPointSel',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25AFPointSel',
                ),
                'pf25imagesize' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25ImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25ImageSize',
                ),
                'pf25wbmode' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25WBMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25WBMode',
                ),
                'pf25parameters' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25Parameters',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25Parameters',
                ),
                'pf25colormatrix' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25ColorMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25ColorMatrix',
                ),
                'pf27value' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF27Value',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF27Value',
                ),
                'pf0customfuncregistration' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF0CustomFuncRegistration',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF0CustomFuncRegistration',
                ),
                'pf1disableshootingmodes' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF1DisableShootingModes',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF1DisableShootingModes',
                ),
                'pf2disablemeteringmodes' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF2DisableMeteringModes',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF2DisableMeteringModes',
                ),
                'pf3manualexposuremetering' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF3ManualExposureMetering',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF3ManualExposureMetering',
                ),
                'pf4exposuretimelimits' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF4ExposureTimeLimits',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF4ExposureTimeLimits',
                ),
                'pf5aperturelimits' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF5ApertureLimits',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF5ApertureLimits',
                ),
                'pf6presetshootingmodes' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF6PresetShootingModes',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF6PresetShootingModes',
                ),
                'pf7bracketcontinuousshoot' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF7BracketContinuousShoot',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF7BracketContinuousShoot',
                ),
                'pf8setbracketshots' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF8SetBracketShots',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF8SetBracketShots',
                ),
                'pf9changebracketsequence' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF9ChangeBracketSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF9ChangeBracketSequence',
                ),
                'pf10retainprogramshift' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF10RetainProgramShift',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF10RetainProgramShift',
                ),
                'pf13drivepriority' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF13DrivePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF13DrivePriority',
                ),
                'pf14disablefocussearch' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF14DisableFocusSearch',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF14DisableFocusSearch',
                ),
                'pf15disableafassistbeam' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF15DisableAFAssistBeam',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF15DisableAFAssistBeam',
                ),
                'pf16autofocuspointshoot' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF16AutoFocusPointShoot',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF16AutoFocusPointShoot',
                ),
                'pf17disableafpointsel' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF17DisableAFPointSel',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF17DisableAFPointSel',
                ),
                'pf18enableautoafpointsel' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF18EnableAutoAFPointSel',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF18EnableAutoAFPointSel',
                ),
                'pf19continuousshootspeed' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF19ContinuousShootSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF19ContinuousShootSpeed',
                ),
                'pf20limitcontinousshots' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF20LimitContinousShots',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF20LimitContinousShots',
                ),
                'pf21enablequietoperation' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF21EnableQuietOperation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF21EnableQuietOperation',
                ),
                'pf23settimerlengths' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF23SetTimerLengths',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF23SetTimerLengths',
                ),
                'pf24lightlcdduringbulb' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF24LightLCDDuringBulb',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF24LightLCDDuringBulb',
                ),
                'pf25defaultclearsettings' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF25DefaultClearSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF25DefaultClearSettings',
                ),
                'pf26shortenreleaselag' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF26ShortenReleaseLag',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF26ShortenReleaseLag',
                ),
                'pf27reversedialrotation' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF27ReverseDialRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF27ReverseDialRotation',
                ),
                'pf28noquickdialexpcomp' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF28NoQuickDialExpComp',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF28NoQuickDialExpComp',
                ),
                'pf29quickdialswitchoff' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF29QuickDialSwitchOff',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF29QuickDialSwitchOff',
                ),
                'pf30enlargementmode' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF30EnlargementMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF30EnlargementMode',
                ),
                'pf31originaldecisiondata' => array(
                    'namespace' => 'CanonCustom',
                    'tagname' => 'PF31OriginalDecisionData',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonCustom\PF31OriginalDecisionData',
                ),

            ),
            'canonraw' => array(
                'decodertablenumber' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'DecoderTableNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\DecoderTableNumber',
                ),
                'compresseddataoffset' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CompressedDataOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CompressedDataOffset',
                ),
                'compresseddatalength' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CompressedDataLength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CompressedDataLength',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ExposureCompensation',
                ),
                'shutterspeedvalue' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ShutterSpeedValue',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ShutterSpeedValue',
                ),
                'aperturevalue' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ApertureValue',
                ),
                'flashguidenumber' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'FlashGuideNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\FlashGuideNumber',
                ),
                'flashthreshold' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'FlashThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\FlashThreshold',
                ),
                'fileformat' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'FileFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\FileFormat',
                ),
                'targetcompressionratio' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'TargetCompressionRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\TargetCompressionRatio',
                ),
                'imagewidth' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ImageHeight',
                ),
                'pixelaspectratio' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'PixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\PixelAspectRatio',
                ),
                'rotation' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\Rotation',
                ),
                'componentbitdepth' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ComponentBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ComponentBitDepth',
                ),
                'colorbitdepth' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ColorBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ColorBitDepth',
                ),
                'colorbw' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ColorBW',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ColorBW',
                ),
                'nullrecord' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'NullRecord',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\NullRecord',
                ),
                'freebytes' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'FreeBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\FreeBytes',
                ),
                'canoncolorinfo1' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CanonColorInfo1',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CanonColorInfo1',
                ),
                'canonfiledescription' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CanonFileDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CanonFileDescription',
                ),
                'usercomment' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'UserComment',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\UserComment',
                ),
                'canonfirmwareversion' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CanonFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CanonFirmwareVersion',
                ),
                'componentversion' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ComponentVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ComponentVersion',
                ),
                'romoperationmode' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ROMOperationMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ROMOperationMode',
                ),
                'ownername' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'OwnerName',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\OwnerName',
                ),
                'canonimagetype' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CanonImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CanonImageType',
                ),
                'originalfilename' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'OriginalFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\OriginalFileName',
                ),
                'thumbnailfilename' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ThumbnailFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ThumbnailFileName',
                ),
                'targetimagetype' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'TargetImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\TargetImageType',
                ),
                'shutterreleasemethod' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ShutterReleaseMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ShutterReleaseMethod',
                ),
                'shutterreleasetiming' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ShutterReleaseTiming',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ShutterReleaseTiming',
                ),
                'releasesetting' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ReleaseSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ReleaseSetting',
                ),
                'baseiso' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'BaseISO',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\BaseISO',
                ),
                'canonflashinfo' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CanonFlashInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CanonFlashInfo',
                ),
                'canoncolorinfo2' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CanonColorInfo2',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CanonColorInfo2',
                ),
                'colortemperature' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ColorTemperature',
                ),
                'colorspace' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ColorSpace',
                ),
                'recordid' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'RecordID',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\RecordID',
                ),
                'selftimertime' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'SelfTimerTime',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\SelfTimerTime',
                ),
                'targetdistancesetting' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'TargetDistanceSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\TargetDistanceSetting',
                ),
                'serialnumber' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\SerialNumber',
                ),
                'unknownnumber' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'UnknownNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\UnknownNumber',
                ),
                'measuredev' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'MeasuredEV',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\MeasuredEV',
                ),
                'filenumber' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'FileNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\FileNumber',
                ),
                'canonmodelid' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'CanonModelID',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\CanonModelID',
                ),
                'serialnumberformat' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'SerialNumberFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\SerialNumberFormat',
                ),
                'rawdata' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'RawData',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\RawData',
                ),
                'jpgfromraw' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'JpgFromRaw',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\JpgFromRaw',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\ThumbnailImage',
                ),
                'make' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\Make',
                ),
                'model' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\Model',
                ),
                'rawjpgquality' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'RawJpgQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\RawJpgQuality',
                ),
                'rawjpgsize' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'RawJpgSize',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\RawJpgSize',
                ),
                'rawjpgwidth' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'RawJpgWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\RawJpgWidth',
                ),
                'rawjpgheight' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'RawJpgHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\RawJpgHeight',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\DateTimeOriginal',
                ),
                'timezonecode' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'TimeZoneCode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\TimeZoneCode',
                ),
                'timezoneinfo' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'TimeZoneInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\TimeZoneInfo',
                ),
                'whitesamplewidth' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'WhiteSampleWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleWidth',
                ),
                'whitesampleheight' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'WhiteSampleHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleHeight',
                ),
                'whitesampleleftborder' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'WhiteSampleLeftBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleLeftBorder',
                ),
                'whitesampletopborder' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'WhiteSampleTopBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleTopBorder',
                ),
                'whitesamplebits' => array(
                    'namespace' => 'CanonRaw',
                    'tagname' => 'WhiteSampleBits',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonRaw\WhiteSampleBits',
                ),

            ),
            'canonvrd' => array(
                'ihl_exif' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'IHL_EXIF',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\IHLEXIF',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ThumbnailImage',
                ),
                'previewimage' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PreviewImage',
                ),
                'rawcodecversion' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RawCodecVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RawCodecVersion',
                ),
                'crcdevelparams' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CRCDevelParams',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CRCDevelParams',
                ),
                'xmp' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'XMP',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\XMP',
                ),
                'stamptoolcount' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StampToolCount',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StampToolCount',
                ),
                'vrdversion' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'VRDVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\VRDVersion',
                ),
                'wbadjrggblevels' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'WBAdjRGGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\WBAdjRGGBLevels',
                ),
                'whitebalanceadj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'WhiteBalanceAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\WhiteBalanceAdj',
                ),
                'wbadjcolortemp' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'WBAdjColorTemp',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\WBAdjColorTemp',
                ),
                'wbfinetuneactive' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'WBFineTuneActive',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\WBFineTuneActive',
                ),
                'wbfinetunesaturation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'WBFineTuneSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\WBFineTuneSaturation',
                ),
                'wbfinetunetone' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'WBFineTuneTone',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\WBFineTuneTone',
                ),
                'rawcoloradj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RawColorAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RawColorAdj',
                ),
                'rawcustomsaturation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RawCustomSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RawCustomSaturation',
                ),
                'rawcustomtone' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RawCustomTone',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RawCustomTone',
                ),
                'rawbrightnessadj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RawBrightnessAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RawBrightnessAdj',
                ),
                'tonecurveproperty' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ToneCurveProperty',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ToneCurveProperty',
                ),
                'dynamicrangemin' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DynamicRangeMin',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DynamicRangeMin',
                ),
                'dynamicrangemax' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DynamicRangeMax',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DynamicRangeMax',
                ),
                'tonecurveactive' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ToneCurveActive',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ToneCurveActive',
                ),
                'tonecurvemode' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ToneCurveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ToneCurveMode',
                ),
                'brightnessadj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'BrightnessAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\BrightnessAdj',
                ),
                'contrastadj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ContrastAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ContrastAdj',
                ),
                'saturationadj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'SaturationAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\SaturationAdj',
                ),
                'colortoneadj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ColorToneAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ColorToneAdj',
                ),
                'luminancecurvepoints' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LuminanceCurvePoints',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LuminanceCurvePoints',
                ),
                'luminancecurvelimits' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LuminanceCurveLimits',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LuminanceCurveLimits',
                ),
                'tonecurveinterpolation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ToneCurveInterpolation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ToneCurveInterpolation',
                ),
                'redcurvepoints' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RedCurvePoints',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RedCurvePoints',
                ),
                'redcurvelimits' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RedCurveLimits',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RedCurveLimits',
                ),
                'greencurvepoints' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'GreenCurvePoints',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\GreenCurvePoints',
                ),
                'greencurvelimits' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'GreenCurveLimits',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\GreenCurveLimits',
                ),
                'bluecurvepoints' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'BlueCurvePoints',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\BlueCurvePoints',
                ),
                'bluecurvelimits' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'BlueCurveLimits',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\BlueCurveLimits',
                ),
                'rgbcurvepoints' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RGBCurvePoints',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RGBCurvePoints',
                ),
                'rgbcurvelimits' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'RGBCurveLimits',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\RGBCurveLimits',
                ),
                'cropactive' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropActive',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropActive',
                ),
                'cropleft' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropLeft',
                ),
                'croptop' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropTop',
                ),
                'cropwidth' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropWidth',
                ),
                'cropheight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropHeight',
                ),
                'sharpnessadj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'SharpnessAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\SharpnessAdj',
                ),
                'cropaspectratio' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropAspectRatio',
                ),
                'constrainedcropwidth' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ConstrainedCropWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ConstrainedCropWidth',
                ),
                'constrainedcropheight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ConstrainedCropHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ConstrainedCropHeight',
                ),
                'checkmark' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CheckMark',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CheckMark',
                ),
                'rotation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\Rotation',
                ),
                'workcolorspace' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'WorkColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\WorkColorSpace',
                ),
                'picturestyle' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PictureStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PictureStyle',
                ),
                'iscustompicturestyle' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'IsCustomPictureStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\IsCustomPictureStyle',
                ),
                'standardrawcolortone' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawColorTone',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawColorTone',
                ),
                'standardrawsaturation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawSaturation',
                ),
                'standardrawcontrast' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawContrast',
                ),
                'standardrawlinear' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawLinear',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawLinear',
                ),
                'standardrawsharpness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawSharpness',
                ),
                'standardrawhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawHighlightPoint',
                ),
                'standardrawshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawShadowPoint',
                ),
                'standardoutputhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardOutputHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardOutputHighlightPoint',
                ),
                'standardoutputshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardOutputShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardOutputShadowPoint',
                ),
                'portraitrawcolortone' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawColorTone',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawColorTone',
                ),
                'portraitrawsaturation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawSaturation',
                ),
                'portraitrawcontrast' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawContrast',
                ),
                'portraitrawlinear' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawLinear',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawLinear',
                ),
                'portraitrawsharpness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawSharpness',
                ),
                'portraitrawhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawHighlightPoint',
                ),
                'portraitrawshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawShadowPoint',
                ),
                'portraitoutputhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitOutputHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitOutputHighlightPoint',
                ),
                'portraitoutputshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitOutputShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitOutputShadowPoint',
                ),
                'landscaperawcolortone' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawColorTone',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawColorTone',
                ),
                'landscaperawsaturation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawSaturation',
                ),
                'landscaperawcontrast' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawContrast',
                ),
                'landscaperawlinear' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawLinear',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawLinear',
                ),
                'landscaperawsharpness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawSharpness',
                ),
                'landscaperawhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawHighlightPoint',
                ),
                'landscaperawshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawShadowPoint',
                ),
                'landscapeoutputhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeOutputHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeOutputHighlightPoint',
                ),
                'landscapeoutputshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeOutputShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeOutputShadowPoint',
                ),
                'neutralrawcolortone' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawColorTone',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawColorTone',
                ),
                'neutralrawsaturation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawSaturation',
                ),
                'neutralrawcontrast' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawContrast',
                ),
                'neutralrawlinear' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawLinear',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawLinear',
                ),
                'neutralrawsharpness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawSharpness',
                ),
                'neutralrawhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawHighlightPoint',
                ),
                'neutralrawshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawShadowPoint',
                ),
                'neutraloutputhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralOutputHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralOutputHighlightPoint',
                ),
                'neutraloutputshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralOutputShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralOutputShadowPoint',
                ),
                'faithfulrawcolortone' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawColorTone',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawColorTone',
                ),
                'faithfulrawsaturation' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawSaturation',
                ),
                'faithfulrawcontrast' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawContrast',
                ),
                'faithfulrawlinear' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawLinear',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawLinear',
                ),
                'faithfulrawsharpness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawSharpness',
                ),
                'faithfulrawhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawHighlightPoint',
                ),
                'faithfulrawshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawShadowPoint',
                ),
                'faithfuloutputhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulOutputHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulOutputHighlightPoint',
                ),
                'faithfuloutputshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulOutputShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulOutputShadowPoint',
                ),
                'monochromefiltereffect' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeFilterEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeFilterEffect',
                ),
                'monochrometoningeffect' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeToningEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeToningEffect',
                ),
                'monochromecontrast' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeContrast',
                ),
                'monochromelinear' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeLinear',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeLinear',
                ),
                'monochromesharpness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeSharpness',
                ),
                'monochromerawhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeRawHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeRawHighlightPoint',
                ),
                'monochromerawshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeRawShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeRawShadowPoint',
                ),
                'monochromeoutputhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeOutputHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeOutputHighlightPoint',
                ),
                'monochromeoutputshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeOutputShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeOutputShadowPoint',
                ),
                'unknowncontrast' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownContrast',
                ),
                'unknownlinear' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownLinear',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownLinear',
                ),
                'unknownsharpness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownSharpness',
                ),
                'unknownrawhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownRawHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownRawHighlightPoint',
                ),
                'unknownrawshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownRawShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownRawShadowPoint',
                ),
                'unknownoutputhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownOutputHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownOutputHighlightPoint',
                ),
                'unknownoutputshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownOutputShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownOutputShadowPoint',
                ),
                'customcontrast' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomContrast',
                ),
                'customlinear' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomLinear',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomLinear',
                ),
                'customsharpness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomSharpness',
                ),
                'customrawhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomRawHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomRawHighlightPoint',
                ),
                'customrawshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomRawShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomRawShadowPoint',
                ),
                'customoutputhighlightpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomOutputHighlightPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomOutputHighlightPoint',
                ),
                'customoutputshadowpoint' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomOutputShadowPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomOutputShadowPoint',
                ),
                'custompicturestyledata' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomPictureStyleData',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomPictureStyleData',
                ),
                'chrominancenoisereduction' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ChrominanceNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ChrominanceNoiseReduction',
                ),
                'luminancenoisereduction' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LuminanceNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LuminanceNoiseReduction',
                ),
                'chrominancenr_tiff_jpeg' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ChrominanceNR_TIFF_JPEG',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ChrominanceNRTIFFJPEG',
                ),
                'chromaticaberrationon' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ChromaticAberrationOn',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ChromaticAberrationOn',
                ),
                'distortioncorrectionon' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DistortionCorrectionOn',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DistortionCorrectionOn',
                ),
                'peripheralilluminationon' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PeripheralIlluminationOn',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PeripheralIlluminationOn',
                ),
                'colorblur' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ColorBlur',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ColorBlur',
                ),
                'chromaticaberration' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ChromaticAberration',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ChromaticAberration',
                ),
                'distortioncorrection' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DistortionCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DistortionCorrection',
                ),
                'peripheralillumination' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PeripheralIllumination',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PeripheralIllumination',
                ),
                'aberrationcorrectiondistance' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'AberrationCorrectionDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\AberrationCorrectionDistance',
                ),
                'chromaticaberrationred' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ChromaticAberrationRed',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ChromaticAberrationRed',
                ),
                'chromaticaberrationblue' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'ChromaticAberrationBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\ChromaticAberrationBlue',
                ),
                'luminancenr_tiff_jpeg' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LuminanceNR_TIFF_JPEG',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LuminanceNRTIFFJPEG',
                ),
                'autolightingoptimizeron' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'AutoLightingOptimizerOn',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\AutoLightingOptimizerOn',
                ),
                'autolightingoptimizer' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'AutoLightingOptimizer',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\AutoLightingOptimizer',
                ),
                'standardrawhighlight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawHighlight',
                ),
                'portraitrawhighlight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawHighlight',
                ),
                'landscaperawhighlight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawHighlight',
                ),
                'neutralrawhighlight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawHighlight',
                ),
                'faithfulrawhighlight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawHighlight',
                ),
                'monochromerawhighlight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeRawHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeRawHighlight',
                ),
                'unknownrawhighlight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownRawHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownRawHighlight',
                ),
                'customrawhighlight' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomRawHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomRawHighlight',
                ),
                'standardrawshadow' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardRawShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardRawShadow',
                ),
                'portraitrawshadow' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitRawShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitRawShadow',
                ),
                'landscaperawshadow' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeRawShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeRawShadow',
                ),
                'neutralrawshadow' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralRawShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralRawShadow',
                ),
                'faithfulrawshadow' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulRawShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulRawShadow',
                ),
                'monochromerawshadow' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeRawShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeRawShadow',
                ),
                'unknownrawshadow' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnknownRawShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnknownRawShadow',
                ),
                'customrawshadow' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomRawShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomRawShadow',
                ),
                'angleadj' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'AngleAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\AngleAdj',
                ),
                'checkmark2' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CheckMark2',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CheckMark2',
                ),
                'unsharpmask' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'UnsharpMask',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\UnsharpMask',
                ),
                'standardunsharpmaskstrength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardUnsharpMaskStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardUnsharpMaskStrength',
                ),
                'standardunsharpmaskfineness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardUnsharpMaskFineness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardUnsharpMaskFineness',
                ),
                'standardunsharpmaskthreshold' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'StandardUnsharpMaskThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\StandardUnsharpMaskThreshold',
                ),
                'portraitunsharpmaskstrength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitUnsharpMaskStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitUnsharpMaskStrength',
                ),
                'portraitunsharpmaskfineness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitUnsharpMaskFineness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitUnsharpMaskFineness',
                ),
                'portraitunsharpmaskthreshold' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'PortraitUnsharpMaskThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\PortraitUnsharpMaskThreshold',
                ),
                'landscapeunsharpmaskstrength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeUnsharpMaskStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeUnsharpMaskStrength',
                ),
                'landscapeunsharpmaskfineness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeUnsharpMaskFineness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeUnsharpMaskFineness',
                ),
                'landscapeunsharpmaskthreshold' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'LandscapeUnsharpMaskThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\LandscapeUnsharpMaskThreshold',
                ),
                'neutraunsharpmaskstrength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutraUnsharpMaskStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutraUnsharpMaskStrength',
                ),
                'neutralunsharpmaskfineness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralUnsharpMaskFineness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralUnsharpMaskFineness',
                ),
                'neutralunsharpmaskthreshold' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'NeutralUnsharpMaskThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\NeutralUnsharpMaskThreshold',
                ),
                'faithfulunsharpmaskstrength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulUnsharpMaskStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulUnsharpMaskStrength',
                ),
                'faithfulunsharpmaskfineness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulUnsharpMaskFineness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulUnsharpMaskFineness',
                ),
                'faithfulunsharpmaskthreshold' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'FaithfulUnsharpMaskThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\FaithfulUnsharpMaskThreshold',
                ),
                'monochromeunsharpmaskstrength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeUnsharpMaskStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeUnsharpMaskStrength',
                ),
                'monochromeunsharpmaskfineness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeUnsharpMaskFineness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeUnsharpMaskFineness',
                ),
                'monochromeunsharpmaskthreshold' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'MonochromeUnsharpMaskThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\MonochromeUnsharpMaskThreshold',
                ),
                'customunsharpmaskstrength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomUnsharpMaskStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomUnsharpMaskStrength',
                ),
                'customunsharpmaskfineness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomUnsharpMaskFineness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomUnsharpMaskFineness',
                ),
                'customunsharpmaskthreshold' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomUnsharpMaskThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomUnsharpMaskThreshold',
                ),
                'customdefaultunsharpstrength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomDefaultUnsharpStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomDefaultUnsharpStrength',
                ),
                'customdefaultunsharpfineness' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomDefaultUnsharpFineness',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomDefaultUnsharpFineness',
                ),
                'customdefaultunsharpthreshold' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CustomDefaultUnsharpThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CustomDefaultUnsharpThreshold',
                ),
                'cropcircleactive' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropCircleActive',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropCircleActive',
                ),
                'cropcirclex' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropCircleX',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropCircleX',
                ),
                'cropcircley' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropCircleY',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropCircleY',
                ),
                'cropcircleradius' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CropCircleRadius',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CropCircleRadius',
                ),
                'dloon' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DLOOn',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DLOOn',
                ),
                'dlosetting' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DLOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DLOSetting',
                ),
                'dloshootingdistance' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DLOShootingDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DLOShootingDistance',
                ),
                'dlodatalength' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DLODataLength',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DLODataLength',
                ),
                'dlosettingapplied' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DLOSettingApplied',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DLOSettingApplied',
                ),
                'dloversion' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DLOVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DLOVersion',
                ),
                'dlodata' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'DLOData',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\DLOData',
                ),
                'canonvrd' => array(
                    'namespace' => 'CanonVRD',
                    'tagname' => 'CanonVRD',
                    'classname' => 'PHPExiftool\Driver\Tag\CanonVRD\CanonVRD',
                ),

            ),
            'casio' => array(
                'software' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Software',
                ),
                'facesdetected' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FacesDetected',
                ),
                'facedetectframesize' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FaceDetectFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FaceDetectFrameSize',
                ),
                'face1position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face1Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face1Position',
                ),
                'face2position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face2Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face2Position',
                ),
                'face3position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face3Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face3Position',
                ),
                'face4position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face4Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face4Position',
                ),
                'face5position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face5Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face5Position',
                ),
                'face6position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face6Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face6Position',
                ),
                'face7position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face7Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face7Position',
                ),
                'face8position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face8Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face8Position',
                ),
                'face9position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face9Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face9Position',
                ),
                'face10position' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Face10Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Face10Position',
                ),
                'faceorientation' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FaceOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FaceOrientation',
                ),
                'recordingmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'RecordingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\RecordingMode',
                ),
                'quality' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Quality',
                ),
                'focusmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FocusMode',
                ),
                'flashmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FlashMode',
                ),
                'flashintensity' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FlashIntensity',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FlashIntensity',
                ),
                'objectdistance' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ObjectDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ObjectDistance',
                ),
                'whitebalance' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\WhiteBalance',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\DigitalZoom',
                ),
                'sharpness' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Sharpness',
                ),
                'contrast' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Contrast',
                ),
                'saturation' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Saturation',
                ),
                'iso' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ISO',
                ),
                'firmwaredate' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FirmwareDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FirmwareDate',
                ),
                'enhancement' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'Enhancement',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\Enhancement',
                ),
                'colorfilter' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ColorFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ColorFilter',
                ),
                'afpoint' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'AFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\AFPoint',
                ),
                'casioquality' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'CasioQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\CasioQuality',
                ),
                'focalrange' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FocalRange',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FocalRange',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\DateTimeOriginal',
                ),
                'modeltype' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ModelType',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ModelType',
                ),
                'manufactureindex' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ManufactureIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ManufactureIndex',
                ),
                'manufacturecode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ManufactureCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ManufactureCode',
                ),
                'previewimagesize' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'PreviewImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\PreviewImageSize',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\PreviewImageLength',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\PreviewImageStart',
                ),
                'qualitymode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'QualityMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\QualityMode',
                ),
                'casioimagesize' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'CasioImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\CasioImageSize',
                ),
                'focallength' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FocalLength',
                ),
                'previewimage' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\PreviewImage',
                ),
                'whitebalancebias' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'WhiteBalanceBias',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\WhiteBalanceBias',
                ),
                'afpointposition' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'AFPointPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\AFPointPosition',
                ),
                'flashdistance' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FlashDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FlashDistance',
                ),
                'specialeffectmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'SpecialEffectMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\SpecialEffectMode',
                ),
                'faceinfounknown' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'FaceInfoUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\FaceInfoUnknown',
                ),
                'recordmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'RecordMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\RecordMode',
                ),
                'releasemode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ReleaseMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ReleaseMode',
                ),
                'hometowncity' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'HometownCity',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\HometownCity',
                ),
                'bestshotmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'BestShotMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\BestShotMode',
                ),
                'autoiso' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'AutoISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\AutoISO',
                ),
                'afmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'AFMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\AFMode',
                ),
                'colormode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ColorMode',
                ),
                'artmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ArtMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ArtMode',
                ),
                'sequencenumber' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'SequenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\SequenceNumber',
                ),
                'bracketsequence' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'BracketSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\BracketSequence',
                ),
                'imagestabilization' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ImageStabilization',
                ),
                'lightingmode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'LightingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\LightingMode',
                ),
                'portraitrefiner' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'PortraitRefiner',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\PortraitRefiner',
                ),
                'specialeffectlevel' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'SpecialEffectLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\SpecialEffectLevel',
                ),
                'specialeffectsetting' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'SpecialEffectSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\SpecialEffectSetting',
                ),
                'drivemode' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\DriveMode',
                ),
                'artmodeparameters' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'ArtModeParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\ArtModeParameters',
                ),
                'captureframerate' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'CaptureFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\CaptureFrameRate',
                ),
                'videoquality' => array(
                    'namespace' => 'Casio',
                    'tagname' => 'VideoQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Casio\VideoQuality',
                ),

            ),
            'composite' => array(
                'advancedscenemode' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'AdvancedSceneMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\AdvancedSceneMode',
                ),
                'aperture' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'Aperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\Aperture',
                ),
                'audiobitrate' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'AudioBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\AudioBitrate',
                ),
                'autofocus' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'AutoFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\AutoFocus',
                ),
                'avgbitrate' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'AvgBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\AvgBitrate',
                ),
                'bluebalance' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'BlueBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\BlueBalance',
                ),
                'cfapattern' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'CFAPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\CFAPattern',
                ),
                'circleofconfusion' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'CircleOfConfusion',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\CircleOfConfusion',
                ),
                'conditionalfec' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ConditionalFEC',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ConditionalFEC',
                ),
                'dof' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'DOF',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\DOF',
                ),
                'datecreated' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'DateCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\DateCreated',
                ),
                'datetimecreated' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'DateTimeCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\DateTimeCreated',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\DateTimeOriginal',
                ),
                'digitalcreationdatetime' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'DigitalCreationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\DigitalCreationDateTime',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\DigitalZoom',
                ),
                'drivemode' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\DriveMode',
                ),
                'duration' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\Duration',
                ),
                'extenderstatus' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ExtenderStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ExtenderStatus',
                ),
                'fov' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'FOV',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\FOV',
                ),
                'filenumber' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'FileNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\FileNumber',
                ),
                'flash' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\Flash',
                ),
                'flashtype' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'FlashType',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\FlashType',
                ),
                'focallength35efl' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'FocalLength35efl',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\FocalLength35efl',
                ),
                'focusdistance' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'FocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\FocusDistance',
                ),
                'gpsaltitude' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'GPSAltitude',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\GPSAltitude',
                ),
                'gpsaltituderef' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'GPSAltitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\GPSAltitudeRef',
                ),
                'gpsdatetime' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'GPSDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\GPSDateTime',
                ),
                'gpslatitude' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'GPSLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\GPSLatitude',
                ),
                'gpslatituderef' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'GPSLatitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\GPSLatitudeRef',
                ),
                'gpslongitude' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'GPSLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\GPSLongitude',
                ),
                'gpslongituderef' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'GPSLongitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\GPSLongitudeRef',
                ),
                'gpsposition' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'GPSPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\GPSPosition',
                ),
                'hyperfocaldistance' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'HyperfocalDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\HyperfocalDistance',
                ),
                'idcpreviewimage' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'IDCPreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\IDCPreviewImage',
                ),
                'iso' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ISO',
                ),
                'imageheight' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ImageHeight',
                ),
                'imagesize' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ImageSize',
                ),
                'imagewidth' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ImageWidth',
                ),
                'jpgfromraw' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'JpgFromRaw',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\JpgFromRaw',
                ),
                'lens' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'Lens',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\Lens',
                ),
                'lens35efl' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'Lens35efl',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\Lens35efl',
                ),
                'lensid' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'LensID',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\LensID',
                ),
                'lensspec' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'LensSpec',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\LensSpec',
                ),
                'lightvalue' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'LightValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\LightValue',
                ),
                'mpimage' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'MPImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\MPImage',
                ),
                'originaldecisiondata' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'OriginalDecisionData',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\OriginalDecisionData',
                ),
                'otherimage' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'OtherImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\OtherImage',
                ),
                'previewimage' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\PreviewImage',
                ),
                'previewimagesize' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'PreviewImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\PreviewImageSize',
                ),
                'redbalance' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'RedBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\RedBalance',
                ),
                'redeyereduction' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'RedEyeReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\RedEyeReduction',
                ),
                'rotation' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\Rotation',
                ),
                'scalefactor35efl' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ScaleFactor35efl',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ScaleFactor35efl',
                ),
                'shootingmode' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ShootingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ShootingMode',
                ),
                'shuttercurtainhack' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ShutterCurtainHack',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ShutterCurtainHack',
                ),
                'shutterspeed' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ShutterSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ShutterSpeed',
                ),
                'subseccreatedate' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'SubSecCreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\SubSecCreateDate',
                ),
                'subsecdatetimeoriginal' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'SubSecDateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\SubSecDateTimeOriginal',
                ),
                'subsecmodifydate' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'SubSecModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\SubSecModifyDate',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ThumbnailImage',
                ),
                'wb_rgblevels' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'WB_RGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\WBRGBLevels',
                ),
                'wb_rggblevels' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'WB_RGGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\WBRGGBLevels',
                ),
                'zoomedpreviewimage' => array(
                    'namespace' => 'Composite',
                    'tagname' => 'ZoomedPreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Composite\ZoomedPreviewImage',
                ),

            ),
            'dicom' => array(
                'filemetainfogrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FileMetaInfoGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FileMetaInfoGroupLength',
                ),
                'filemetainfoversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FileMetaInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FileMetaInfoVersion',
                ),
                'mediastoragesopclassuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MediaStorageSOPClassUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MediaStorageSOPClassUID',
                ),
                'mediastoragesopinstanceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MediaStorageSOPInstanceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MediaStorageSOPInstanceUID',
                ),
                'transfersyntaxuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransferSyntaxUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransferSyntaxUID',
                ),
                'implementationclassuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImplementationClassUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImplementationClassUID',
                ),
                'implementationversionname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImplementationVersionName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImplementationVersionName',
                ),
                'sourceapplicationentitytitle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicationEntityTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicationEntityTitle',
                ),
                'privateinformationcreatoruid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrivateInformationCreatorUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrivateInformationCreatorUID',
                ),
                'privateinformation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrivateInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrivateInformation',
                ),
                'filesetid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FileSetID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FileSetID',
                ),
                'filesetdescriptorfileid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FileSetDescriptorFileID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FileSetDescriptorFileID',
                ),
                'specificcharactersetoffile' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecificCharacterSetOfFile',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecificCharacterSetOfFile',
                ),
                'firstdirectoryrecordoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FirstDirectoryRecordOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FirstDirectoryRecordOffset',
                ),
                'lastdirectoryrecordoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LastDirectoryRecordOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LastDirectoryRecordOffset',
                ),
                'filesetconsistencyflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FileSetConsistencyFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FileSetConsistencyFlag',
                ),
                'directoryrecordsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DirectoryRecordSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DirectoryRecordSequence',
                ),
                'offsetofnextdirectoryrecord' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OffsetOfNextDirectoryRecord',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OffsetOfNextDirectoryRecord',
                ),
                'recordinuseflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordInUseFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordInUseFlag',
                ),
                'lowerleveldirectoryentityoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerLevelDirectoryEntityOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerLevelDirectoryEntityOffset',
                ),
                'directoryrecordtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DirectoryRecordType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DirectoryRecordType',
                ),
                'privaterecorduid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrivateRecordUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrivateRecordUID',
                ),
                'referencedfileid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFileID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFileID',
                ),
                'mrdrdirectoryrecordoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRDRDirectoryRecordOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRDRDirectoryRecordOffset',
                ),
                'referencedsopclassuidinfile' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSOPClassUIDInFile',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSOPClassUIDInFile',
                ),
                'referencedsopinstanceuidinfile' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSOPInstanceUIDInFile',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSOPInstanceUIDInFile',
                ),
                'referencedtransfersyntaxuidinfile' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedTransferSyntaxUIDInFile',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedTransferSyntaxUIDInFile',
                ),
                'referencedrelatedsopclassuidinfile' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedRelatedSOPClassUIDInFile',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedRelatedSOPClassUIDInFile',
                ),
                'numberofreferences' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfReferences',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfReferences',
                ),
                'identifyinggrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IdentifyingGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IdentifyingGroupLength',
                ),
                'lengthtoend' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LengthToEnd',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LengthToEnd',
                ),
                'specificcharacterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecificCharacterSet',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecificCharacterSet',
                ),
                'languagecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LanguageCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LanguageCodeSequence',
                ),
                'imagetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageType',
                ),
                'recognitioncode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecognitionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecognitionCode',
                ),
                'instancecreationdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstanceCreationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstanceCreationDate',
                ),
                'instancecreationtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstanceCreationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstanceCreationTime',
                ),
                'instancecreatoruid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstanceCreatorUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstanceCreatorUID',
                ),
                'sopclassuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SOPClassUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SOPClassUID',
                ),
                'sopinstanceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SOPInstanceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SOPInstanceUID',
                ),
                'relatedgeneralsopclassuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelatedGeneralSOPClassUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelatedGeneralSOPClassUID',
                ),
                'originalspecializedsopclassuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OriginalSpecializedSOPClassUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OriginalSpecializedSOPClassUID',
                ),
                'studydate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyDate',
                ),
                'seriesdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesDate',
                ),
                'acquisitiondate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionDate',
                ),
                'contentdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentDate',
                ),
                'overlaydate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayDate',
                ),
                'curvedate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveDate',
                ),
                'acquisitiondatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionDateTime',
                ),
                'studytime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyTime',
                ),
                'seriestime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesTime',
                ),
                'acquisitiontime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionTime',
                ),
                'contenttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentTime',
                ),
                'overlaytime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayTime',
                ),
                'curvetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveTime',
                ),
                'datasettype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataSetType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataSetType',
                ),
                'datasetsubtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataSetSubtype',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataSetSubtype',
                ),
                'nuclearmedicineseriestype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NuclearMedicineSeriesType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NuclearMedicineSeriesType',
                ),
                'accessionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AccessionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AccessionNumber',
                ),
                'queryretrievelevel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'QueryRetrieveLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\QueryRetrieveLevel',
                ),
                'retrieveaetitle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RetrieveAETitle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RetrieveAETitle',
                ),
                'instanceavailability' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstanceAvailability',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstanceAvailability',
                ),
                'failedsopinstanceuidlist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FailedSOPInstanceUIDList',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FailedSOPInstanceUIDList',
                ),
                'modality' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Modality',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Modality',
                ),
                'modalitiesinstudy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModalitiesInStudy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModalitiesInStudy',
                ),
                'sopclassesinstudy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SOPClassesInStudy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SOPClassesInStudy',
                ),
                'conversiontype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConversionType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConversionType',
                ),
                'presentationintenttype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationIntentType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationIntentType',
                ),
                'manufacturer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Manufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Manufacturer',
                ),
                'institutionname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstitutionName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstitutionName',
                ),
                'institutionaddress' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstitutionAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstitutionAddress',
                ),
                'institutioncodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstitutionCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstitutionCodeSequence',
                ),
                'referringphysicianname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferringPhysicianName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferringPhysicianName',
                ),
                'referringphysicianaddress' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferringPhysicianAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferringPhysicianAddress',
                ),
                'referringphysiciantelephonenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferringPhysicianTelephoneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferringPhysicianTelephoneNumber',
                ),
                'referringphysicianidsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferringPhysicianIDSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferringPhysicianIDSequence',
                ),
                'codevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodeValue',
                ),
                'codingschemedesignator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodingSchemeDesignator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodingSchemeDesignator',
                ),
                'codingschemeversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodingSchemeVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodingSchemeVersion',
                ),
                'codemeaning' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodeMeaning',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodeMeaning',
                ),
                'mappingresource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MappingResource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MappingResource',
                ),
                'contextgroupversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContextGroupVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContextGroupVersion',
                ),
                'contextgrouplocalversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContextGroupLocalVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContextGroupLocalVersion',
                ),
                'contextgroupextensionflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContextGroupExtensionFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContextGroupExtensionFlag',
                ),
                'codingschemeuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodingSchemeUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodingSchemeUID',
                ),
                'contextgroupextensioncreatoruid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContextGroupExtensionCreatorUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContextGroupExtensionCreatorUID',
                ),
                'contextidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContextIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContextIdentifier',
                ),
                'codingschemeidsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodingSchemeIDSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodingSchemeIDSequence',
                ),
                'codingschemeregistry' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodingSchemeRegistry',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodingSchemeRegistry',
                ),
                'codingschemeexternalid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodingSchemeExternalID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodingSchemeExternalID',
                ),
                'codingschemename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodingSchemeName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodingSchemeName',
                ),
                'responsibleorganization' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResponsibleOrganization',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResponsibleOrganization',
                ),
                'contextuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContextUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContextUID',
                ),
                'timezoneoffsetfromutc' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimezoneOffsetFromUTC',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimezoneOffsetFromUTC',
                ),
                'networkid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NetworkID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NetworkID',
                ),
                'stationname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StationName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StationName',
                ),
                'studydescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyDescription',
                ),
                'procedurecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProcedureCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProcedureCodeSequence',
                ),
                'seriesdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesDescription',
                ),
                'institutionaldepartmentname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstitutionalDepartmentName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstitutionalDepartmentName',
                ),
                'physiciansofrecord' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysiciansOfRecord',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysiciansOfRecord',
                ),
                'physiciansofrecordidsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysiciansOfRecordIDSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysiciansOfRecordIDSequence',
                ),
                'performingphysicianname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformingPhysicianName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformingPhysicianName',
                ),
                'performingphysicianidsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformingPhysicianIDSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformingPhysicianIDSequence',
                ),
                'nameofphysicianreadingstudy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NameOfPhysicianReadingStudy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NameOfPhysicianReadingStudy',
                ),
                'physicianreadingstudyidsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysicianReadingStudyIDSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysicianReadingStudyIDSequence',
                ),
                'operatorsname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OperatorsName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OperatorsName',
                ),
                'operatoridsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OperatorIDSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OperatorIDSequence',
                ),
                'admittingdiagnosesdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdmittingDiagnosesDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdmittingDiagnosesDescription',
                ),
                'admittingdiagnosescodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdmittingDiagnosesCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdmittingDiagnosesCodeSequence',
                ),
                'manufacturersmodelname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ManufacturersModelName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ManufacturersModelName',
                ),
                'referencedresultssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedResultsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedResultsSequence',
                ),
                'referencedstudysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedStudySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedStudySequence',
                ),
                'referencedprocedurestepsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedProcedureStepSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedProcedureStepSequence',
                ),
                'referencedseriessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSeriesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSeriesSequence',
                ),
                'referencedpatientsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedPatientSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedPatientSequence',
                ),
                'referencedvisitsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedVisitSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedVisitSequence',
                ),
                'referencedoverlaysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedOverlaySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedOverlaySequence',
                ),
                'referencedwaveformsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedWaveformSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedWaveformSequence',
                ),
                'referencedimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedImageSequence',
                ),
                'referencedcurvesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedCurveSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedCurveSequence',
                ),
                'referencedinstancesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedInstanceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedInstanceSequence',
                ),
                'referencedsopclassuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSOPClassUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSOPClassUID',
                ),
                'referencedsopinstanceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSOPInstanceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSOPInstanceUID',
                ),
                'sopclassessupported' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SOPClassesSupported',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SOPClassesSupported',
                ),
                'referencedframenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFrameNumber',
                ),
                'simpleframelist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SimpleFrameList',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SimpleFrameList',
                ),
                'calculatedframelist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalculatedFrameList',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalculatedFrameList',
                ),
                'timerange' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeRange',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeRange',
                ),
                'frameextractionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameExtractionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameExtractionSequence',
                ),
                'transactionuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransactionUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransactionUID',
                ),
                'failurereason' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FailureReason',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FailureReason',
                ),
                'failedsopsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FailedSOPSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FailedSOPSequence',
                ),
                'referencedsopsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSOPSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSOPSequence',
                ),
                'otherreferencedstudiessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherReferencedStudiesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherReferencedStudiesSequence',
                ),
                'relatedseriessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelatedSeriesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelatedSeriesSequence',
                ),
                'lossyimagecompression' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LossyImageCompression',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LossyImageCompression',
                ),
                'derivationdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DerivationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DerivationDescription',
                ),
                'sourceimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceImageSequence',
                ),
                'stagename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StageName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StageName',
                ),
                'stagenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StageNumber',
                ),
                'numberofstages' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfStages',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfStages',
                ),
                'viewname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewName',
                ),
                'viewnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewNumber',
                ),
                'numberofeventtimers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfEventTimers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfEventTimers',
                ),
                'numberofviewsinstage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfViewsInStage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInStage',
                ),
                'eventelapsedtimes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EventElapsedTimes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EventElapsedTimes',
                ),
                'eventtimernames' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EventTimerNames',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EventTimerNames',
                ),
                'eventtimersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EventTimerSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EventTimerSequence',
                ),
                'eventtimeoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EventTimeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EventTimeOffset',
                ),
                'eventcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EventCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EventCodeSequence',
                ),
                'starttrim' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartTrim',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartTrim',
                ),
                'stoptrim' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StopTrim',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StopTrim',
                ),
                'recommendeddisplayframerate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecommendedDisplayFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecommendedDisplayFrameRate',
                ),
                'transducerposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerPosition',
                ),
                'transducerorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerOrientation',
                ),
                'anatomicstructure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicStructure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicStructure',
                ),
                'anatomicregionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicRegionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicRegionSequence',
                ),
                'anatomicregionmodifiersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicRegionModifierSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicRegionModifierSequence',
                ),
                'primaryanatomicstructuresequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimaryAnatomicStructureSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimaryAnatomicStructureSequence',
                ),
                'anatomicstructureorregionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicStructureOrRegionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicStructureOrRegionSequence',
                ),
                'anatomicstructuremodifiersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicStructureModifierSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicStructureModifierSequence',
                ),
                'transducerpositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerPositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerPositionSequence',
                ),
                'transducerpositionmodifiersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerPositionModifierSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerPositionModifierSequence',
                ),
                'transducerorientationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerOrientationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerOrientationSequence',
                ),
                'transducerorientationmodifierseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerOrientationModifierSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerOrientationModifierSeq',
                ),
                'anatomicentranceportalcodeseqtrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicEntrancePortalCodeSeqTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicEntrancePortalCodeSeqTrial',
                ),
                'anatomicapproachdircodeseqtrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicApproachDirCodeSeqTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicApproachDirCodeSeqTrial',
                ),
                'anatomicperspectivedescrtrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicPerspectiveDescrTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicPerspectiveDescrTrial',
                ),
                'anatomicperspectivecodeseqtrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicPerspectiveCodeSeqTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicPerspectiveCodeSeqTrial',
                ),
                'alternaterepresentationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlternateRepresentationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlternateRepresentationSequence',
                ),
                'irradiationeventuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IrradiationEventUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IrradiationEventUID',
                ),
                'identifyingcomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IdentifyingComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IdentifyingComments',
                ),
                'frametype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameType',
                ),
                'referencedimageevidencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedImageEvidenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedImageEvidenceSequence',
                ),
                'referencedrawdatasequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedRawDataSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedRawDataSequence',
                ),
                'creatorversionuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CreatorVersionUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CreatorVersionUID',
                ),
                'derivationimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DerivationImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DerivationImageSequence',
                ),
                'sourceimageevidencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceImageEvidenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceImageEvidenceSequence',
                ),
                'pixelpresentation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelPresentation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelPresentation',
                ),
                'volumetricproperties' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VolumetricProperties',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VolumetricProperties',
                ),
                'volumebasedcalculationtechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VolumeBasedCalculationTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VolumeBasedCalculationTechnique',
                ),
                'compleximagecomponent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ComplexImageComponent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ComplexImageComponent',
                ),
                'acquisitioncontrast' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionContrast',
                ),
                'derivationcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DerivationCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DerivationCodeSequence',
                ),
                'grayscalepresentationstatesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GrayscalePresentationStateSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GrayscalePresentationStateSequence',
                ),
                'referencedotherplanesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedOtherPlaneSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedOtherPlaneSequence',
                ),
                'framedisplaysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameDisplaySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameDisplaySequence',
                ),
                'recommendeddisplayframerateinfloat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecommendedDisplayFrameRateInFloat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecommendedDisplayFrameRateInFloat',
                ),
                'skipframerangeflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SkipFrameRangeFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SkipFrameRangeFlag',
                ),
                'fullfidelity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FullFidelity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FullFidelity',
                ),
                'suiteid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SuiteID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SuiteID',
                ),
                'productid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProductID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProductID',
                ),
                'imageactualdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageActualDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageActualDate',
                ),
                'serviceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ServiceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ServiceID',
                ),
                'mobilelocationnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MobileLocationNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MobileLocationNumber',
                ),
                'equipmentuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EquipmentUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EquipmentUID',
                ),
                'genesisversionnow' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GenesisVersionNow',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GenesisVersionNow',
                ),
                'examrecordchecksum' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExamRecordChecksum',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExamRecordChecksum',
                ),
                'actualseriesdatatimestamp' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActualSeriesDataTimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActualSeriesDataTimeStamp',
                ),
                'patientgrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientGroupLength',
                ),
                'patientname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientName',
                ),
                'patientid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientID',
                ),
                'issuerofpatientid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IssuerOfPatientID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IssuerOfPatientID',
                ),
                'typeofpatientid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TypeOfPatientID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TypeOfPatientID',
                ),
                'patientbirthdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientBirthDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientBirthDate',
                ),
                'patientbirthtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientBirthTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientBirthTime',
                ),
                'patientsex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSex',
                ),
                'patientinsuranceplancodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientInsurancePlanCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientInsurancePlanCodeSequence',
                ),
                'patientprimarylanguagecodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientPrimaryLanguageCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientPrimaryLanguageCodeSeq',
                ),
                'patientprimarylanguagecodemodseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientPrimaryLanguageCodeModSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientPrimaryLanguageCodeModSeq',
                ),
                'otherpatientids' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherPatientIDs',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherPatientIDs',
                ),
                'otherpatientnames' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherPatientNames',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherPatientNames',
                ),
                'otherpatientidssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherPatientIDsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherPatientIDsSequence',
                ),
                'patientbirthname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientBirthName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientBirthName',
                ),
                'patientage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientAge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientAge',
                ),
                'patientsize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSize',
                ),
                'patientweight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientWeight',
                ),
                'patientaddress' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientAddress',
                ),
                'insuranceplanidentification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InsurancePlanIdentification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InsurancePlanIdentification',
                ),
                'patientmotherbirthname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientMotherBirthName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientMotherBirthName',
                ),
                'militaryrank' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MilitaryRank',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MilitaryRank',
                ),
                'branchofservice' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BranchOfService',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BranchOfService',
                ),
                'medicalrecordlocator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MedicalRecordLocator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MedicalRecordLocator',
                ),
                'medicalalerts' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MedicalAlerts',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MedicalAlerts',
                ),
                'allergies' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Allergies',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Allergies',
                ),
                'countryofresidence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CountryOfResidence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CountryOfResidence',
                ),
                'regionofresidence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionOfResidence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionOfResidence',
                ),
                'patienttelephonenumbers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientTelephoneNumbers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientTelephoneNumbers',
                ),
                'ethnicgroup' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EthnicGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EthnicGroup',
                ),
                'occupation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Occupation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Occupation',
                ),
                'smokingstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SmokingStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SmokingStatus',
                ),
                'additionalpatienthistory' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdditionalPatientHistory',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdditionalPatientHistory',
                ),
                'pregnancystatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PregnancyStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PregnancyStatus',
                ),
                'lastmenstrualdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LastMenstrualDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LastMenstrualDate',
                ),
                'patientreligiouspreference' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientReligiousPreference',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientReligiousPreference',
                ),
                'patientspeciesdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSpeciesDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSpeciesDescription',
                ),
                'patientspeciescodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSpeciesCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSpeciesCodeSequence',
                ),
                'patientsexneutered' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSexNeutered',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSexNeutered',
                ),
                'anatomicalorientationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicalOrientationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicalOrientationType',
                ),
                'patientbreeddescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientBreedDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientBreedDescription',
                ),
                'patientbreedcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientBreedCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientBreedCodeSequence',
                ),
                'breedregistrationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BreedRegistrationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BreedRegistrationSequence',
                ),
                'breedregistrationnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BreedRegistrationNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BreedRegistrationNumber',
                ),
                'breedregistrycodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BreedRegistryCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BreedRegistryCodeSequence',
                ),
                'responsibleperson' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResponsiblePerson',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResponsiblePerson',
                ),
                'responsiblepersonrole' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResponsiblePersonRole',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResponsiblePersonRole',
                ),
                'patientcomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientComments',
                ),
                'examinedbodythickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExaminedBodyThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExaminedBodyThickness',
                ),
                'patientstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientStatus',
                ),
                'clinicaltrialsponsorname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialSponsorName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSponsorName',
                ),
                'clinicaltrialprotocolid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialProtocolID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialProtocolID',
                ),
                'clinicaltrialprotocolname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialProtocolName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialProtocolName',
                ),
                'clinicaltrialsiteid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialSiteID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSiteID',
                ),
                'clinicaltrialsitename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialSiteName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSiteName',
                ),
                'clinicaltrialsubjectid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialSubjectID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSubjectID',
                ),
                'clinicaltrialsubjectreadingid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialSubjectReadingID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSubjectReadingID',
                ),
                'clinicaltrialtimepointid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialTimePointID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialTimePointID',
                ),
                'clinicaltrialtimepointdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialTimePointDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialTimePointDescription',
                ),
                'clinicaltrialcoordinatingcenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialCoordinatingCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialCoordinatingCenter',
                ),
                'patientidentityremoved' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientIdentityRemoved',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientIdentityRemoved',
                ),
                'deidentificationmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeidentificationMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeidentificationMethod',
                ),
                'deidentificationmethodcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeidentificationMethodCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeidentificationMethodCodeSequence',
                ),
                'clinicaltrialseriesid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialSeriesID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSeriesID',
                ),
                'clinicaltrialseriesdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ClinicalTrialSeriesDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ClinicalTrialSeriesDescription',
                ),
                'distributiontype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistributionType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistributionType',
                ),
                'consentfordistributionflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConsentForDistributionFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConsentForDistributionFlag',
                ),
                'acquisitiongrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionGroupLength',
                ),
                'contrastbolusagent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusAgent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgent',
                ),
                'contrastbolusagentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusAgentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentSequence',
                ),
                'contrastbolusadministrationroute' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusAdministrationRoute',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusAdministrationRoute',
                ),
                'bodypartexamined' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BodyPartExamined',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BodyPartExamined',
                ),
                'scanningsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanningSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanningSequence',
                ),
                'sequencevariant' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SequenceVariant',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SequenceVariant',
                ),
                'scanoptions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanOptions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanOptions',
                ),
                'mracquisitiontype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRAcquisitionType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRAcquisitionType',
                ),
                'sequencename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SequenceName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SequenceName',
                ),
                'angioflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AngioFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AngioFlag',
                ),
                'interventiondruginformationseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionDrugInformationSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionDrugInformationSeq',
                ),
                'interventiondrugstoptime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionDrugStopTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionDrugStopTime',
                ),
                'interventiondrugdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionDrugDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionDrugDose',
                ),
                'interventiondrugsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionDrugSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionDrugSequence',
                ),
                'additionaldrugsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdditionalDrugSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdditionalDrugSequence',
                ),
                'radionuclide' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Radionuclide',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Radionuclide',
                ),
                'radiopharmaceutical' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Radiopharmaceutical',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Radiopharmaceutical',
                ),
                'energywindowcenterline' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowCenterline',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowCenterline',
                ),
                'energywindowtotalwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowTotalWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowTotalWidth',
                ),
                'interventiondrugname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionDrugName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionDrugName',
                ),
                'interventiondrugstarttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionDrugStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionDrugStartTime',
                ),
                'interventionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionSequence',
                ),
                'therapytype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TherapyType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TherapyType',
                ),
                'interventionstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionStatus',
                ),
                'therapydescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TherapyDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TherapyDescription',
                ),
                'interventiondescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterventionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterventionDescription',
                ),
                'cinerate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CineRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CineRate',
                ),
                'initialcinerunstate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InitialCineRunState',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InitialCineRunState',
                ),
                'slicethickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SliceThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SliceThickness',
                ),
                'kvp' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'KVP',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\KVP',
                ),
                'countsaccumulated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CountsAccumulated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CountsAccumulated',
                ),
                'acquisitionterminationcondition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionTerminationCondition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionTerminationCondition',
                ),
                'effectiveduration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EffectiveDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EffectiveDuration',
                ),
                'acquisitionstartcondition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionStartCondition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionStartCondition',
                ),
                'acquisitionstartconditiondata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionStartConditionData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionStartConditionData',
                ),
                'acquisitionendconditiondata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionEndConditionData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionEndConditionData',
                ),
                'repetitiontime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RepetitionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RepetitionTime',
                ),
                'echotime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EchoTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EchoTime',
                ),
                'inversiontime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InversionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InversionTime',
                ),
                'numberofaverages' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfAverages',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfAverages',
                ),
                'imagingfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagingFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagingFrequency',
                ),
                'imagednucleus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagedNucleus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagedNucleus',
                ),
                'echonumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EchoNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EchoNumber',
                ),
                'magneticfieldstrength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MagneticFieldStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MagneticFieldStrength',
                ),
                'spacingbetweenslices' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpacingBetweenSlices',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpacingBetweenSlices',
                ),
                'numberofphaseencodingsteps' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPhaseEncodingSteps',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPhaseEncodingSteps',
                ),
                'datacollectiondiameter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataCollectionDiameter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataCollectionDiameter',
                ),
                'echotrainlength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EchoTrainLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EchoTrainLength',
                ),
                'percentsampling' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PercentSampling',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PercentSampling',
                ),
                'percentphasefieldofview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PercentPhaseFieldOfView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PercentPhaseFieldOfView',
                ),
                'pixelbandwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelBandwidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelBandwidth',
                ),
                'deviceserialnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceSerialNumber',
                ),
                'deviceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceUID',
                ),
                'deviceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceID',
                ),
                'plateid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlateID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlateID',
                ),
                'generatorid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeneratorID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeneratorID',
                ),
                'gridid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridID',
                ),
                'cassetteid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CassetteID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CassetteID',
                ),
                'gantryid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryID',
                ),
                'secondarycapturedeviceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryCaptureDeviceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryCaptureDeviceID',
                ),
                'hardcopycreationdeviceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HardcopyCreationDeviceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HardcopyCreationDeviceID',
                ),
                'dateofsecondarycapture' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DateOfSecondaryCapture',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DateOfSecondaryCapture',
                ),
                'timeofsecondarycapture' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeOfSecondaryCapture',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeOfSecondaryCapture',
                ),
                'secondarycapturedevicemanufacturer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryCaptureDeviceManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryCaptureDeviceManufacturer',
                ),
                'hardcopydevicemanufacturer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HardcopyDeviceManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HardcopyDeviceManufacturer',
                ),
                'secondarycapturedevicemodelname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryCaptureDeviceModelName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryCaptureDeviceModelName',
                ),
                'secondarycapturedevicesoftwarevers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryCaptureDeviceSoftwareVers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryCaptureDeviceSoftwareVers',
                ),
                'hardcopydevicesoftwareversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HardcopyDeviceSoftwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HardcopyDeviceSoftwareVersion',
                ),
                'hardcopydevicemodelname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HardcopyDeviceModelName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HardcopyDeviceModelName',
                ),
                'softwareversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SoftwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SoftwareVersion',
                ),
                'videoimageformatacquired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VideoImageFormatAcquired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VideoImageFormatAcquired',
                ),
                'digitalimageformatacquired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DigitalImageFormatAcquired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DigitalImageFormatAcquired',
                ),
                'protocolname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProtocolName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProtocolName',
                ),
                'contrastbolusroute' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusRoute',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusRoute',
                ),
                'contrastbolusvolume' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusVolume',
                ),
                'contrastbolusstarttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusStartTime',
                ),
                'contrastbolusstoptime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusStopTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusStopTime',
                ),
                'contrastbolustotaldose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusTotalDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusTotalDose',
                ),
                'syringecounts' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SyringeCounts',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SyringeCounts',
                ),
                'contrastflowrate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastFlowRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastFlowRate',
                ),
                'contrastflowduration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastFlowDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastFlowDuration',
                ),
                'contrastbolusingredient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusIngredient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusIngredient',
                ),
                'contrastbolusconcentration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusConcentration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusConcentration',
                ),
                'spatialresolution' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpatialResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpatialResolution',
                ),
                'triggertime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerTime',
                ),
                'triggersourceortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerSourceOrType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerSourceOrType',
                ),
                'nominalinterval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalInterval',
                ),
                'frametime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameTime',
                ),
                'cardiacframingtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacFramingType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacFramingType',
                ),
                'frametimevector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameTimeVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameTimeVector',
                ),
                'framedelay' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameDelay',
                ),
                'imagetriggerdelay' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageTriggerDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageTriggerDelay',
                ),
                'multiplexgrouptimeoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultiplexGroupTimeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultiplexGroupTimeOffset',
                ),
                'triggertimeoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerTimeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerTimeOffset',
                ),
                'synchronizationtrigger' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SynchronizationTrigger',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SynchronizationTrigger',
                ),
                'synchronizationchannel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SynchronizationChannel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SynchronizationChannel',
                ),
                'triggersampleposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerSamplePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerSamplePosition',
                ),
                'radiopharmaceuticalroute' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalRoute',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalRoute',
                ),
                'radiopharmaceuticalvolume' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalVolume',
                ),
                'radiopharmaceuticalstarttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalStartTime',
                ),
                'radiopharmaceuticalstoptime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalStopTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalStopTime',
                ),
                'radionuclidetotaldose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadionuclideTotalDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadionuclideTotalDose',
                ),
                'radionuclidehalflife' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadionuclideHalfLife',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadionuclideHalfLife',
                ),
                'radionuclidepositronfraction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadionuclidePositronFraction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadionuclidePositronFraction',
                ),
                'radiopharmaceuticalspecactivity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalSpecActivity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalSpecActivity',
                ),
                'radiopharmaceuticalstartdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalStartDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalStartDateTime',
                ),
                'radiopharmaceuticalstopdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalStopDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalStopDateTime',
                ),
                'beatrejectionflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeatRejectionFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeatRejectionFlag',
                ),
                'lowrrvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowRRValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowRRValue',
                ),
                'highrrvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HighRRValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HighRRValue',
                ),
                'intervalsacquired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntervalsAcquired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntervalsAcquired',
                ),
                'intervalsrejected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntervalsRejected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntervalsRejected',
                ),
                'pvcrejection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PVCRejection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PVCRejection',
                ),
                'skipbeats' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SkipBeats',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SkipBeats',
                ),
                'heartrate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HeartRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HeartRate',
                ),
                'cardiacnumberofimages' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacNumberOfImages',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacNumberOfImages',
                ),
                'triggerwindow' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerWindow',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerWindow',
                ),
                'reconstructiondiameter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionDiameter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionDiameter',
                ),
                'distancesourcetodetector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistanceSourceToDetector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistanceSourceToDetector',
                ),
                'distancesourcetopatient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistanceSourceToPatient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistanceSourceToPatient',
                ),
                'estimatedradiographicmagnification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EstimatedRadiographicMagnification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EstimatedRadiographicMagnification',
                ),
                'gantrydetectortilt' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryDetectorTilt',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryDetectorTilt',
                ),
                'gantrydetectorslew' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryDetectorSlew',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryDetectorSlew',
                ),
                'tableheight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableHeight',
                ),
                'tabletraverse' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTraverse',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTraverse',
                ),
                'tablemotion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableMotion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableMotion',
                ),
                'tableverticalincrement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableVerticalIncrement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableVerticalIncrement',
                ),
                'tablelateralincrement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableLateralIncrement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableLateralIncrement',
                ),
                'tablelongitudinalincrement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableLongitudinalIncrement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableLongitudinalIncrement',
                ),
                'tableangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableAngle',
                ),
                'tabletype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableType',
                ),
                'rotationdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RotationDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RotationDirection',
                ),
                'angularposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AngularPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AngularPosition',
                ),
                'radialposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadialPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadialPosition',
                ),
                'scanarc' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanArc',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanArc',
                ),
                'angularstep' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AngularStep',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AngularStep',
                ),
                'centerofrotationoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterOfRotationOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterOfRotationOffset',
                ),
                'rotationoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RotationOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RotationOffset',
                ),
                'fieldofviewshape' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewShape',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewShape',
                ),
                'fieldofviewdimensions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewDimensions',
                ),
                'exposuretime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureTime',
                ),
                'xraytubecurrent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayTubeCurrent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayTubeCurrent',
                ),
                'exposure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Exposure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Exposure',
                ),
                'exposureinmicroampsec' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureInMicroAmpSec',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureInMicroAmpSec',
                ),
                'averagepulsewidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AveragePulseWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AveragePulseWidth',
                ),
                'radiationsetting' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationSetting',
                ),
                'rectificationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RectificationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RectificationType',
                ),
                'radiationmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationMode',
                ),
                'imageareadoseproduct' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageAreaDoseProduct',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageAreaDoseProduct',
                ),
                'filtertype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterType',
                ),
                'typeoffilters' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TypeOfFilters',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TypeOfFilters',
                ),
                'intensifiersize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntensifierSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntensifierSize',
                ),
                'imagerpixelspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagerPixelSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagerPixelSpacing',
                ),
                'grid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Grid',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Grid',
                ),
                'generatorpower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeneratorPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeneratorPower',
                ),
                'collimatorgridname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollimatorGridName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollimatorGridName',
                ),
                'collimatortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollimatorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollimatorType',
                ),
                'focaldistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FocalDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FocalDistance',
                ),
                'xfocuscenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XFocusCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XFocusCenter',
                ),
                'yfocuscenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'YFocusCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\YFocusCenter',
                ),
                'focalspots' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FocalSpots',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FocalSpots',
                ),
                'anodetargetmaterial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnodeTargetMaterial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnodeTargetMaterial',
                ),
                'bodypartthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BodyPartThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BodyPartThickness',
                ),
                'compressionforce' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompressionForce',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompressionForce',
                ),
                'dateoflastcalibration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DateOfLastCalibration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DateOfLastCalibration',
                ),
                'timeoflastcalibration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeOfLastCalibration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeOfLastCalibration',
                ),
                'convolutionkernel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConvolutionKernel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConvolutionKernel',
                ),
                'upperlowerpixelvalues' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UpperLowerPixelValues',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UpperLowerPixelValues',
                ),
                'actualframeduration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActualFrameDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActualFrameDuration',
                ),
                'countrate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CountRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CountRate',
                ),
                'preferredplaybacksequencing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PreferredPlaybackSequencing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PreferredPlaybackSequencing',
                ),
                'receivecoilname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReceiveCoilName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReceiveCoilName',
                ),
                'transmitcoilname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransmitCoilName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransmitCoilName',
                ),
                'platetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlateType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlateType',
                ),
                'phosphortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhosphorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhosphorType',
                ),
                'scanvelocity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanVelocity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanVelocity',
                ),
                'wholebodytechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WholeBodyTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WholeBodyTechnique',
                ),
                'scanlength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanLength',
                ),
                'acquisitionmatrix' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionMatrix',
                ),
                'inplanephaseencodingdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InPlanePhaseEncodingDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InPlanePhaseEncodingDirection',
                ),
                'flipangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FlipAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FlipAngle',
                ),
                'variableflipangleflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VariableFlipAngleFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VariableFlipAngleFlag',
                ),
                'sar' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SAR',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SAR',
                ),
                'db-dt' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DB-Dt',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DBDt',
                ),
                'acquisitiondeviceprocessingdescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionDeviceProcessingDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionDeviceProcessingDescr',
                ),
                'acquisitiondeviceprocessingcode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionDeviceProcessingCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionDeviceProcessingCode',
                ),
                'cassetteorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CassetteOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CassetteOrientation',
                ),
                'cassettesize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CassetteSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CassetteSize',
                ),
                'exposuresonplate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposuresOnPlate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposuresOnPlate',
                ),
                'relativexrayexposure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelativeXRayExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelativeXRayExposure',
                ),
                'columnangulation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ColumnAngulation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ColumnAngulation',
                ),
                'tomolayerheight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TomoLayerHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TomoLayerHeight',
                ),
                'tomoangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TomoAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TomoAngle',
                ),
                'tomotime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TomoTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TomoTime',
                ),
                'tomotype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TomoType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TomoType',
                ),
                'tomoclass' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TomoClass',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TomoClass',
                ),
                'numberoftomosynthesissourceimages' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTomosynthesisSourceImages',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTomosynthesisSourceImages',
                ),
                'positionermotion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerMotion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerMotion',
                ),
                'positionertype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerType',
                ),
                'positionerprimaryangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerPrimaryAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerPrimaryAngle',
                ),
                'positionersecondaryangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerSecondaryAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerSecondaryAngle',
                ),
                'positionerprimaryangleincrement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerPrimaryAngleIncrement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerPrimaryAngleIncrement',
                ),
                'positionersecondaryangleincrement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerSecondaryAngleIncrement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerSecondaryAngleIncrement',
                ),
                'detectorprimaryangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorPrimaryAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorPrimaryAngle',
                ),
                'detectorsecondaryangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorSecondaryAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorSecondaryAngle',
                ),
                'shuttershape' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShutterShape',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShutterShape',
                ),
                'shutterleftverticaledge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShutterLeftVerticalEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShutterLeftVerticalEdge',
                ),
                'shutterrightverticaledge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShutterRightVerticalEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShutterRightVerticalEdge',
                ),
                'shutterupperhorizontaledge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShutterUpperHorizontalEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShutterUpperHorizontalEdge',
                ),
                'shutterlowerhorizontaledge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShutterLowerHorizontalEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShutterLowerHorizontalEdge',
                ),
                'centerofcircularshutter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterOfCircularShutter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterOfCircularShutter',
                ),
                'radiusofcircularshutter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiusOfCircularShutter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiusOfCircularShutter',
                ),
                'verticesofpolygonalshutter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerticesOfPolygonalShutter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerticesOfPolygonalShutter',
                ),
                'shutterpresentationvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShutterPresentationValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShutterPresentationValue',
                ),
                'shutteroverlaygroup' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShutterOverlayGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShutterOverlayGroup',
                ),
                'shutterpresentationcolorcielabval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShutterPresentationColorCIELabVal',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShutterPresentationColorCIELabVal',
                ),
                'collimatorshape' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollimatorShape',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollimatorShape',
                ),
                'collimatorleftverticaledge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollimatorLeftVerticalEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollimatorLeftVerticalEdge',
                ),
                'collimatorrightverticaledge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollimatorRightVerticalEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollimatorRightVerticalEdge',
                ),
                'collimatorupperhorizontaledge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollimatorUpperHorizontalEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollimatorUpperHorizontalEdge',
                ),
                'collimatorlowerhorizontaledge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollimatorLowerHorizontalEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollimatorLowerHorizontalEdge',
                ),
                'centerofcircularcollimator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterOfCircularCollimator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterOfCircularCollimator',
                ),
                'radiusofcircularcollimator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiusOfCircularCollimator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiusOfCircularCollimator',
                ),
                'verticesofpolygonalcollimator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerticesOfPolygonalCollimator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerticesOfPolygonalCollimator',
                ),
                'acquisitiontimesynchronized' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionTimeSynchronized',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionTimeSynchronized',
                ),
                'timesource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeSource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeSource',
                ),
                'timedistributionprotocol' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeDistributionProtocol',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeDistributionProtocol',
                ),
                'ntpsourceaddress' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NTPSourceAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NTPSourceAddress',
                ),
                'pagenumbervector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PageNumberVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PageNumberVector',
                ),
                'framelabelvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameLabelVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameLabelVector',
                ),
                'frameprimaryanglevector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FramePrimaryAngleVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FramePrimaryAngleVector',
                ),
                'framesecondaryanglevector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameSecondaryAngleVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameSecondaryAngleVector',
                ),
                'slicelocationvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SliceLocationVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SliceLocationVector',
                ),
                'displaywindowlabelvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayWindowLabelVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayWindowLabelVector',
                ),
                'nominalscannedpixelspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalScannedPixelSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalScannedPixelSpacing',
                ),
                'digitizingdevicetransportdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DigitizingDeviceTransportDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DigitizingDeviceTransportDirection',
                ),
                'rotationofscannedfilm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RotationOfScannedFilm',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RotationOfScannedFilm',
                ),
                'ivusacquisition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IVUSAcquisition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IVUSAcquisition',
                ),
                'ivuspullbackrate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IVUSPullbackRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IVUSPullbackRate',
                ),
                'ivusgatedrate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IVUSGatedRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IVUSGatedRate',
                ),
                'ivuspullbackstartframenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IVUSPullbackStartFrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IVUSPullbackStartFrameNumber',
                ),
                'ivuspullbackstopframenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IVUSPullbackStopFrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IVUSPullbackStopFrameNumber',
                ),
                'lesionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LesionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LesionNumber',
                ),
                'acquisitioncomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionComments',
                ),
                'outputpower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OutputPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OutputPower',
                ),
                'transducerdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerData',
                ),
                'focusdepth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FocusDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FocusDepth',
                ),
                'processingfunction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProcessingFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProcessingFunction',
                ),
                'postprocessingfunction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PostprocessingFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PostprocessingFunction',
                ),
                'mechanicalindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MechanicalIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MechanicalIndex',
                ),
                'bonethermalindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BoneThermalIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BoneThermalIndex',
                ),
                'cranialthermalindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CranialThermalIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CranialThermalIndex',
                ),
                'softtissuethermalindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SoftTissueThermalIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SoftTissueThermalIndex',
                ),
                'softtissuefocusthermalindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SoftTissueFocusThermalIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SoftTissueFocusThermalIndex',
                ),
                'softtissuesurfacethermalindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SoftTissueSurfaceThermalIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SoftTissueSurfaceThermalIndex',
                ),
                'dynamicrange' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DynamicRange',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DynamicRange',
                ),
                'totalgain' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalGain',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalGain',
                ),
                'depthofscanfield' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DepthOfScanField',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DepthOfScanField',
                ),
                'patientposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientPosition',
                ),
                'viewposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewPosition',
                ),
                'projectioneponymousnamecodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProjectionEponymousNameCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProjectionEponymousNameCodeSeq',
                ),
                'imagetransformationmatrix' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageTransformationMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageTransformationMatrix',
                ),
                'imagetranslationvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageTranslationVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageTranslationVector',
                ),
                'sensitivity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Sensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Sensitivity',
                ),
                'sequenceofultrasoundregions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SequenceOfUltrasoundRegions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SequenceOfUltrasoundRegions',
                ),
                'regionspatialformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionSpatialFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionSpatialFormat',
                ),
                'regiondatatype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionDataType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionDataType',
                ),
                'regionflags' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionFlags',
                ),
                'regionlocationminx0' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionLocationMinX0',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionLocationMinX0',
                ),
                'regionlocationminy0' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionLocationMinY0',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionLocationMinY0',
                ),
                'regionlocationmaxx1' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionLocationMaxX1',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionLocationMaxX1',
                ),
                'regionlocationmaxy1' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionLocationMaxY1',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionLocationMaxY1',
                ),
                'referencepixelx0' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencePixelX0',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencePixelX0',
                ),
                'referencepixely0' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencePixelY0',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencePixelY0',
                ),
                'physicalunitsxdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysicalUnitsXDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysicalUnitsXDirection',
                ),
                'physicalunitsydirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysicalUnitsYDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysicalUnitsYDirection',
                ),
                'referencepixelphysicalvaluex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencePixelPhysicalValueX',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencePixelPhysicalValueX',
                ),
                'referencepixelphysicalvaluey' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencePixelPhysicalValueY',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencePixelPhysicalValueY',
                ),
                'physicaldeltax' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysicalDeltaX',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysicalDeltaX',
                ),
                'physicaldeltay' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysicalDeltaY',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysicalDeltaY',
                ),
                'transducerfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerFrequency',
                ),
                'transducertype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransducerType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransducerType',
                ),
                'pulserepetitionfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PulseRepetitionFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PulseRepetitionFrequency',
                ),
                'dopplercorrectionangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DopplerCorrectionAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DopplerCorrectionAngle',
                ),
                'steeringangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SteeringAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SteeringAngle',
                ),
                'dopplersamplevolumexposretired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DopplerSampleVolumeXPosRetired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DopplerSampleVolumeXPosRetired',
                ),
                'dopplersamplevolumexposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DopplerSampleVolumeXPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DopplerSampleVolumeXPosition',
                ),
                'dopplersamplevolumeyposretired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DopplerSampleVolumeYPosRetired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DopplerSampleVolumeYPosRetired',
                ),
                'dopplersamplevolumeyposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DopplerSampleVolumeYPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DopplerSampleVolumeYPosition',
                ),
                'tmlinepositionx0retired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TMLinePositionX0Retired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TMLinePositionX0Retired',
                ),
                'tmlinepositionx0' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TMLinePositionX0',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TMLinePositionX0',
                ),
                'tmlinepositiony0retired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TMLinePositionY0Retired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TMLinePositionY0Retired',
                ),
                'tmlinepositiony0' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TMLinePositionY0',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TMLinePositionY0',
                ),
                'tmlinepositionx1retired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TMLinePositionX1Retired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TMLinePositionX1Retired',
                ),
                'tmlinepositionx1' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TMLinePositionX1',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TMLinePositionX1',
                ),
                'tmlinepositiony1retired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TMLinePositionY1Retired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TMLinePositionY1Retired',
                ),
                'tmlinepositiony1' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TMLinePositionY1',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TMLinePositionY1',
                ),
                'pixelcomponentorganization' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelComponentOrganization',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelComponentOrganization',
                ),
                'pixelcomponentmask' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelComponentMask',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelComponentMask',
                ),
                'pixelcomponentrangestart' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelComponentRangeStart',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelComponentRangeStart',
                ),
                'pixelcomponentrangestop' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelComponentRangeStop',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelComponentRangeStop',
                ),
                'pixelcomponentphysicalunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelComponentPhysicalUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelComponentPhysicalUnits',
                ),
                'pixelcomponentdatatype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelComponentDataType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelComponentDataType',
                ),
                'numberoftablebreakpoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTableBreakPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTableBreakPoints',
                ),
                'tableofxbreakpoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableOfXBreakPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableOfXBreakPoints',
                ),
                'tableofybreakpoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableOfYBreakPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableOfYBreakPoints',
                ),
                'numberoftableentries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTableEntries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTableEntries',
                ),
                'tableofpixelvalues' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableOfPixelValues',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableOfPixelValues',
                ),
                'tableofparametervalues' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableOfParameterValues',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableOfParameterValues',
                ),
                'rwavetimevector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RWaveTimeVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RWaveTimeVector',
                ),
                'detectorconditionsnominalflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorConditionsNominalFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorConditionsNominalFlag',
                ),
                'detectortemperature' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorTemperature',
                ),
                'detectortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorType',
                ),
                'detectorconfiguration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorConfiguration',
                ),
                'detectordescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorDescription',
                ),
                'detectormode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorMode',
                ),
                'detectorid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorID',
                ),
                'dateoflastdetectorcalibration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DateOfLastDetectorCalibration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DateOfLastDetectorCalibration',
                ),
                'timeoflastdetectorcalibration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeOfLastDetectorCalibration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeOfLastDetectorCalibration',
                ),
                'detectorexposuressincecalibration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorExposuresSinceCalibration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorExposuresSinceCalibration',
                ),
                'detectorexposuressincemanufactured' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorExposuresSinceManufactured',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorExposuresSinceManufactured',
                ),
                'detectortimesincelastexposure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorTimeSinceLastExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorTimeSinceLastExposure',
                ),
                'detectoractivetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorActiveTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorActiveTime',
                ),
                'detectoractiveoffsetfromexposure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorActiveOffsetFromExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorActiveOffsetFromExposure',
                ),
                'detectorbinning' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorBinning',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorBinning',
                ),
                'detectorelementphysicalsize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorElementPhysicalSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorElementPhysicalSize',
                ),
                'detectorelementspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorElementSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorElementSpacing',
                ),
                'detectoractiveshape' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorActiveShape',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorActiveShape',
                ),
                'detectoractivedimensions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorActiveDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorActiveDimensions',
                ),
                'detectoractiveorigin' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorActiveOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorActiveOrigin',
                ),
                'detectormanufacturername' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorManufacturerName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorManufacturerName',
                ),
                'detectormanufacturersmodelname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorManufacturersModelName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorManufacturersModelName',
                ),
                'fieldofvieworigin' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewOrigin',
                ),
                'fieldofviewrotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewRotation',
                ),
                'fieldofviewhorizontalflip' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewHorizontalFlip',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewHorizontalFlip',
                ),
                'gridabsorbingmaterial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridAbsorbingMaterial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridAbsorbingMaterial',
                ),
                'gridspacingmaterial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridSpacingMaterial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridSpacingMaterial',
                ),
                'gridthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridThickness',
                ),
                'gridpitch' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridPitch',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridPitch',
                ),
                'gridaspectratio' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridAspectRatio',
                ),
                'gridperiod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridPeriod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridPeriod',
                ),
                'gridfocaldistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridFocalDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridFocalDistance',
                ),
                'filtermaterial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterMaterial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterMaterial',
                ),
                'filterthicknessminimum' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterThicknessMinimum',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterThicknessMinimum',
                ),
                'filterthicknessmaximum' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterThicknessMaximum',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterThicknessMaximum',
                ),
                'exposurecontrolmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureControlMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureControlMode',
                ),
                'exposurecontrolmodedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureControlModeDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureControlModeDescription',
                ),
                'exposurestatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureStatus',
                ),
                'phototimersetting' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhototimerSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhototimerSetting',
                ),
                'exposuretimeinmicrosec' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureTimeInMicroSec',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureTimeInMicroSec',
                ),
                'xraytubecurrentinmicroamps' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayTubeCurrentInMicroAmps',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayTubeCurrentInMicroAmps',
                ),
                'contentqualification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentQualification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentQualification',
                ),
                'pulsesequencename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PulseSequenceName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PulseSequenceName',
                ),
                'mrimagingmodifiersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRImagingModifierSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRImagingModifierSequence',
                ),
                'echopulsesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EchoPulseSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EchoPulseSequence',
                ),
                'inversionrecovery' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InversionRecovery',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InversionRecovery',
                ),
                'flowcompensation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FlowCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FlowCompensation',
                ),
                'multiplespinecho' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultipleSpinEcho',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultipleSpinEcho',
                ),
                'multiplanarexcitation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultiPlanarExcitation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultiPlanarExcitation',
                ),
                'phasecontrast' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhaseContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhaseContrast',
                ),
                'timeofflightcontrast' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeOfFlightContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeOfFlightContrast',
                ),
                'spoiling' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Spoiling',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Spoiling',
                ),
                'steadystatepulsesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SteadyStatePulseSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SteadyStatePulseSequence',
                ),
                'echoplanarpulsesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EchoPlanarPulseSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EchoPlanarPulseSequence',
                ),
                'taganglefirstaxis' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TagAngleFirstAxis',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TagAngleFirstAxis',
                ),
                'magnetizationtransfer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MagnetizationTransfer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MagnetizationTransfer',
                ),
                't2preparation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'T2Preparation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\T2Preparation',
                ),
                'bloodsignalnulling' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BloodSignalNulling',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BloodSignalNulling',
                ),
                'saturationrecovery' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SaturationRecovery',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SaturationRecovery',
                ),
                'spectrallyselectedsuppression' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpectrallySelectedSuppression',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpectrallySelectedSuppression',
                ),
                'spectrallyselectedexcitation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpectrallySelectedExcitation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpectrallySelectedExcitation',
                ),
                'spatialpresaturation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpatialPresaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpatialPresaturation',
                ),
                'tagging' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Tagging',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Tagging',
                ),
                'oversamplingphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OversamplingPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OversamplingPhase',
                ),
                'tagspacingfirstdimension' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TagSpacingFirstDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TagSpacingFirstDimension',
                ),
                'geometryofkspacetraversal' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeometryOfKSpaceTraversal',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeometryOfKSpaceTraversal',
                ),
                'segmentedkspacetraversal' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentedKSpaceTraversal',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentedKSpaceTraversal',
                ),
                'rectilinearphaseencodereordering' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RectilinearPhaseEncodeReordering',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RectilinearPhaseEncodeReordering',
                ),
                'tagthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TagThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TagThickness',
                ),
                'partialfourierdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PartialFourierDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PartialFourierDirection',
                ),
                'cardiacsynchronizationtechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacSynchronizationTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacSynchronizationTechnique',
                ),
                'receivecoilmanufacturername' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReceiveCoilManufacturerName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReceiveCoilManufacturerName',
                ),
                'mrreceivecoilsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRReceiveCoilSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRReceiveCoilSequence',
                ),
                'receivecoiltype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReceiveCoilType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReceiveCoilType',
                ),
                'quadraturereceivecoil' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'QuadratureReceiveCoil',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\QuadratureReceiveCoil',
                ),
                'multicoildefinitionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultiCoilDefinitionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultiCoilDefinitionSequence',
                ),
                'multicoilconfiguration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultiCoilConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultiCoilConfiguration',
                ),
                'multicoilelementname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultiCoilElementName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultiCoilElementName',
                ),
                'multicoilelementused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultiCoilElementUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultiCoilElementUsed',
                ),
                'mrtransmitcoilsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRTransmitCoilSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRTransmitCoilSequence',
                ),
                'transmitcoilmanufacturername' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransmitCoilManufacturerName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransmitCoilManufacturerName',
                ),
                'transmitcoiltype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransmitCoilType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransmitCoilType',
                ),
                'spectralwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpectralWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpectralWidth',
                ),
                'chemicalshiftreference' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChemicalShiftReference',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChemicalShiftReference',
                ),
                'volumelocalizationtechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VolumeLocalizationTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VolumeLocalizationTechnique',
                ),
                'mracquisitionfrequencyencodesteps' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRAcquisitionFrequencyEncodeSteps',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRAcquisitionFrequencyEncodeSteps',
                ),
                'decoupling' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Decoupling',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Decoupling',
                ),
                'decouplednucleus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecoupledNucleus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecoupledNucleus',
                ),
                'decouplingfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecouplingFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecouplingFrequency',
                ),
                'decouplingmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecouplingMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecouplingMethod',
                ),
                'decouplingchemicalshiftreference' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecouplingChemicalShiftReference',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecouplingChemicalShiftReference',
                ),
                'kspacefiltering' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'KSpaceFiltering',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\KSpaceFiltering',
                ),
                'timedomainfiltering' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeDomainFiltering',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeDomainFiltering',
                ),
                'numberofzerofills' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfZeroFills',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfZeroFills',
                ),
                'baselinecorrection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BaselineCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BaselineCorrection',
                ),
                'parallelreductionfactorinplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParallelReductionFactorInPlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParallelReductionFactorInPlane',
                ),
                'cardiacrrintervalspecified' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacRRIntervalSpecified',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacRRIntervalSpecified',
                ),
                'acquisitionduration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionDuration',
                ),
                'frameacquisitiondatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameAcquisitionDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameAcquisitionDateTime',
                ),
                'diffusiondirectionality' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionDirectionality',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionDirectionality',
                ),
                'diffusiongradientdirectionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionGradientDirectionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionGradientDirectionSequence',
                ),
                'parallelacquisition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParallelAcquisition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParallelAcquisition',
                ),
                'parallelacquisitiontechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParallelAcquisitionTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParallelAcquisitionTechnique',
                ),
                'inversiontimes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InversionTimes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InversionTimes',
                ),
                'metabolitemapdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MetaboliteMapDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MetaboliteMapDescription',
                ),
                'partialfourier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PartialFourier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PartialFourier',
                ),
                'effectiveechotime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EffectiveEchoTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EffectiveEchoTime',
                ),
                'metabolitemapcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MetaboliteMapCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MetaboliteMapCodeSequence',
                ),
                'chemicalshiftsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChemicalShiftSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChemicalShiftSequence',
                ),
                'cardiacsignalsource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacSignalSource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacSignalSource',
                ),
                'diffusionbvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionBValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionBValue',
                ),
                'diffusiongradientorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionGradientOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionGradientOrientation',
                ),
                'velocityencodingdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VelocityEncodingDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VelocityEncodingDirection',
                ),
                'velocityencodingminimumvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VelocityEncodingMinimumValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VelocityEncodingMinimumValue',
                ),
                'numberofkspacetrajectories' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfKSpaceTrajectories',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfKSpaceTrajectories',
                ),
                'coverageofkspace' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CoverageOfKSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CoverageOfKSpace',
                ),
                'spectroscopyacquisitionphaserows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpectroscopyAcquisitionPhaseRows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpectroscopyAcquisitionPhaseRows',
                ),
                'parallelreductfactorinplaneretired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParallelReductFactorInPlaneRetired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParallelReductFactorInPlaneRetired',
                ),
                'transmitterfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransmitterFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransmitterFrequency',
                ),
                'resonantnucleus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResonantNucleus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResonantNucleus',
                ),
                'frequencycorrection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrequencyCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrequencyCorrection',
                ),
                'mrspectroscopyfov-geometrysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRSpectroscopyFOV-GeometrySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRSpectroscopyFOVGeometrySequence',
                ),
                'slabthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SlabThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SlabThickness',
                ),
                'slaborientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SlabOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SlabOrientation',
                ),
                'midslabposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MidSlabPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MidSlabPosition',
                ),
                'mrspatialsaturationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRSpatialSaturationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRSpatialSaturationSequence',
                ),
                'mrtimingandrelatedparametersseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRTimingAndRelatedParametersSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRTimingAndRelatedParametersSeq',
                ),
                'mrechosequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MREchoSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MREchoSequence',
                ),
                'mrmodifiersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRModifierSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRModifierSequence',
                ),
                'mrdiffusionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRDiffusionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRDiffusionSequence',
                ),
                'cardiactriggersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacTriggerSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacTriggerSequence',
                ),
                'mraveragessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRAveragesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRAveragesSequence',
                ),
                'mrfov-geometrysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRFOV-GeometrySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRFOVGeometrySequence',
                ),
                'volumelocalizationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VolumeLocalizationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VolumeLocalizationSequence',
                ),
                'spectroscopyacquisitiondatacolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpectroscopyAcquisitionDataColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpectroscopyAcquisitionDataColumns',
                ),
                'diffusionanisotropytype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionAnisotropyType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionAnisotropyType',
                ),
                'framereferencedatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameReferenceDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameReferenceDateTime',
                ),
                'mrmetabolitemapsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRMetaboliteMapSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRMetaboliteMapSequence',
                ),
                'parallelreductionfactoroutofplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParallelReductionFactorOutOfPlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParallelReductionFactorOutOfPlane',
                ),
                'spectroscopyoutofplanephasesteps' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpectroscopyOutOfPlanePhaseSteps',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpectroscopyOutOfPlanePhaseSteps',
                ),
                'bulkmotionstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BulkMotionStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BulkMotionStatus',
                ),
                'parallelreductionfactsecondinplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParallelReductionFactSecondInPlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParallelReductionFactSecondInPlane',
                ),
                'cardiacbeatrejectiontechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacBeatRejectionTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacBeatRejectionTechnique',
                ),
                'respiratorymotioncomptechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratoryMotionCompTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratoryMotionCompTechnique',
                ),
                'respiratorysignalsource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratorySignalSource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratorySignalSource',
                ),
                'bulkmotioncompensationtechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BulkMotionCompensationTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BulkMotionCompensationTechnique',
                ),
                'bulkmotionsignalsource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BulkMotionSignalSource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BulkMotionSignalSource',
                ),
                'applicablesafetystandardagency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicableSafetyStandardAgency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicableSafetyStandardAgency',
                ),
                'applicablesafetystandarddescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicableSafetyStandardDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicableSafetyStandardDescr',
                ),
                'operatingmodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OperatingModeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OperatingModeSequence',
                ),
                'operatingmodetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OperatingModeType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OperatingModeType',
                ),
                'operatingmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OperatingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OperatingMode',
                ),
                'specificabsorptionratedefinition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecificAbsorptionRateDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecificAbsorptionRateDefinition',
                ),
                'gradientoutputtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GradientOutputType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GradientOutputType',
                ),
                'specificabsorptionratevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecificAbsorptionRateValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecificAbsorptionRateValue',
                ),
                'gradientoutput' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GradientOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GradientOutput',
                ),
                'flowcompensationdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FlowCompensationDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FlowCompensationDirection',
                ),
                'taggingdelay' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TaggingDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TaggingDelay',
                ),
                'respiratorymotioncomptechdescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratoryMotionCompTechDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratoryMotionCompTechDescr',
                ),
                'respiratorysignalsourceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratorySignalSourceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratorySignalSourceID',
                ),
                'chemicalshiftsminintegratelimithz' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChemicalShiftsMinIntegrateLimitHz',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChemicalShiftsMinIntegrateLimitHz',
                ),
                'chemicalshiftsmaxintegratelimithz' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChemicalShiftsMaxIntegrateLimitHz',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChemicalShiftsMaxIntegrateLimitHz',
                ),
                'mrvelocityencodingsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRVelocityEncodingSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRVelocityEncodingSequence',
                ),
                'firstorderphasecorrection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FirstOrderPhaseCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FirstOrderPhaseCorrection',
                ),
                'waterreferencedphasecorrection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaterReferencedPhaseCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaterReferencedPhaseCorrection',
                ),
                'mrspectroscopyacquisitiontype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRSpectroscopyAcquisitionType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRSpectroscopyAcquisitionType',
                ),
                'respiratorycycleposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratoryCyclePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratoryCyclePosition',
                ),
                'velocityencodingmaximumvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VelocityEncodingMaximumValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VelocityEncodingMaximumValue',
                ),
                'tagspacingseconddimension' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TagSpacingSecondDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TagSpacingSecondDimension',
                ),
                'taganglesecondaxis' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TagAngleSecondAxis',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TagAngleSecondAxis',
                ),
                'frameacquisitionduration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameAcquisitionDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameAcquisitionDuration',
                ),
                'mrimageframetypesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRImageFrameTypeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRImageFrameTypeSequence',
                ),
                'mrspectroscopyframetypesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRSpectroscopyFrameTypeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRSpectroscopyFrameTypeSequence',
                ),
                'mracqphaseencodingstepsinplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRAcqPhaseEncodingStepsInPlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRAcqPhaseEncodingStepsInPlane',
                ),
                'mracqphaseencodingstepsoutofplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MRAcqPhaseEncodingStepsOutOfPlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MRAcqPhaseEncodingStepsOutOfPlane',
                ),
                'spectroscopyacqphasecolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpectroscopyAcqPhaseColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpectroscopyAcqPhaseColumns',
                ),
                'cardiaccycleposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacCyclePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacCyclePosition',
                ),
                'specificabsorptionratesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecificAbsorptionRateSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecificAbsorptionRateSequence',
                ),
                'rfechotrainlength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RFEchoTrainLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RFEchoTrainLength',
                ),
                'gradientechotrainlength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GradientEchoTrainLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GradientEchoTrainLength',
                ),
                'chemicalshiftsminintegratelimitppm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChemicalShiftsMinIntegrateLimitPPM',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChemicalShiftsMinIntegrateLimitPPM',
                ),
                'chemicalshiftsmaxintegratelimitppm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChemicalShiftsMaxIntegrateLimitPPM',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChemicalShiftsMaxIntegrateLimitPPM',
                ),
                'ctacquisitiontypesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTAcquisitionTypeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTAcquisitionTypeSequence',
                ),
                'acquisitiontype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionType',
                ),
                'tubeangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TubeAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TubeAngle',
                ),
                'ctacquisitiondetailssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTAcquisitionDetailsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTAcquisitionDetailsSequence',
                ),
                'revolutiontime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RevolutionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RevolutionTime',
                ),
                'singlecollimationwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SingleCollimationWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SingleCollimationWidth',
                ),
                'totalcollimationwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalCollimationWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalCollimationWidth',
                ),
                'cttabledynamicssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTTableDynamicsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTTableDynamicsSequence',
                ),
                'tablespeed' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableSpeed',
                ),
                'tablefeedperrotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableFeedPerRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableFeedPerRotation',
                ),
                'spiralpitchfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpiralPitchFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpiralPitchFactor',
                ),
                'ctgeometrysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTGeometrySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTGeometrySequence',
                ),
                'datacollectioncenterpatient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataCollectionCenterPatient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataCollectionCenterPatient',
                ),
                'ctreconstructionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTReconstructionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTReconstructionSequence',
                ),
                'reconstructionalgorithm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionAlgorithm',
                ),
                'convolutionkernelgroup' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConvolutionKernelGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConvolutionKernelGroup',
                ),
                'reconstructionfieldofview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionFieldOfView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionFieldOfView',
                ),
                'reconstructiontargetcenterpatient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionTargetCenterPatient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionTargetCenterPatient',
                ),
                'reconstructionangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionAngle',
                ),
                'imagefilter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageFilter',
                ),
                'ctexposuresequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTExposureSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTExposureSequence',
                ),
                'reconstructionpixelspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionPixelSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionPixelSpacing',
                ),
                'exposuremodulationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureModulationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureModulationType',
                ),
                'estimateddosesaving' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EstimatedDoseSaving',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EstimatedDoseSaving',
                ),
                'ctxraydetailssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTXRayDetailsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTXRayDetailsSequence',
                ),
                'ctpositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTPositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTPositionSequence',
                ),
                'tableposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TablePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TablePosition',
                ),
                'exposuretimeinmillisec' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureTimeInMilliSec',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureTimeInMilliSec',
                ),
                'ctimageframetypesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTImageFrameTypeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTImageFrameTypeSequence',
                ),
                'xraytubecurrentinmilliamps' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayTubeCurrentInMilliAmps',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayTubeCurrentInMilliAmps',
                ),
                'exposureinmilliampsec' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureInMilliAmpSec',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureInMilliAmpSec',
                ),
                'constantvolumeflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConstantVolumeFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConstantVolumeFlag',
                ),
                'fluoroscopyflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FluoroscopyFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FluoroscopyFlag',
                ),
                'sourcetodatacollectioncenterdist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceToDataCollectionCenterDist',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceToDataCollectionCenterDist',
                ),
                'contrastbolusagentnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusAgentNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentNumber',
                ),
                'contrastbolusingredientcodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusIngredientCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusIngredientCodeSeq',
                ),
                'contrastadministrationprofileseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastAdministrationProfileSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastAdministrationProfileSeq',
                ),
                'contrastbolususagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusUsageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusUsageSequence',
                ),
                'contrastbolusagentadministered' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusAgentAdministered',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentAdministered',
                ),
                'contrastbolusagentdetected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusAgentDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentDetected',
                ),
                'contrastbolusagentphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusAgentPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusAgentPhase',
                ),
                'ctdivol' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTDIvol',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTDIvol',
                ),
                'ctdiphantomtypecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTDIPhantomTypeCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTDIPhantomTypeCodeSequence',
                ),
                'calciumscoringmassfactorpatient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalciumScoringMassFactorPatient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalciumScoringMassFactorPatient',
                ),
                'calciumscoringmassfactordevice' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalciumScoringMassFactorDevice',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalciumScoringMassFactorDevice',
                ),
                'energyweightingfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWeightingFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWeightingFactor',
                ),
                'ctadditionalxraysourcesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTAdditionalXRaySourceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTAdditionalXRaySourceSequence',
                ),
                'projectionpixelcalibrationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProjectionPixelCalibrationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProjectionPixelCalibrationSequence',
                ),
                'distancesourcetoisocenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistanceSourceToIsocenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistanceSourceToIsocenter',
                ),
                'distanceobjecttotabletop' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistanceObjectToTableTop',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistanceObjectToTableTop',
                ),
                'objectpixelspacingincenterofbeam' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ObjectPixelSpacingInCenterOfBeam',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ObjectPixelSpacingInCenterOfBeam',
                ),
                'positionerpositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerPositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerPositionSequence',
                ),
                'tablepositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TablePositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TablePositionSequence',
                ),
                'collimatorshapesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollimatorShapeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollimatorShapeSequence',
                ),
                'xa-xrfframecharacteristicssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XA-XRFFrameCharacteristicsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XAXRFFrameCharacteristicsSequence',
                ),
                'frameacquisitionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameAcquisitionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameAcquisitionSequence',
                ),
                'xrayreceptortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayReceptorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayReceptorType',
                ),
                'acquisitionprotocolname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionProtocolName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionProtocolName',
                ),
                'acquisitionprotocoldescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionProtocolDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionProtocolDescription',
                ),
                'contrastbolusingredientopaque' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastBolusIngredientOpaque',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastBolusIngredientOpaque',
                ),
                'distancereceptorplanetodethousing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistanceReceptorPlaneToDetHousing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistanceReceptorPlaneToDetHousing',
                ),
                'intensifieractiveshape' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntensifierActiveShape',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntensifierActiveShape',
                ),
                'intensifieractivedimensions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntensifierActiveDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntensifierActiveDimensions',
                ),
                'physicaldetectorsize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysicalDetectorSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysicalDetectorSize',
                ),
                'positionofisocenterprojection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionOfIsocenterProjection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionOfIsocenterProjection',
                ),
                'fieldofviewsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewSequence',
                ),
                'fieldofviewdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewDescription',
                ),
                'exposurecontrolsensingregionsseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureControlSensingRegionsSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureControlSensingRegionsSeq',
                ),
                'exposurecontrolsensingregionshape' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureControlSensingRegionShape',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureControlSensingRegionShape',
                ),
                'exposurecontrolsensregionleftedge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureControlSensRegionLeftEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureControlSensRegionLeftEdge',
                ),
                'exposurecontrolsensregionrightedge' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureControlSensRegionRightEdge',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureControlSensRegionRightEdge',
                ),
                'centerofcircexposcontrolsensregion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterOfCircExposControlSensRegion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterOfCircExposControlSensRegion',
                ),
                'radiusofcircexposcontrolsensregion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiusOfCircExposControlSensRegion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiusOfCircExposControlSensRegion',
                ),
                'columnangulationpatient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ColumnAngulationPatient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ColumnAngulationPatient',
                ),
                'beamangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamAngle',
                ),
                'framedetectorparameterssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameDetectorParametersSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameDetectorParametersSequence',
                ),
                'calculatedanatomythickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalculatedAnatomyThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalculatedAnatomyThickness',
                ),
                'calibrationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalibrationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalibrationSequence',
                ),
                'objectthicknesssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ObjectThicknessSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ObjectThicknessSequence',
                ),
                'planeidentification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlaneIdentification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlaneIdentification',
                ),
                'fieldofviewdimensionsinfloat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewDimensionsInFloat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewDimensionsInFloat',
                ),
                'isocenterreferencesystemsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterReferenceSystemSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterReferenceSystemSequence',
                ),
                'positionerisocenterprimaryangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerIsocenterPrimaryAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerIsocenterPrimaryAngle',
                ),
                'positionerisocentersecondaryangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerIsocenterSecondaryAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerIsocenterSecondaryAngle',
                ),
                'positionerisocenterdetrotangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionerIsocenterDetRotAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionerIsocenterDetRotAngle',
                ),
                'tablexpositiontoisocenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableXPositionToIsocenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableXPositionToIsocenter',
                ),
                'tableypositiontoisocenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableYPositionToIsocenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableYPositionToIsocenter',
                ),
                'tablezpositiontoisocenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableZPositionToIsocenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableZPositionToIsocenter',
                ),
                'tablehorizontalrotationangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableHorizontalRotationAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableHorizontalRotationAngle',
                ),
                'tableheadtiltangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableHeadTiltAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableHeadTiltAngle',
                ),
                'tablecradletiltangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableCradleTiltAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableCradleTiltAngle',
                ),
                'framedisplayshuttersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameDisplayShutterSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameDisplayShutterSequence',
                ),
                'acquiredimageareadoseproduct' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquiredImageAreaDoseProduct',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquiredImageAreaDoseProduct',
                ),
                'carmpositionertabletoprelationship' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CArmPositionerTabletopRelationship',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CArmPositionerTabletopRelationship',
                ),
                'xraygeometrysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayGeometrySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayGeometrySequence',
                ),
                'irradiationeventidsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IrradiationEventIDSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IrradiationEventIDSequence',
                ),
                'xray3dframetypesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRay3DFrameTypeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRay3DFrameTypeSequence',
                ),
                'contributingsourcessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContributingSourcesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContributingSourcesSequence',
                ),
                'xray3dacquisitionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRay3DAcquisitionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRay3DAcquisitionSequence',
                ),
                'primarypositionerscanarc' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimaryPositionerScanArc',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimaryPositionerScanArc',
                ),
                'secondarypositionerscanarc' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryPositionerScanArc',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryPositionerScanArc',
                ),
                'primarypositionerscanstartangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimaryPositionerScanStartAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimaryPositionerScanStartAngle',
                ),
                'secondarypositionerscanstartangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryPositionerScanStartAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryPositionerScanStartAngle',
                ),
                'primarypositionerincrement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimaryPositionerIncrement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimaryPositionerIncrement',
                ),
                'secondarypositionerincrement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryPositionerIncrement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryPositionerIncrement',
                ),
                'startacquisitiondatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartAcquisitionDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartAcquisitionDateTime',
                ),
                'endacquisitiondatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndAcquisitionDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndAcquisitionDateTime',
                ),
                'applicationname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationName',
                ),
                'applicationversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationVersion',
                ),
                'applicationmanufacturer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationManufacturer',
                ),
                'algorithmtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlgorithmType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlgorithmType',
                ),
                'algorithmdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlgorithmDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlgorithmDescription',
                ),
                'xray3dreconstructionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRay3DReconstructionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRay3DReconstructionSequence',
                ),
                'reconstructiondescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionDescription',
                ),
                'perprojectionacquisitionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerProjectionAcquisitionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerProjectionAcquisitionSequence',
                ),
                'diffusionbmatrixsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionBMatrixSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionBMatrixSequence',
                ),
                'diffusionbvaluexx' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionBValueXX',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionBValueXX',
                ),
                'diffusionbvaluexy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionBValueXY',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionBValueXY',
                ),
                'diffusionbvaluexz' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionBValueXZ',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionBValueXZ',
                ),
                'diffusionbvalueyy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionBValueYY',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionBValueYY',
                ),
                'diffusionbvalueyz' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionBValueYZ',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionBValueYZ',
                ),
                'diffusionbvaluezz' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiffusionBValueZZ',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiffusionBValueZZ',
                ),
                'decaycorrectiondatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecayCorrectionDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecayCorrectionDateTime',
                ),
                'startdensitythreshold' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartDensityThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartDensityThreshold',
                ),
                'terminationtimethreshold' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TerminationTimeThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TerminationTimeThreshold',
                ),
                'detectorgeometry' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorGeometry',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorGeometry',
                ),
                'axialdetectordimension' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AxialDetectorDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AxialDetectorDimension',
                ),
                'petpositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PETPositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PETPositionSequence',
                ),
                'numberofiterations' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfIterations',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfIterations',
                ),
                'numberofsubsets' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfSubsets',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfSubsets',
                ),
                'petframetypesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PETFrameTypeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PETFrameTypeSequence',
                ),
                'reconstructiontype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionType',
                ),
                'decaycorrected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecayCorrected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecayCorrected',
                ),
                'attenuationcorrected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AttenuationCorrected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AttenuationCorrected',
                ),
                'scattercorrected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScatterCorrected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScatterCorrected',
                ),
                'deadtimecorrected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeadTimeCorrected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeadTimeCorrected',
                ),
                'gantrymotioncorrected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryMotionCorrected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryMotionCorrected',
                ),
                'patientmotioncorrected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientMotionCorrected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientMotionCorrected',
                ),
                'randomscorrected' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RandomsCorrected',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RandomsCorrected',
                ),
                'sensitivitycalibrated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SensitivityCalibrated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SensitivityCalibrated',
                ),
                'depthsoffocus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DepthsOfFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DepthsOfFocus',
                ),
                'exclusionstartdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExclusionStartDatetime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExclusionStartDatetime',
                ),
                'exclusionduration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExclusionDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExclusionDuration',
                ),
                'imagedatatypesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageDataTypeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageDataTypeSequence',
                ),
                'datatype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataType',
                ),
                'aliaseddatatype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AliasedDataType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AliasedDataType',
                ),
                'contributingequipmentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContributingEquipmentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContributingEquipmentSequence',
                ),
                'contributiondatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContributionDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContributionDateTime',
                ),
                'contributiondescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContributionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContributionDescription',
                ),
                'numberofcellsiindetector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfCellsIInDetector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfCellsIInDetector',
                ),
                'cellnumberattheta' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CellNumberAtTheta',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CellNumberAtTheta',
                ),
                'cellspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CellSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CellSpacing',
                ),
                'horizframeofref' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HorizFrameOfRef',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HorizFrameOfRef',
                ),
                'seriescontrast' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesContrast',
                ),
                'lastpseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LastPseq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LastPseq',
                ),
                'startnumberforbaseline' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartNumberForBaseline',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartNumberForBaseline',
                ),
                'endnumberforbaseline' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndNumberForBaseline',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndNumberForBaseline',
                ),
                'startnumberforenhancedscans' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartNumberForEnhancedScans',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartNumberForEnhancedScans',
                ),
                'endnumberforenhancedscans' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndNumberForEnhancedScans',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndNumberForEnhancedScans',
                ),
                'seriesplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesPlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesPlane',
                ),
                'firstscanras' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FirstScanRas',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FirstScanRas',
                ),
                'firstscanlocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FirstScanLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FirstScanLocation',
                ),
                'lastscanras' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LastScanRas',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LastScanRas',
                ),
                'lastscanloc' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LastScanLoc',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LastScanLoc',
                ),
                'displayfieldofview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayFieldOfView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayFieldOfView',
                ),
                'midscantime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MidScanTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MidScanTime',
                ),
                'midscanflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MidScanFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MidScanFlag',
                ),
                'degreesofazimuth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DegreesOfAzimuth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DegreesOfAzimuth',
                ),
                'gantryperiod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryPeriod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryPeriod',
                ),
                'xrayonposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayOnPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayOnPosition',
                ),
                'xrayoffposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayOffPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayOffPosition',
                ),
                'numberoftriggers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTriggers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTriggers',
                ),
                'angleoffirstview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AngleOfFirstView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AngleOfFirstView',
                ),
                'triggerfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerFrequency',
                ),
                'scanfovtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanFOVType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanFOVType',
                ),
                'statreconflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StatReconFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StatReconFlag',
                ),
                'computetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ComputeType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ComputeType',
                ),
                'segmentnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentNumber',
                ),
                'totalsegmentsrequested' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalSegmentsRequested',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalSegmentsRequested',
                ),
                'interscandelay' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterscanDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterscanDelay',
                ),
                'viewcompressionfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewCompressionFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewCompressionFactor',
                ),
                'totalnoofrefchannels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalNoOfRefChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalNoOfRefChannels',
                ),
                'datasizeforscandata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataSizeForScanData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataSizeForScanData',
                ),
                'reconpostprocflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconPostProcflag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconPostProcflag',
                ),
                'ctwaternumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTWaterNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTWaterNumber',
                ),
                'ctbonenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CTBoneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CTBoneNumber',
                ),
                'numberofchannels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfChannels',
                ),
                'incrementbetweenchannels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IncrementBetweenChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IncrementBetweenChannels',
                ),
                'startingview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingView',
                ),
                'numberofviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfViews',
                ),
                'incrementbetweenviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IncrementBetweenViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IncrementBetweenViews',
                ),
                'dependantonnoviewsprocessed' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DependantOnNoViewsProcessed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DependantOnNoViewsProcessed',
                ),
                'fieldofviewindetectorcells' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FieldOfViewInDetectorCells',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FieldOfViewInDetectorCells',
                ),
                'valueofbackprojectionbutton' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ValueOfBackProjectionButton',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ValueOfBackProjectionButton',
                ),
                'setiffatqestimateswereused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetIfFatqEstimatesWereUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetIfFatqEstimatesWereUsed',
                ),
                'zchanavgoverviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZChanAvgOverViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZChanAvgOverViews',
                ),
                'avgofleftrefchansoverviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AvgOfLeftRefChansOverViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AvgOfLeftRefChansOverViews',
                ),
                'maxleftchanoverviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaxLeftChanOverViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaxLeftChanOverViews',
                ),
                'avgofrightrefchansoverviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AvgOfRightRefChansOverViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AvgOfRightRefChansOverViews',
                ),
                'maxrightchanoverviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaxRightChanOverViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaxRightChanOverViews',
                ),
                'secondecho' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondEcho',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondEcho',
                ),
                'numberofechoes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfEchoes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfEchoes',
                ),
                'tabledelta' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableDelta',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableDelta',
                ),
                'contiguous' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Contiguous',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Contiguous',
                ),
                'peaksar' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PeakSAR',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PeakSAR',
                ),
                'monitorsar' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MonitorSAR',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MonitorSAR',
                ),
                'cardiacrepetitiontime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacRepetitionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacRepetitionTime',
                ),
                'imagespercardiaccycle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagesPerCardiacCycle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagesPerCardiacCycle',
                ),
                'actualreceivegainanalog' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActualReceiveGainAnalog',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActualReceiveGainAnalog',
                ),
                'actualreceivegaindigital' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActualReceiveGainDigital',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActualReceiveGainDigital',
                ),
                'delayaftertrigger' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DelayAfterTrigger',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DelayAfterTrigger',
                ),
                'swappf' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Swappf',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Swappf',
                ),
                'pauseinterval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PauseInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PauseInterval',
                ),
                'pulsetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PulseTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PulseTime',
                ),
                'sliceoffsetonfreqaxis' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SliceOffsetOnFreqAxis',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SliceOffsetOnFreqAxis',
                ),
                'centerfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterFrequency',
                ),
                'transmitgain' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransmitGain',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransmitGain',
                ),
                'analogreceivergain' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnalogReceiverGain',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnalogReceiverGain',
                ),
                'digitalreceivergain' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DigitalReceiverGain',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DigitalReceiverGain',
                ),
                'bitmapdefiningcvs' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BitmapDefiningCVs',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BitmapDefiningCVs',
                ),
                'centerfreqmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterFreqMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterFreqMethod',
                ),
                'pulseseqmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PulseSeqMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PulseSeqMode',
                ),
                'pulseseqname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PulseSeqName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PulseSeqName',
                ),
                'pulseseqdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PulseSeqDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PulseSeqDate',
                ),
                'internalpulseseqname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InternalPulseSeqName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InternalPulseSeqName',
                ),
                'transmittingcoil' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransmittingCoil',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransmittingCoil',
                ),
                'surfacecoiltype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceCoilType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceCoilType',
                ),
                'extremitycoilflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExtremityCoilFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExtremityCoilFlag',
                ),
                'rawdatarunnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RawDataRunNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RawDataRunNumber',
                ),
                'calibratedfieldstrength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalibratedFieldStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalibratedFieldStrength',
                ),
                'satfatwaterbone' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATFatWaterBone',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATFatWaterBone',
                ),
                'receivebandwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReceiveBandwidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReceiveBandwidth',
                ),
                'userdata01' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData01',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData01',
                ),
                'userdata02' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData02',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData02',
                ),
                'userdata03' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData03',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData03',
                ),
                'userdata04' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData04',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData04',
                ),
                'userdata05' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData05',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData05',
                ),
                'userdata06' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData06',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData06',
                ),
                'userdata07' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData07',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData07',
                ),
                'userdata08' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData08',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData08',
                ),
                'userdata09' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData09',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData09',
                ),
                'userdata10' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData10',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData10',
                ),
                'userdata11' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData11',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData11',
                ),
                'userdata12' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData12',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData12',
                ),
                'userdata13' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData13',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData13',
                ),
                'userdata14' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData14',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData14',
                ),
                'userdata15' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData15',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData15',
                ),
                'userdata16' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData16',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData16',
                ),
                'userdata17' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData17',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData17',
                ),
                'userdata18' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData18',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData18',
                ),
                'userdata19' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData19',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData19',
                ),
                'userdata20' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData20',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData20',
                ),
                'userdata21' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData21',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData21',
                ),
                'userdata22' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData22',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData22',
                ),
                'userdata23' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData23',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData23',
                ),
                'projectionangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProjectionAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProjectionAngle',
                ),
                'saturationplanes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SaturationPlanes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SaturationPlanes',
                ),
                'surfacecoilintensity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceCoilIntensity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceCoilIntensity',
                ),
                'satlocationr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATLocationR',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATLocationR',
                ),
                'satlocationl' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATLocationL',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATLocationL',
                ),
                'satlocationa' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATLocationA',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATLocationA',
                ),
                'satlocationp' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATLocationP',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATLocationP',
                ),
                'satlocationh' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATLocationH',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATLocationH',
                ),
                'satlocationf' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATLocationF',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATLocationF',
                ),
                'satthicknessr-l' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATThicknessR-L',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATThicknessRL',
                ),
                'satthicknessa-p' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATThicknessA-P',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATThicknessAP',
                ),
                'satthicknessh-f' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SATThicknessH-F',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SATThicknessHF',
                ),
                'prescribedflowaxis' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrescribedFlowAxis',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrescribedFlowAxis',
                ),
                'velocityencoding' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VelocityEncoding',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VelocityEncoding',
                ),
                'thicknessdisclaimer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ThicknessDisclaimer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ThicknessDisclaimer',
                ),
                'prescantype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrescanType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrescanType',
                ),
                'prescanstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrescanStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrescanStatus',
                ),
                'rawdatatype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RawDataType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RawDataType',
                ),
                'projectionalgorithm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProjectionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProjectionAlgorithm',
                ),
                'fractionalecho' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionalEcho',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionalEcho',
                ),
                'preppulse' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrepPulse',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrepPulse',
                ),
                'cardiacphases' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CardiacPhases',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CardiacPhases',
                ),
                'variableechoflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VariableEchoflag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VariableEchoflag',
                ),
                'concatenatedsat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConcatenatedSAT',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConcatenatedSAT',
                ),
                'referencechannelused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferenceChannelUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferenceChannelUsed',
                ),
                'backprojectorcoefficient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BackProjectorCoefficient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BackProjectorCoefficient',
                ),
                'primaryspeedcorrectionused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimarySpeedCorrectionUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimarySpeedCorrectionUsed',
                ),
                'overrangecorrectionused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverrangeCorrectionUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverrangeCorrectionUsed',
                ),
                'dynamiczalphavalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DynamicZAlphaValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DynamicZAlphaValue',
                ),
                'userdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserData',
                ),
                'velocityencodescale' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VelocityEncodeScale',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VelocityEncodeScale',
                ),
                'fastphases' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FastPhases',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FastPhases',
                ),
                'transmissiongain' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransmissionGain',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransmissionGain',
                ),
                'relationshipgrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelationshipGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelationshipGroupLength',
                ),
                'studyinstanceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyInstanceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyInstanceUID',
                ),
                'seriesinstanceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesInstanceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesInstanceUID',
                ),
                'studyid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyID',
                ),
                'seriesnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesNumber',
                ),
                'acquisitionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionNumber',
                ),
                'instancenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InstanceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InstanceNumber',
                ),
                'isotopenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsotopeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsotopeNumber',
                ),
                'phasenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhaseNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhaseNumber',
                ),
                'intervalnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntervalNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntervalNumber',
                ),
                'timeslotnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeSlotNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeSlotNumber',
                ),
                'anglenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AngleNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AngleNumber',
                ),
                'itemnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ItemNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ItemNumber',
                ),
                'patientorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientOrientation',
                ),
                'overlaynumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayNumber',
                ),
                'curvenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveNumber',
                ),
                'lookuptablenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LookupTableNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LookupTableNumber',
                ),
                'imageposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePosition',
                ),
                'imagepositionpatient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePositionPatient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePositionPatient',
                ),
                'imageorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageOrientation',
                ),
                'imageorientationpatient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageOrientationPatient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageOrientationPatient',
                ),
                'location' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Location',
                ),
                'frameofreferenceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameOfReferenceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceUID',
                ),
                'laterality' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Laterality',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Laterality',
                ),
                'imagelaterality' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageLaterality',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageLaterality',
                ),
                'imagegeometrytype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageGeometryType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageGeometryType',
                ),
                'maskingimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskingImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskingImage',
                ),
                'temporalpositionidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemporalPositionIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemporalPositionIdentifier',
                ),
                'numberoftemporalpositions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTemporalPositions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTemporalPositions',
                ),
                'temporalresolution' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemporalResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemporalResolution',
                ),
                'synchronizationframeofreferenceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SynchronizationFrameOfReferenceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SynchronizationFrameOfReferenceUID',
                ),
                'seriesinstudy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesInStudy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesInStudy',
                ),
                'acquisitionsinseries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionsInSeries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionsInSeries',
                ),
                'imagesinacquisition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagesInAcquisition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagesInAcquisition',
                ),
                'imagesinseries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagesInSeries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagesInSeries',
                ),
                'acquisitionsinstudy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionsInStudy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionsInStudy',
                ),
                'imagesinstudy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagesInStudy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagesInStudy',
                ),
                'reference' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Reference',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Reference',
                ),
                'positionreferenceindicator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PositionReferenceIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PositionReferenceIndicator',
                ),
                'slicelocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SliceLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SliceLocation',
                ),
                'otherstudynumbers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherStudyNumbers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherStudyNumbers',
                ),
                'numberofpatientrelatedstudies' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPatientRelatedStudies',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPatientRelatedStudies',
                ),
                'numberofpatientrelatedseries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPatientRelatedSeries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPatientRelatedSeries',
                ),
                'numberofpatientrelatedinstances' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPatientRelatedInstances',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPatientRelatedInstances',
                ),
                'numberofstudyrelatedseries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfStudyRelatedSeries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfStudyRelatedSeries',
                ),
                'numberofstudyrelatedinstances' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfStudyRelatedInstances',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfStudyRelatedInstances',
                ),
                'numberofseriesrelatedinstances' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfSeriesRelatedInstances',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfSeriesRelatedInstances',
                ),
                'sourceimageids' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceImageIDs',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceImageIDs',
                ),
                'modifyingdeviceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifyingDeviceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifyingDeviceID',
                ),
                'modifiedimageid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifiedImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifiedImageID',
                ),
                'modifiedimagedate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifiedImageDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifiedImageDate',
                ),
                'modifyingdevicemanufacturer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifyingDeviceManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifyingDeviceManufacturer',
                ),
                'modifiedimagetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifiedImageTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifiedImageTime',
                ),
                'modifiedimagedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifiedImageDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifiedImageDescription',
                ),
                'imagecomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageComments',
                ),
                'originalimageidentification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OriginalImageIdentification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OriginalImageIdentification',
                ),
                'originalimageidentnomenclature' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OriginalImageIdentNomenclature',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OriginalImageIdentNomenclature',
                ),
                'stackid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StackID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StackID',
                ),
                'instackpositionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InStackPositionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InStackPositionNumber',
                ),
                'frameanatomysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameAnatomySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameAnatomySequence',
                ),
                'framelaterality' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameLaterality',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameLaterality',
                ),
                'framecontentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameContentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameContentSequence',
                ),
                'planepositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlanePositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlanePositionSequence',
                ),
                'planeorientationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlaneOrientationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlaneOrientationSequence',
                ),
                'temporalpositionindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemporalPositionIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemporalPositionIndex',
                ),
                'triggerdelaytime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerDelayTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerDelayTime',
                ),
                'frameacquisitionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameAcquisitionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameAcquisitionNumber',
                ),
                'dimensionindexvalues' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DimensionIndexValues',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DimensionIndexValues',
                ),
                'framecomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameComments',
                ),
                'concatenationuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConcatenationUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConcatenationUID',
                ),
                'inconcatenationnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InConcatenationNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InConcatenationNumber',
                ),
                'inconcatenationtotalnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InConcatenationTotalNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InConcatenationTotalNumber',
                ),
                'dimensionorganizationuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DimensionOrganizationUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DimensionOrganizationUID',
                ),
                'dimensionindexpointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DimensionIndexPointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DimensionIndexPointer',
                ),
                'functionalgrouppointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FunctionalGroupPointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FunctionalGroupPointer',
                ),
                'dimensionindexprivatecreator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DimensionIndexPrivateCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DimensionIndexPrivateCreator',
                ),
                'dimensionorganizationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DimensionOrganizationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DimensionOrganizationSequence',
                ),
                'dimensionindexsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DimensionIndexSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DimensionIndexSequence',
                ),
                'concatenationframeoffsetnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConcatenationFrameOffsetNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConcatenationFrameOffsetNumber',
                ),
                'functionalgroupprivatecreator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FunctionalGroupPrivateCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FunctionalGroupPrivateCreator',
                ),
                'nominalpercentageofcardiacphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalPercentageOfCardiacPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalPercentageOfCardiacPhase',
                ),
                'nominalpercentofrespiratoryphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalPercentOfRespiratoryPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalPercentOfRespiratoryPhase',
                ),
                'startingrespiratoryamplitude' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingRespiratoryAmplitude',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingRespiratoryAmplitude',
                ),
                'startingrespiratoryphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingRespiratoryPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingRespiratoryPhase',
                ),
                'endingrespiratoryamplitude' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndingRespiratoryAmplitude',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndingRespiratoryAmplitude',
                ),
                'endingrespiratoryphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndingRespiratoryPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndingRespiratoryPhase',
                ),
                'respiratorytriggertype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratoryTriggerType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratoryTriggerType',
                ),
                'rrintervaltimenominal' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RRIntervalTimeNominal',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RRIntervalTimeNominal',
                ),
                'actualcardiactriggerdelaytime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActualCardiacTriggerDelayTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActualCardiacTriggerDelayTime',
                ),
                'respiratorysynchronizationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratorySynchronizationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratorySynchronizationSequence',
                ),
                'respiratoryintervaltime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratoryIntervalTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratoryIntervalTime',
                ),
                'nominalrespiratorytriggerdelaytime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalRespiratoryTriggerDelayTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalRespiratoryTriggerDelayTime',
                ),
                'respiratorytriggerdelaythreshold' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratoryTriggerDelayThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratoryTriggerDelayThreshold',
                ),
                'actualrespiratorytriggerdelaytime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActualRespiratoryTriggerDelayTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActualRespiratoryTriggerDelayTime',
                ),
                'imagepositionvolume' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePositionVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePositionVolume',
                ),
                'imageorientationvolume' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageOrientationVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageOrientationVolume',
                ),
                'apexposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApexPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApexPosition',
                ),
                'dimensiondescriptionlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DimensionDescriptionLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DimensionDescriptionLabel',
                ),
                'patientorientationinframesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientOrientationInFrameSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientOrientationInFrameSequence',
                ),
                'framelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameLabel',
                ),
                'acquisitionindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionIndex',
                ),
                'contributingsopinstancesrefseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContributingSOPInstancesRefSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContributingSOPInstancesRefSeq',
                ),
                'reconstructionindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionIndex',
                ),
                'seriesfromwhichprescribed' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesFromWhichPrescribed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesFromWhichPrescribed',
                ),
                'seriesrecordchecksum' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesRecordChecksum',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesRecordChecksum',
                ),
                'acqreconrecordchecksum' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcqreconRecordChecksum',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcqreconRecordChecksum',
                ),
                'tablestartlocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableStartLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableStartLocation',
                ),
                'imagefromwhichprescribed' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageFromWhichPrescribed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageFromWhichPrescribed',
                ),
                'screenformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScreenFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScreenFormat',
                ),
                'anatomicalreferenceforscout' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnatomicalReferenceForScout',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnatomicalReferenceForScout',
                ),
                'locationsinacquisition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LocationsInAcquisition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LocationsInAcquisition',
                ),
                'graphicallyprescribed' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicallyPrescribed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicallyPrescribed',
                ),
                'rotationfromsourcexrot' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RotationFromSourceXRot',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RotationFromSourceXRot',
                ),
                'rotationfromsourceyrot' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RotationFromSourceYRot',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RotationFromSourceYRot',
                ),
                'rotationfromsourcezrot' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RotationFromSourceZRot',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RotationFromSourceZRot',
                ),
                'integerslop' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntegerSlop',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntegerSlop',
                ),
                'floatslop' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FloatSlop',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FloatSlop',
                ),
                'autowindowlevelalpha' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AutoWindowLevelAlpha',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AutoWindowLevelAlpha',
                ),
                'autowindowlevelbeta' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AutoWindowLevelBeta',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AutoWindowLevelBeta',
                ),
                'autowindowlevelwindow' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AutoWindowLevelWindow',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AutoWindowLevelWindow',
                ),
                'towindowlevellevel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ToWindowLevelLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ToWindowLevelLevel',
                ),
                'tubefocalspotposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TubeFocalSpotPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TubeFocalSpotPosition',
                ),
                'biopsyposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BiopsyPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BiopsyPosition',
                ),
                'biopsytlocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BiopsyTLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BiopsyTLocation',
                ),
                'biopsyreflocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BiopsyRefLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BiopsyRefLocation',
                ),
                'lightpathfilterpassthroughwavelen' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LightPathFilterPassThroughWavelen',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LightPathFilterPassThroughWavelen',
                ),
                'lightpathfilterpassband' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LightPathFilterPassBand',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LightPathFilterPassBand',
                ),
                'imagepathfilterpassthroughwavelen' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePathFilterPassThroughWavelen',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePathFilterPassThroughWavelen',
                ),
                'imagepathfilterpassband' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePathFilterPassBand',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePathFilterPassBand',
                ),
                'patienteyemovementcommanded' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientEyeMovementCommanded',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientEyeMovementCommanded',
                ),
                'patienteyemovementcommandcodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientEyeMovementCommandCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientEyeMovementCommandCodeSeq',
                ),
                'sphericallenspower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SphericalLensPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SphericalLensPower',
                ),
                'cylinderlenspower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CylinderLensPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CylinderLensPower',
                ),
                'cylinderaxis' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CylinderAxis',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CylinderAxis',
                ),
                'emmetropicmagnification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EmmetropicMagnification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EmmetropicMagnification',
                ),
                'intraocularpressure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntraOcularPressure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntraOcularPressure',
                ),
                'horizontalfieldofview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HorizontalFieldOfView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HorizontalFieldOfView',
                ),
                'pupildilated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PupilDilated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PupilDilated',
                ),
                'degreeofdilation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DegreeOfDilation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DegreeOfDilation',
                ),
                'stereobaselineangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StereoBaselineAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StereoBaselineAngle',
                ),
                'stereobaselinedisplacement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StereoBaselineDisplacement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StereoBaselineDisplacement',
                ),
                'stereohorizontalpixeloffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StereoHorizontalPixelOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StereoHorizontalPixelOffset',
                ),
                'stereoverticalpixeloffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StereoVerticalPixelOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StereoVerticalPixelOffset',
                ),
                'stereorotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StereoRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StereoRotation',
                ),
                'acquisitiondevicetypecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionDeviceTypeCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionDeviceTypeCodeSequence',
                ),
                'illuminationtypecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IlluminationTypeCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IlluminationTypeCodeSequence',
                ),
                'lightpathfiltertypestackcodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LightPathFilterTypeStackCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LightPathFilterTypeStackCodeSeq',
                ),
                'imagepathfiltertypestackcodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePathFilterTypeStackCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePathFilterTypeStackCodeSeq',
                ),
                'lensescodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LensesCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LensesCodeSequence',
                ),
                'channeldescriptioncodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelDescriptionCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelDescriptionCodeSequence',
                ),
                'refractivestatesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RefractiveStateSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RefractiveStateSequence',
                ),
                'mydriaticagentcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MydriaticAgentCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MydriaticAgentCodeSequence',
                ),
                'relativeimagepositioncodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelativeImagePositionCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelativeImagePositionCodeSequence',
                ),
                'stereopairssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StereoPairsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StereoPairsSequence',
                ),
                'leftimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LeftImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LeftImageSequence',
                ),
                'rightimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RightImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RightImageSequence',
                ),
                'axiallengthoftheeye' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AxialLengthOfTheEye',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AxialLengthOfTheEye',
                ),
                'ophthalmicframelocationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OphthalmicFrameLocationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OphthalmicFrameLocationSequence',
                ),
                'referencecoordinates' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferenceCoordinates',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferenceCoordinates',
                ),
                'depthspatialresolution' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DepthSpatialResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DepthSpatialResolution',
                ),
                'maximumdepthdistortion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumDepthDistortion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumDepthDistortion',
                ),
                'alongscanspatialresolution' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlongScanSpatialResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlongScanSpatialResolution',
                ),
                'maximumalongscandistortion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumAlongScanDistortion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumAlongScanDistortion',
                ),
                'ophthalmicimageorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OphthalmicImageOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OphthalmicImageOrientation',
                ),
                'depthoftransverseimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DepthOfTransverseImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DepthOfTransverseImage',
                ),
                'mydriaticagentconcunitsseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MydriaticAgentConcUnitsSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MydriaticAgentConcUnitsSeq',
                ),
                'acrossscanspatialresolution' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcrossScanSpatialResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcrossScanSpatialResolution',
                ),
                'maximumacrossscandistortion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumAcrossScanDistortion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumAcrossScanDistortion',
                ),
                'mydriaticagentconcentration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MydriaticAgentConcentration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MydriaticAgentConcentration',
                ),
                'illuminationwavelength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IlluminationWaveLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IlluminationWaveLength',
                ),
                'illuminationpower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IlluminationPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IlluminationPower',
                ),
                'illuminationbandwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IlluminationBandwidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IlluminationBandwidth',
                ),
                'mydriaticagentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MydriaticAgentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MydriaticAgentSequence',
                ),
                'numberofseriesinstudy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfSeriesInStudy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfSeriesInStudy',
                ),
                'numberofunarchivedseries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfUnarchivedSeries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfUnarchivedSeries',
                ),
                'referenceimagefield' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferenceImageField',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferenceImageField',
                ),
                'summaryimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SummaryImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SummaryImage',
                ),
                'starttimesecsinfirstaxial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartTimeSecsInFirstAxial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartTimeSecsInFirstAxial',
                ),
                'noofupdatestoheader' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NoofUpdatesToHeader',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NoofUpdatesToHeader',
                ),
                'indicatesifthestudyhascompleteinfo' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IndicatesIfTheStudyHasCompleteInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IndicatesIfTheStudyHasCompleteInfo',
                ),
                'lastpulsesequenceused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LastPulseSequenceUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LastPulseSequenceUsed',
                ),
                'landmarkcounter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LandmarkCounter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LandmarkCounter',
                ),
                'numberofacquisitions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfAcquisitions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfAcquisitions',
                ),
                'indicatesnoofupdatestoheader' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IndicatesNoofUpdatesToHeader',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IndicatesNoofUpdatesToHeader',
                ),
                'seriescompleteflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesCompleteFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesCompleteFlag',
                ),
                'numberofimagesarchived' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfImagesArchived',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfImagesArchived',
                ),
                'lastimagenumberused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LastImageNumberUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LastImageNumberUsed',
                ),
                'primaryreceiversuiteandhost' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimaryReceiverSuiteAndHost',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimaryReceiverSuiteAndHost',
                ),
                'imagearchiveflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageArchiveFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageArchiveFlag',
                ),
                'scouttype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScoutType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScoutType',
                ),
                'vmamamp' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VmaMamp',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VmaMamp',
                ),
                'vmaphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VmaPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VmaPhase',
                ),
                'vmamod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VmaMod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VmaMod',
                ),
                'vmaclip' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VmaClip',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VmaClip',
                ),
                'smartscanonoffflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SmartScanOnOffFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SmartScanOnOffFlag',
                ),
                'foreignimagerevision' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ForeignImageRevision',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ForeignImageRevision',
                ),
                'imagingmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagingMode',
                ),
                'pulsesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PulseSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PulseSequence',
                ),
                'imagingoptions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagingOptions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagingOptions',
                ),
                'planetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlaneType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlaneType',
                ),
                'obliqueplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ObliquePlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ObliquePlane',
                ),
                'rasletterofimagelocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RASLetterOfImageLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RASLetterOfImageLocation',
                ),
                'imagelocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageLocation',
                ),
                'centerrcoordofplaneimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterRCoordOfPlaneImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterRCoordOfPlaneImage',
                ),
                'centeracoordofplaneimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterACoordOfPlaneImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterACoordOfPlaneImage',
                ),
                'centerscoordofplaneimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterSCoordOfPlaneImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterSCoordOfPlaneImage',
                ),
                'normalrcoord' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NormalRCoord',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NormalRCoord',
                ),
                'normalacoord' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NormalACoord',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NormalACoord',
                ),
                'normalscoord' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NormalSCoord',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NormalSCoord',
                ),
                'rcoordoftoprightcorner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RCoordOfTopRightCorner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RCoordOfTopRightCorner',
                ),
                'acoordoftoprightcorner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ACoordOfTopRightCorner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ACoordOfTopRightCorner',
                ),
                'scoordoftoprightcorner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SCoordOfTopRightCorner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SCoordOfTopRightCorner',
                ),
                'rcoordofbottomrightcorner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RCoordOfBottomRightCorner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RCoordOfBottomRightCorner',
                ),
                'acoordofbottomrightcorner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ACoordOfBottomRightCorner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ACoordOfBottomRightCorner',
                ),
                'scoordofbottomrightcorner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SCoordOfBottomRightCorner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SCoordOfBottomRightCorner',
                ),
                'tableendlocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableEndLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableEndLocation',
                ),
                'rasletterforsideofimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RASLetterForSideOfImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RASLetterForSideOfImage',
                ),
                'rasletterforanteriorposterior' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RASLetterForAnteriorPosterior',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RASLetterForAnteriorPosterior',
                ),
                'rasletterforscoutstartloc' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RASLetterForScoutStartLoc',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RASLetterForScoutStartLoc',
                ),
                'rasletterforscoutendloc' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RASLetterForScoutEndLoc',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RASLetterForScoutEndLoc',
                ),
                'imagedimensionx' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageDimensionX',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageDimensionX',
                ),
                'imagedimensiony' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageDimensionY',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageDimensionY',
                ),
                'numberofexcitations' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfExcitations',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfExcitations',
                ),
                'imagepresentationgrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePresentationGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePresentationGroupLength',
                ),
                'samplesperpixel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SamplesPerPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SamplesPerPixel',
                ),
                'samplesperpixelused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SamplesPerPixelUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SamplesPerPixelUsed',
                ),
                'photometricinterpretation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhotometricInterpretation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhotometricInterpretation',
                ),
                'imagedimensions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageDimensions',
                ),
                'planarconfiguration' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlanarConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlanarConfiguration',
                ),
                'numberofframes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfFrames',
                ),
                'frameincrementpointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameIncrementPointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameIncrementPointer',
                ),
                'framedimensionpointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameDimensionPointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameDimensionPointer',
                ),
                'rows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Rows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Rows',
                ),
                'columns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Columns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Columns',
                ),
                'planes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Planes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Planes',
                ),
                'ultrasoundcolordatapresent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UltrasoundColorDataPresent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UltrasoundColorDataPresent',
                ),
                'pixelspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelSpacing',
                ),
                'zoomfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZoomFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZoomFactor',
                ),
                'zoomcenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZoomCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZoomCenter',
                ),
                'pixelaspectratio' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelAspectRatio',
                ),
                'imageformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageFormat',
                ),
                'manipulatedimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ManipulatedImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ManipulatedImage',
                ),
                'correctedimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CorrectedImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CorrectedImage',
                ),
                'compressionrecognitioncode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompressionRecognitionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompressionRecognitionCode',
                ),
                'compressioncode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompressionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompressionCode',
                ),
                'compressionoriginator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompressionOriginator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompressionOriginator',
                ),
                'compressionlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompressionLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompressionLabel',
                ),
                'compressiondescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompressionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompressionDescription',
                ),
                'compressionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompressionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompressionSequence',
                ),
                'compressionsteppointers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompressionStepPointers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompressionStepPointers',
                ),
                'repeatinterval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RepeatInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RepeatInterval',
                ),
                'bitsgrouped' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BitsGrouped',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BitsGrouped',
                ),
                'perimetertable' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerimeterTable',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerimeterTable',
                ),
                'perimetervalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerimeterValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerimeterValue',
                ),
                'predictorrows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PredictorRows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PredictorRows',
                ),
                'predictorcolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PredictorColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PredictorColumns',
                ),
                'predictorconstants' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PredictorConstants',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PredictorConstants',
                ),
                'blockedpixels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockedPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockedPixels',
                ),
                'blockrows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockRows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockRows',
                ),
                'blockcolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockColumns',
                ),
                'rowoverlap' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RowOverlap',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RowOverlap',
                ),
                'columnoverlap' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ColumnOverlap',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ColumnOverlap',
                ),
                'bitsallocated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BitsAllocated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BitsAllocated',
                ),
                'bitsstored' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BitsStored',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BitsStored',
                ),
                'highbit' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HighBit',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HighBit',
                ),
                'pixelrepresentation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelRepresentation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelRepresentation',
                ),
                'smallestvalidpixelvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SmallestValidPixelValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SmallestValidPixelValue',
                ),
                'largestvalidpixelvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargestValidPixelValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargestValidPixelValue',
                ),
                'smallestimagepixelvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SmallestImagePixelValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SmallestImagePixelValue',
                ),
                'largestimagepixelvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargestImagePixelValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargestImagePixelValue',
                ),
                'smallestpixelvalueinseries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SmallestPixelValueInSeries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SmallestPixelValueInSeries',
                ),
                'largestpixelvalueinseries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargestPixelValueInSeries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargestPixelValueInSeries',
                ),
                'smallestimagepixelvalueinplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SmallestImagePixelValueInPlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SmallestImagePixelValueInPlane',
                ),
                'largestimagepixelvalueinplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargestImagePixelValueInPlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargestImagePixelValueInPlane',
                ),
                'pixelpaddingvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelPaddingValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelPaddingValue',
                ),
                'pixelpaddingrangelimit' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelPaddingRangeLimit',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelPaddingRangeLimit',
                ),
                'qualitycontrolimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'QualityControlImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\QualityControlImage',
                ),
                'burnedinannotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BurnedInAnnotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BurnedInAnnotation',
                ),
                'transformlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransformLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransformLabel',
                ),
                'transformversionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransformVersionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransformVersionNumber',
                ),
                'numberoftransformsteps' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTransformSteps',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTransformSteps',
                ),
                'sequenceofcompresseddata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SequenceOfCompressedData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SequenceOfCompressedData',
                ),
                'detailsofcoefficients' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetailsOfCoefficients',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetailsOfCoefficients',
                ),
                'coefficientcoding' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CoefficientCoding',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CoefficientCoding',
                ),
                'coefficientcodingpointers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CoefficientCodingPointers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CoefficientCodingPointers',
                ),
                'dctlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DCTLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DCTLabel',
                ),
                'datablockdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataBlockDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataBlockDescription',
                ),
                'datablock' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataBlock',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataBlock',
                ),
                'normalizationfactorformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NormalizationFactorFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NormalizationFactorFormat',
                ),
                'zonalmapnumberformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZonalMapNumberFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZonalMapNumberFormat',
                ),
                'zonalmaplocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZonalMapLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZonalMapLocation',
                ),
                'zonalmapformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZonalMapFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZonalMapFormat',
                ),
                'adaptivemapformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdaptiveMapFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdaptiveMapFormat',
                ),
                'codenumberformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodeNumberFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodeNumberFormat',
                ),
                'codelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodeLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodeLabel',
                ),
                'numberoftables' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTables',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTables',
                ),
                'codetablelocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CodeTableLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CodeTableLocation',
                ),
                'bitsforcodeword' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BitsForCodeWord',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BitsForCodeWord',
                ),
                'imagedatalocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageDataLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageDataLocation',
                ),
                'pixelspacingcalibrationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelSpacingCalibrationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelSpacingCalibrationType',
                ),
                'pixelspacingcalibrationdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelSpacingCalibrationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelSpacingCalibrationDescription',
                ),
                'pixelintensityrelationship' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelIntensityRelationship',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelIntensityRelationship',
                ),
                'pixelintensityrelationshipsign' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelIntensityRelationshipSign',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelIntensityRelationshipSign',
                ),
                'windowcenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WindowCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WindowCenter',
                ),
                'windowwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WindowWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WindowWidth',
                ),
                'rescaleintercept' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RescaleIntercept',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RescaleIntercept',
                ),
                'rescaleslope' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RescaleSlope',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RescaleSlope',
                ),
                'rescaletype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RescaleType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RescaleType',
                ),
                'windowcenterandwidthexplanation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WindowCenterAndWidthExplanation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WindowCenterAndWidthExplanation',
                ),
                'voi_lutfunction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VOI_LUTFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VOILUTFunction',
                ),
                'grayscale' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GrayScale',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GrayScale',
                ),
                'recommendedviewingmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecommendedViewingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecommendedViewingMode',
                ),
                'graylookuptabledescriptor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GrayLookupTableDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GrayLookupTableDescriptor',
                ),
                'redpalettecolortabledescriptor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RedPaletteColorTableDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RedPaletteColorTableDescriptor',
                ),
                'greenpalettecolortabledescriptor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GreenPaletteColorTableDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GreenPaletteColorTableDescriptor',
                ),
                'bluepalettecolortabledescriptor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BluePaletteColorTableDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BluePaletteColorTableDescriptor',
                ),
                'largeredpalettecolortabledescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargeRedPaletteColorTableDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargeRedPaletteColorTableDescr',
                ),
                'largegreenpalettecolortabledescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargeGreenPaletteColorTableDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargeGreenPaletteColorTableDescr',
                ),
                'largebluepalettecolortabledescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargeBluePaletteColorTableDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargeBluePaletteColorTableDescr',
                ),
                'palettecolortableuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PaletteColorTableUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PaletteColorTableUID',
                ),
                'graylookuptabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GrayLookupTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GrayLookupTableData',
                ),
                'redpalettecolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RedPaletteColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RedPaletteColorTableData',
                ),
                'greenpalettecolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GreenPaletteColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GreenPaletteColorTableData',
                ),
                'bluepalettecolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BluePaletteColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BluePaletteColorTableData',
                ),
                'largeredpalettecolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargeRedPaletteColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargeRedPaletteColorTableData',
                ),
                'largegreenpalettecolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargeGreenPaletteColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargeGreenPaletteColorTableData',
                ),
                'largebluepalettecolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargeBluePaletteColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargeBluePaletteColorTableData',
                ),
                'largepalettecolorlookuptableuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargePaletteColorLookupTableUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargePaletteColorLookupTableUID',
                ),
                'segmentedredcolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentedRedColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentedRedColorTableData',
                ),
                'segmentedgreencolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentedGreenColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentedGreenColorTableData',
                ),
                'segmentedbluecolortabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentedBlueColorTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentedBlueColorTableData',
                ),
                'breastimplantpresent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BreastImplantPresent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BreastImplantPresent',
                ),
                'partialview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PartialView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PartialView',
                ),
                'partialviewdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PartialViewDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PartialViewDescription',
                ),
                'partialviewcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PartialViewCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PartialViewCodeSequence',
                ),
                'spatiallocationspreserved' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpatialLocationsPreserved',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpatialLocationsPreserved',
                ),
                'datapathassignment' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataPathAssignment',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataPathAssignment',
                ),
                'blendinglut1sequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlendingLUT1Sequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlendingLUT1Sequence',
                ),
                'blendingweightconstant' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlendingWeightConstant',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlendingWeightConstant',
                ),
                'blendinglookuptabledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlendingLookupTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlendingLookupTableData',
                ),
                'blendinglut2sequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlendingLUT2Sequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlendingLUT2Sequence',
                ),
                'datapathid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataPathID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataPathID',
                ),
                'rgbluttransferfunction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RGBLUTTransferFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RGBLUTTransferFunction',
                ),
                'alphaluttransferfunction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlphaLUTTransferFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlphaLUTTransferFunction',
                ),
                'iccprofile' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ICCProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ICCProfile',
                ),
                'lossyimagecompressionratio' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LossyImageCompressionRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LossyImageCompressionRatio',
                ),
                'lossyimagecompressionmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LossyImageCompressionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LossyImageCompressionMethod',
                ),
                'modalitylutsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModalityLUTSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModalityLUTSequence',
                ),
                'lutdescriptor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LUTDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LUTDescriptor',
                ),
                'lutexplanation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LUTExplanation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LUTExplanation',
                ),
                'modalityluttype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModalityLUTType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModalityLUTType',
                ),
                'lutdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LUTData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LUTData',
                ),
                'voilutsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VOILUTSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VOILUTSequence',
                ),
                'softcopyvoilutsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SoftcopyVOILUTSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SoftcopyVOILUTSequence',
                ),
                'imagepresentationcomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePresentationComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePresentationComments',
                ),
                'biplaneacquisitionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BiPlaneAcquisitionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BiPlaneAcquisitionSequence',
                ),
                'representativeframenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RepresentativeFrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RepresentativeFrameNumber',
                ),
                'framenumbersofinterest' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameNumbersOfInterest',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameNumbersOfInterest',
                ),
                'frameofinterestdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameOfInterestDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameOfInterestDescription',
                ),
                'frameofinteresttype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameOfInterestType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameOfInterestType',
                ),
                'maskpointers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskPointers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskPointers',
                ),
                'rwavepointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RWavePointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RWavePointer',
                ),
                'masksubtractionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskSubtractionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskSubtractionSequence',
                ),
                'maskoperation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskOperation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskOperation',
                ),
                'applicableframerange' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicableFrameRange',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicableFrameRange',
                ),
                'maskframenumbers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskFrameNumbers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskFrameNumbers',
                ),
                'contrastframeaveraging' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContrastFrameAveraging',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContrastFrameAveraging',
                ),
                'masksubpixelshift' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskSubPixelShift',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskSubPixelShift',
                ),
                'tidoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TIDOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TIDOffset',
                ),
                'maskoperationexplanation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskOperationExplanation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskOperationExplanation',
                ),
                'pixeldataproviderurl' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelDataProviderURL',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelDataProviderURL',
                ),
                'datapointrows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataPointRows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataPointRows',
                ),
                'datapointcolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataPointColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataPointColumns',
                ),
                'signaldomaincolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SignalDomainColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SignalDomainColumns',
                ),
                'largestmonochromepixelvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LargestMonochromePixelValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LargestMonochromePixelValue',
                ),
                'datarepresentation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataRepresentation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataRepresentation',
                ),
                'pixelmeasuressequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelMeasuresSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelMeasuresSequence',
                ),
                'framevoilutsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameVOILUTSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameVOILUTSequence',
                ),
                'pixelvaluetransformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelValueTransformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelValueTransformationSequence',
                ),
                'signaldomainrows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SignalDomainRows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SignalDomainRows',
                ),
                'displayfilterpercentage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayFilterPercentage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayFilterPercentage',
                ),
                'framepixelshiftsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FramePixelShiftSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FramePixelShiftSequence',
                ),
                'subtractionitemid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SubtractionItemID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SubtractionItemID',
                ),
                'pixelintensityrelationshiplutseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelIntensityRelationshipLUTSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelIntensityRelationshipLUTSeq',
                ),
                'framepixeldatapropertiessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FramePixelDataPropertiesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FramePixelDataPropertiesSequence',
                ),
                'geometricalproperties' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeometricalProperties',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeometricalProperties',
                ),
                'geometricmaximumdistortion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeometricMaximumDistortion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeometricMaximumDistortion',
                ),
                'imageprocessingapplied' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageProcessingApplied',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageProcessingApplied',
                ),
                'maskselectionmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskSelectionMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskSelectionMode',
                ),
                'lutfunction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LUTFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LUTFunction',
                ),
                'maskvisibilitypercentage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaskVisibilityPercentage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaskVisibilityPercentage',
                ),
                'pixelshiftsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelShiftSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelShiftSequence',
                ),
                'regionpixelshiftsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegionPixelShiftSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegionPixelShiftSequence',
                ),
                'verticesoftheregion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerticesOfTheRegion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerticesOfTheRegion',
                ),
                'pixelshiftframerange' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelShiftFrameRange',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelShiftFrameRange',
                ),
                'lutframerange' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LUTFrameRange',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LUTFrameRange',
                ),
                'imagetoequipmentmappingmatrix' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageToEquipmentMappingMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageToEquipmentMappingMatrix',
                ),
                'equipmentcoordinatesystemid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EquipmentCoordinateSystemID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EquipmentCoordinateSystemID',
                ),
                'lowerrangeofpixels1a' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1a',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1a',
                ),
                'lowerrangeofpixels1b' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1b',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1b',
                ),
                'lowerrangeofpixels1c' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1c',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1c',
                ),
                'lowerrangeofpixels1d' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1d',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1d',
                ),
                'lowerrangeofpixels1e' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1e',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1e',
                ),
                'lowerrangeofpixels1f' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1f',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1f',
                ),
                'lowerrangeofpixels1g' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1g',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1g',
                ),
                'lowerrangeofpixels1h' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1h',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1h',
                ),
                'lowerrangeofpixels1i' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels1i',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels1i',
                ),
                'lowerrangeofpixels2' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LowerRangeOfPixels2',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LowerRangeOfPixels2',
                ),
                'upperrangeofpixels2' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UpperRangeOfPixels2',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UpperRangeOfPixels2',
                ),
                'lenoftothdrinbytes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LenOfTotHdrInBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LenOfTotHdrInBytes',
                ),
                'versionofthehdrstruct' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VersionOfTheHdrStruct',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VersionOfTheHdrStruct',
                ),
                'advantagecompoverflow' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdvantageCompOverflow',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdvantageCompOverflow',
                ),
                'advantagecompunderflow' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdvantageCompUnderflow',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdvantageCompUnderflow',
                ),
                'studygrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyGroupLength',
                ),
                'studystatusid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyStatusID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyStatusID',
                ),
                'studypriorityid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyPriorityID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyPriorityID',
                ),
                'studyidissuer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyIDIssuer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyIDIssuer',
                ),
                'studyverifieddate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyVerifiedDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyVerifiedDate',
                ),
                'studyverifiedtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyVerifiedTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyVerifiedTime',
                ),
                'studyreaddate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyReadDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyReadDate',
                ),
                'studyreadtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyReadTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyReadTime',
                ),
                'scheduledstudystartdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStudyStartDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStudyStartDate',
                ),
                'scheduledstudystarttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStudyStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStudyStartTime',
                ),
                'scheduledstudystopdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStudyStopDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStudyStopDate',
                ),
                'scheduledstudystoptime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStudyStopTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStudyStopTime',
                ),
                'scheduledstudylocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStudyLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStudyLocation',
                ),
                'scheduledstudylocationaetitle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStudyLocationAETitle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStudyLocationAETitle',
                ),
                'reasonforstudy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReasonForStudy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReasonForStudy',
                ),
                'requestingphysicianidsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestingPhysicianIDSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestingPhysicianIDSequence',
                ),
                'requestingphysician' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestingPhysician',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestingPhysician',
                ),
                'requestingservice' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestingService',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestingService',
                ),
                'studyarrivaldate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyArrivalDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyArrivalDate',
                ),
                'studyarrivaltime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyArrivalTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyArrivalTime',
                ),
                'studycompletiondate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyCompletionDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyCompletionDate',
                ),
                'studycompletiontime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyCompletionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyCompletionTime',
                ),
                'studycomponentstatusid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyComponentStatusID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyComponentStatusID',
                ),
                'requestedproceduredescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedProcedureDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedProcedureDescription',
                ),
                'requestedprocedurecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedProcedureCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedProcedureCodeSequence',
                ),
                'requestedcontrastagent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedContrastAgent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedContrastAgent',
                ),
                'studycomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StudyComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StudyComments',
                ),
                'referencedpatientaliassequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedPatientAliasSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedPatientAliasSequence',
                ),
                'visitstatusid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VisitStatusID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VisitStatusID',
                ),
                'admissionid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdmissionID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdmissionID',
                ),
                'issuerofadmissionid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IssuerOfAdmissionID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IssuerOfAdmissionID',
                ),
                'routeofadmissions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RouteOfAdmissions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RouteOfAdmissions',
                ),
                'scheduledadmissiondate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledAdmissionDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledAdmissionDate',
                ),
                'scheduledadmissiontime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledAdmissionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledAdmissionTime',
                ),
                'scheduleddischargedate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledDischargeDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledDischargeDate',
                ),
                'scheduleddischargetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledDischargeTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledDischargeTime',
                ),
                'scheduledpatientinstitresidence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledPatientInstitResidence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledPatientInstitResidence',
                ),
                'admittingdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdmittingDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdmittingDate',
                ),
                'admittingtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdmittingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdmittingTime',
                ),
                'dischargedate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DischargeDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DischargeDate',
                ),
                'dischargetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DischargeTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DischargeTime',
                ),
                'dischargediagnosisdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DischargeDiagnosisDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DischargeDiagnosisDescription',
                ),
                'dischargediagnosiscodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DischargeDiagnosisCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DischargeDiagnosisCodeSequence',
                ),
                'specialneeds' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecialNeeds',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecialNeeds',
                ),
                'serviceepisodeid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ServiceEpisodeID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ServiceEpisodeID',
                ),
                'issuerofserviceepisodeid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IssuerOfServiceEpisodeID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IssuerOfServiceEpisodeID',
                ),
                'serviceepisodedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ServiceEpisodeDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ServiceEpisodeDescription',
                ),
                'pertinentdocumentssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PertinentDocumentsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PertinentDocumentsSequence',
                ),
                'currentpatientlocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurrentPatientLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurrentPatientLocation',
                ),
                'patientinstitutionresidence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientInstitutionResidence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientInstitutionResidence',
                ),
                'patientstate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientState',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientState',
                ),
                'patientclinicaltrialparticipseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientClinicalTrialParticipSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientClinicalTrialParticipSeq',
                ),
                'visitcomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VisitComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VisitComments',
                ),
                'waveformoriginality' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformOriginality',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformOriginality',
                ),
                'numberofwaveformchannels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfWaveformChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfWaveformChannels',
                ),
                'numberofwaveformsamples' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfWaveformSamples',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfWaveformSamples',
                ),
                'samplingfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SamplingFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SamplingFrequency',
                ),
                'multiplexgrouplabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultiplexGroupLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultiplexGroupLabel',
                ),
                'channeldefinitionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelDefinitionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelDefinitionSequence',
                ),
                'waveformchannelnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformChannelNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformChannelNumber',
                ),
                'channellabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelLabel',
                ),
                'channelstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelStatus',
                ),
                'channelsourcesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelSourceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelSourceSequence',
                ),
                'channelsourcemodifierssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelSourceModifiersSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelSourceModifiersSequence',
                ),
                'sourcewaveformsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceWaveformSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceWaveformSequence',
                ),
                'channelderivationdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelDerivationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelDerivationDescription',
                ),
                'channelsensitivity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelSensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelSensitivity',
                ),
                'channelsensitivityunitssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelSensitivityUnitsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelSensitivityUnitsSequence',
                ),
                'channelsensitivitycorrectionfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelSensitivityCorrectionFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelSensitivityCorrectionFactor',
                ),
                'channelbaseline' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelBaseline',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelBaseline',
                ),
                'channeltimeskew' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelTimeSkew',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelTimeSkew',
                ),
                'channelsampleskew' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelSampleSkew',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelSampleSkew',
                ),
                'channeloffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelOffset',
                ),
                'waveformbitsstored' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformBitsStored',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformBitsStored',
                ),
                'filterlowfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterLowFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterLowFrequency',
                ),
                'filterhighfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterHighFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterHighFrequency',
                ),
                'notchfilterfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NotchFilterFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NotchFilterFrequency',
                ),
                'notchfilterbandwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NotchFilterBandwidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NotchFilterBandwidth',
                ),
                'waveformdatadisplayscale' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformDataDisplayScale',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformDataDisplayScale',
                ),
                'waveformdisplaybkgcielabvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformDisplayBkgCIELabValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformDisplayBkgCIELabValue',
                ),
                'waveformpresentationgroupsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformPresentationGroupSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformPresentationGroupSequence',
                ),
                'presentationgroupnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationGroupNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationGroupNumber',
                ),
                'channeldisplaysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelDisplaySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelDisplaySequence',
                ),
                'channelrecommenddisplaycielabvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelRecommendDisplayCIELabValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelRecommendDisplayCIELabValue',
                ),
                'channelposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelPosition',
                ),
                'displayshadingflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayShadingFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayShadingFlag',
                ),
                'fractionalchanneldisplayscale' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionalChannelDisplayScale',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionalChannelDisplayScale',
                ),
                'absolutechanneldisplayscale' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AbsoluteChannelDisplayScale',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AbsoluteChannelDisplayScale',
                ),
                'multiplexaudiochannelsdescrcodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultiplexAudioChannelsDescrCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultiplexAudioChannelsDescrCodeSeq',
                ),
                'channelidentificationcode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelIdentificationCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelIdentificationCode',
                ),
                'channelmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelMode',
                ),
                'scheduledstationaetitle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStationAETitle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStationAETitle',
                ),
                'scheduledprocedurestepstartdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepStartDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepStartDate',
                ),
                'scheduledprocedurestepstarttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepStartTime',
                ),
                'scheduledprocedurestependdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepEndDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepEndDate',
                ),
                'scheduledprocedurestependtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepEndTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepEndTime',
                ),
                'scheduledperformingphysiciansname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledPerformingPhysiciansName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledPerformingPhysiciansName',
                ),
                'scheduledprocedurestepdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepDescription',
                ),
                'scheduledprotocolcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProtocolCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProtocolCodeSequence',
                ),
                'scheduledprocedurestepid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepID',
                ),
                'stagecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StageCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StageCodeSequence',
                ),
                'scheduledperformingphysicianidseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledPerformingPhysicianIDSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledPerformingPhysicianIDSeq',
                ),
                'scheduledstationname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStationName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStationName',
                ),
                'scheduledproceduresteplocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepLocation',
                ),
                'premedication' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PreMedication',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PreMedication',
                ),
                'scheduledprocedurestepstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepStatus',
                ),
                'localnamespaceentityid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LocalNamespaceEntityID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LocalNamespaceEntityID',
                ),
                'universalentityid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UniversalEntityID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UniversalEntityID',
                ),
                'universalentityidtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UniversalEntityIDType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UniversalEntityIDType',
                ),
                'identifiertypecode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IdentifierTypeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IdentifierTypeCode',
                ),
                'assigningfacilitysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AssigningFacilitySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AssigningFacilitySequence',
                ),
                'scheduledprocedurestepsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepSequence',
                ),
                'referencednonimagecompositesopseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedNonImageCompositeSOPSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedNonImageCompositeSOPSeq',
                ),
                'performedstationaetitle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedStationAETitle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedStationAETitle',
                ),
                'performedstationname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedStationName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedStationName',
                ),
                'performedlocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedLocation',
                ),
                'performedprocedurestepstartdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureStepStartDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepStartDate',
                ),
                'performedprocedurestepstarttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureStepStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepStartTime',
                ),
                'performedprocedurestependdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureStepEndDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepEndDate',
                ),
                'performedprocedurestependtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureStepEndTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepEndTime',
                ),
                'performedprocedurestepstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureStepStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepStatus',
                ),
                'performedprocedurestepid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureStepID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepID',
                ),
                'performedprocedurestepdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureStepDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureStepDescription',
                ),
                'performedproceduretypedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureTypeDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureTypeDescription',
                ),
                'performedprotocolcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProtocolCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProtocolCodeSequence',
                ),
                'performedprotocoltype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProtocolType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProtocolType',
                ),
                'scheduledstepattributessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStepAttributesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStepAttributesSequence',
                ),
                'requestattributessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestAttributesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestAttributesSequence',
                ),
                'commentsonperformedprocedurestep' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CommentsOnPerformedProcedureStep',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CommentsOnPerformedProcedureStep',
                ),
                'procstepdiscontinuereasoncodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProcStepDiscontinueReasonCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProcStepDiscontinueReasonCodeSeq',
                ),
                'quantitysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'QuantitySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\QuantitySequence',
                ),
                'quantity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Quantity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Quantity',
                ),
                'measuringunitssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeasuringUnitsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeasuringUnitsSequence',
                ),
                'billingitemsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BillingItemSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BillingItemSequence',
                ),
                'totaltimeoffluoroscopy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalTimeOfFluoroscopy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalTimeOfFluoroscopy',
                ),
                'totalnumberofexposures' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalNumberOfExposures',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalNumberOfExposures',
                ),
                'entrancedose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EntranceDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EntranceDose',
                ),
                'exposedarea' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposedArea',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposedArea',
                ),
                'distancesourcetoentrance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistanceSourceToEntrance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistanceSourceToEntrance',
                ),
                'distancesourcetosupport' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistanceSourceToSupport',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistanceSourceToSupport',
                ),
                'exposuredosesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureDoseSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureDoseSequence',
                ),
                'commentsonradiationdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CommentsOnRadiationDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CommentsOnRadiationDose',
                ),
                'xrayoutput' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayOutput',
                ),
                'halfvaluelayer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HalfValueLayer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HalfValueLayer',
                ),
                'organdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrganDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrganDose',
                ),
                'organexposed' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrganExposed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrganExposed',
                ),
                'billingprocedurestepsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BillingProcedureStepSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BillingProcedureStepSequence',
                ),
                'filmconsumptionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilmConsumptionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilmConsumptionSequence',
                ),
                'billingsuppliesanddevicessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BillingSuppliesAndDevicesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BillingSuppliesAndDevicesSequence',
                ),
                'performedseriessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedSeriesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedSeriesSequence',
                ),
                'commentsonscheduledprocedurestep' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CommentsOnScheduledProcedureStep',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CommentsOnScheduledProcedureStep',
                ),
                'protocolcontextsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProtocolContextSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProtocolContextSequence',
                ),
                'contentitemmodifiersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentItemModifierSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentItemModifierSequence',
                ),
                'specimenaccessionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecimenAccessionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecimenAccessionNumber',
                ),
                'containeridentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContainerIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContainerIdentifier',
                ),
                'containerdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContainerDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContainerDescription',
                ),
                'specimensequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecimenSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecimenSequence',
                ),
                'specimenidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecimenIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecimenIdentifier',
                ),
                'specimendescriptionsequencetrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecimenDescriptionSequenceTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecimenDescriptionSequenceTrial',
                ),
                'specimendescriptiontrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecimenDescriptionTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecimenDescriptionTrial',
                ),
                'specimenuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecimenUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecimenUID',
                ),
                'acquisitioncontextsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionContextSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionContextSequence',
                ),
                'acquisitioncontextdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AcquisitionContextDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AcquisitionContextDescription',
                ),
                'specimentypecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecimenTypeCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecimenTypeCodeSequence',
                ),
                'specimenshortdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecimenShortDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecimenShortDescription',
                ),
                'slideidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SlideIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SlideIdentifier',
                ),
                'imagecenterpointcoordinatesseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageCenterPointCoordinatesSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageCenterPointCoordinatesSeq',
                ),
                'xoffsetinslidecoordinatesystem' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XOffsetInSlideCoordinateSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XOffsetInSlideCoordinateSystem',
                ),
                'yoffsetinslidecoordinatesystem' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'YOffsetInSlideCoordinateSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\YOffsetInSlideCoordinateSystem',
                ),
                'zoffsetinslidecoordinatesystem' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZOffsetInSlideCoordinateSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZOffsetInSlideCoordinateSystem',
                ),
                'pixelspacingsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelSpacingSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelSpacingSequence',
                ),
                'coordinatesystemaxiscodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CoordinateSystemAxisCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CoordinateSystemAxisCodeSequence',
                ),
                'measurementunitscodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeasurementUnitsCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeasurementUnitsCodeSequence',
                ),
                'vitalstaincodesequencetrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VitalStainCodeSequenceTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VitalStainCodeSequenceTrial',
                ),
                'requestedprocedureid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedProcedureID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedProcedureID',
                ),
                'reasonforrequestedprocedure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReasonForRequestedProcedure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReasonForRequestedProcedure',
                ),
                'requestedprocedurepriority' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedProcedurePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedProcedurePriority',
                ),
                'patienttransportarrangements' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientTransportArrangements',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientTransportArrangements',
                ),
                'requestedprocedurelocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedProcedureLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedProcedureLocation',
                ),
                'placerordernumber-procedure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlacerOrderNumber-Procedure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlacerOrderNumberProcedure',
                ),
                'fillerordernumber-procedure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FillerOrderNumber-Procedure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FillerOrderNumberProcedure',
                ),
                'confidentialitycode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConfidentialityCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConfidentialityCode',
                ),
                'reportingpriority' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReportingPriority',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReportingPriority',
                ),
                'reasonforrequestedprocedurecodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReasonForRequestedProcedureCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReasonForRequestedProcedureCodeSeq',
                ),
                'namesofintendedrecipientsofresults' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NamesOfIntendedRecipientsOfResults',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NamesOfIntendedRecipientsOfResults',
                ),
                'intendedrecipientsofresultsidseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IntendedRecipientsOfResultsIDSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IntendedRecipientsOfResultsIDSeq',
                ),
                'personidentificationcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PersonIdentificationCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PersonIdentificationCodeSequence',
                ),
                'personaddress' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PersonAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PersonAddress',
                ),
                'persontelephonenumbers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PersonTelephoneNumbers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PersonTelephoneNumbers',
                ),
                'requestedprocedurecomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedProcedureComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedProcedureComments',
                ),
                'reasonforimagingservicerequest' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReasonForImagingServiceRequest',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReasonForImagingServiceRequest',
                ),
                'issuedateofimagingservicerequest' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IssueDateOfImagingServiceRequest',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IssueDateOfImagingServiceRequest',
                ),
                'issuetimeofimagingservicerequest' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IssueTimeOfImagingServiceRequest',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IssueTimeOfImagingServiceRequest',
                ),
                'placerordernum-imagingservicereq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlacerOrderNum-ImagingServiceReq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlacerOrderNumImagingServiceReq',
                ),
                'fillerordernum-imagingservicereq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FillerOrderNum-ImagingServiceReq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FillerOrderNumImagingServiceReq',
                ),
                'orderenteredby' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrderEnteredBy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrderEnteredBy',
                ),
                'orderentererlocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrderEntererLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrderEntererLocation',
                ),
                'ordercallbackphonenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrderCallbackPhoneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrderCallbackPhoneNumber',
                ),
                'imagingservicerequestcomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagingServiceRequestComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagingServiceRequestComments',
                ),
                'confidentialityonpatientdatadescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConfidentialityOnPatientDataDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConfidentialityOnPatientDataDescr',
                ),
                'genpurposescheduledprocstepstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GenPurposeScheduledProcStepStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GenPurposeScheduledProcStepStatus',
                ),
                'genpurposeperformedprocstepstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GenPurposePerformedProcStepStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GenPurposePerformedProcStepStatus',
                ),
                'genpurposeschedprocsteppriority' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GenPurposeSchedProcStepPriority',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GenPurposeSchedProcStepPriority',
                ),
                'schedprocessingapplicationscodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SchedProcessingApplicationsCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SchedProcessingApplicationsCodeSeq',
                ),
                'schedprocedurestepstartdateandtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SchedProcedureStepStartDateAndTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SchedProcedureStepStartDateAndTime',
                ),
                'multiplecopiesflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MultipleCopiesFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MultipleCopiesFlag',
                ),
                'performedprocessingappscodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcessingAppsCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcessingAppsCodeSeq',
                ),
                'humanperformercodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HumanPerformerCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HumanPerformerCodeSequence',
                ),
                'schedprocstepmodificationdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SchedProcStepModificationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SchedProcStepModificationDateTime',
                ),
                'expectedcompletiondateandtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExpectedCompletionDateAndTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExpectedCompletionDateAndTime',
                ),
                'resultinggenpurposeperfprocstepseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResultingGenPurposePerfProcStepSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResultingGenPurposePerfProcStepSeq',
                ),
                'refgenpurposeschedprocstepseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RefGenPurposeSchedProcStepSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RefGenPurposeSchedProcStepSeq',
                ),
                'scheduledworkitemcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledWorkitemCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledWorkitemCodeSequence',
                ),
                'performedworkitemcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedWorkitemCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedWorkitemCodeSequence',
                ),
                'inputavailabilityflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InputAvailabilityFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InputAvailabilityFlag',
                ),
                'inputinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InputInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InputInformationSequence',
                ),
                'relevantinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelevantInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelevantInformationSequence',
                ),
                'refgenpurschedprocsteptransuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RefGenPurSchedProcStepTransUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RefGenPurSchedProcStepTransUID',
                ),
                'scheduledstationnamecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStationNameCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStationNameCodeSequence',
                ),
                'scheduledstationclasscodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledStationClassCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledStationClassCodeSequence',
                ),
                'schedstationgeographicloccodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SchedStationGeographicLocCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SchedStationGeographicLocCodeSeq',
                ),
                'performedstationnamecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedStationNameCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedStationNameCodeSequence',
                ),
                'performedstationclasscodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedStationClassCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedStationClassCodeSequence',
                ),
                'performedstationgeogloccodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedStationGeogLocCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedStationGeogLocCodeSeq',
                ),
                'requestedsubsequentworkitemcodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedSubsequentWorkItemCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedSubsequentWorkItemCodeSeq',
                ),
                'nondicomoutputcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NonDICOMOutputCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NonDICOMOutputCodeSequence',
                ),
                'outputinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OutputInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OutputInformationSequence',
                ),
                'scheduledhumanperformerssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledHumanPerformersSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledHumanPerformersSequence',
                ),
                'actualhumanperformerssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActualHumanPerformersSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActualHumanPerformersSequence',
                ),
                'humanperformersorganization' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HumanPerformersOrganization',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HumanPerformersOrganization',
                ),
                'humanperformername' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HumanPerformerName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HumanPerformerName',
                ),
                'rawdatahandling' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RawDataHandling',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RawDataHandling',
                ),
                'entrancedoseinmilligy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EntranceDoseInMilliGy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EntranceDoseInMilliGy',
                ),
                'refimagerealworldvaluemappingseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RefImageRealWorldValueMappingSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RefImageRealWorldValueMappingSeq',
                ),
                'realworldvaluemappingsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RealWorldValueMappingSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RealWorldValueMappingSequence',
                ),
                'pixelvaluemappingcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelValueMappingCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelValueMappingCodeSequence',
                ),
                'lutlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LUTLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LUTLabel',
                ),
                'realworldvaluelastvaluemapped' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RealWorldValueLastValueMapped',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RealWorldValueLastValueMapped',
                ),
                'realworldvaluelutdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RealWorldValueLUTData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RealWorldValueLUTData',
                ),
                'realworldvaluefirstvaluemapped' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RealWorldValueFirstValueMapped',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RealWorldValueFirstValueMapped',
                ),
                'realworldvalueintercept' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RealWorldValueIntercept',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RealWorldValueIntercept',
                ),
                'realworldvalueslope' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RealWorldValueSlope',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RealWorldValueSlope',
                ),
                'relationshiptype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelationshipType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelationshipType',
                ),
                'verifyingorganization' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerifyingOrganization',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerifyingOrganization',
                ),
                'verificationdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerificationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerificationDateTime',
                ),
                'observationdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ObservationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ObservationDateTime',
                ),
                'valuetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ValueType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ValueType',
                ),
                'conceptnamecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConceptNameCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConceptNameCodeSequence',
                ),
                'continuityofcontent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContinuityOfContent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContinuityOfContent',
                ),
                'verifyingobserversequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerifyingObserverSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerifyingObserverSequence',
                ),
                'verifyingobservername' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerifyingObserverName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerifyingObserverName',
                ),
                'authorobserversequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AuthorObserverSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AuthorObserverSequence',
                ),
                'participantsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParticipantSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParticipantSequence',
                ),
                'custodialorganizationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CustodialOrganizationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CustodialOrganizationSequence',
                ),
                'participationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParticipationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParticipationType',
                ),
                'participationdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParticipationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParticipationDateTime',
                ),
                'observertype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ObserverType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ObserverType',
                ),
                'verifyingobserveridentcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerifyingObserverIdentCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerifyingObserverIdentCodeSequence',
                ),
                'equivalentcdadocumentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EquivalentCDADocumentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EquivalentCDADocumentSequence',
                ),
                'referencedwaveformchannels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedWaveformChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedWaveformChannels',
                ),
                'datetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DateTime',
                ),
                'date' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Date',
                ),
                'time' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Time',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Time',
                ),
                'personname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PersonName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PersonName',
                ),
                'uid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UID',
                ),
                'temporalrangetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemporalRangeType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemporalRangeType',
                ),
                'referencedsamplepositions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSamplePositions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSamplePositions',
                ),
                'referencedframenumbers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFrameNumbers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFrameNumbers',
                ),
                'referencedtimeoffsets' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedTimeOffsets',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedTimeOffsets',
                ),
                'referenceddatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedDateTime',
                ),
                'textvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TextValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TextValue',
                ),
                'conceptcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConceptCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConceptCodeSequence',
                ),
                'purposeofreferencecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PurposeOfReferenceCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PurposeOfReferenceCodeSequence',
                ),
                'annotationgroupnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnnotationGroupNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnnotationGroupNumber',
                ),
                'modifiercodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifierCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifierCodeSequence',
                ),
                'measuredvaluesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeasuredValueSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeasuredValueSequence',
                ),
                'numericvaluequalifiercodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumericValueQualifierCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumericValueQualifierCodeSequence',
                ),
                'numericvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumericValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumericValue',
                ),
                'addresstrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AddressTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AddressTrial',
                ),
                'telephonenumbertrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TelephoneNumberTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TelephoneNumberTrial',
                ),
                'predecessordocumentssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PredecessorDocumentsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PredecessorDocumentsSequence',
                ),
                'referencedrequestsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedRequestSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedRequestSequence',
                ),
                'performedprocedurecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcedureCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcedureCodeSequence',
                ),
                'currentrequestedprocevidenceseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurrentRequestedProcEvidenceSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurrentRequestedProcEvidenceSeq',
                ),
                'pertinentotherevidencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PertinentOtherEvidenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PertinentOtherEvidenceSequence',
                ),
                'hl7structureddocumentrefseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HL7StructuredDocumentRefSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HL7StructuredDocumentRefSeq',
                ),
                'completionflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompletionFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompletionFlag',
                ),
                'completionflagdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompletionFlagDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompletionFlagDescription',
                ),
                'verificationflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerificationFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerificationFlag',
                ),
                'archiverequested' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ArchiveRequested',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ArchiveRequested',
                ),
                'preliminaryflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PreliminaryFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PreliminaryFlag',
                ),
                'contenttemplatesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentTemplateSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentTemplateSequence',
                ),
                'identicaldocumentssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IdenticalDocumentsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IdenticalDocumentsSequence',
                ),
                'contentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentSequence',
                ),
                'annotationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnnotationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnnotationSequence',
                ),
                'templateidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateIdentifier',
                ),
                'templateversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateVersion',
                ),
                'templatelocalversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateLocalVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateLocalVersion',
                ),
                'templateextensionflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateExtensionFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateExtensionFlag',
                ),
                'templateextensionorganizationuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateExtensionOrganizationUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateExtensionOrganizationUID',
                ),
                'templateextensioncreatoruid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateExtensionCreatorUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateExtensionCreatorUID',
                ),
                'referencedcontentitemidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedContentItemIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedContentItemIdentifier',
                ),
                'hl7instanceidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HL7InstanceIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HL7InstanceIdentifier',
                ),
                'hl7documenteffectivetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HL7DocumentEffectiveTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HL7DocumentEffectiveTime',
                ),
                'hl7documenttypecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HL7DocumentTypeCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HL7DocumentTypeCodeSequence',
                ),
                'retrieveuri' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RetrieveURI',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RetrieveURI',
                ),
                'retrievelocationuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RetrieveLocationUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RetrieveLocationUID',
                ),
                'documenttitle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DocumentTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DocumentTitle',
                ),
                'encapsulateddocument' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EncapsulatedDocument',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EncapsulatedDocument',
                ),
                'mimetypeofencapsulateddocument' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MIMETypeOfEncapsulatedDocument',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MIMETypeOfEncapsulatedDocument',
                ),
                'sourceinstancesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceInstanceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceInstanceSequence',
                ),
                'listofmimetypes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ListOfMIMETypes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ListOfMIMETypes',
                ),
                'bitmapofprescanoptions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BitmapOfPrescanOptions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BitmapOfPrescanOptions',
                ),
                'gradientoffsetinx' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GradientOffsetInX',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GradientOffsetInX',
                ),
                'gradientoffsetiny' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GradientOffsetInY',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GradientOffsetInY',
                ),
                'gradientoffsetinz' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GradientOffsetInZ',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GradientOffsetInZ',
                ),
                'imgisoriginalorunoriginal' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImgIsOriginalOrUnoriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImgIsOriginalOrUnoriginal',
                ),
                'numberofepishots' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfEPIShots',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfEPIShots',
                ),
                'viewspersegment' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewsPerSegment',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewsPerSegment',
                ),
                'respiratoryratebpm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratoryRateBpm',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratoryRateBpm',
                ),
                'respiratorytriggerpoint' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RespiratoryTriggerPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RespiratoryTriggerPoint',
                ),
                'typeofreceiverused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TypeOfReceiverUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TypeOfReceiverUsed',
                ),
                'peakrateofchangeofgradientfield' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PeakRateOfChangeOfGradientField',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PeakRateOfChangeOfGradientField',
                ),
                'limitsinunitsofpercent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LimitsInUnitsOfPercent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LimitsInUnitsOfPercent',
                ),
                'psdestimatedlimit' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PSDEstimatedLimit',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PSDEstimatedLimit',
                ),
                'psdestimatedlimitinteslapersecond' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PSDEstimatedLimitInTeslaPerSecond',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PSDEstimatedLimitInTeslaPerSecond',
                ),
                'saravghead' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Saravghead',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Saravghead',
                ),
                'windowvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WindowValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WindowValue',
                ),
                'totalinputviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalInputViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalInputViews',
                ),
                'x-raychain' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'X-RayChain',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayChain',
                ),
                'deconkernelparameters' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeconKernelParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeconKernelParameters',
                ),
                'calibrationparameters' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalibrationParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalibrationParameters',
                ),
                'totaloutputviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalOutputViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalOutputViews',
                ),
                'numberofoverranges' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfOverranges',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfOverranges',
                ),
                'ibhimagescalefactors' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IBHImageScaleFactors',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IBHImageScaleFactors',
                ),
                'bbhcoefficients' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BBHCoefficients',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BBHCoefficients',
                ),
                'numberofbbhchainstoblend' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfBBHChainsToBlend',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfBBHChainsToBlend',
                ),
                'startingchannelnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingChannelNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingChannelNumber',
                ),
                'ppscanparameters' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PpscanParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PpscanParameters',
                ),
                'geimageintegrity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GEImageIntegrity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GEImageIntegrity',
                ),
                'levelvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LevelValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LevelValue',
                ),
                'deltastarttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeltaStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeltaStartTime',
                ),
                'maxoverrangesinaview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaxOverrangesInAView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaxOverrangesInAView',
                ),
                'avgoverrangesallviews' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AvgOverrangesAllViews',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AvgOverrangesAllViews',
                ),
                'correctedafterglowterms' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CorrectedAfterGlowTerms',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CorrectedAfterGlowTerms',
                ),
                'referencechannels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferenceChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferenceChannels',
                ),
                'noviewsrefchansblocked' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NoViewsRefChansBlocked',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NoViewsRefChansBlocked',
                ),
                'scanpitchratio' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanPitchRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanPitchRatio',
                ),
                'uniqueimageiden' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UniqueImageIden',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UniqueImageIden',
                ),
                'histogramtables' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HistogramTables',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HistogramTables',
                ),
                'userdefineddata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserDefinedData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserDefinedData',
                ),
                'privatescanoptions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrivateScanOptions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrivateScanOptions',
                ),
                'effectiveechospacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EffectiveEchoSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EffectiveEchoSpacing',
                ),
                'stringslopfield1' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StringSlopField1',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StringSlopField1',
                ),
                'stringslopfield2' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StringSlopField2',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StringSlopField2',
                ),
                'racordoftargetreconcenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RACordOfTargetReconCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RACordOfTargetReconCenter',
                ),
                'negscanspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NegScanspacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NegScanspacing',
                ),
                'offsetfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OffsetFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OffsetFrequency',
                ),
                'userusagetag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserUsageTag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserUsageTag',
                ),
                'userfillmapmsw' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserFillMapMSW',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserFillMapMSW',
                ),
                'userfillmaplsw' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UserFillMapLSW',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UserFillMapLSW',
                ),
                'user25-48' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'User25-48',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\User2548',
                ),
                'slopint6-9' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SlopInt6-9',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SlopInt69',
                ),
                'triggeronposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerOnPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerOnPosition',
                ),
                'degreeofrotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DegreeOfRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DegreeOfRotation',
                ),
                'dastriggersource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASTriggerSource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASTriggerSource',
                ),
                'dasfpagain' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASFpaGain',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASFpaGain',
                ),
                'dasoutputsource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASOutputSource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASOutputSource',
                ),
                'dasadinput' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASAdInput',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASAdInput',
                ),
                'dascalmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASCalMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASCalMode',
                ),
                'dascalfrequency' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASCalFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASCalFrequency',
                ),
                'dasregxm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASRegXm',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASRegXm',
                ),
                'dasautozero' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASAutoZero',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASAutoZero',
                ),
                'startingchannelofview' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingChannelOfView',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingChannelOfView',
                ),
                'dasxmpattern' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASXmPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASXmPattern',
                ),
                'tggctriggermode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TGGCTriggerMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TGGCTriggerMode',
                ),
                'startscantoxrayondelay' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartScanToXrayOnDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartScanToXrayOnDelay',
                ),
                'durationofxrayon' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DurationOfXrayOn',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DurationOfXrayOn',
                ),
                'slopint10-17' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SlopInt10-17',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SlopInt1017',
                ),
                'scannerstudyentityuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScannerStudyEntityUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScannerStudyEntityUID',
                ),
                'scannerstudyid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScannerStudyID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScannerStudyID',
                ),
                'scannertableentry' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScannerTableEntry',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScannerTableEntry',
                ),
                'productpackageidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProductPackageIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProductPackageIdentifier',
                ),
                'substanceadministrationapproval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SubstanceAdministrationApproval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SubstanceAdministrationApproval',
                ),
                'approvalstatusfurtherdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApprovalStatusFurtherDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApprovalStatusFurtherDescription',
                ),
                'approvalstatusdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApprovalStatusDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApprovalStatusDateTime',
                ),
                'producttypecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProductTypeCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProductTypeCodeSequence',
                ),
                'productname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProductName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProductName',
                ),
                'productdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProductDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProductDescription',
                ),
                'productlotidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProductLotIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProductLotIdentifier',
                ),
                'productexpirationdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProductExpirationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProductExpirationDateTime',
                ),
                'substanceadministrationdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SubstanceAdministrationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SubstanceAdministrationDateTime',
                ),
                'substanceadministrationnotes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SubstanceAdministrationNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SubstanceAdministrationNotes',
                ),
                'substanceadministrationdeviceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SubstanceAdministrationDeviceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SubstanceAdministrationDeviceID',
                ),
                'productparametersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProductParameterSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProductParameterSequence',
                ),
                'substanceadminparameterseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SubstanceAdminParameterSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SubstanceAdminParameterSeq',
                ),
                'numberofmacrorowsindetector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfMacroRowsInDetector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfMacroRowsInDetector',
                ),
                'macrowidthatisocenter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MacroWidthAtISOCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MacroWidthAtISOCenter',
                ),
                'dastype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASType',
                ),
                'dasgain' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASGain',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASGain',
                ),
                'dastemperature' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DASTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DASTemperature',
                ),
                'tabledirectioninorout' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableDirectionInOrOut',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableDirectionInOrOut',
                ),
                'zsmoothingfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZSmoothingFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZSmoothingFactor',
                ),
                'viewweightingmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewWeightingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewWeightingMode',
                ),
                'sigmarownumberwhichrowswereused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SigmaRowNumberWhichRowsWereUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SigmaRowNumberWhichRowsWereUsed',
                ),
                'minimumdasvaluefoundinthescandata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MinimumDasValueFoundInTheScanData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MinimumDasValueFoundInTheScanData',
                ),
                'maximumoffsetshiftvalueused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumOffsetShiftValueUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumOffsetShiftValueUsed',
                ),
                'numberofviewsshifted' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfViewsShifted',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfViewsShifted',
                ),
                'ztrackingflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZTrackingFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZTrackingFlag',
                ),
                'meanzerror' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeanZError',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeanZError',
                ),
                'ztrackingmaximumerror' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZTrackingMaximumError',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZTrackingMaximumError',
                ),
                'startingviewforrow2a' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingViewForRow2a',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingViewForRow2a',
                ),
                'numberofviewsinrow2a' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfViewsInRow2a',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInRow2a',
                ),
                'startingviewforrow1a' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingViewForRow1a',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingViewForRow1a',
                ),
                'sigmamode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SigmaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SigmaMode',
                ),
                'numberofviewsinrow1a' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfViewsInRow1a',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInRow1a',
                ),
                'startingviewforrow2b' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingViewForRow2b',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingViewForRow2b',
                ),
                'numberofviewsinrow2b' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfViewsInRow2b',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInRow2b',
                ),
                'startingviewforrow1b' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartingViewForRow1b',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartingViewForRow1b',
                ),
                'numberofviewsinrow1b' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfViewsInRow1b',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfViewsInRow1b',
                ),
                'airfiltercalibrationdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AirFilterCalibrationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AirFilterCalibrationDate',
                ),
                'airfiltercalibrationtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AirFilterCalibrationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AirFilterCalibrationTime',
                ),
                'phantomcalibrationdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhantomCalibrationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhantomCalibrationDate',
                ),
                'phantomcalibrationtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhantomCalibrationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhantomCalibrationTime',
                ),
                'zslopecalibrationdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZSlopeCalibrationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZSlopeCalibrationDate',
                ),
                'zslopecalibrationtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZSlopeCalibrationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZSlopeCalibrationTime',
                ),
                'crosstalkcalibrationdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CrosstalkCalibrationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CrosstalkCalibrationDate',
                ),
                'crosstalkcalibrationtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CrosstalkCalibrationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CrosstalkCalibrationTime',
                ),
                'iterboneoptionflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IterboneOptionFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IterboneOptionFlag',
                ),
                'peristalticflagoption' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PeristalticFlagOption',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PeristalticFlagOption',
                ),
                'lensdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LensDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LensDescription',
                ),
                'rightlenssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RightLensSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RightLensSequence',
                ),
                'leftlenssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LeftLensSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LeftLensSequence',
                ),
                'cylindersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CylinderSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CylinderSequence',
                ),
                'prismsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrismSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrismSequence',
                ),
                'horizontalprismpower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HorizontalPrismPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HorizontalPrismPower',
                ),
                'horizontalprismbase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HorizontalPrismBase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HorizontalPrismBase',
                ),
                'verticalprismpower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerticalPrismPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerticalPrismPower',
                ),
                'verticalprismbase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerticalPrismBase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerticalPrismBase',
                ),
                'lenssegmenttype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LensSegmentType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LensSegmentType',
                ),
                'opticaltransmittance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OpticalTransmittance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OpticalTransmittance',
                ),
                'channelwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelWidth',
                ),
                'pupilsize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PupilSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PupilSize',
                ),
                'cornealsize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CornealSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CornealSize',
                ),
                'distancepupillarydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistancePupillaryDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistancePupillaryDistance',
                ),
                'nearpupillarydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NearPupillaryDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NearPupillaryDistance',
                ),
                'otherpupillarydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherPupillaryDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherPupillaryDistance',
                ),
                'radiusofcurvature' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiusOfCurvature',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiusOfCurvature',
                ),
                'keratometricpower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'KeratometricPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\KeratometricPower',
                ),
                'keratometricaxis' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'KeratometricAxis',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\KeratometricAxis',
                ),
                'backgroundcolor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BackgroundColor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BackgroundColor',
                ),
                'optotype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Optotype',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Optotype',
                ),
                'optotypepresentation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OptotypePresentation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OptotypePresentation',
                ),
                'addnearsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AddNearSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AddNearSequence',
                ),
                'addintermediatesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AddIntermediateSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AddIntermediateSequence',
                ),
                'addothersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AddOtherSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AddOtherSequence',
                ),
                'addpower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AddPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AddPower',
                ),
                'viewingdistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewingDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewingDistance',
                ),
                'viewingdistancetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewingDistanceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewingDistanceType',
                ),
                'visualacuitymodifiers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VisualAcuityModifiers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VisualAcuityModifiers',
                ),
                'decimalvisualacuity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecimalVisualAcuity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecimalVisualAcuity',
                ),
                'optotypedetaileddefinition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OptotypeDetailedDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OptotypeDetailedDefinition',
                ),
                'spherepower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpherePower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpherePower',
                ),
                'cylinderpower' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CylinderPower',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CylinderPower',
                ),
                'calibrationimage' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalibrationImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalibrationImage',
                ),
                'devicesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceSequence',
                ),
                'devicelength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceLength',
                ),
                'containercomponentwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContainerComponentWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContainerComponentWidth',
                ),
                'devicediameter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceDiameter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceDiameter',
                ),
                'devicediameterunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceDiameterUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceDiameterUnits',
                ),
                'devicevolume' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceVolume',
                ),
                'intermarkerdistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterMarkerDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterMarkerDistance',
                ),
                'containercomponentid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContainerComponentID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContainerComponentID',
                ),
                'devicedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeviceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeviceDescription',
                ),
                'energywindowvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowVector',
                ),
                'numberofenergywindows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfEnergyWindows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfEnergyWindows',
                ),
                'energywindowinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowInformationSequence',
                ),
                'energywindowrangesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowRangeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowRangeSequence',
                ),
                'energywindowlowerlimit' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowLowerLimit',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowLowerLimit',
                ),
                'energywindowupperlimit' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowUpperLimit',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowUpperLimit',
                ),
                'radiopharmaceuticalinformationseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalInformationSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalInformationSeq',
                ),
                'residualsyringecounts' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResidualSyringeCounts',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResidualSyringeCounts',
                ),
                'energywindowname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowName',
                ),
                'detectorvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorVector',
                ),
                'numberofdetectors' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfDetectors',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfDetectors',
                ),
                'detectorinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorInformationSequence',
                ),
                'phasevector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhaseVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhaseVector',
                ),
                'numberofphases' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPhases',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPhases',
                ),
                'phaseinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhaseInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhaseInformationSequence',
                ),
                'numberofframesinphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfFramesInPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfFramesInPhase',
                ),
                'phasedelay' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhaseDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhaseDelay',
                ),
                'pausebetweenframes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PauseBetweenFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PauseBetweenFrames',
                ),
                'phasedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhaseDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhaseDescription',
                ),
                'rotationvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RotationVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RotationVector',
                ),
                'numberofrotations' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfRotations',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfRotations',
                ),
                'rotationinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RotationInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RotationInformationSequence',
                ),
                'numberofframesinrotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfFramesInRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfFramesInRotation',
                ),
                'rrintervalvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RRIntervalVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RRIntervalVector',
                ),
                'numberofrrintervals' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfRRIntervals',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfRRIntervals',
                ),
                'gatedinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GatedInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GatedInformationSequence',
                ),
                'datainformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataInformationSequence',
                ),
                'timeslotvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeSlotVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeSlotVector',
                ),
                'numberoftimeslots' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTimeSlots',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTimeSlots',
                ),
                'timeslotinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeSlotInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeSlotInformationSequence',
                ),
                'timeslottime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeSlotTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeSlotTime',
                ),
                'slicevector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SliceVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SliceVector',
                ),
                'numberofslices' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfSlices',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfSlices',
                ),
                'angularviewvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AngularViewVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AngularViewVector',
                ),
                'timeslicevector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeSliceVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeSliceVector',
                ),
                'numberoftimeslices' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTimeSlices',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTimeSlices',
                ),
                'startangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartAngle',
                ),
                'typeofdetectormotion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TypeOfDetectorMotion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TypeOfDetectorMotion',
                ),
                'triggervector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriggerVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriggerVector',
                ),
                'numberoftriggersinphase' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfTriggersInPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfTriggersInPhase',
                ),
                'viewcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewCodeSequence',
                ),
                'viewmodifiercodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ViewModifierCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ViewModifierCodeSequence',
                ),
                'radionuclidecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadionuclideCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadionuclideCodeSequence',
                ),
                'administrationroutecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AdministrationRouteCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AdministrationRouteCodeSequence',
                ),
                'radiopharmaceuticalcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiopharmaceuticalCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiopharmaceuticalCodeSequence',
                ),
                'calibrationdatasequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalibrationDataSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalibrationDataSequence',
                ),
                'energywindownumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EnergyWindowNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EnergyWindowNumber',
                ),
                'imageid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageID',
                ),
                'patientorientationcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientOrientationCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientOrientationCodeSequence',
                ),
                'patientorientationmodifiercodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientOrientationModifierCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientOrientationModifierCodeSeq',
                ),
                'patientgantryrelationshipcodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientGantryRelationshipCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientGantryRelationshipCodeSeq',
                ),
                'sliceprogressiondirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SliceProgressionDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SliceProgressionDirection',
                ),
                'seriestype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SeriesType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SeriesType',
                ),
                'units' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Units',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Units',
                ),
                'countssource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CountsSource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CountsSource',
                ),
                'reprojectionmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReprojectionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReprojectionMethod',
                ),
                'randomscorrectionmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RandomsCorrectionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RandomsCorrectionMethod',
                ),
                'attenuationcorrectionmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AttenuationCorrectionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AttenuationCorrectionMethod',
                ),
                'decaycorrection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecayCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecayCorrection',
                ),
                'reconstructionmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReconstructionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReconstructionMethod',
                ),
                'detectorlinesofresponseused' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorLinesOfResponseUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorLinesOfResponseUsed',
                ),
                'scattercorrectionmethod' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScatterCorrectionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScatterCorrectionMethod',
                ),
                'axialacceptance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AxialAcceptance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AxialAcceptance',
                ),
                'axialmash' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AxialMash',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AxialMash',
                ),
                'transversemash' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransverseMash',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransverseMash',
                ),
                'detectorelementsize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DetectorElementSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DetectorElementSize',
                ),
                'coincidencewindowwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CoincidenceWindowWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CoincidenceWindowWidth',
                ),
                'secondarycountstype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryCountsType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryCountsType',
                ),
                'framereferencetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameReferenceTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameReferenceTime',
                ),
                'primarycountsaccumulated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimaryCountsAccumulated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimaryCountsAccumulated',
                ),
                'secondarycountsaccumulated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SecondaryCountsAccumulated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SecondaryCountsAccumulated',
                ),
                'slicesensitivityfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SliceSensitivityFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SliceSensitivityFactor',
                ),
                'decayfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecayFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecayFactor',
                ),
                'dosecalibrationfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseCalibrationFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseCalibrationFactor',
                ),
                'scatterfractionfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScatterFractionFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScatterFractionFactor',
                ),
                'deadtimefactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeadTimeFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeadTimeFactor',
                ),
                'imageindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageIndex',
                ),
                'countsincluded' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CountsIncluded',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CountsIncluded',
                ),
                'deadtimecorrectionflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeadTimeCorrectionFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeadTimeCorrectionFlag',
                ),
                'histogramsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HistogramSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HistogramSequence',
                ),
                'histogramnumberofbins' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HistogramNumberOfBins',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HistogramNumberOfBins',
                ),
                'histogramfirstbinvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HistogramFirstBinValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HistogramFirstBinValue',
                ),
                'histogramlastbinvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HistogramLastBinValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HistogramLastBinValue',
                ),
                'histogrambinwidth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HistogramBinWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HistogramBinWidth',
                ),
                'histogramexplanation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HistogramExplanation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HistogramExplanation',
                ),
                'histogramdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HistogramData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HistogramData',
                ),
                'segmentationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentationType',
                ),
                'segmentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentSequence',
                ),
                'segmentedpropertycategorycodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentedPropertyCategoryCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentedPropertyCategoryCodeSeq',
                ),
                'segmentlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentLabel',
                ),
                'segmentdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentDescription',
                ),
                'segmentalgorithmtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentAlgorithmType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentAlgorithmType',
                ),
                'segmentalgorithmname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentAlgorithmName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentAlgorithmName',
                ),
                'segmentidentificationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentIdentificationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentIdentificationSequence',
                ),
                'referencedsegmentnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSegmentNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSegmentNumber',
                ),
                'recommendeddisplaygrayscalevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecommendedDisplayGrayscaleValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecommendedDisplayGrayscaleValue',
                ),
                'recommendeddisplaycielabvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecommendedDisplayCIELabValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecommendedDisplayCIELabValue',
                ),
                'maximumfractionalvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumFractionalValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumFractionalValue',
                ),
                'segmentedpropertytypecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentedPropertyTypeCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentedPropertyTypeCodeSequence',
                ),
                'segmentationfractionaltype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SegmentationFractionalType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SegmentationFractionalType',
                ),
                'deformableregistrationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeformableRegistrationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeformableRegistrationSequence',
                ),
                'sourceframeofreferenceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceFrameOfReferenceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceFrameOfReferenceUID',
                ),
                'deformableregistrationgridsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeformableRegistrationGridSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeformableRegistrationGridSequence',
                ),
                'griddimensions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridDimensions',
                ),
                'gridresolution' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridResolution',
                ),
                'vectorgriddata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VectorGridData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VectorGridData',
                ),
                'predeformationmatrixregistseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PreDeformationMatrixRegistSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PreDeformationMatrixRegistSeq',
                ),
                'postdeformationmatrixregistseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PostDeformationMatrixRegistSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PostDeformationMatrixRegistSeq',
                ),
                'numberofsurfaces' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfSurfaces',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfSurfaces',
                ),
                'surfacesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceSequence',
                ),
                'surfacenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceNumber',
                ),
                'surfacecomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceComments',
                ),
                'surfaceprocessing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceProcessing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceProcessing',
                ),
                'surfaceprocessingratio' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceProcessingRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceProcessingRatio',
                ),
                'finitevolume' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FiniteVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FiniteVolume',
                ),
                'manifold' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Manifold',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Manifold',
                ),
                'surfacepointssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfacePointsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfacePointsSequence',
                ),
                'numberofsurfacepoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfSurfacePoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfSurfacePoints',
                ),
                'pointcoordinatesdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PointCoordinatesData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PointCoordinatesData',
                ),
                'pointpositionaccuracy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PointPositionAccuracy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PointPositionAccuracy',
                ),
                'meanpointdistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeanPointDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeanPointDistance',
                ),
                'maximumpointdistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumPointDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumPointDistance',
                ),
                'axisofrotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AxisOfRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AxisOfRotation',
                ),
                'centerofrotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CenterOfRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CenterOfRotation',
                ),
                'numberofvectors' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfVectors',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfVectors',
                ),
                'vectordimensionality' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VectorDimensionality',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VectorDimensionality',
                ),
                'vectoraccuracy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VectorAccuracy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VectorAccuracy',
                ),
                'vectorcoordinatedata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VectorCoordinateData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VectorCoordinateData',
                ),
                'trianglepointindexlist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TrianglePointIndexList',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TrianglePointIndexList',
                ),
                'edgepointindexlist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EdgePointIndexList',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EdgePointIndexList',
                ),
                'vertexpointindexlist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VertexPointIndexList',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VertexPointIndexList',
                ),
                'trianglestripsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriangleStripSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriangleStripSequence',
                ),
                'trianglefansequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TriangleFanSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TriangleFanSequence',
                ),
                'linesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LineSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LineSequence',
                ),
                'primitivepointindexlist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimitivePointIndexList',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimitivePointIndexList',
                ),
                'surfacecount' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceCount',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceCount',
                ),
                'algorithmfamilycodesequ' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlgorithmFamilyCodeSequ',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlgorithmFamilyCodeSequ',
                ),
                'algorithmversion' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlgorithmVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlgorithmVersion',
                ),
                'algorithmparameters' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlgorithmParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlgorithmParameters',
                ),
                'facetsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FacetSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FacetSequence',
                ),
                'algorithmname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AlgorithmName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AlgorithmName',
                ),
                'graphicannotationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicAnnotationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicAnnotationSequence',
                ),
                'graphiclayer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicLayer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicLayer',
                ),
                'boundingboxannotationunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BoundingBoxAnnotationUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BoundingBoxAnnotationUnits',
                ),
                'anchorpointannotationunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnchorPointAnnotationUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnchorPointAnnotationUnits',
                ),
                'graphicannotationunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicAnnotationUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicAnnotationUnits',
                ),
                'unformattedtextvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UnformattedTextValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UnformattedTextValue',
                ),
                'textobjectsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TextObjectSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TextObjectSequence',
                ),
                'graphicobjectsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicObjectSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicObjectSequence',
                ),
                'boundingboxtoplefthandcorner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BoundingBoxTopLeftHandCorner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BoundingBoxTopLeftHandCorner',
                ),
                'boundingboxbottomrighthandcorner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BoundingBoxBottomRightHandCorner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BoundingBoxBottomRightHandCorner',
                ),
                'boundingboxtexthorizjustification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BoundingBoxTextHorizJustification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BoundingBoxTextHorizJustification',
                ),
                'anchorpoint' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnchorPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnchorPoint',
                ),
                'anchorpointvisibility' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnchorPointVisibility',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnchorPointVisibility',
                ),
                'graphicdimensions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicDimensions',
                ),
                'numberofgraphicpoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfGraphicPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfGraphicPoints',
                ),
                'graphicdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicData',
                ),
                'graphictype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicType',
                ),
                'graphicfilled' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicFilled',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicFilled',
                ),
                'imagerotationretired' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageRotationRetired',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageRotationRetired',
                ),
                'imagehorizontalflip' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageHorizontalFlip',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageHorizontalFlip',
                ),
                'imagerotation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageRotation',
                ),
                'displayedareatoplefttrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayedAreaTopLeftTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayedAreaTopLeftTrial',
                ),
                'displayedareabottomrighttrial' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayedAreaBottomRightTrial',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayedAreaBottomRightTrial',
                ),
                'displayedareatopleft' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayedAreaTopLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayedAreaTopLeft',
                ),
                'displayedareabottomright' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayedAreaBottomRight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayedAreaBottomRight',
                ),
                'displayedareaselectionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayedAreaSelectionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayedAreaSelectionSequence',
                ),
                'graphiclayersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicLayerSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicLayerSequence',
                ),
                'graphiclayerorder' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicLayerOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicLayerOrder',
                ),
                'graphiclayerrecdisplaygraysclvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicLayerRecDisplayGraysclValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicLayerRecDisplayGraysclValue',
                ),
                'graphiclayerrecdisplayrgbvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicLayerRecDisplayRGBValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicLayerRecDisplayRGBValue',
                ),
                'graphiclayerdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicLayerDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicLayerDescription',
                ),
                'contentlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentLabel',
                ),
                'contentdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentDescription',
                ),
                'presentationcreationdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationCreationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationCreationDate',
                ),
                'presentationcreationtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationCreationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationCreationTime',
                ),
                'contentcreatorname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentCreatorName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentCreatorName',
                ),
                'contentcreatoridcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContentCreatorIDCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContentCreatorIDCodeSequence',
                ),
                'presentationsizemode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationSizeMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationSizeMode',
                ),
                'presentationpixelspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationPixelSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationPixelSpacing',
                ),
                'presentationpixelaspectratio' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationPixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationPixelAspectRatio',
                ),
                'presentationpixelmagratio' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationPixelMagRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationPixelMagRatio',
                ),
                'shapetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShapeType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShapeType',
                ),
                'registrationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegistrationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegistrationSequence',
                ),
                'matrixregistrationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MatrixRegistrationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MatrixRegistrationSequence',
                ),
                'matrixsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MatrixSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MatrixSequence',
                ),
                'frameofreftransformationmatrixtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameOfRefTransformationMatrixType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameOfRefTransformationMatrixType',
                ),
                'registrationtypecodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RegistrationTypeCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RegistrationTypeCodeSequence',
                ),
                'fiducialdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FiducialDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FiducialDescription',
                ),
                'fiducialidentifier' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FiducialIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FiducialIdentifier',
                ),
                'fiducialidentifiercodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FiducialIdentifierCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FiducialIdentifierCodeSequence',
                ),
                'contouruncertaintyradius' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContourUncertaintyRadius',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContourUncertaintyRadius',
                ),
                'usedfiducialssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UsedFiducialsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UsedFiducialsSequence',
                ),
                'graphiccoordinatesdatasequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicCoordinatesDataSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicCoordinatesDataSequence',
                ),
                'fiducialuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FiducialUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FiducialUID',
                ),
                'fiducialsetsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FiducialSetSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FiducialSetSequence',
                ),
                'fiducialsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FiducialSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FiducialSequence',
                ),
                'graphiclayerrecomdisplaycielabval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GraphicLayerRecomDisplayCIELabVal',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GraphicLayerRecomDisplayCIELabVal',
                ),
                'blendingsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlendingSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlendingSequence',
                ),
                'relativeopacity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelativeOpacity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelativeOpacity',
                ),
                'referencedspatialregistrationseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSpatialRegistrationSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSpatialRegistrationSeq',
                ),
                'blendingposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlendingPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlendingPosition',
                ),
                'hangingprotocolname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HangingProtocolName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HangingProtocolName',
                ),
                'hangingprotocoldescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HangingProtocolDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HangingProtocolDescription',
                ),
                'hangingprotocollevel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HangingProtocolLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HangingProtocolLevel',
                ),
                'hangingprotocolcreator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HangingProtocolCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HangingProtocolCreator',
                ),
                'hangingprotocolcreationdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HangingProtocolCreationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HangingProtocolCreationDateTime',
                ),
                'hangingprotocoldefinitionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HangingProtocolDefinitionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HangingProtocolDefinitionSequence',
                ),
                'hangingprotocoluseridcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HangingProtocolUserIDCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HangingProtocolUserIDCodeSequence',
                ),
                'hangingprotocolusergroupname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HangingProtocolUserGroupName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HangingProtocolUserGroupName',
                ),
                'sourcehangingprotocolsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceHangingProtocolSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceHangingProtocolSequence',
                ),
                'numberofpriorsreferenced' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPriorsReferenced',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPriorsReferenced',
                ),
                'imagesetssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageSetsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageSetsSequence',
                ),
                'imagesetselectorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageSetSelectorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageSetSelectorSequence',
                ),
                'imagesetselectorusageflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageSetSelectorUsageFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageSetSelectorUsageFlag',
                ),
                'selectorattribute' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorAttribute',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorAttribute',
                ),
                'selectorvaluenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorValueNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorValueNumber',
                ),
                'timebasedimagesetssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TimeBasedImageSetsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TimeBasedImageSetsSequence',
                ),
                'imagesetnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageSetNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageSetNumber',
                ),
                'imagesetselectorcategory' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageSetSelectorCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageSetSelectorCategory',
                ),
                'relativetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelativeTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelativeTime',
                ),
                'relativetimeunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelativeTimeUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelativeTimeUnits',
                ),
                'abstractpriorvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AbstractPriorValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AbstractPriorValue',
                ),
                'abstractpriorcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AbstractPriorCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AbstractPriorCodeSequence',
                ),
                'imagesetlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageSetLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageSetLabel',
                ),
                'selectorattributevr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorAttributeVR',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorAttributeVR',
                ),
                'selectorsequencepointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorSequencePointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorSequencePointer',
                ),
                'selectorseqpointerprivatecreator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorSeqPointerPrivateCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorSeqPointerPrivateCreator',
                ),
                'selectorattributeprivatecreator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorAttributePrivateCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorAttributePrivateCreator',
                ),
                'selectoratvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorATValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorATValue',
                ),
                'selectorcsvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorCSValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorCSValue',
                ),
                'selectorisvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorISValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorISValue',
                ),
                'selectorlovalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorLOValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorLOValue',
                ),
                'selectorltvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorLTValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorLTValue',
                ),
                'selectorpnvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorPNValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorPNValue',
                ),
                'selectorshvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorSHValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorSHValue',
                ),
                'selectorstvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorSTValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorSTValue',
                ),
                'selectorutvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorUTValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorUTValue',
                ),
                'selectordsvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorDSValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorDSValue',
                ),
                'selectorfdvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorFDValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorFDValue',
                ),
                'selectorflvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorFLValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorFLValue',
                ),
                'selectorulvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorULValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorULValue',
                ),
                'selectorusvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorUSValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorUSValue',
                ),
                'selectorslvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorSLValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorSLValue',
                ),
                'selectorssvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorSSValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorSSValue',
                ),
                'selectorcodesequencevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SelectorCodeSequenceValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SelectorCodeSequenceValue',
                ),
                'numberofscreens' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfScreens',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfScreens',
                ),
                'nominalscreendefinitionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalScreenDefinitionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalScreenDefinitionSequence',
                ),
                'numberofverticalpixels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfVerticalPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfVerticalPixels',
                ),
                'numberofhorizontalpixels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfHorizontalPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfHorizontalPixels',
                ),
                'displayenvironmentspatialposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplayEnvironmentSpatialPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplayEnvironmentSpatialPosition',
                ),
                'screenminimumgrayscalebitdepth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScreenMinimumGrayscaleBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScreenMinimumGrayscaleBitDepth',
                ),
                'screenminimumcolorbitdepth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScreenMinimumColorBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScreenMinimumColorBitDepth',
                ),
                'applicationmaximumrepainttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationMaximumRepaintTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationMaximumRepaintTime',
                ),
                'displaysetssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetsSequence',
                ),
                'displaysetnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetNumber',
                ),
                'displaysetlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetLabel',
                ),
                'displaysetpresentationgroup' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetPresentationGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetPresentationGroup',
                ),
                'displaysetpresentationgroupdescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetPresentationGroupDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetPresentationGroupDescr',
                ),
                'partialdatadisplayhandling' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PartialDataDisplayHandling',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PartialDataDisplayHandling',
                ),
                'synchronizedscrollingsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SynchronizedScrollingSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SynchronizedScrollingSequence',
                ),
                'displaysetscrollinggroup' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetScrollingGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetScrollingGroup',
                ),
                'navigationindicatorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NavigationIndicatorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NavigationIndicatorSequence',
                ),
                'navigationdisplayset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NavigationDisplaySet',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NavigationDisplaySet',
                ),
                'referencedisplaysets' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferenceDisplaySets',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferenceDisplaySets',
                ),
                'imageboxessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxesSequence',
                ),
                'imageboxnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxNumber',
                ),
                'imageboxlayouttype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxLayoutType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxLayoutType',
                ),
                'imageboxtilehorizontaldimension' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxTileHorizontalDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxTileHorizontalDimension',
                ),
                'imageboxtileverticaldimension' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxTileVerticalDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxTileVerticalDimension',
                ),
                'imageboxscrolldirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxScrollDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxScrollDirection',
                ),
                'imageboxsmallscrolltype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxSmallScrollType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxSmallScrollType',
                ),
                'imageboxsmallscrollamount' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxSmallScrollAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxSmallScrollAmount',
                ),
                'imageboxlargescrolltype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxLargeScrollType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxLargeScrollType',
                ),
                'imageboxlargescrollamount' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxLargeScrollAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxLargeScrollAmount',
                ),
                'imageboxoverlappriority' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxOverlapPriority',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxOverlapPriority',
                ),
                'cinerelativetorealtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CineRelativeToRealTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CineRelativeToRealTime',
                ),
                'filteroperationssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterOperationsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterOperationsSequence',
                ),
                'filterbycategory' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterByCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterByCategory',
                ),
                'filterbyattributepresence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterByAttributePresence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterByAttributePresence',
                ),
                'filterbyoperator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilterByOperator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilterByOperator',
                ),
                'synchronizedimageboxlist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SynchronizedImageBoxList',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SynchronizedImageBoxList',
                ),
                'typeofsynchronization' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TypeOfSynchronization',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TypeOfSynchronization',
                ),
                'blendingoperationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlendingOperationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlendingOperationType',
                ),
                'reformattingoperationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReformattingOperationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReformattingOperationType',
                ),
                'reformattingthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReformattingThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReformattingThickness',
                ),
                'reformattinginterval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReformattingInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReformattingInterval',
                ),
                'reformattingopinitialviewdir' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReformattingOpInitialViewDir',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReformattingOpInitialViewDir',
                ),
                'renderingtype3d' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RenderingType3D',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RenderingType3D',
                ),
                'sortingoperationssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SortingOperationsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SortingOperationsSequence',
                ),
                'sortbycategory' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SortByCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SortByCategory',
                ),
                'sortingdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SortingDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SortingDirection',
                ),
                'displaysetpatientorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetPatientOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetPatientOrientation',
                ),
                'voitype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VOIType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VOIType',
                ),
                'pseudocolortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PseudoColorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PseudoColorType',
                ),
                'showgrayscaleinverted' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShowGrayscaleInverted',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShowGrayscaleInverted',
                ),
                'showimagetruesizeflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShowImageTrueSizeFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShowImageTrueSizeFlag',
                ),
                'showgraphicannotationflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShowGraphicAnnotationFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShowGraphicAnnotationFlag',
                ),
                'showpatientdemographicsflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShowPatientDemographicsFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShowPatientDemographicsFlag',
                ),
                'showacquisitiontechniquesflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShowAcquisitionTechniquesFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShowAcquisitionTechniquesFlag',
                ),
                'displaysethorizontaljustification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetHorizontalJustification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetHorizontalJustification',
                ),
                'displaysetverticaljustification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DisplaySetVerticalJustification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DisplaySetVerticalJustification',
                ),
                'unifiedprocedurestepstate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UnifiedProcedureStepState',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UnifiedProcedureStepState',
                ),
                'upsprogressinformationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UPSProgressInformationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UPSProgressInformationSequence',
                ),
                'unifiedprocedurestepprogress' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UnifiedProcedureStepProgress',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UnifiedProcedureStepProgress',
                ),
                'unifiedprocedurestepprogressdescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UnifiedProcedureStepProgressDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UnifiedProcedureStepProgressDescr',
                ),
                'unifiedprocedurestepcomuriseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UnifiedProcedureStepComURISeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UnifiedProcedureStepComURISeq',
                ),
                'contacturi' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContactURI',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContactURI',
                ),
                'contactdisplayname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContactDisplayName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContactDisplayName',
                ),
                'beamtasksequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamTaskSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamTaskSequence',
                ),
                'beamtasktype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamTaskType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamTaskType',
                ),
                'beamorderindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamOrderIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamOrderIndex',
                ),
                'deliveryverificationimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveryVerificationImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveryVerificationImageSequence',
                ),
                'verificationimagetiming' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VerificationImageTiming',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VerificationImageTiming',
                ),
                'doubleexposureflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoubleExposureFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoubleExposureFlag',
                ),
                'doubleexposureordering' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoubleExposureOrdering',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoubleExposureOrdering',
                ),
                'doubleexposuremeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoubleExposureMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoubleExposureMeterset',
                ),
                'doubleexposurefielddelta' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoubleExposureFieldDelta',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoubleExposureFieldDelta',
                ),
                'relatedreferencertimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelatedReferenceRTImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelatedReferenceRTImageSequence',
                ),
                'generalmachineverificationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeneralMachineVerificationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeneralMachineVerificationSequence',
                ),
                'conventionalmachineverificationseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConventionalMachineVerificationSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConventionalMachineVerificationSeq',
                ),
                'ionmachineverificationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonMachineVerificationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonMachineVerificationSequence',
                ),
                'failedattributessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FailedAttributesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FailedAttributesSequence',
                ),
                'overriddenattributessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverriddenAttributesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverriddenAttributesSequence',
                ),
                'conventionalcontrolpointverifyseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConventionalControlPointVerifySeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConventionalControlPointVerifySeq',
                ),
                'ioncontrolpointverificationseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonControlPointVerificationSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonControlPointVerificationSeq',
                ),
                'attributeoccurrencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AttributeOccurrenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AttributeOccurrenceSequence',
                ),
                'attributeoccurrencepointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AttributeOccurrencePointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AttributeOccurrencePointer',
                ),
                'attributeitemselector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AttributeItemSelector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AttributeItemSelector',
                ),
                'attributeoccurrenceprivatecreator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AttributeOccurrencePrivateCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AttributeOccurrencePrivateCreator',
                ),
                'scheduledproceduresteppriority' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcedureStepPriority',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcedureStepPriority',
                ),
                'worklistlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WorklistLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WorklistLabel',
                ),
                'proceduresteplabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProcedureStepLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProcedureStepLabel',
                ),
                'scheduledprocessingparametersseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScheduledProcessingParametersSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScheduledProcessingParametersSeq',
                ),
                'performedprocessingparametersseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerformedProcessingParametersSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerformedProcessingParametersSeq',
                ),
                'upsperformedproceduresequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UPSPerformedProcedureSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UPSPerformedProcedureSequence',
                ),
                'relatedprocedurestepsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelatedProcedureStepSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelatedProcedureStepSequence',
                ),
                'proceduresteprelationshiptype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProcedureStepRelationshipType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProcedureStepRelationshipType',
                ),
                'deletionlock' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeletionLock',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeletionLock',
                ),
                'receivingae' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReceivingAE',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReceivingAE',
                ),
                'requestingae' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestingAE',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestingAE',
                ),
                'reasonforcancellation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReasonForCancellation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReasonForCancellation',
                ),
                'scpstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SCPStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SCPStatus',
                ),
                'subscriptionliststatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SubscriptionListStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SubscriptionListStatus',
                ),
                'upsliststatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'UPSListStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\UPSListStatus',
                ),
                'storagemediafilesetid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StorageMediaFileSetID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StorageMediaFileSetID',
                ),
                'storagemediafilesetuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StorageMediaFileSetUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StorageMediaFileSetUID',
                ),
                'iconimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IconImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IconImageSequence',
                ),
                'topictitle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TopicTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TopicTitle',
                ),
                'topicsubject' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TopicSubject',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TopicSubject',
                ),
                'topicauthor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TopicAuthor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TopicAuthor',
                ),
                'topickeywords' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TopicKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TopicKeywords',
                ),
                'sopinstancestatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SOPInstanceStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SOPInstanceStatus',
                ),
                'sopauthorizationdateandtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SOPAuthorizationDateAndTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SOPAuthorizationDateAndTime',
                ),
                'sopauthorizationcomment' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SOPAuthorizationComment',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SOPAuthorizationComment',
                ),
                'authorizationequipmentcertnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AuthorizationEquipmentCertNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AuthorizationEquipmentCertNumber',
                ),
                'macidnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MACIDNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MACIDNumber',
                ),
                'maccalculationtransfersyntaxuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MACCalculationTransferSyntaxUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MACCalculationTransferSyntaxUID',
                ),
                'macalgorithm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MACAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MACAlgorithm',
                ),
                'dataelementssigned' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataElementsSigned',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataElementsSigned',
                ),
                'digitalsignatureuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DigitalSignatureUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DigitalSignatureUID',
                ),
                'digitalsignaturedatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DigitalSignatureDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DigitalSignatureDateTime',
                ),
                'certificatetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CertificateType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CertificateType',
                ),
                'certificateofsigner' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CertificateOfSigner',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CertificateOfSigner',
                ),
                'signature' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Signature',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Signature',
                ),
                'certifiedtimestamptype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CertifiedTimestampType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CertifiedTimestampType',
                ),
                'certifiedtimestamp' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CertifiedTimestamp',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CertifiedTimestamp',
                ),
                'digitalsignaturepurposecodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DigitalSignaturePurposeCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DigitalSignaturePurposeCodeSeq',
                ),
                'referenceddigitalsignatureseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedDigitalSignatureSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedDigitalSignatureSeq',
                ),
                'referencedsopinstancemacseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSOPInstanceMACSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSOPInstanceMACSeq',
                ),
                'mac' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MAC',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MAC',
                ),
                'encryptedattributessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EncryptedAttributesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EncryptedAttributesSequence',
                ),
                'encryptedcontenttransfersyntaxuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EncryptedContentTransferSyntaxUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EncryptedContentTransferSyntaxUID',
                ),
                'encryptedcontent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EncryptedContent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EncryptedContent',
                ),
                'modifiedattributessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifiedAttributesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifiedAttributesSequence',
                ),
                'originalattributessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OriginalAttributesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OriginalAttributesSequence',
                ),
                'attributemodificationdatetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AttributeModificationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AttributeModificationDateTime',
                ),
                'modifyingsystem' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ModifyingSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ModifyingSystem',
                ),
                'sourceofpreviousvalues' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceOfPreviousValues',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceOfPreviousValues',
                ),
                'reasonfortheattributemodification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReasonForTheAttributeModification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReasonForTheAttributeModification',
                ),
                'escapetriplet' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EscapeTriplet',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EscapeTriplet',
                ),
                'runlengthtriplet' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RunLengthTriplet',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RunLengthTriplet',
                ),
                'huffmantablesize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HuffmanTableSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HuffmanTableSize',
                ),
                'huffmantabletriplet' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HuffmanTableTriplet',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HuffmanTableTriplet',
                ),
                'shifttablesize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShiftTableSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShiftTableSize',
                ),
                'shifttabletriplet' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShiftTableTriplet',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShiftTableTriplet',
                ),
                'zonalmap' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ZonalMap',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ZonalMap',
                ),
                'numberofcopies' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfCopies',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfCopies',
                ),
                'printerconfigurationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrinterConfigurationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrinterConfigurationSequence',
                ),
                'printpriority' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrintPriority',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrintPriority',
                ),
                'mediumtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MediumType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MediumType',
                ),
                'filmdestination' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilmDestination',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilmDestination',
                ),
                'filmsessionlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilmSessionLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilmSessionLabel',
                ),
                'memoryallocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MemoryAllocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MemoryAllocation',
                ),
                'maximummemoryallocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumMemoryAllocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumMemoryAllocation',
                ),
                'colorimageprintingflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ColorImagePrintingFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ColorImagePrintingFlag',
                ),
                'collationflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CollationFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CollationFlag',
                ),
                'annotationflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnnotationFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnnotationFlag',
                ),
                'imageoverlayflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageOverlayFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageOverlayFlag',
                ),
                'presentationlutflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationLUTFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationLUTFlag',
                ),
                'imageboxpresentationlutflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxPresentationLUTFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxPresentationLUTFlag',
                ),
                'memorybitdepth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MemoryBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MemoryBitDepth',
                ),
                'printingbitdepth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrintingBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrintingBitDepth',
                ),
                'mediainstalledsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MediaInstalledSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MediaInstalledSequence',
                ),
                'othermediaavailablesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherMediaAvailableSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherMediaAvailableSequence',
                ),
                'supportedimagedisplayformatseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SupportedImageDisplayFormatSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SupportedImageDisplayFormatSeq',
                ),
                'referencedfilmboxsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFilmBoxSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFilmBoxSequence',
                ),
                'referencedstoredprintsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedStoredPrintSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedStoredPrintSequence',
                ),
                'imagedisplayformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageDisplayFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageDisplayFormat',
                ),
                'annotationdisplayformatid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnnotationDisplayFormatID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnnotationDisplayFormatID',
                ),
                'filmorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilmOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilmOrientation',
                ),
                'filmsizeid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilmSizeID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilmSizeID',
                ),
                'printerresolutionid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrinterResolutionID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrinterResolutionID',
                ),
                'defaultprinterresolutionid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DefaultPrinterResolutionID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DefaultPrinterResolutionID',
                ),
                'magnificationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MagnificationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MagnificationType',
                ),
                'smoothingtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SmoothingType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SmoothingType',
                ),
                'defaultmagnificationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DefaultMagnificationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DefaultMagnificationType',
                ),
                'othermagnificationtypesavailable' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherMagnificationTypesAvailable',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherMagnificationTypesAvailable',
                ),
                'defaultsmoothingtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DefaultSmoothingType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DefaultSmoothingType',
                ),
                'othersmoothingtypesavailable' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OtherSmoothingTypesAvailable',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OtherSmoothingTypesAvailable',
                ),
                'borderdensity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BorderDensity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BorderDensity',
                ),
                'emptyimagedensity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EmptyImageDensity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EmptyImageDensity',
                ),
                'mindensity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MinDensity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MinDensity',
                ),
                'maxdensity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaxDensity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaxDensity',
                ),
                'trim' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Trim',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Trim',
                ),
                'configurationinformation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConfigurationInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConfigurationInformation',
                ),
                'configurationinformationdescr' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConfigurationInformationDescr',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConfigurationInformationDescr',
                ),
                'maximumcollatedfilms' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumCollatedFilms',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumCollatedFilms',
                ),
                'illumination' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Illumination',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Illumination',
                ),
                'reflectedambientlight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReflectedAmbientLight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReflectedAmbientLight',
                ),
                'printerpixelspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrinterPixelSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrinterPixelSpacing',
                ),
                'referencedfilmsessionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFilmSessionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFilmSessionSequence',
                ),
                'referencedimageboxsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedImageBoxSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedImageBoxSequence',
                ),
                'referencedbasicannotationboxseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedBasicAnnotationBoxSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedBasicAnnotationBoxSeq',
                ),
                'imageboxposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxPosition',
                ),
                'polarity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Polarity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Polarity',
                ),
                'requestedimagesize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedImageSize',
                ),
                'requesteddecimate-cropbehavior' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedDecimate-CropBehavior',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedDecimateCropBehavior',
                ),
                'requestedresolutionid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedResolutionID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedResolutionID',
                ),
                'requestedimagesizeflag' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedImageSizeFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedImageSizeFlag',
                ),
                'decimatecropresult' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DecimateCropResult',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DecimateCropResult',
                ),
                'basicgrayscaleimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BasicGrayscaleImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BasicGrayscaleImageSequence',
                ),
                'basiccolorimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BasicColorImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BasicColorImageSequence',
                ),
                'referencedimageoverlayboxsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedImageOverlayBoxSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedImageOverlayBoxSequence',
                ),
                'referencedvoilutboxsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedVOILUTBoxSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedVOILUTBoxSequence',
                ),
                'annotationposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnnotationPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnnotationPosition',
                ),
                'textstring' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TextString',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TextString',
                ),
                'referencedoverlayplanesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedOverlayPlaneSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedOverlayPlaneSequence',
                ),
                'referencedoverlayplanegroups' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedOverlayPlaneGroups',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedOverlayPlaneGroups',
                ),
                'overlaypixeldatasequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayPixelDataSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayPixelDataSequence',
                ),
                'overlaymagnificationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayMagnificationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayMagnificationType',
                ),
                'overlaysmoothingtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlaySmoothingType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlaySmoothingType',
                ),
                'overlayorimagemagnification' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayOrImageMagnification',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayOrImageMagnification',
                ),
                'magnifytonumberofcolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MagnifyToNumberOfColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MagnifyToNumberOfColumns',
                ),
                'overlayforegrounddensity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayForegroundDensity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayForegroundDensity',
                ),
                'overlaybackgrounddensity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayBackgroundDensity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayBackgroundDensity',
                ),
                'overlaymode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayMode',
                ),
                'thresholddensity' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ThresholdDensity',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ThresholdDensity',
                ),
                'presentationlutsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationLUTSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationLUTSequence',
                ),
                'presentationlutshape' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationLUTShape',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationLUTShape',
                ),
                'referencedpresentationlutsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedPresentationLUTSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedPresentationLUTSequence',
                ),
                'printjobid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrintJobID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrintJobID',
                ),
                'executionstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExecutionStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExecutionStatus',
                ),
                'executionstatusinfo' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExecutionStatusInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExecutionStatusInfo',
                ),
                'creationdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CreationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CreationDate',
                ),
                'creationtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CreationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CreationTime',
                ),
                'originator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Originator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Originator',
                ),
                'destinationae' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DestinationAE',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DestinationAE',
                ),
                'ownerid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OwnerID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OwnerID',
                ),
                'numberoffilms' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfFilms',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfFilms',
                ),
                'referencedprintjobsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedPrintJobSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedPrintJobSequence',
                ),
                'printerstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrinterStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrinterStatus',
                ),
                'printerstatusinfo' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrinterStatusInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrinterStatusInfo',
                ),
                'printername' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrinterName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrinterName',
                ),
                'printqueueid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrintQueueID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrintQueueID',
                ),
                'queuestatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'QueueStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\QueueStatus',
                ),
                'printjobdescriptionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrintJobDescriptionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrintJobDescriptionSequence',
                ),
                'printmanagementcapabilitiesseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrintManagementCapabilitiesSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrintManagementCapabilitiesSeq',
                ),
                'printercharacteristicssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrinterCharacteristicsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrinterCharacteristicsSequence',
                ),
                'filmboxcontentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FilmBoxContentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FilmBoxContentSequence',
                ),
                'imageboxcontentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageBoxContentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageBoxContentSequence',
                ),
                'annotationcontentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AnnotationContentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AnnotationContentSequence',
                ),
                'imageoverlayboxcontentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageOverlayBoxContentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageOverlayBoxContentSequence',
                ),
                'presentationlutcontentsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PresentationLUTContentSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PresentationLUTContentSequence',
                ),
                'proposedstudysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ProposedStudySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ProposedStudySequence',
                ),
                'originalimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OriginalImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OriginalImageSequence',
                ),
                'labelfrominfoextractedfrominstance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LabelFromInfoExtractedFromInstance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LabelFromInfoExtractedFromInstance',
                ),
                'labeltext' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LabelText',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LabelText',
                ),
                'labelstyleselection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LabelStyleSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LabelStyleSelection',
                ),
                'mediadisposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MediaDisposition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MediaDisposition',
                ),
                'barcodevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BarcodeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BarcodeValue',
                ),
                'barcodesymbology' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BarcodeSymbology',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BarcodeSymbology',
                ),
                'allowmediasplitting' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AllowMediaSplitting',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AllowMediaSplitting',
                ),
                'includenondicomobjects' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IncludeNonDICOMObjects',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IncludeNonDICOMObjects',
                ),
                'includedisplayapplication' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IncludeDisplayApplication',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IncludeDisplayApplication',
                ),
                'savecompinstancesaftermediacreate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SaveCompInstancesAfterMediaCreate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SaveCompInstancesAfterMediaCreate',
                ),
                'totalnumbermediapiecescreated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalNumberMediaPiecesCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalNumberMediaPiecesCreated',
                ),
                'requestedmediaapplicationprofile' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestedMediaApplicationProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestedMediaApplicationProfile',
                ),
                'referencedstoragemediasequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedStorageMediaSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedStorageMediaSequence',
                ),
                'failureattributes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FailureAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FailureAttributes',
                ),
                'allowlossycompression' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AllowLossyCompression',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AllowLossyCompression',
                ),
                'requestpriority' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RequestPriority',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RequestPriority',
                ),
                'rtimagelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTImageLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTImageLabel',
                ),
                'rtimagename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTImageName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTImageName',
                ),
                'rtimagedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTImageDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTImageDescription',
                ),
                'reportedvaluesorigin' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReportedValuesOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReportedValuesOrigin',
                ),
                'rtimageplane' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTImagePlane',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTImagePlane',
                ),
                'xrayimagereceptortranslation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayImageReceptorTranslation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayImageReceptorTranslation',
                ),
                'xrayimagereceptorangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'XRayImageReceptorAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\XRayImageReceptorAngle',
                ),
                'rtimageorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTImageOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTImageOrientation',
                ),
                'imageplanepixelspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagePlanePixelSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagePlanePixelSpacing',
                ),
                'rtimageposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTImagePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTImagePosition',
                ),
                'radiationmachinename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationMachineName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationMachineName',
                ),
                'radiationmachinesad' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationMachineSAD',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationMachineSAD',
                ),
                'radiationmachinessd' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationMachineSSD',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationMachineSSD',
                ),
                'rtimagesid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTImageSID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTImageSID',
                ),
                'sourcetoreferenceobjectdistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceToReferenceObjectDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceToReferenceObjectDistance',
                ),
                'fractionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionNumber',
                ),
                'exposuresequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ExposureSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ExposureSequence',
                ),
                'metersetexposure' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MetersetExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MetersetExposure',
                ),
                'diaphragmposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DiaphragmPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DiaphragmPosition',
                ),
                'fluencemapsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FluenceMapSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FluenceMapSequence',
                ),
                'fluencedatasource' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FluenceDataSource',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FluenceDataSource',
                ),
                'fluencedatascale' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FluenceDataScale',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FluenceDataScale',
                ),
                'fluencemode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FluenceMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FluenceMode',
                ),
                'fluencemodeid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FluenceModeID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FluenceModeID',
                ),
                'dvhtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHType',
                ),
                'doseunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseUnits',
                ),
                'dosetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseType',
                ),
                'dosecomment' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseComment',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseComment',
                ),
                'normalizationpoint' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NormalizationPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NormalizationPoint',
                ),
                'dosesummationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseSummationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseSummationType',
                ),
                'gridframeoffsetvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GridFrameOffsetVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GridFrameOffsetVector',
                ),
                'dosegridscaling' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseGridScaling',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseGridScaling',
                ),
                'rtdoseroisequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTDoseROISequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTDoseROISequence',
                ),
                'dosevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseValue',
                ),
                'tissueheterogeneitycorrection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TissueHeterogeneityCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TissueHeterogeneityCorrection',
                ),
                'dvhnormalizationpoint' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHNormalizationPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHNormalizationPoint',
                ),
                'dvhnormalizationdosevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHNormalizationDoseValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHNormalizationDoseValue',
                ),
                'dvhsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHSequence',
                ),
                'dvhdosescaling' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHDoseScaling',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHDoseScaling',
                ),
                'dvhvolumeunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHVolumeUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHVolumeUnits',
                ),
                'dvhnumberofbins' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHNumberOfBins',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHNumberOfBins',
                ),
                'dvhdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHData',
                ),
                'dvhreferencedroisequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHReferencedROISequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHReferencedROISequence',
                ),
                'dvhroicontributiontype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHROIContributionType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHROIContributionType',
                ),
                'dvhminimumdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHMinimumDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHMinimumDose',
                ),
                'dvhmaximumdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHMaximumDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHMaximumDose',
                ),
                'dvhmeandose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DVHMeanDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DVHMeanDose',
                ),
                'structuresetlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StructureSetLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StructureSetLabel',
                ),
                'structuresetname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StructureSetName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StructureSetName',
                ),
                'structuresetdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StructureSetDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StructureSetDescription',
                ),
                'structuresetdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StructureSetDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StructureSetDate',
                ),
                'structuresettime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StructureSetTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StructureSetTime',
                ),
                'referencedframeofreferencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFrameOfReferenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFrameOfReferenceSequence',
                ),
                'rtreferencedstudysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTReferencedStudySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTReferencedStudySequence',
                ),
                'rtreferencedseriessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTReferencedSeriesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTReferencedSeriesSequence',
                ),
                'contourimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContourImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContourImageSequence',
                ),
                'structuresetroisequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StructureSetROISequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StructureSetROISequence',
                ),
                'roinumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROINumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROINumber',
                ),
                'referencedframeofreferenceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFrameOfReferenceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFrameOfReferenceUID',
                ),
                'roiname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIName',
                ),
                'roidescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIDescription',
                ),
                'roidisplaycolor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIDisplayColor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIDisplayColor',
                ),
                'roivolume' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIVolume',
                ),
                'rtrelatedroisequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTRelatedROISequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTRelatedROISequence',
                ),
                'rtroirelationship' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTROIRelationship',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTROIRelationship',
                ),
                'roigenerationalgorithm' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIGenerationAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIGenerationAlgorithm',
                ),
                'roigenerationdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIGenerationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIGenerationDescription',
                ),
                'roicontoursequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIContourSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIContourSequence',
                ),
                'contoursequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContourSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContourSequence',
                ),
                'contourgeometrictype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContourGeometricType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContourGeometricType',
                ),
                'contourslabthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContourSlabThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContourSlabThickness',
                ),
                'contouroffsetvector' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContourOffsetVector',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContourOffsetVector',
                ),
                'numberofcontourpoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfContourPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfContourPoints',
                ),
                'contournumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContourNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContourNumber',
                ),
                'attachedcontours' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AttachedContours',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AttachedContours',
                ),
                'contourdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ContourData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ContourData',
                ),
                'rtroiobservationssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTROIObservationsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTROIObservationsSequence',
                ),
                'observationnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ObservationNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ObservationNumber',
                ),
                'referencedroinumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedROINumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedROINumber',
                ),
                'roiobservationlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIObservationLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIObservationLabel',
                ),
                'rtroiidentificationcodesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTROIIdentificationCodeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTROIIdentificationCodeSequence',
                ),
                'roiobservationdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIObservationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIObservationDescription',
                ),
                'relatedrtroiobservationssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelatedRTROIObservationsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelatedRTROIObservationsSequence',
                ),
                'rtroiinterpretedtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTROIInterpretedType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTROIInterpretedType',
                ),
                'roiinterpreter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIInterpreter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIInterpreter',
                ),
                'roiphysicalpropertiessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIPhysicalPropertiesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIPhysicalPropertiesSequence',
                ),
                'roiphysicalproperty' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIPhysicalProperty',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIPhysicalProperty',
                ),
                'roiphysicalpropertyvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIPhysicalPropertyValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIPhysicalPropertyValue',
                ),
                'roielementalcompositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIElementalCompositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIElementalCompositionSequence',
                ),
                'roielementalcompatomicnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIElementalCompAtomicNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIElementalCompAtomicNumber',
                ),
                'roielementalcompatomicmassfraction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIElementalCompAtomicMassFraction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIElementalCompAtomicMassFraction',
                ),
                'frameofreferencerelationshipseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameOfReferenceRelationshipSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceRelationshipSeq',
                ),
                'relatedframeofreferenceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RelatedFrameOfReferenceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RelatedFrameOfReferenceUID',
                ),
                'frameofreferencetransformtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameOfReferenceTransformType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceTransformType',
                ),
                'frameofreferencetransformmatrix' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameOfReferenceTransformMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceTransformMatrix',
                ),
                'frameofreferencetransformcomment' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FrameOfReferenceTransformComment',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FrameOfReferenceTransformComment',
                ),
                'measureddosereferencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeasuredDoseReferenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeasuredDoseReferenceSequence',
                ),
                'measureddosedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeasuredDoseDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeasuredDoseDescription',
                ),
                'measureddosetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeasuredDoseType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeasuredDoseType',
                ),
                'measureddosevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeasuredDoseValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeasuredDoseValue',
                ),
                'treatmentsessionbeamsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentSessionBeamSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentSessionBeamSequence',
                ),
                'treatmentsessionionbeamsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentSessionIonBeamSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentSessionIonBeamSequence',
                ),
                'currentfractionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurrentFractionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurrentFractionNumber',
                ),
                'treatmentcontrolpointdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentControlPointDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentControlPointDate',
                ),
                'treatmentcontrolpointtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentControlPointTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentControlPointTime',
                ),
                'treatmentterminationstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentTerminationStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentTerminationStatus',
                ),
                'treatmentterminationcode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentTerminationCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentTerminationCode',
                ),
                'treatmentverificationstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentVerificationStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentVerificationStatus',
                ),
                'referencedtreatmentrecordsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedTreatmentRecordSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedTreatmentRecordSequence',
                ),
                'specifiedprimarymeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecifiedPrimaryMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecifiedPrimaryMeterset',
                ),
                'specifiedsecondarymeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecifiedSecondaryMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecifiedSecondaryMeterset',
                ),
                'deliveredprimarymeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveredPrimaryMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveredPrimaryMeterset',
                ),
                'deliveredsecondarymeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveredSecondaryMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveredSecondaryMeterset',
                ),
                'specifiedtreatmenttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecifiedTreatmentTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecifiedTreatmentTime',
                ),
                'deliveredtreatmenttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveredTreatmentTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveredTreatmentTime',
                ),
                'controlpointdeliverysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ControlPointDeliverySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ControlPointDeliverySequence',
                ),
                'ioncontrolpointdeliverysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonControlPointDeliverySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonControlPointDeliverySequence',
                ),
                'specifiedmeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecifiedMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecifiedMeterset',
                ),
                'deliveredmeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveredMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveredMeterset',
                ),
                'metersetrateset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MetersetRateSet',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MetersetRateSet',
                ),
                'metersetratedelivered' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MetersetRateDelivered',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MetersetRateDelivered',
                ),
                'scanspotmetersetsdelivered' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanSpotMetersetsDelivered',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanSpotMetersetsDelivered',
                ),
                'doseratedelivered' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseRateDelivered',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseRateDelivered',
                ),
                'treatmentsummarycalcdoserefseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentSummaryCalcDoseRefSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentSummaryCalcDoseRefSeq',
                ),
                'cumulativedosetodosereference' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CumulativeDoseToDoseReference',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CumulativeDoseToDoseReference',
                ),
                'firsttreatmentdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FirstTreatmentDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FirstTreatmentDate',
                ),
                'mostrecenttreatmentdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MostRecentTreatmentDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MostRecentTreatmentDate',
                ),
                'numberoffractionsdelivered' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfFractionsDelivered',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfFractionsDelivered',
                ),
                'overridesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverrideSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverrideSequence',
                ),
                'parametersequencepointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParameterSequencePointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParameterSequencePointer',
                ),
                'overrideparameterpointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverrideParameterPointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverrideParameterPointer',
                ),
                'parameteritemindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParameterItemIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParameterItemIndex',
                ),
                'measureddosereferencenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MeasuredDoseReferenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MeasuredDoseReferenceNumber',
                ),
                'parameterpointer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ParameterPointer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ParameterPointer',
                ),
                'overridereason' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverrideReason',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverrideReason',
                ),
                'correctedparametersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CorrectedParameterSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CorrectedParameterSequence',
                ),
                'correctionvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CorrectionValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CorrectionValue',
                ),
                'calculateddosereferencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalculatedDoseReferenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalculatedDoseReferenceSequence',
                ),
                'calculateddosereferencenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalculatedDoseReferenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalculatedDoseReferenceNumber',
                ),
                'calculateddosereferencedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalculatedDoseReferenceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalculatedDoseReferenceDescription',
                ),
                'calculateddosereferencedosevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CalculatedDoseReferenceDoseValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CalculatedDoseReferenceDoseValue',
                ),
                'startmeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartMeterset',
                ),
                'endmeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndMeterset',
                ),
                'referencedmeasureddosereferenceseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedMeasuredDoseReferenceSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedMeasuredDoseReferenceSeq',
                ),
                'referencedmeasureddosereferencenum' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedMeasuredDoseReferenceNum',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedMeasuredDoseReferenceNum',
                ),
                'referencedcalculateddoserefseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedCalculatedDoseRefSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedCalculatedDoseRefSeq',
                ),
                'referencedcalculateddoserefnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedCalculatedDoseRefNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedCalculatedDoseRefNumber',
                ),
                'beamlimitingdeviceleafpairsseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamLimitingDeviceLeafPairsSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceLeafPairsSeq',
                ),
                'recordedwedgesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedWedgeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedWedgeSequence',
                ),
                'recordedcompensatorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedCompensatorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedCompensatorSequence',
                ),
                'recordedblocksequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedBlockSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedBlockSequence',
                ),
                'treatmentsummarymeasureddoserefseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentSummaryMeasuredDoseRefSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentSummaryMeasuredDoseRefSeq',
                ),
                'recordedsnoutsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedSnoutSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedSnoutSequence',
                ),
                'recordedrangeshiftersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedRangeShifterSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedRangeShifterSequence',
                ),
                'recordedlateralspreadingdeviceseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedLateralSpreadingDeviceSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedLateralSpreadingDeviceSeq',
                ),
                'recordedrangemodulatorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedRangeModulatorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedRangeModulatorSequence',
                ),
                'recordedsourcesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedSourceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedSourceSequence',
                ),
                'sourceserialnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceSerialNumber',
                ),
                'treatmentsessionappsetupseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentSessionAppSetupSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentSessionAppSetupSeq',
                ),
                'applicationsetupcheck' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationSetupCheck',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationSetupCheck',
                ),
                'recordedbrachyaccessorydeviceseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedBrachyAccessoryDeviceSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedBrachyAccessoryDeviceSeq',
                ),
                'referencedbrachyaccessorydevicenum' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedBrachyAccessoryDeviceNum',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedBrachyAccessoryDeviceNum',
                ),
                'recordedchannelsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedChannelSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedChannelSequence',
                ),
                'specifiedchanneltotaltime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecifiedChannelTotalTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecifiedChannelTotalTime',
                ),
                'deliveredchanneltotaltime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveredChannelTotalTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveredChannelTotalTime',
                ),
                'specifiednumberofpulses' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecifiedNumberOfPulses',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecifiedNumberOfPulses',
                ),
                'deliverednumberofpulses' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveredNumberOfPulses',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveredNumberOfPulses',
                ),
                'specifiedpulserepetitioninterval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpecifiedPulseRepetitionInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpecifiedPulseRepetitionInterval',
                ),
                'deliveredpulserepetitioninterval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveredPulseRepetitionInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveredPulseRepetitionInterval',
                ),
                'recordedsourceapplicatorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedSourceApplicatorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedSourceApplicatorSequence',
                ),
                'referencedsourceapplicatornumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSourceApplicatorNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSourceApplicatorNumber',
                ),
                'recordedchannelshieldsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RecordedChannelShieldSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RecordedChannelShieldSequence',
                ),
                'referencedchannelshieldnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedChannelShieldNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedChannelShieldNumber',
                ),
                'brachycontrolpointdeliveredseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyControlPointDeliveredSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyControlPointDeliveredSeq',
                ),
                'safepositionexitdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SafePositionExitDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SafePositionExitDate',
                ),
                'safepositionexittime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SafePositionExitTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SafePositionExitTime',
                ),
                'safepositionreturndate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SafePositionReturnDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SafePositionReturnDate',
                ),
                'safepositionreturntime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SafePositionReturnTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SafePositionReturnTime',
                ),
                'currenttreatmentstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurrentTreatmentStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurrentTreatmentStatus',
                ),
                'treatmentstatuscomment' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentStatusComment',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentStatusComment',
                ),
                'fractiongroupsummarysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionGroupSummarySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionGroupSummarySequence',
                ),
                'referencedfractionnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFractionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFractionNumber',
                ),
                'fractiongrouptype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionGroupType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionGroupType',
                ),
                'beamstopperposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamStopperPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamStopperPosition',
                ),
                'fractionstatussummarysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionStatusSummarySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionStatusSummarySequence',
                ),
                'treatmentdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentDate',
                ),
                'treatmenttime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentTime',
                ),
                'rtplanlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTPlanLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTPlanLabel',
                ),
                'rtplanname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTPlanName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTPlanName',
                ),
                'rtplandescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTPlanDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTPlanDescription',
                ),
                'rtplandate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTPlanDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTPlanDate',
                ),
                'rtplantime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTPlanTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTPlanTime',
                ),
                'treatmentprotocols' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentProtocols',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentProtocols',
                ),
                'planintent' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlanIntent',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlanIntent',
                ),
                'treatmentsites' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentSites',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentSites',
                ),
                'rtplangeometry' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTPlanGeometry',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTPlanGeometry',
                ),
                'prescriptiondescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrescriptionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrescriptionDescription',
                ),
                'dosereferencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseReferenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseReferenceSequence',
                ),
                'dosereferencenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseReferenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseReferenceNumber',
                ),
                'dosereferenceuid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseReferenceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseReferenceUID',
                ),
                'dosereferencestructuretype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseReferenceStructureType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseReferenceStructureType',
                ),
                'nominalbeamenergyunit' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalBeamEnergyUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalBeamEnergyUnit',
                ),
                'dosereferencedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseReferenceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseReferenceDescription',
                ),
                'dosereferencepointcoordinates' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseReferencePointCoordinates',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseReferencePointCoordinates',
                ),
                'nominalpriordose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalPriorDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalPriorDose',
                ),
                'dosereferencetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseReferenceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseReferenceType',
                ),
                'constraintweight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ConstraintWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ConstraintWeight',
                ),
                'deliverywarningdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveryWarningDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveryWarningDose',
                ),
                'deliverymaximumdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DeliveryMaximumDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DeliveryMaximumDose',
                ),
                'targetminimumdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TargetMinimumDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TargetMinimumDose',
                ),
                'targetprescriptiondose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TargetPrescriptionDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TargetPrescriptionDose',
                ),
                'targetmaximumdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TargetMaximumDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TargetMaximumDose',
                ),
                'targetunderdosevolumefraction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TargetUnderdoseVolumeFraction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TargetUnderdoseVolumeFraction',
                ),
                'organatriskfullvolumedose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrganAtRiskFullVolumeDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrganAtRiskFullVolumeDose',
                ),
                'organatrisklimitdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrganAtRiskLimitDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrganAtRiskLimitDose',
                ),
                'organatriskmaximumdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrganAtRiskMaximumDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrganAtRiskMaximumDose',
                ),
                'organatriskoverdosevolumefraction' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OrganAtRiskOverdoseVolumeFraction',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OrganAtRiskOverdoseVolumeFraction',
                ),
                'tolerancetablesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ToleranceTableSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ToleranceTableSequence',
                ),
                'tolerancetablenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ToleranceTableNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ToleranceTableNumber',
                ),
                'tolerancetablelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ToleranceTableLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ToleranceTableLabel',
                ),
                'gantryangletolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryAngleTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryAngleTolerance',
                ),
                'beamlimitingdeviceangletolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamLimitingDeviceAngleTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceAngleTolerance',
                ),
                'beamlimitingdevicetoleranceseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamLimitingDeviceToleranceSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceToleranceSeq',
                ),
                'beamlimitingdevicepositiontol' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamLimitingDevicePositionTol',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamLimitingDevicePositionTol',
                ),
                'snoutpositiontolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SnoutPositionTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SnoutPositionTolerance',
                ),
                'patientsupportangletolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSupportAngleTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSupportAngleTolerance',
                ),
                'tabletopeccentricangletolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopEccentricAngleTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopEccentricAngleTolerance',
                ),
                'tabletoppitchangletolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopPitchAngleTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopPitchAngleTolerance',
                ),
                'tabletoprollangletolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopRollAngleTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopRollAngleTolerance',
                ),
                'tabletopverticalpositiontolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopVerticalPositionTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopVerticalPositionTolerance',
                ),
                'tabletoplongitudinalpositiontol' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopLongitudinalPositionTol',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopLongitudinalPositionTol',
                ),
                'tabletoplateralpositiontolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopLateralPositionTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopLateralPositionTolerance',
                ),
                'rtplanrelationship' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTPlanRelationship',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTPlanRelationship',
                ),
                'fractiongroupsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionGroupSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionGroupSequence',
                ),
                'fractiongroupnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionGroupNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionGroupNumber',
                ),
                'fractiongroupdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionGroupDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionGroupDescription',
                ),
                'numberoffractionsplanned' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfFractionsPlanned',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfFractionsPlanned',
                ),
                'numberfractionpatterndigitsperday' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberFractionPatternDigitsPerDay',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberFractionPatternDigitsPerDay',
                ),
                'repeatfractioncyclelength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RepeatFractionCycleLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RepeatFractionCycleLength',
                ),
                'fractionpattern' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FractionPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FractionPattern',
                ),
                'numberofbeams' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfBeams',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfBeams',
                ),
                'beamdosespecificationpoint' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamDoseSpecificationPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamDoseSpecificationPoint',
                ),
                'beamdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamDose',
                ),
                'beammeterset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamMeterset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamMeterset',
                ),
                'beamdosepointdepth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamDosePointDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamDosePointDepth',
                ),
                'beamdosepointequivalentdepth' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamDosePointEquivalentDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamDosePointEquivalentDepth',
                ),
                'beamdosepointssd' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamDosePointSSD',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamDosePointSSD',
                ),
                'numberofbrachyapplicationsetups' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfBrachyApplicationSetups',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfBrachyApplicationSetups',
                ),
                'brachyappsetupdosespecpoint' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyAppSetupDoseSpecPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyAppSetupDoseSpecPoint',
                ),
                'brachyapplicationsetupdose' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyApplicationSetupDose',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyApplicationSetupDose',
                ),
                'beamsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamSequence',
                ),
                'treatmentmachinename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentMachineName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentMachineName',
                ),
                'primarydosimeterunit' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PrimaryDosimeterUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PrimaryDosimeterUnit',
                ),
                'sourceaxisdistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceAxisDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceAxisDistance',
                ),
                'beamlimitingdevicesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamLimitingDeviceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceSequence',
                ),
                'rtbeamlimitingdevicetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RTBeamLimitingDeviceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RTBeamLimitingDeviceType',
                ),
                'sourcetobeamlimitingdevicedistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceToBeamLimitingDeviceDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceToBeamLimitingDeviceDistance',
                ),
                'isocentertobeamlimitingdevicedist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterToBeamLimitingDeviceDist',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterToBeamLimitingDeviceDist',
                ),
                'numberofleafjawpairs' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfLeafJawPairs',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfLeafJawPairs',
                ),
                'leafpositionboundaries' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LeafPositionBoundaries',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LeafPositionBoundaries',
                ),
                'beamnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamNumber',
                ),
                'beamname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamName',
                ),
                'beamdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamDescription',
                ),
                'beamtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamType',
                ),
                'radiationtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationType',
                ),
                'highdosetechniquetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HighDoseTechniqueType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HighDoseTechniqueType',
                ),
                'referenceimagenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferenceImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferenceImageNumber',
                ),
                'plannedverificationimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PlannedVerificationImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PlannedVerificationImageSequence',
                ),
                'imagingdevicespecificacqparams' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImagingDeviceSpecificAcqParams',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImagingDeviceSpecificAcqParams',
                ),
                'treatmentdeliverytype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentDeliveryType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentDeliveryType',
                ),
                'numberofwedges' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfWedges',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfWedges',
                ),
                'wedgesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgeSequence',
                ),
                'wedgenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgeNumber',
                ),
                'wedgetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgeType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgeType',
                ),
                'wedgeid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgeID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgeID',
                ),
                'wedgeangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgeAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgeAngle',
                ),
                'wedgefactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgeFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgeFactor',
                ),
                'totalwedgetraywaterequivthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalWedgeTrayWaterEquivThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalWedgeTrayWaterEquivThickness',
                ),
                'wedgeorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgeOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgeOrientation',
                ),
                'isocentertowedgetraydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterToWedgeTrayDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterToWedgeTrayDistance',
                ),
                'sourcetowedgetraydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceToWedgeTrayDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceToWedgeTrayDistance',
                ),
                'wedgethinedgeposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgeThinEdgePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgeThinEdgePosition',
                ),
                'bolusid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BolusID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BolusID',
                ),
                'bolusdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BolusDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BolusDescription',
                ),
                'numberofcompensators' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfCompensators',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfCompensators',
                ),
                'materialid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaterialID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaterialID',
                ),
                'totalcompensatortrayfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalCompensatorTrayFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalCompensatorTrayFactor',
                ),
                'compensatorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorSequence',
                ),
                'compensatornumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorNumber',
                ),
                'compensatorid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorID',
                ),
                'sourcetocompensatortraydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceToCompensatorTrayDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceToCompensatorTrayDistance',
                ),
                'compensatorrows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorRows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorRows',
                ),
                'compensatorcolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorColumns',
                ),
                'compensatorpixelspacing' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorPixelSpacing',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorPixelSpacing',
                ),
                'compensatorposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorPosition',
                ),
                'compensatortransmissiondata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorTransmissionData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorTransmissionData',
                ),
                'compensatorthicknessdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorThicknessData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorThicknessData',
                ),
                'numberofboli' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfBoli',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfBoli',
                ),
                'compensatortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorType',
                ),
                'numberofblocks' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfBlocks',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfBlocks',
                ),
                'totalblocktrayfactor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalBlockTrayFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalBlockTrayFactor',
                ),
                'totalblocktraywaterequivthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalBlockTrayWaterEquivThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalBlockTrayWaterEquivThickness',
                ),
                'blocksequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockSequence',
                ),
                'blocktrayid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockTrayID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockTrayID',
                ),
                'sourcetoblocktraydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceToBlockTrayDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceToBlockTrayDistance',
                ),
                'isocentertoblocktraydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterToBlockTrayDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterToBlockTrayDistance',
                ),
                'blocktype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockType',
                ),
                'accessorycode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AccessoryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AccessoryCode',
                ),
                'blockdivergence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockDivergence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockDivergence',
                ),
                'blockmountingposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockMountingPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockMountingPosition',
                ),
                'blocknumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockNumber',
                ),
                'blockname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockName',
                ),
                'blockthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockThickness',
                ),
                'blocktransmission' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockTransmission',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockTransmission',
                ),
                'blocknumberofpoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockNumberOfPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockNumberOfPoints',
                ),
                'blockdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BlockData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BlockData',
                ),
                'applicatorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicatorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicatorSequence',
                ),
                'applicatorid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicatorID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicatorID',
                ),
                'applicatortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicatorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicatorType',
                ),
                'applicatordescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicatorDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicatorDescription',
                ),
                'cumulativedosereferencecoefficient' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CumulativeDoseReferenceCoefficient',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CumulativeDoseReferenceCoefficient',
                ),
                'finalcumulativemetersetweight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FinalCumulativeMetersetWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FinalCumulativeMetersetWeight',
                ),
                'numberofcontrolpoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfControlPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfControlPoints',
                ),
                'controlpointsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ControlPointSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ControlPointSequence',
                ),
                'controlpointindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ControlPointIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ControlPointIndex',
                ),
                'nominalbeamenergy' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NominalBeamEnergy',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NominalBeamEnergy',
                ),
                'doserateset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DoseRateSet',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DoseRateSet',
                ),
                'wedgepositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgePositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgePositionSequence',
                ),
                'wedgeposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WedgePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WedgePosition',
                ),
                'beamlimitingdevicepositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamLimitingDevicePositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamLimitingDevicePositionSequence',
                ),
                'leafjawpositions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LeafJawPositions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LeafJawPositions',
                ),
                'gantryangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryAngle',
                ),
                'gantryrotationdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryRotationDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryRotationDirection',
                ),
                'beamlimitingdeviceangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamLimitingDeviceAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceAngle',
                ),
                'beamlimitingdevicerotatedirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamLimitingDeviceRotateDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamLimitingDeviceRotateDirection',
                ),
                'patientsupportangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSupportAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSupportAngle',
                ),
                'patientsupportrotationdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSupportRotationDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSupportRotationDirection',
                ),
                'tabletopeccentricaxisdistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopEccentricAxisDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopEccentricAxisDistance',
                ),
                'tabletopeccentricangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopEccentricAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopEccentricAngle',
                ),
                'tabletopeccentricrotatedirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopEccentricRotateDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopEccentricRotateDirection',
                ),
                'tabletopverticalposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopVerticalPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopVerticalPosition',
                ),
                'tabletoplongitudinalposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopLongitudinalPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopLongitudinalPosition',
                ),
                'tabletoplateralposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopLateralPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopLateralPosition',
                ),
                'isocenterposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterPosition',
                ),
                'surfaceentrypoint' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SurfaceEntryPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SurfaceEntryPoint',
                ),
                'sourcetosurfacedistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceToSurfaceDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceToSurfaceDistance',
                ),
                'cumulativemetersetweight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CumulativeMetersetWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CumulativeMetersetWeight',
                ),
                'tabletoppitchangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopPitchAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopPitchAngle',
                ),
                'tabletoppitchrotationdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopPitchRotationDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopPitchRotationDirection',
                ),
                'tabletoprollangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopRollAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopRollAngle',
                ),
                'tabletoprollrotationdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopRollRotationDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopRollRotationDirection',
                ),
                'headfixationangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'HeadFixationAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\HeadFixationAngle',
                ),
                'gantrypitchangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryPitchAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryPitchAngle',
                ),
                'gantrypitchrotationdirection' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryPitchRotationDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryPitchRotationDirection',
                ),
                'gantrypitchangletolerance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GantryPitchAngleTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GantryPitchAngleTolerance',
                ),
                'patientsetupsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSetupSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSetupSequence',
                ),
                'patientsetupnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSetupNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSetupNumber',
                ),
                'patientsetuplabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSetupLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSetupLabel',
                ),
                'patientadditionalposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientAdditionalPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientAdditionalPosition',
                ),
                'fixationdevicesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationDeviceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationDeviceSequence',
                ),
                'fixationdevicetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationDeviceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationDeviceType',
                ),
                'fixationdevicelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationDeviceLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationDeviceLabel',
                ),
                'fixationdevicedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationDeviceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationDeviceDescription',
                ),
                'fixationdeviceposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationDevicePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationDevicePosition',
                ),
                'fixationdevicepitchangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationDevicePitchAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationDevicePitchAngle',
                ),
                'fixationdevicerollangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationDeviceRollAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationDeviceRollAngle',
                ),
                'shieldingdevicesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShieldingDeviceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShieldingDeviceSequence',
                ),
                'shieldingdevicetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShieldingDeviceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShieldingDeviceType',
                ),
                'shieldingdevicelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShieldingDeviceLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShieldingDeviceLabel',
                ),
                'shieldingdevicedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShieldingDeviceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShieldingDeviceDescription',
                ),
                'shieldingdeviceposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ShieldingDevicePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ShieldingDevicePosition',
                ),
                'setuptechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupTechnique',
                ),
                'setuptechniquedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupTechniqueDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupTechniqueDescription',
                ),
                'setupdevicesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupDeviceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupDeviceSequence',
                ),
                'setupdevicetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupDeviceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupDeviceType',
                ),
                'setupdevicelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupDeviceLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupDeviceLabel',
                ),
                'setupdevicedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupDeviceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupDeviceDescription',
                ),
                'setupdeviceparameter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupDeviceParameter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupDeviceParameter',
                ),
                'setupreferencedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupReferenceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupReferenceDescription',
                ),
                'tabletopverticalsetupdisplacement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopVerticalSetupDisplacement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopVerticalSetupDisplacement',
                ),
                'tabletoplongitudinalsetupdisplace' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopLongitudinalSetupDisplace',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopLongitudinalSetupDisplace',
                ),
                'tabletoplateralsetupdisplacement' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TableTopLateralSetupDisplacement',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TableTopLateralSetupDisplacement',
                ),
                'brachytreatmenttechnique' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyTreatmentTechnique',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyTreatmentTechnique',
                ),
                'brachytreatmenttype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyTreatmentType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyTreatmentType',
                ),
                'treatmentmachinesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TreatmentMachineSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TreatmentMachineSequence',
                ),
                'sourcesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceSequence',
                ),
                'sourcenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceNumber',
                ),
                'sourcetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceType',
                ),
                'sourcemanufacturer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceManufacturer',
                ),
                'activesourcediameter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActiveSourceDiameter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActiveSourceDiameter',
                ),
                'activesourcelength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ActiveSourceLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ActiveSourceLength',
                ),
                'sourceencapsulationnomthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceEncapsulationNomThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceEncapsulationNomThickness',
                ),
                'sourceencapsulationnomtransmission' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceEncapsulationNomTransmission',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceEncapsulationNomTransmission',
                ),
                'sourceisotopename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceIsotopeName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceIsotopeName',
                ),
                'sourceisotopehalflife' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceIsotopeHalfLife',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceIsotopeHalfLife',
                ),
                'sourcestrengthunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceStrengthUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceStrengthUnits',
                ),
                'referenceairkermarate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferenceAirKermaRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferenceAirKermaRate',
                ),
                'sourcestrength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceStrength',
                ),
                'sourcestrengthreferencedate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceStrengthReferenceDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceStrengthReferenceDate',
                ),
                'sourcestrengthreferencetime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceStrengthReferenceTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceStrengthReferenceTime',
                ),
                'applicationsetupsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationSetupSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationSetupSequence',
                ),
                'applicationsetuptype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationSetupType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationSetupType',
                ),
                'applicationsetupnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationSetupNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationSetupNumber',
                ),
                'applicationsetupname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationSetupName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationSetupName',
                ),
                'applicationsetupmanufacturer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApplicationSetupManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApplicationSetupManufacturer',
                ),
                'templatenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateNumber',
                ),
                'templatetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateType',
                ),
                'templatename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TemplateName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TemplateName',
                ),
                'totalreferenceairkerma' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalReferenceAirKerma',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalReferenceAirKerma',
                ),
                'brachyaccessorydevicesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyAccessoryDeviceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceSequence',
                ),
                'brachyaccessorydevicenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyAccessoryDeviceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceNumber',
                ),
                'brachyaccessorydeviceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyAccessoryDeviceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceID',
                ),
                'brachyaccessorydevicetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyAccessoryDeviceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceType',
                ),
                'brachyaccessorydevicename' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyAccessoryDeviceName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceName',
                ),
                'brachyaccessorydevicenomthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyAccessoryDeviceNomThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDeviceNomThickness',
                ),
                'brachyaccessorydevnomtransmission' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyAccessoryDevNomTransmission',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyAccessoryDevNomTransmission',
                ),
                'channelsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelSequence',
                ),
                'channelnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelNumber',
                ),
                'channellength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelLength',
                ),
                'channeltotaltime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelTotalTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelTotalTime',
                ),
                'sourcemovementtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceMovementType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceMovementType',
                ),
                'numberofpulses' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPulses',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPulses',
                ),
                'pulserepetitioninterval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PulseRepetitionInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PulseRepetitionInterval',
                ),
                'sourceapplicatornumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorNumber',
                ),
                'sourceapplicatorid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorID',
                ),
                'sourceapplicatortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorType',
                ),
                'sourceapplicatorname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorName',
                ),
                'sourceapplicatorlength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorLength',
                ),
                'sourceapplicatormanufacturer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorManufacturer',
                ),
                'sourceapplicatorwallnomthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorWallNomThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorWallNomThickness',
                ),
                'sourceapplicatorwallnomtrans' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorWallNomTrans',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorWallNomTrans',
                ),
                'sourceapplicatorstepsize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceApplicatorStepSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceApplicatorStepSize',
                ),
                'transfertubenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransferTubeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransferTubeNumber',
                ),
                'transfertubelength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TransferTubeLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TransferTubeLength',
                ),
                'channelshieldsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelShieldSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelShieldSequence',
                ),
                'channelshieldnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelShieldNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelShieldNumber',
                ),
                'channelshieldid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelShieldID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelShieldID',
                ),
                'channelshieldname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelShieldName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelShieldName',
                ),
                'channelshieldnominalthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelShieldNominalThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelShieldNominalThickness',
                ),
                'channelshieldnominaltransmission' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelShieldNominalTransmission',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelShieldNominalTransmission',
                ),
                'finalcumulativetimeweight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FinalCumulativeTimeWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FinalCumulativeTimeWeight',
                ),
                'brachycontrolpointsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyControlPointSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyControlPointSequence',
                ),
                'controlpointrelativeposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ControlPointRelativePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ControlPointRelativePosition',
                ),
                'controlpoint3dposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ControlPoint3DPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ControlPoint3DPosition',
                ),
                'cumulativetimeweight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CumulativeTimeWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CumulativeTimeWeight',
                ),
                'compensatordivergence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorDivergence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorDivergence',
                ),
                'compensatormountingposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorMountingPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorMountingPosition',
                ),
                'sourcetocompensatordistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SourceToCompensatorDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SourceToCompensatorDistance',
                ),
                'totalcomptraywaterequivthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalCompTrayWaterEquivThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalCompTrayWaterEquivThickness',
                ),
                'isocentertocompensatortraydistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterToCompensatorTrayDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterToCompensatorTrayDistance',
                ),
                'compensatorcolumnoffset' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorColumnOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorColumnOffset',
                ),
                'isocentertocompensatordistances' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterToCompensatorDistances',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterToCompensatorDistances',
                ),
                'compensatorrelstoppingpowerratio' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorRelStoppingPowerRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorRelStoppingPowerRatio',
                ),
                'compensatormillingtooldiameter' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorMillingToolDiameter',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorMillingToolDiameter',
                ),
                'ionrangecompensatorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonRangeCompensatorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonRangeCompensatorSequence',
                ),
                'compensatordescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CompensatorDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CompensatorDescription',
                ),
                'radiationmassnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationMassNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationMassNumber',
                ),
                'radiationatomicnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationAtomicNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationAtomicNumber',
                ),
                'radiationchargestate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RadiationChargeState',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RadiationChargeState',
                ),
                'scanmode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanMode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanMode',
                ),
                'virtualsourceaxisdistances' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VirtualSourceAxisDistances',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VirtualSourceAxisDistances',
                ),
                'snoutsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SnoutSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SnoutSequence',
                ),
                'snoutposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SnoutPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SnoutPosition',
                ),
                'snoutid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SnoutID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SnoutID',
                ),
                'numberofrangeshifters' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfRangeShifters',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfRangeShifters',
                ),
                'rangeshiftersequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeShifterSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeShifterSequence',
                ),
                'rangeshifternumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeShifterNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeShifterNumber',
                ),
                'rangeshifterid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeShifterID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeShifterID',
                ),
                'rangeshiftertype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeShifterType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeShifterType',
                ),
                'rangeshifterdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeShifterDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeShifterDescription',
                ),
                'numberoflateralspreadingdevices' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfLateralSpreadingDevices',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfLateralSpreadingDevices',
                ),
                'lateralspreadingdevicesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LateralSpreadingDeviceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceSequence',
                ),
                'lateralspreadingdevicenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LateralSpreadingDeviceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceNumber',
                ),
                'lateralspreadingdeviceid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LateralSpreadingDeviceID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceID',
                ),
                'lateralspreadingdevicetype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LateralSpreadingDeviceType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceType',
                ),
                'lateralspreadingdevicedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LateralSpreadingDeviceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceDescription',
                ),
                'lateralspreadingdevwaterequivthick' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LateralSpreadingDevWaterEquivThick',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDevWaterEquivThick',
                ),
                'numberofrangemodulators' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfRangeModulators',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfRangeModulators',
                ),
                'rangemodulatorsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeModulatorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeModulatorSequence',
                ),
                'rangemodulatornumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeModulatorNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeModulatorNumber',
                ),
                'rangemodulatorid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeModulatorID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeModulatorID',
                ),
                'rangemodulatortype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeModulatorType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeModulatorType',
                ),
                'rangemodulatordescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeModulatorDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeModulatorDescription',
                ),
                'beamcurrentmodulationid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BeamCurrentModulationID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BeamCurrentModulationID',
                ),
                'patientsupporttype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSupportType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSupportType',
                ),
                'patientsupportid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSupportID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSupportID',
                ),
                'patientsupportaccessorycode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PatientSupportAccessoryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PatientSupportAccessoryCode',
                ),
                'fixationlightazimuthalangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationLightAzimuthalAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationLightAzimuthalAngle',
                ),
                'fixationlightpolarangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FixationLightPolarAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FixationLightPolarAngle',
                ),
                'metersetrate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MetersetRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MetersetRate',
                ),
                'rangeshiftersettingssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeShifterSettingsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeShifterSettingsSequence',
                ),
                'rangeshiftersetting' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeShifterSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeShifterSetting',
                ),
                'isocentertorangeshifterdistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterToRangeShifterDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterToRangeShifterDistance',
                ),
                'rangeshifterwaterequivthickness' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeShifterWaterEquivThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeShifterWaterEquivThickness',
                ),
                'lateralspreadingdevicesettingsseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LateralSpreadingDeviceSettingsSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceSettingsSeq',
                ),
                'lateralspreadingdevicesetting' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'LateralSpreadingDeviceSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\LateralSpreadingDeviceSetting',
                ),
                'isocentertolateralspreadingdevdist' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterToLateralSpreadingDevDist',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterToLateralSpreadingDevDist',
                ),
                'rangemodulatorsettingssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeModulatorSettingsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeModulatorSettingsSequence',
                ),
                'rangemodulatorgatingstartvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeModulatorGatingStartValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeModulatorGatingStartValue',
                ),
                'rangemodulatorgatingstopvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'RangeModulatorGatingStopValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\RangeModulatorGatingStopValue',
                ),
                'isocentertorangemodulatordistance' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IsocenterToRangeModulatorDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IsocenterToRangeModulatorDistance',
                ),
                'scanspottuneid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanSpotTuneID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanSpotTuneID',
                ),
                'numberofscanspotpositions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfScanSpotPositions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfScanSpotPositions',
                ),
                'scanspotpositionmap' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanSpotPositionMap',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanSpotPositionMap',
                ),
                'scanspotmetersetweights' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanSpotMetersetWeights',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanSpotMetersetWeights',
                ),
                'scanningspotsize' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ScanningSpotSize',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ScanningSpotSize',
                ),
                'numberofpaintings' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPaintings',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPaintings',
                ),
                'iontolerancetablesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonToleranceTableSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonToleranceTableSequence',
                ),
                'ionbeamsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonBeamSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonBeamSequence',
                ),
                'ionbeamlimitingdevicesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonBeamLimitingDeviceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonBeamLimitingDeviceSequence',
                ),
                'ionblocksequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonBlockSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonBlockSequence',
                ),
                'ioncontrolpointsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonControlPointSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonControlPointSequence',
                ),
                'ionwedgesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonWedgeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonWedgeSequence',
                ),
                'ionwedgepositionsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'IonWedgePositionSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\IonWedgePositionSequence',
                ),
                'referencedsetupimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSetupImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSetupImageSequence',
                ),
                'setupimagecomment' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SetupImageComment',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SetupImageComment',
                ),
                'motionsynchronizationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MotionSynchronizationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MotionSynchronizationSequence',
                ),
                'controlpointorientation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ControlPointOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ControlPointOrientation',
                ),
                'generalaccessorysequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeneralAccessorySequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeneralAccessorySequence',
                ),
                'generalaccessoryid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeneralAccessoryID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeneralAccessoryID',
                ),
                'generalaccessorydescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeneralAccessoryDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeneralAccessoryDescription',
                ),
                'generalaccessorytype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeneralAccessoryType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeneralAccessoryType',
                ),
                'generalaccessorynumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'GeneralAccessoryNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\GeneralAccessoryNumber',
                ),
                'referencedrtplansequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedRTPlanSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedRTPlanSequence',
                ),
                'referencedbeamsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedBeamSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedBeamSequence',
                ),
                'referencedbeamnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedBeamNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedBeamNumber',
                ),
                'referencedreferenceimagenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedReferenceImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedReferenceImageNumber',
                ),
                'startcumulativemetersetweight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartCumulativeMetersetWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartCumulativeMetersetWeight',
                ),
                'endcumulativemetersetweight' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndCumulativeMetersetWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndCumulativeMetersetWeight',
                ),
                'referencedbrachyappsetupseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedBrachyAppSetupSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedBrachyAppSetupSeq',
                ),
                'referencedbrachyappsetupnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedBrachyAppSetupNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedBrachyAppSetupNumber',
                ),
                'referencedsourcenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedSourceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedSourceNumber',
                ),
                'referencedfractiongroupsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFractionGroupSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFractionGroupSequence',
                ),
                'referencedfractiongroupnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedFractionGroupNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedFractionGroupNumber',
                ),
                'referencedverificationimageseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedVerificationImageSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedVerificationImageSeq',
                ),
                'referencedreferenceimagesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedReferenceImageSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedReferenceImageSequence',
                ),
                'referenceddosereferencesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedDoseReferenceSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedDoseReferenceSequence',
                ),
                'referenceddosereferencenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedDoseReferenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedDoseReferenceNumber',
                ),
                'brachyreferenceddosereferenceseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'BrachyReferencedDoseReferenceSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\BrachyReferencedDoseReferenceSeq',
                ),
                'referencedstructuresetsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedStructureSetSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedStructureSetSequence',
                ),
                'referencedpatientsetupnumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedPatientSetupNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedPatientSetupNumber',
                ),
                'referenceddosesequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedDoseSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedDoseSequence',
                ),
                'referencedtolerancetablenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedToleranceTableNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedToleranceTableNumber',
                ),
                'referencedbolussequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedBolusSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedBolusSequence',
                ),
                'referencedwedgenumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedWedgeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedWedgeNumber',
                ),
                'referencedcompensatornumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedCompensatorNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedCompensatorNumber',
                ),
                'referencedblocknumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedBlockNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedBlockNumber',
                ),
                'referencedcontrolpointindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedControlPointIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedControlPointIndex',
                ),
                'referencedcontrolpointsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedControlPointSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedControlPointSequence',
                ),
                'referencedstartcontrolpointindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedStartControlPointIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedStartControlPointIndex',
                ),
                'referencedstopcontrolpointindex' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedStopControlPointIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedStopControlPointIndex',
                ),
                'referencedrangeshifternumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedRangeShifterNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedRangeShifterNumber',
                ),
                'referencedlateralspreadingdevnum' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedLateralSpreadingDevNum',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedLateralSpreadingDevNum',
                ),
                'referencedrangemodulatornumber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedRangeModulatorNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedRangeModulatorNumber',
                ),
                'approvalstatus' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ApprovalStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ApprovalStatus',
                ),
                'reviewdate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReviewDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReviewDate',
                ),
                'reviewtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReviewTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReviewTime',
                ),
                'reviewername' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReviewerName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReviewerName',
                ),
                'textgrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TextGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TextGroupLength',
                ),
                'arbitrary' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Arbitrary',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Arbitrary',
                ),
                'textcomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TextComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TextComments',
                ),
                'resultsid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResultsID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResultsID',
                ),
                'resultsidissuer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResultsIDIssuer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResultsIDIssuer',
                ),
                'referencedinterpretationsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedInterpretationSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedInterpretationSequence',
                ),
                'interpretationrecordeddate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationRecordedDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationRecordedDate',
                ),
                'interpretationrecordedtime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationRecordedTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationRecordedTime',
                ),
                'interpretationrecorder' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationRecorder',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationRecorder',
                ),
                'referencetorecordedsound' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferenceToRecordedSound',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferenceToRecordedSound',
                ),
                'interpretationtranscriptiondate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationTranscriptionDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationTranscriptionDate',
                ),
                'interpretationtranscriptiontime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationTranscriptionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationTranscriptionTime',
                ),
                'interpretationtranscriber' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationTranscriber',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationTranscriber',
                ),
                'interpretationtext' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationText',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationText',
                ),
                'interpretationauthor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationAuthor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationAuthor',
                ),
                'interpretationapproversequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationApproverSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationApproverSequence',
                ),
                'interpretationapprovaldate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationApprovalDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationApprovalDate',
                ),
                'interpretationapprovaltime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationApprovalTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationApprovalTime',
                ),
                'physicianapprovinginterpretation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PhysicianApprovingInterpretation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PhysicianApprovingInterpretation',
                ),
                'interpretationdiagnosisdescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationDiagnosisDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationDiagnosisDescription',
                ),
                'interpretationdiagnosiscodeseq' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationDiagnosisCodeSeq',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationDiagnosisCodeSeq',
                ),
                'resultsdistributionlistsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResultsDistributionListSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResultsDistributionListSequence',
                ),
                'distributionname' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistributionName',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistributionName',
                ),
                'distributionaddress' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DistributionAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DistributionAddress',
                ),
                'interpretationid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationID',
                ),
                'interpretationidissuer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationIDIssuer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationIDIssuer',
                ),
                'interpretationtypeid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationTypeID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationTypeID',
                ),
                'interpretationstatusid' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'InterpretationStatusID',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\InterpretationStatusID',
                ),
                'impressions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'Impressions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\Impressions',
                ),
                'resultscomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ResultsComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ResultsComments',
                ),
                'macparameterssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MACParametersSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MACParametersSequence',
                ),
                'curvedimensions' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveDimensions',
                ),
                'numberofpoints' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfPoints',
                ),
                'typeofdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TypeOfData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TypeOfData',
                ),
                'curvedescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveDescription',
                ),
                'axisunits' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AxisUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AxisUnits',
                ),
                'axislabels' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AxisLabels',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AxisLabels',
                ),
                'datavaluerepresentation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataValueRepresentation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataValueRepresentation',
                ),
                'minimumcoordinatevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MinimumCoordinateValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MinimumCoordinateValue',
                ),
                'maximumcoordinatevalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'MaximumCoordinateValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\MaximumCoordinateValue',
                ),
                'curverange' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveRange',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveRange',
                ),
                'curvedatadescriptor' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveDataDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveDataDescriptor',
                ),
                'coordinatestartvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CoordinateStartValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CoordinateStartValue',
                ),
                'coordinatestepvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CoordinateStepValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CoordinateStepValue',
                ),
                'curveactivationlayer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveActivationLayer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveActivationLayer',
                ),
                'audiotype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AudioType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AudioType',
                ),
                'audiosampleformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AudioSampleFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AudioSampleFormat',
                ),
                'numberofsamples' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfSamples',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfSamples',
                ),
                'samplerate' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SampleRate',
                ),
                'totaltime' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'TotalTime',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\TotalTime',
                ),
                'audiosampledata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AudioSampleData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AudioSampleData',
                ),
                'audiocomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'AudioComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\AudioComments',
                ),
                'curvelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveLabel',
                ),
                'referencedoverlaygroup' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ReferencedOverlayGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ReferencedOverlayGroup',
                ),
                'curvedata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'CurveData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\CurveData',
                ),
                'sharedfunctionalgroupssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SharedFunctionalGroupsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SharedFunctionalGroupsSequence',
                ),
                'perframefunctionalgroupssequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PerFrameFunctionalGroupsSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PerFrameFunctionalGroupsSequence',
                ),
                'waveformsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformSequence',
                ),
                'channelminimumvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelMinimumValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelMinimumValue',
                ),
                'channelmaximumvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ChannelMaximumValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ChannelMaximumValue',
                ),
                'waveformbitsallocated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformBitsAllocated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformBitsAllocated',
                ),
                'waveformsampleinterpretation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformSampleInterpretation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformSampleInterpretation',
                ),
                'waveformpaddingvalue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformPaddingValue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformPaddingValue',
                ),
                'waveformdata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'WaveformData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\WaveformData',
                ),
                'firstorderphasecorrectionangle' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'FirstOrderPhaseCorrectionAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\FirstOrderPhaseCorrectionAngle',
                ),
                'spectroscopydata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'SpectroscopyData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\SpectroscopyData',
                ),
                'overlaygrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayGroupLength',
                ),
                'overlayrows' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayRows',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayRows',
                ),
                'overlaycolumns' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayColumns',
                ),
                'overlayplanes' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayPlanes',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayPlanes',
                ),
                'numberofframesinoverlay' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'NumberOfFramesInOverlay',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\NumberOfFramesInOverlay',
                ),
                'overlaydescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayDescription',
                ),
                'overlaytype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayType',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayType',
                ),
                'overlaysubtype' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlaySubtype',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlaySubtype',
                ),
                'overlayorigin' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayOrigin',
                ),
                'imageframeorigin' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ImageFrameOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ImageFrameOrigin',
                ),
                'overlayplaneorigin' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayPlaneOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayPlaneOrigin',
                ),
                'overlaycompressioncode' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayCompressionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayCompressionCode',
                ),
                'overlaycompressionoriginator' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayCompressionOriginator',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayCompressionOriginator',
                ),
                'overlaycompressionlabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayCompressionLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayCompressionLabel',
                ),
                'overlaycompressiondescription' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayCompressionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayCompressionDescription',
                ),
                'overlaycompressionsteppointers' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayCompressionStepPointers',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayCompressionStepPointers',
                ),
                'overlayrepeatinterval' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayRepeatInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayRepeatInterval',
                ),
                'overlaybitsgrouped' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayBitsGrouped',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayBitsGrouped',
                ),
                'overlaybitsallocated' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayBitsAllocated',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayBitsAllocated',
                ),
                'overlaybitposition' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayBitPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayBitPosition',
                ),
                'overlayformat' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayFormat',
                ),
                'overlaylocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayLocation',
                ),
                'overlaycodelabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayCodeLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayCodeLabel',
                ),
                'overlaynumberoftables' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayNumberOfTables',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayNumberOfTables',
                ),
                'overlaycodetablelocation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayCodeTableLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayCodeTableLocation',
                ),
                'overlaybitsforcodeword' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayBitsForCodeWord',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayBitsForCodeWord',
                ),
                'overlayactivationlayer' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayActivationLayer',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayActivationLayer',
                ),
                'overlaydescriptorgray' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayDescriptorGray',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayDescriptorGray',
                ),
                'overlaydescriptorred' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayDescriptorRed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayDescriptorRed',
                ),
                'overlaydescriptorgreen' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayDescriptorGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayDescriptorGreen',
                ),
                'overlaydescriptorblue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayDescriptorBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayDescriptorBlue',
                ),
                'overlaysgray' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlaysGray',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlaysGray',
                ),
                'overlaysred' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlaysRed',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlaysRed',
                ),
                'overlaysgreen' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlaysGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlaysGreen',
                ),
                'overlaysblue' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlaysBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlaysBlue',
                ),
                'roiarea' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIArea',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIArea',
                ),
                'roimean' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIMean',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIMean',
                ),
                'roistandarddeviation' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'ROIStandardDeviation',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\ROIStandardDeviation',
                ),
                'overlaylabel' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayLabel',
                ),
                'overlaydata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayData',
                ),
                'overlaycomments' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'OverlayComments',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\OverlayComments',
                ),
                'pixeldatagrouplength' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelDataGroupLength',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelDataGroupLength',
                ),
                'pixeldata' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'PixelData',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\PixelData',
                ),
                'variablenextdatagroup' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VariableNextDataGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VariableNextDataGroup',
                ),
                'variablecoefficientssdvn' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VariableCoefficientsSDVN',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VariableCoefficientsSDVN',
                ),
                'variablecoefficientssdhn' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VariableCoefficientsSDHN',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VariableCoefficientsSDHN',
                ),
                'variablecoefficientssddn' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'VariableCoefficientsSDDN',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\VariableCoefficientsSDDN',
                ),
                'digitalsignaturessequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DigitalSignaturesSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DigitalSignaturesSequence',
                ),
                'datasettrailingpadding' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'DataSetTrailingPadding',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\DataSetTrailingPadding',
                ),
                'startofitem' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'StartOfItem',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\StartOfItem',
                ),
                'endofitems' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndOfItems',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndOfItems',
                ),
                'endofsequence' => array(
                    'namespace' => 'DICOM',
                    'tagname' => 'EndOfSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\DICOM\EndOfSequence',
                ),

            ),
            'exififd' => array(
                'makernotenikon' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteNikon',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteNikon',
                ),
                'makernotecanon' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteCanon',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteCanon',
                ),
                'makernotecasio' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteCasio',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteCasio',
                ),
                'makernotecasio2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteCasio2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteCasio2',
                ),
                'makernotefujifilm' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteFujiFilm',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteFujiFilm',
                ),
                'makernotege' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteGE',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteGE',
                ),
                'makernotege2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteGE2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteGE2',
                ),
                'makernotehasselblad' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteHasselblad',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHasselblad',
                ),
                'makernotehp' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteHP',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHP',
                ),
                'makernotehp2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteHP2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHP2',
                ),
                'makernotehp4' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteHP4',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHP4',
                ),
                'makernotehp6' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteHP6',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteHP6',
                ),
                'makernoteisl' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteISL',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteISL',
                ),
                'makernotejvc' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteJVC',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteJVC',
                ),
                'makernotejvctext' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteJVCText',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteJVCText',
                ),
                'makernotekodak1a' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak1a',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak1a',
                ),
                'makernotekodak1b' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak1b',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak1b',
                ),
                'makernotekodak2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak2',
                ),
                'makernotekodak3' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak3',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak3',
                ),
                'makernotekodak4' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak4',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak4',
                ),
                'makernotekodak5' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak5',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak5',
                ),
                'makernotekodak6a' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak6a',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak6a',
                ),
                'makernotekodak6b' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak6b',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak6b',
                ),
                'makernotekodak7' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak7',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak7',
                ),
                'makernotekodak8a' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak8a',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak8a',
                ),
                'makernotekodak8b' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak8b',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak8b',
                ),
                'makernotekodak9' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak9',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak9',
                ),
                'makernotekodak10' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodak10',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodak10',
                ),
                'makernotekodakunknown' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKodakUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKodakUnknown',
                ),
                'makernotekyocera' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteKyocera',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteKyocera',
                ),
                'makernoteminolta' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteMinolta',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteMinolta',
                ),
                'makernoteminolta2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteMinolta2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteMinolta2',
                ),
                'makernoteminolta3' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteMinolta3',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteMinolta3',
                ),
                'makernotenikon2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteNikon2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteNikon2',
                ),
                'makernotenikon3' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteNikon3',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteNikon3',
                ),
                'makernoteolympus' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteOlympus',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteOlympus',
                ),
                'makernoteolympus2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteOlympus2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteOlympus2',
                ),
                'makernoteleica' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteLeica',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica',
                ),
                'makernoteleica2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteLeica2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica2',
                ),
                'makernoteleica3' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteLeica3',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica3',
                ),
                'makernoteleica4' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteLeica4',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica4',
                ),
                'makernoteleica5' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteLeica5',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica5',
                ),
                'makernoteleica6' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteLeica6',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteLeica6',
                ),
                'makernotepanasonic' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePanasonic',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePanasonic',
                ),
                'makernotepanasonic2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePanasonic2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePanasonic2',
                ),
                'makernotepentax' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePentax',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax',
                ),
                'makernotepentax2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePentax2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax2',
                ),
                'makernotepentax3' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePentax3',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax3',
                ),
                'makernotepentax4' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePentax4',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax4',
                ),
                'makernotepentax5' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePentax5',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax5',
                ),
                'makernotepentax6' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePentax6',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePentax6',
                ),
                'makernotephaseone' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNotePhaseOne',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNotePhaseOne',
                ),
                'makernotereconyx' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteReconyx',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteReconyx',
                ),
                'makernotericoh' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteRicoh',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteRicoh',
                ),
                'makernotericohtext' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteRicohText',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteRicohText',
                ),
                'makernotesamsung1a' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSamsung1a',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSamsung1a',
                ),
                'makernotesamsung1b' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSamsung1b',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSamsung1b',
                ),
                'makernotesamsung2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSamsung2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSamsung2',
                ),
                'makernotesanyo' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSanyo',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSanyo',
                ),
                'makernotesanyoc4' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSanyoC4',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSanyoC4',
                ),
                'makernotesanyopatch' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSanyoPatch',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSanyoPatch',
                ),
                'makernotesigma' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSigma',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSigma',
                ),
                'makernotesony' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSony',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSony',
                ),
                'makernotesony2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSony2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSony2',
                ),
                'makernotesony3' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSony3',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSony3',
                ),
                'makernotesony4' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSony4',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSony4',
                ),
                'makernotesonyericsson' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSonyEricsson',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSonyEricsson',
                ),
                'makernotesonysrf' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteSonySRF',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteSonySRF',
                ),
                'makernoteunknowntext' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteUnknownText',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteUnknownText',
                ),
                'makernoteunknown' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MakerNoteUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MakerNoteUnknown',
                ),
                'stripoffsets' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'StripOffsets',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\StripOffsets',
                ),
                'stripbytecounts' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'StripByteCounts',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\StripByteCounts',
                ),
                'freeoffsets' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FreeOffsets',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FreeOffsets',
                ),
                'freebytecounts' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FreeByteCounts',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FreeByteCounts',
                ),
                'grayresponsecurve' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'GrayResponseCurve',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\GrayResponseCurve',
                ),
                't4options' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'T4Options',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\T4Options',
                ),
                't6options' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'T6Options',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\T6Options',
                ),
                'colorresponseunit' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ColorResponseUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ColorResponseUnit',
                ),
                'colormap' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ColorMap',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ColorMap',
                ),
                'tileoffsets' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TileOffsets',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TileOffsets',
                ),
                'tilebytecounts' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TileByteCounts',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TileByteCounts',
                ),
                'badfaxlines' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BadFaxLines',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BadFaxLines',
                ),
                'cleanfaxdata' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CleanFaxData',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CleanFaxData',
                ),
                'consecutivebadfaxlines' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ConsecutiveBadFaxLines',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ConsecutiveBadFaxLines',
                ),
                'a100dataoffset' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'A100DataOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\A100DataOffset',
                ),
                'inknames' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'InkNames',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\InkNames',
                ),
                'numberofinks' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'NumberofInks',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\NumberofInks',
                ),
                'targetprinter' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TargetPrinter',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TargetPrinter',
                ),
                'extrasamples' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExtraSamples',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExtraSamples',
                ),
                'sampleformat' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SampleFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SampleFormat',
                ),
                'sminsamplevalue' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SMinSampleValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SMinSampleValue',
                ),
                'smaxsamplevalue' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SMaxSampleValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SMaxSampleValue',
                ),
                'transferrange' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TransferRange',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TransferRange',
                ),
                'clippath' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ClipPath',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ClipPath',
                ),
                'xclippathunits' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'XClipPathUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\XClipPathUnits',
                ),
                'yclippathunits' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'YClipPathUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\YClipPathUnits',
                ),
                'indexed' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Indexed',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Indexed',
                ),
                'jpegtables' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'JPEGTables',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\JPEGTables',
                ),
                'opiproxy' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OPIProxy',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OPIProxy',
                ),
                'profiletype' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ProfileType',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ProfileType',
                ),
                'faxprofile' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FaxProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FaxProfile',
                ),
                'codingmethods' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CodingMethods',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CodingMethods',
                ),
                'versionyear' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'VersionYear',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\VersionYear',
                ),
                'modenumber' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ModeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ModeNumber',
                ),
                'decode' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Decode',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Decode',
                ),
                'defaultimagecolor' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'DefaultImageColor',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\DefaultImageColor',
                ),
                't82options' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'T82Options',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\T82Options',
                ),
                'jpegproc' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'JPEGProc',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\JPEGProc',
                ),
                'otherimagestart' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OtherImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OtherImageStart',
                ),
                'otherimagelength' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OtherImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OtherImageLength',
                ),
                'jpegrestartinterval' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'JPEGRestartInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\JPEGRestartInterval',
                ),
                'jpeglosslesspredictors' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'JPEGLosslessPredictors',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\JPEGLosslessPredictors',
                ),
                'jpegpointtransforms' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'JPEGPointTransforms',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\JPEGPointTransforms',
                ),
                'jpegqtables' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'JPEGQTables',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\JPEGQTables',
                ),
                'jpegdctables' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'JPEGDCTables',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\JPEGDCTables',
                ),
                'jpegactables' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'JPEGACTables',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\JPEGACTables',
                ),
                'striprowcounts' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'StripRowCounts',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\StripRowCounts',
                ),
                'applicationnotes' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ApplicationNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ApplicationNotes',
                ),
                'usptomiscellaneous' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'USPTOMiscellaneous',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\USPTOMiscellaneous',
                ),
                'xp_dip_xml' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'XP_DIP_XML',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\XPDIPXML',
                ),
                'imageid' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageID',
                ),
                'wangtag1' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'WangTag1',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\WangTag1',
                ),
                'wangannotation' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'WangAnnotation',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\WangAnnotation',
                ),
                'wangtag3' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'WangTag3',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\WangTag3',
                ),
                'wangtag4' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'WangTag4',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\WangTag4',
                ),
                'matteing' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Matteing',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Matteing',
                ),
                'datatype' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'DataType',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\DataType',
                ),
                'imagedepth' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageDepth',
                ),
                'tiledepth' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TileDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TileDepth',
                ),
                'model2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Model2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Model2',
                ),
                'batterylevel' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BatteryLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BatteryLevel',
                ),
                'exposuretime' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExposureTime',
                ),
                'fnumber' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FNumber',
                ),
                'mdfiletag' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MDFileTag',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MDFileTag',
                ),
                'mdscalepixel' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MDScalePixel',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MDScalePixel',
                ),
                'mdcolortable' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MDColorTable',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MDColorTable',
                ),
                'mdlabname' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MDLabName',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MDLabName',
                ),
                'mdsampleinfo' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MDSampleInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MDSampleInfo',
                ),
                'mdprepdate' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MDPrepDate',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MDPrepDate',
                ),
                'mdpreptime' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MDPrepTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MDPrepTime',
                ),
                'mdfileunits' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MDFileUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MDFileUnits',
                ),
                'pixelscale' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'PixelScale',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\PixelScale',
                ),
                'adventscale' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'AdventScale',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\AdventScale',
                ),
                'adventrevision' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'AdventRevision',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\AdventRevision',
                ),
                'uic1tag' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'UIC1Tag',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\UIC1Tag',
                ),
                'uic2tag' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'UIC2Tag',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\UIC2Tag',
                ),
                'uic3tag' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'UIC3Tag',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\UIC3Tag',
                ),
                'uic4tag' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'UIC4Tag',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\UIC4Tag',
                ),
                'intergraphpacketdata' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'IntergraphPacketData',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\IntergraphPacketData',
                ),
                'intergraphflagregisters' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'IntergraphFlagRegisters',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\IntergraphFlagRegisters',
                ),
                'intergraphmatrix' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'IntergraphMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\IntergraphMatrix',
                ),
                'ingrreserved' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'INGRReserved',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\INGRReserved',
                ),
                'modeltiepoint' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ModelTiePoint',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ModelTiePoint',
                ),
                'site' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Site',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Site',
                ),
                'colorsequence' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ColorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ColorSequence',
                ),
                'it8header' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'IT8Header',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\IT8Header',
                ),
                'rasterpadding' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'RasterPadding',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\RasterPadding',
                ),
                'bitsperrunlength' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BitsPerRunLength',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BitsPerRunLength',
                ),
                'bitsperextendedrunlength' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BitsPerExtendedRunLength',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BitsPerExtendedRunLength',
                ),
                'colortable' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ColorTable',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ColorTable',
                ),
                'imagecolorindicator' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageColorIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageColorIndicator',
                ),
                'backgroundcolorindicator' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BackgroundColorIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BackgroundColorIndicator',
                ),
                'imagecolorvalue' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageColorValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageColorValue',
                ),
                'backgroundcolorvalue' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BackgroundColorValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BackgroundColorValue',
                ),
                'pixelintensityrange' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'PixelIntensityRange',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\PixelIntensityRange',
                ),
                'transparencyindicator' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TransparencyIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TransparencyIndicator',
                ),
                'colorcharacterization' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ColorCharacterization',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ColorCharacterization',
                ),
                'hcusage' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'HCUsage',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\HCUsage',
                ),
                'trapindicator' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TrapIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TrapIndicator',
                ),
                'cmykequivalent' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CMYKEquivalent',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CMYKEquivalent',
                ),
                'pixelmagicjbigoptions' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'PixelMagicJBIGOptions',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\PixelMagicJBIGOptions',
                ),
                'modeltransform' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ModelTransform',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ModelTransform',
                ),
                'wb_grgblevels' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'WB_GRGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\WBGRGBLevels',
                ),
                'tiff_fxextensions' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TIFF_FXExtensions',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TIFFFXExtensions',
                ),
                'multiprofiles' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MultiProfiles',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MultiProfiles',
                ),
                'shareddata' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SharedData',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SharedData',
                ),
                't88options' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'T88Options',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\T88Options',
                ),
                'imagelayer' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageLayer',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageLayer',
                ),
                'geotiffdirectory' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'GeoTiffDirectory',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\GeoTiffDirectory',
                ),
                'geotiffdoubleparams' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'GeoTiffDoubleParams',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\GeoTiffDoubleParams',
                ),
                'geotiffasciiparams' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'GeoTiffAsciiParams',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\GeoTiffAsciiParams',
                ),
                'exposureprogram' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExposureProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExposureProgram',
                ),
                'spectralsensitivity' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SpectralSensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SpectralSensitivity',
                ),
                'iso' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ISO',
                ),
                'opto-electricconvfactor' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Opto-ElectricConvFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OptoElectricConvFactor',
                ),
                'interlace' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Interlace',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Interlace',
                ),
                'timezoneoffset' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TimeZoneOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TimeZoneOffset',
                ),
                'selftimermode' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SelfTimerMode',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SelfTimerMode',
                ),
                'sensitivitytype' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SensitivityType',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SensitivityType',
                ),
                'standardoutputsensitivity' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'StandardOutputSensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\StandardOutputSensitivity',
                ),
                'recommendedexposureindex' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'RecommendedExposureIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\RecommendedExposureIndex',
                ),
                'isospeed' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ISOSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ISOSpeed',
                ),
                'isospeedlatitudeyyy' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ISOSpeedLatitudeyyy',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ISOSpeedLatitudeyyy',
                ),
                'isospeedlatitudezzz' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ISOSpeedLatitudezzz',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ISOSpeedLatitudezzz',
                ),
                'faxrecvparams' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FaxRecvParams',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FaxRecvParams',
                ),
                'faxsubaddress' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FaxSubAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FaxSubAddress',
                ),
                'faxrecvtime' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FaxRecvTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FaxRecvTime',
                ),
                'exifversion' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExifVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExifVersion',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\DateTimeOriginal',
                ),
                'createdate' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CreateDate',
                ),
                'componentsconfiguration' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ComponentsConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ComponentsConfiguration',
                ),
                'compressedbitsperpixel' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CompressedBitsPerPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CompressedBitsPerPixel',
                ),
                'shutterspeedvalue' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ShutterSpeedValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ShutterSpeedValue',
                ),
                'aperturevalue' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ApertureValue',
                ),
                'brightnessvalue' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BrightnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BrightnessValue',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExposureCompensation',
                ),
                'maxaperturevalue' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MaxApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MaxApertureValue',
                ),
                'subjectdistance' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SubjectDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SubjectDistance',
                ),
                'meteringmode' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MeteringMode',
                ),
                'lightsource' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'LightSource',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\LightSource',
                ),
                'flash' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Flash',
                ),
                'focallength' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FocalLength',
                ),
                'flashenergy' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FlashEnergy',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FlashEnergy',
                ),
                'spatialfrequencyresponse' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SpatialFrequencyResponse',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SpatialFrequencyResponse',
                ),
                'noise' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Noise',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Noise',
                ),
                'focalplanexresolution' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FocalPlaneXResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FocalPlaneXResolution',
                ),
                'focalplaneyresolution' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FocalPlaneYResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FocalPlaneYResolution',
                ),
                'focalplaneresolutionunit' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FocalPlaneResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FocalPlaneResolutionUnit',
                ),
                'imagenumber' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageNumber',
                ),
                'securityclassification' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SecurityClassification',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SecurityClassification',
                ),
                'imagehistory' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageHistory',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageHistory',
                ),
                'subjectarea' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SubjectArea',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SubjectArea',
                ),
                'exposureindex' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExposureIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExposureIndex',
                ),
                'tiff-epstandardid' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'TIFF-EPStandardID',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\TIFFEPStandardID',
                ),
                'sensingmethod' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SensingMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SensingMethod',
                ),
                'cip3datafile' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CIP3DataFile',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CIP3DataFile',
                ),
                'cip3sheet' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CIP3Sheet',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CIP3Sheet',
                ),
                'cip3side' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CIP3Side',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CIP3Side',
                ),
                'stonits' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'StoNits',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\StoNits',
                ),
                'usercomment' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'UserComment',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\UserComment',
                ),
                'subsectime' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SubSecTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SubSecTime',
                ),
                'subsectimeoriginal' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SubSecTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SubSecTimeOriginal',
                ),
                'subsectimedigitized' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SubSecTimeDigitized',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SubSecTimeDigitized',
                ),
                'msdocumenttext' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MSDocumentText',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MSDocumentText',
                ),
                'mspropertysetstorage' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MSPropertySetStorage',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MSPropertySetStorage',
                ),
                'msdocumenttextposition' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MSDocumentTextPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MSDocumentTextPosition',
                ),
                'flashpixversion' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FlashpixVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FlashpixVersion',
                ),
                'colorspace' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ColorSpace',
                ),
                'exifimagewidth' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExifImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExifImageWidth',
                ),
                'exifimageheight' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExifImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExifImageHeight',
                ),
                'relatedsoundfile' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'RelatedSoundFile',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\RelatedSoundFile',
                ),
                'subjectlocation' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SubjectLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SubjectLocation',
                ),
                'filesource' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FileSource',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FileSource',
                ),
                'scenetype' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SceneType',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SceneType',
                ),
                'cfapattern' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CFAPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CFAPattern',
                ),
                'customrendered' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CustomRendered',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CustomRendered',
                ),
                'exposuremode' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExposureMode',
                ),
                'whitebalance' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\WhiteBalance',
                ),
                'digitalzoomratio' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'DigitalZoomRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\DigitalZoomRatio',
                ),
                'focallengthin35mmformat' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'FocalLengthIn35mmFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\FocalLengthIn35mmFormat',
                ),
                'scenecapturetype' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SceneCaptureType',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SceneCaptureType',
                ),
                'gaincontrol' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'GainControl',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\GainControl',
                ),
                'contrast' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Contrast',
                ),
                'saturation' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Saturation',
                ),
                'sharpness' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Sharpness',
                ),
                'devicesettingdescription' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'DeviceSettingDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\DeviceSettingDescription',
                ),
                'subjectdistancerange' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SubjectDistanceRange',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SubjectDistanceRange',
                ),
                'imageuniqueid' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageUniqueID',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageUniqueID',
                ),
                'ownername' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OwnerName',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OwnerName',
                ),
                'serialnumber' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SerialNumber',
                ),
                'lensinfo' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'LensInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\LensInfo',
                ),
                'lensmake' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'LensMake',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\LensMake',
                ),
                'lensmodel' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'LensModel',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\LensModel',
                ),
                'lensserialnumber' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'LensSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\LensSerialNumber',
                ),
                'gdalmetadata' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'GDALMetadata',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\GDALMetadata',
                ),
                'gdalnodata' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'GDALNoData',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\GDALNoData',
                ),
                'gamma' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Gamma',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Gamma',
                ),
                'expandsoftware' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExpandSoftware',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExpandSoftware',
                ),
                'expandlens' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExpandLens',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExpandLens',
                ),
                'expandfilm' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExpandFilm',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExpandFilm',
                ),
                'expandfilterlens' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExpandFilterLens',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExpandFilterLens',
                ),
                'expandscanner' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExpandScanner',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExpandScanner',
                ),
                'expandflashlamp' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ExpandFlashLamp',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ExpandFlashLamp',
                ),
                'pixelformat' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'PixelFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\PixelFormat',
                ),
                'transformation' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Transformation',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Transformation',
                ),
                'uncompressed' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Uncompressed',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Uncompressed',
                ),
                'imagetype' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageType',
                ),
                'imagewidth' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageHeight',
                ),
                'widthresolution' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'WidthResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\WidthResolution',
                ),
                'heightresolution' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'HeightResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\HeightResolution',
                ),
                'imageoffset' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageOffset',
                ),
                'imagebytecount' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageByteCount',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageByteCount',
                ),
                'alphaoffset' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'AlphaOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\AlphaOffset',
                ),
                'alphabytecount' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'AlphaByteCount',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\AlphaByteCount',
                ),
                'imagedatadiscard' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'ImageDataDiscard',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\ImageDataDiscard',
                ),
                'alphadatadiscard' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'AlphaDataDiscard',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\AlphaDataDiscard',
                ),
                'ocescanjobdesc' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OceScanjobDesc',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OceScanjobDesc',
                ),
                'oceapplicationselector' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OceApplicationSelector',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OceApplicationSelector',
                ),
                'oceidnumber' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OceIDNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OceIDNumber',
                ),
                'oceimagelogic' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OceImageLogic',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OceImageLogic',
                ),
                'annotations' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Annotations',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Annotations',
                ),
                'usptooriginalcontenttype' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'USPTOOriginalContentType',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\USPTOOriginalContentType',
                ),
                'cfaplanecolor' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CFAPlaneColor',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CFAPlaneColor',
                ),
                'cfalayout' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'CFALayout',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\CFALayout',
                ),
                'blackleveldeltah' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BlackLevelDeltaH',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BlackLevelDeltaH',
                ),
                'blackleveldeltav' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'BlackLevelDeltaV',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\BlackLevelDeltaV',
                ),
                'dngprivatedata' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'DNGPrivateData',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\DNGPrivateData',
                ),
                'rawimagesegmentation' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'RawImageSegmentation',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\RawImageSegmentation',
                ),
                'aliaslayermetadata' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'AliasLayerMetadata',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\AliasLayerMetadata',
                ),
                'subtileblocksize' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'SubTileBlockSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\SubTileBlockSize',
                ),
                'rowinterleavefactor' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'RowInterleaveFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\RowInterleaveFactor',
                ),
                'opcodelist1' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OpcodeList1',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OpcodeList1',
                ),
                'opcodelist2' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OpcodeList2',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OpcodeList2',
                ),
                'opcodelist3' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OpcodeList3',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OpcodeList3',
                ),
                'noiseprofile' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'NoiseProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\NoiseProfile',
                ),
                'padding' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Padding',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Padding',
                ),
                'offsetschema' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'OffsetSchema',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\OffsetSchema',
                ),
                'lens' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Lens',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Lens',
                ),
                'rawfile' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'RawFile',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\RawFile',
                ),
                'converter' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Converter',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Converter',
                ),
                'exposure' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Exposure',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Exposure',
                ),
                'shadows' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Shadows',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Shadows',
                ),
                'brightness' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Brightness',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Brightness',
                ),
                'smoothness' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'Smoothness',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\Smoothness',
                ),
                'moirefilter' => array(
                    'namespace' => 'ExifIFD',
                    'tagname' => 'MoireFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifIFD\MoireFilter',
                ),

            ),
            'dng' => array(
                'originalrawimage' => array(
                    'namespace' => 'DNG',
                    'tagname' => 'OriginalRawImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DNG\OriginalRawImage',
                ),
                'originalrawresource' => array(
                    'namespace' => 'DNG',
                    'tagname' => 'OriginalRawResource',
                    'classname' => 'PHPExiftool\Driver\Tag\DNG\OriginalRawResource',
                ),
                'originalrawfiletype' => array(
                    'namespace' => 'DNG',
                    'tagname' => 'OriginalRawFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\DNG\OriginalRawFileType',
                ),
                'originalrawcreator' => array(
                    'namespace' => 'DNG',
                    'tagname' => 'OriginalRawCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\DNG\OriginalRawCreator',
                ),
                'originalthmimage' => array(
                    'namespace' => 'DNG',
                    'tagname' => 'OriginalTHMImage',
                    'classname' => 'PHPExiftool\Driver\Tag\DNG\OriginalTHMImage',
                ),
                'originalthmresource' => array(
                    'namespace' => 'DNG',
                    'tagname' => 'OriginalTHMResource',
                    'classname' => 'PHPExiftool\Driver\Tag\DNG\OriginalTHMResource',
                ),
                'originalthmfiletype' => array(
                    'namespace' => 'DNG',
                    'tagname' => 'OriginalTHMFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\DNG\OriginalTHMFileType',
                ),
                'originalthmcreator' => array(
                    'namespace' => 'DNG',
                    'tagname' => 'OriginalTHMCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\DNG\OriginalTHMCreator',
                ),

            ),
            'dv' => array(
                'aspectratio' => array(
                    'namespace' => 'DV',
                    'tagname' => 'AspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\AspectRatio',
                ),
                'audiobitspersample' => array(
                    'namespace' => 'DV',
                    'tagname' => 'AudioBitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\AudioBitsPerSample',
                ),
                'audiochannels' => array(
                    'namespace' => 'DV',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\AudioChannels',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'DV',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\AudioSampleRate',
                ),
                'colorimetry' => array(
                    'namespace' => 'DV',
                    'tagname' => 'Colorimetry',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\Colorimetry',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'DV',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\DateTimeOriginal',
                ),
                'duration' => array(
                    'namespace' => 'DV',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\Duration',
                ),
                'framerate' => array(
                    'namespace' => 'DV',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\FrameRate',
                ),
                'imageheight' => array(
                    'namespace' => 'DV',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'DV',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\ImageWidth',
                ),
                'totalbitrate' => array(
                    'namespace' => 'DV',
                    'tagname' => 'TotalBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\TotalBitrate',
                ),
                'videoformat' => array(
                    'namespace' => 'DV',
                    'tagname' => 'VideoFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\VideoFormat',
                ),
                'videoscantype' => array(
                    'namespace' => 'DV',
                    'tagname' => 'VideoScanType',
                    'classname' => 'PHPExiftool\Driver\Tag\DV\VideoScanType',
                ),

            ),
            'djvu' => array(
                'subfiletype' => array(
                    'namespace' => 'DjVu',
                    'tagname' => 'SubfileType',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVu\SubfileType',
                ),
                'imagewidth' => array(
                    'namespace' => 'DjVu',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVu\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'DjVu',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVu\ImageHeight',
                ),
                'djvuversion' => array(
                    'namespace' => 'DjVu',
                    'tagname' => 'DjVuVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVu\DjVuVersion',
                ),
                'spatialresolution' => array(
                    'namespace' => 'DjVu',
                    'tagname' => 'SpatialResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVu\SpatialResolution',
                ),
                'gamma' => array(
                    'namespace' => 'DjVu',
                    'tagname' => 'Gamma',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVu\Gamma',
                ),
                'orientation' => array(
                    'namespace' => 'DjVu',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVu\Orientation',
                ),
                'includedfileid' => array(
                    'namespace' => 'DjVu',
                    'tagname' => 'IncludedFileID',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVu\IncludedFileID',
                ),

            ),
            'djvu-meta' => array(
                'author' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Author',
                ),
                'createdate' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\CreateDate',
                ),
                'creator' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Creator',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Creator',
                ),
                'keywords' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Keywords',
                ),
                'modifydate' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\ModifyDate',
                ),
                'producer' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Producer',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Producer',
                ),
                'subject' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Subject',
                ),
                'title' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Title',
                ),
                'trapped' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Trapped',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Trapped',
                ),
                'address' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Address',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Address',
                ),
                'annotation' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Annotation',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Annotation',
                ),
                'booktitle' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'BookTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\BookTitle',
                ),
                'chapter' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Chapter',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Chapter',
                ),
                'crossref' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'CrossRef',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\CrossRef',
                ),
                'edition' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Edition',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Edition',
                ),
                'eprint' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'EPrint',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\EPrint',
                ),
                'howpublished' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'HowPublished',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\HowPublished',
                ),
                'institution' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Institution',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Institution',
                ),
                'journal' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Journal',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Journal',
                ),
                'key' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Key',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Key',
                ),
                'month' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Month',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Month',
                ),
                'note' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Note',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Note',
                ),
                'number' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Number',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Number',
                ),
                'organization' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Organization',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Organization',
                ),
                'pages' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Pages',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Pages',
                ),
                'publisher' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Publisher',
                ),
                'school' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'School',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\School',
                ),
                'series' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Series',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Series',
                ),
                'type' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Type',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Type',
                ),
                'url' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\URL',
                ),
                'volume' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Volume',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Volume',
                ),
                'year' => array(
                    'namespace' => 'DjVu-Meta',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\DjVuMeta\Year',
                ),

            ),
            'exe' => array(
                'chmversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CHMVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CHMVersion',
                ),
                'languagecode' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'LanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\LanguageCode',
                ),
                'cpuarchitecture' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CPUArchitecture',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CPUArchitecture',
                ),
                'cpubyteorder' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CPUByteOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CPUByteOrder',
                ),
                'objectfiletype' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'ObjectFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\ObjectFileType',
                ),
                'cputype' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CPUType',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CPUType',
                ),
                'cpucount' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CPUCount',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CPUCount',
                ),
                'cpusubtype' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CPUSubtype',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CPUSubtype',
                ),
                'machinetype' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'MachineType',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\MachineType',
                ),
                'timestamp' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'TimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\TimeStamp',
                ),
                'petype' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'PEType',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\PEType',
                ),
                'linkerversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'LinkerVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\LinkerVersion',
                ),
                'codesize' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CodeSize',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CodeSize',
                ),
                'initializeddatasize' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'InitializedDataSize',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\InitializedDataSize',
                ),
                'uninitializeddatasize' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'UninitializedDataSize',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\UninitializedDataSize',
                ),
                'entrypoint' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'EntryPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\EntryPoint',
                ),
                'osversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'OSVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\OSVersion',
                ),
                'imageversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'ImageVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\ImageVersion',
                ),
                'subsystemversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'SubsystemVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\SubsystemVersion',
                ),
                'subsystem' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'Subsystem',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\Subsystem',
                ),
                'pefversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'PEFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\PEFVersion',
                ),
                'builddate' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'BuildDate',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\BuildDate',
                ),
                'buildversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'BuildVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\BuildVersion',
                ),
                'characterset' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CharacterSet',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CharacterSet',
                ),
                'comments' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'Comments',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\Comments',
                ),
                'companyname' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'CompanyName',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\CompanyName',
                ),
                'copyright' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\Copyright',
                ),
                'filedescription' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'FileDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\FileDescription',
                ),
                'fileversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'FileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\FileVersion',
                ),
                'internalname' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'InternalName',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\InternalName',
                ),
                'legalcopyright' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'LegalCopyright',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\LegalCopyright',
                ),
                'legaltrademarks' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'LegalTrademarks',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\LegalTrademarks',
                ),
                'originalfilename' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'OriginalFilename',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\OriginalFilename',
                ),
                'privatebuild' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'PrivateBuild',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\PrivateBuild',
                ),
                'productname' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'ProductName',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\ProductName',
                ),
                'productversion' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'ProductVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\ProductVersion',
                ),
                'specialbuild' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'SpecialBuild',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\SpecialBuild',
                ),
                'fileversionnumber' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'FileVersionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\FileVersionNumber',
                ),
                'productversionnumber' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'ProductVersionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\ProductVersionNumber',
                ),
                'fileflagsmask' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'FileFlagsMask',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\FileFlagsMask',
                ),
                'fileflags' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'FileFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\FileFlags',
                ),
                'fileos' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'FileOS',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\FileOS',
                ),
                'filesubtype' => array(
                    'namespace' => 'EXE',
                    'tagname' => 'FileSubtype',
                    'classname' => 'PHPExiftool\Driver\Tag\EXE\FileSubtype',
                ),

            ),
            'interopifd' => array(
                'interopindex' => array(
                    'namespace' => 'InteropIFD',
                    'tagname' => 'InteropIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\InteropIFD\InteropIndex',
                ),
                'interopversion' => array(
                    'namespace' => 'InteropIFD',
                    'tagname' => 'InteropVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\InteropIFD\InteropVersion',
                ),
                'relatedimagefileformat' => array(
                    'namespace' => 'InteropIFD',
                    'tagname' => 'RelatedImageFileFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\InteropIFD\RelatedImageFileFormat',
                ),
                'relatedimagewidth' => array(
                    'namespace' => 'InteropIFD',
                    'tagname' => 'RelatedImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\InteropIFD\RelatedImageWidth',
                ),
                'relatedimageheight' => array(
                    'namespace' => 'InteropIFD',
                    'tagname' => 'RelatedImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\InteropIFD\RelatedImageHeight',
                ),

            ),
            'ifd0' => array(
                'processingsoftware' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProcessingSoftware',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProcessingSoftware',
                ),
                'subfiletype' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SubfileType',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SubfileType',
                ),
                'oldsubfiletype' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'OldSubfileType',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\OldSubfileType',
                ),
                'imagewidth' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ImageHeight',
                ),
                'bitspersample' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\BitsPerSample',
                ),
                'compression' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Compression',
                ),
                'photometricinterpretation' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PhotometricInterpretation',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PhotometricInterpretation',
                ),
                'thresholding' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Thresholding',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Thresholding',
                ),
                'cellwidth' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CellWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CellWidth',
                ),
                'celllength' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CellLength',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CellLength',
                ),
                'fillorder' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'FillOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\FillOrder',
                ),
                'documentname' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'DocumentName',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\DocumentName',
                ),
                'imagedescription' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ImageDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ImageDescription',
                ),
                'make' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Make',
                ),
                'model' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Model',
                ),
                'previewimagestart' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PreviewImageStart',
                ),
                'orientation' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Orientation',
                ),
                'samplesperpixel' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SamplesPerPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SamplesPerPixel',
                ),
                'rowsperstrip' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'RowsPerStrip',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\RowsPerStrip',
                ),
                'previewimagelength' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PreviewImageLength',
                ),
                'minsamplevalue' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'MinSampleValue',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\MinSampleValue',
                ),
                'maxsamplevalue' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'MaxSampleValue',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\MaxSampleValue',
                ),
                'xresolution' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\XResolution',
                ),
                'yresolution' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\YResolution',
                ),
                'planarconfiguration' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PlanarConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PlanarConfiguration',
                ),
                'pagename' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PageName',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PageName',
                ),
                'xposition' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'XPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\XPosition',
                ),
                'yposition' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'YPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\YPosition',
                ),
                'grayresponseunit' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'GrayResponseUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\GrayResponseUnit',
                ),
                'resolutionunit' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ResolutionUnit',
                ),
                'pagenumber' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PageNumber',
                ),
                'transferfunction' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'TransferFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\TransferFunction',
                ),
                'software' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Software',
                ),
                'modifydate' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ModifyDate',
                ),
                'artist' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Artist',
                ),
                'hostcomputer' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'HostComputer',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\HostComputer',
                ),
                'predictor' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Predictor',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Predictor',
                ),
                'whitepoint' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'WhitePoint',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\WhitePoint',
                ),
                'primarychromaticities' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PrimaryChromaticities',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PrimaryChromaticities',
                ),
                'halftonehints' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'HalftoneHints',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\HalftoneHints',
                ),
                'tilewidth' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'TileWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\TileWidth',
                ),
                'tilelength' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'TileLength',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\TileLength',
                ),
                'inkset' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'InkSet',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\InkSet',
                ),
                'dotrange' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'DotRange',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\DotRange',
                ),
                'thumbnailoffset' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ThumbnailOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ThumbnailOffset',
                ),
                'thumbnaillength' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ThumbnailLength',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ThumbnailLength',
                ),
                'ycbcrcoefficients' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'YCbCrCoefficients',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\YCbCrCoefficients',
                ),
                'ycbcrsubsampling' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'YCbCrSubSampling',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\YCbCrSubSampling',
                ),
                'ycbcrpositioning' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'YCbCrPositioning',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\YCbCrPositioning',
                ),
                'referenceblackwhite' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ReferenceBlackWhite',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ReferenceBlackWhite',
                ),
                'rating' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Rating',
                ),
                'ratingpercent' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'RatingPercent',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\RatingPercent',
                ),
                'copyright' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\Copyright',
                ),
                'iptc-naa' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'IPTC-NAA',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\IPTCNAA',
                ),
                'seminfo' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SEMInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SEMInfo',
                ),
                'imagesourcedata' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ImageSourceData',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ImageSourceData',
                ),
                'xptitle' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'XPTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\XPTitle',
                ),
                'xpcomment' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'XPComment',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\XPComment',
                ),
                'xpauthor' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'XPAuthor',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\XPAuthor',
                ),
                'xpkeywords' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'XPKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\XPKeywords',
                ),
                'xpsubject' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'XPSubject',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\XPSubject',
                ),
                'printim' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PrintIM',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PrintIM',
                ),
                'dngversion' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'DNGVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\DNGVersion',
                ),
                'dngbackwardversion' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'DNGBackwardVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\DNGBackwardVersion',
                ),
                'uniquecameramodel' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'UniqueCameraModel',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\UniqueCameraModel',
                ),
                'localizedcameramodel' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'LocalizedCameraModel',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\LocalizedCameraModel',
                ),
                'colormatrix1' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ColorMatrix1',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ColorMatrix1',
                ),
                'colormatrix2' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ColorMatrix2',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ColorMatrix2',
                ),
                'cameracalibration1' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CameraCalibration1',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CameraCalibration1',
                ),
                'cameracalibration2' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CameraCalibration2',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CameraCalibration2',
                ),
                'reductionmatrix1' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ReductionMatrix1',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ReductionMatrix1',
                ),
                'reductionmatrix2' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ReductionMatrix2',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ReductionMatrix2',
                ),
                'analogbalance' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'AnalogBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\AnalogBalance',
                ),
                'asshotneutral' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'AsShotNeutral',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\AsShotNeutral',
                ),
                'asshotwhitexy' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'AsShotWhiteXY',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\AsShotWhiteXY',
                ),
                'baselineexposure' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'BaselineExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\BaselineExposure',
                ),
                'baselinenoise' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'BaselineNoise',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\BaselineNoise',
                ),
                'baselinesharpness' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'BaselineSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\BaselineSharpness',
                ),
                'linearresponselimit' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'LinearResponseLimit',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\LinearResponseLimit',
                ),
                'cameraserialnumber' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CameraSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CameraSerialNumber',
                ),
                'dnglensinfo' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'DNGLensInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\DNGLensInfo',
                ),
                'shadowscale' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ShadowScale',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ShadowScale',
                ),
                'makernotesafety' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'MakerNoteSafety',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\MakerNoteSafety',
                ),
                'calibrationilluminant1' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CalibrationIlluminant1',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CalibrationIlluminant1',
                ),
                'calibrationilluminant2' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CalibrationIlluminant2',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CalibrationIlluminant2',
                ),
                'rawdatauniqueid' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'RawDataUniqueID',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\RawDataUniqueID',
                ),
                'originalrawfilename' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'OriginalRawFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\OriginalRawFileName',
                ),
                'originalrawfiledata' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'OriginalRawFileData',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\OriginalRawFileData',
                ),
                'asshoticcprofile' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'AsShotICCProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\AsShotICCProfile',
                ),
                'asshotpreprofilematrix' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'AsShotPreProfileMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\AsShotPreProfileMatrix',
                ),
                'currenticcprofile' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CurrentICCProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CurrentICCProfile',
                ),
                'currentpreprofilematrix' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CurrentPreProfileMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CurrentPreProfileMatrix',
                ),
                'colorimetricreference' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ColorimetricReference',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ColorimetricReference',
                ),
                'panasonictitle' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PanasonicTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PanasonicTitle',
                ),
                'panasonictitle2' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PanasonicTitle2',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PanasonicTitle2',
                ),
                'cameracalibrationsig' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'CameraCalibrationSig',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\CameraCalibrationSig',
                ),
                'profilecalibrationsig' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileCalibrationSig',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileCalibrationSig',
                ),
                'asshotprofilename' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'AsShotProfileName',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\AsShotProfileName',
                ),
                'profilename' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileName',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileName',
                ),
                'profilehuesatmapdims' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileHueSatMapDims',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileHueSatMapDims',
                ),
                'profilehuesatmapdata1' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileHueSatMapData1',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileHueSatMapData1',
                ),
                'profilehuesatmapdata2' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileHueSatMapData2',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileHueSatMapData2',
                ),
                'profiletonecurve' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileToneCurve',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileToneCurve',
                ),
                'profileembedpolicy' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileEmbedPolicy',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileEmbedPolicy',
                ),
                'profilecopyright' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileCopyright',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileCopyright',
                ),
                'forwardmatrix1' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ForwardMatrix1',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ForwardMatrix1',
                ),
                'forwardmatrix2' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ForwardMatrix2',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ForwardMatrix2',
                ),
                'previewapplicationname' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PreviewApplicationName',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PreviewApplicationName',
                ),
                'previewapplicationversion' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PreviewApplicationVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PreviewApplicationVersion',
                ),
                'previewsettingsname' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PreviewSettingsName',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PreviewSettingsName',
                ),
                'previewsettingsdigest' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PreviewSettingsDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PreviewSettingsDigest',
                ),
                'previewcolorspace' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PreviewColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PreviewColorSpace',
                ),
                'previewdatetime' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PreviewDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PreviewDateTime',
                ),
                'rawimagedigest' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'RawImageDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\RawImageDigest',
                ),
                'originalrawfiledigest' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'OriginalRawFileDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\OriginalRawFileDigest',
                ),
                'profilelooktabledims' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileLookTableDims',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileLookTableDims',
                ),
                'profilelooktabledata' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileLookTableData',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileLookTableData',
                ),
                'originaldefaultfinalsize' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'OriginalDefaultFinalSize',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\OriginalDefaultFinalSize',
                ),
                'originalbestqualitysize' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'OriginalBestQualitySize',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\OriginalBestQualitySize',
                ),
                'originaldefaultcropsize' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'OriginalDefaultCropSize',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\OriginalDefaultCropSize',
                ),
                'profilehuesatmapencoding' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileHueSatMapEncoding',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileHueSatMapEncoding',
                ),
                'profilelooktableencoding' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ProfileLookTableEncoding',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ProfileLookTableEncoding',
                ),
                'baselineexposureoffset' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'BaselineExposureOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\BaselineExposureOffset',
                ),
                'defaultblackrender' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'DefaultBlackRender',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\DefaultBlackRender',
                ),
                'newrawimagedigest' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'NewRawImageDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\NewRawImageDigest',
                ),
                'rawtopreviewgain' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'RawToPreviewGain',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\RawToPreviewGain',
                ),
                'panasonicrawversion' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'PanasonicRawVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\PanasonicRawVersion',
                ),
                'sensorwidth' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SensorWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SensorWidth',
                ),
                'sensorheight' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SensorHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SensorHeight',
                ),
                'sensortopborder' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SensorTopBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SensorTopBorder',
                ),
                'sensorleftborder' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SensorLeftBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SensorLeftBorder',
                ),
                'sensorbottomborder' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SensorBottomBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SensorBottomBorder',
                ),
                'sensorrightborder' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'SensorRightBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\SensorRightBorder',
                ),
                'redbalance' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'RedBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\RedBalance',
                ),
                'bluebalance' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'BlueBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\BlueBalance',
                ),
                'iso' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ISO',
                ),
                'wbredlevel' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'WBRedLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\WBRedLevel',
                ),
                'wbgreenlevel' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'WBGreenLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\WBGreenLevel',
                ),
                'wbbluelevel' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'WBBlueLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\WBBlueLevel',
                ),
                'jpgfromraw' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'JpgFromRaw',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\JpgFromRaw',
                ),
                'stripoffsets' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'StripOffsets',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\StripOffsets',
                ),
                'stripbytecounts' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'StripByteCounts',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\StripByteCounts',
                ),
                'rawdataoffset' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'RawDataOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\RawDataOffset',
                ),
                'applicationnotes' => array(
                    'namespace' => 'IFD0',
                    'tagname' => 'ApplicationNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD0\ApplicationNotes',
                ),

            ),
            'subifd1' => array(
                'previewimagestart' => array(
                    'namespace' => 'SubIFD1',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD1\PreviewImageStart',
                ),
                'previewimagelength' => array(
                    'namespace' => 'SubIFD1',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD1\PreviewImageLength',
                ),
                'otherimagestart' => array(
                    'namespace' => 'SubIFD1',
                    'tagname' => 'OtherImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD1\OtherImageStart',
                ),
                'otherimagelength' => array(
                    'namespace' => 'SubIFD1',
                    'tagname' => 'OtherImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD1\OtherImageLength',
                ),

            ),
            'subifd2' => array(
                'jpgfromrawstart' => array(
                    'namespace' => 'SubIFD2',
                    'tagname' => 'JpgFromRawStart',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD2\JpgFromRawStart',
                ),
                'jpgfromrawlength' => array(
                    'namespace' => 'SubIFD2',
                    'tagname' => 'JpgFromRawLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD2\JpgFromRawLength',
                ),
                'otherimagestart' => array(
                    'namespace' => 'SubIFD2',
                    'tagname' => 'OtherImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD2\OtherImageStart',
                ),
                'otherimagelength' => array(
                    'namespace' => 'SubIFD2',
                    'tagname' => 'OtherImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD2\OtherImageLength',
                ),

            ),
            'ifd1' => array(
                'thumbnailoffset' => array(
                    'namespace' => 'IFD1',
                    'tagname' => 'ThumbnailOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD1\ThumbnailOffset',
                ),
                'thumbnaillength' => array(
                    'namespace' => 'IFD1',
                    'tagname' => 'ThumbnailLength',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD1\ThumbnailLength',
                ),

            ),
            'subifd' => array(
                'thumbnailoffset' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'ThumbnailOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\ThumbnailOffset',
                ),
                'jpgfromrawstart' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'JpgFromRawStart',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\JpgFromRawStart',
                ),
                'thumbnaillength' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'ThumbnailLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\ThumbnailLength',
                ),
                'jpgfromrawlength' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'JpgFromRawLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\JpgFromRawLength',
                ),
                'cfarepeatpatterndim' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'CFARepeatPatternDim',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\CFARepeatPatternDim',
                ),
                'cfapattern2' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'CFAPattern2',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\CFAPattern2',
                ),
                'linearizationtable' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'LinearizationTable',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\LinearizationTable',
                ),
                'blacklevelrepeatdim' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'BlackLevelRepeatDim',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\BlackLevelRepeatDim',
                ),
                'blacklevel' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'BlackLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\BlackLevel',
                ),
                'whitelevel' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'WhiteLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\WhiteLevel',
                ),
                'defaultscale' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'DefaultScale',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\DefaultScale',
                ),
                'defaultcroporigin' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'DefaultCropOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\DefaultCropOrigin',
                ),
                'defaultcropsize' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'DefaultCropSize',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\DefaultCropSize',
                ),
                'bayergreensplit' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'BayerGreenSplit',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\BayerGreenSplit',
                ),
                'chromablurradius' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'ChromaBlurRadius',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\ChromaBlurRadius',
                ),
                'antialiasstrength' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'AntiAliasStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\AntiAliasStrength',
                ),
                'bestqualityscale' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'BestQualityScale',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\BestQualityScale',
                ),
                'activearea' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'ActiveArea',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\ActiveArea',
                ),
                'maskedareas' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'MaskedAreas',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\MaskedAreas',
                ),
                'noisereductionapplied' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'NoiseReductionApplied',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\NoiseReductionApplied',
                ),
                'defaultusercrop' => array(
                    'namespace' => 'SubIFD',
                    'tagname' => 'DefaultUserCrop',
                    'classname' => 'PHPExiftool\Driver\Tag\SubIFD\DefaultUserCrop',
                ),

            ),
            'ifd2' => array(
                'jpgfromrawstart' => array(
                    'namespace' => 'IFD2',
                    'tagname' => 'JpgFromRawStart',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD2\JpgFromRawStart',
                ),
                'jpgfromrawlength' => array(
                    'namespace' => 'IFD2',
                    'tagname' => 'JpgFromRawLength',
                    'classname' => 'PHPExiftool\Driver\Tag\IFD2\JpgFromRawLength',
                ),

            ),
            'adobe' => array(
                'adobe' => array(
                    'namespace' => 'Adobe',
                    'tagname' => 'Adobe',
                    'classname' => 'PHPExiftool\Driver\Tag\Adobe\Adobe',
                ),
                'dctencodeversion' => array(
                    'namespace' => 'Adobe',
                    'tagname' => 'DCTEncodeVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Adobe\DCTEncodeVersion',
                ),
                'app14flags0' => array(
                    'namespace' => 'Adobe',
                    'tagname' => 'APP14Flags0',
                    'classname' => 'PHPExiftool\Driver\Tag\Adobe\APP14Flags0',
                ),
                'app14flags1' => array(
                    'namespace' => 'Adobe',
                    'tagname' => 'APP14Flags1',
                    'classname' => 'PHPExiftool\Driver\Tag\Adobe\APP14Flags1',
                ),
                'colortransform' => array(
                    'namespace' => 'Adobe',
                    'tagname' => 'ColorTransform',
                    'classname' => 'PHPExiftool\Driver\Tag\Adobe\ColorTransform',
                ),

            ),
            'system' => array(
                'directory' => array(
                    'namespace' => 'System',
                    'tagname' => 'Directory',
                    'classname' => 'PHPExiftool\Driver\Tag\System\Directory',
                ),
                'fileaccessdate' => array(
                    'namespace' => 'System',
                    'tagname' => 'FileAccessDate',
                    'classname' => 'PHPExiftool\Driver\Tag\System\FileAccessDate',
                ),
                'filecreatedate' => array(
                    'namespace' => 'System',
                    'tagname' => 'FileCreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\System\FileCreateDate',
                ),
                'fileinodechangedate' => array(
                    'namespace' => 'System',
                    'tagname' => 'FileInodeChangeDate',
                    'classname' => 'PHPExiftool\Driver\Tag\System\FileInodeChangeDate',
                ),
                'filemodifydate' => array(
                    'namespace' => 'System',
                    'tagname' => 'FileModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\System\FileModifyDate',
                ),
                'filename' => array(
                    'namespace' => 'System',
                    'tagname' => 'FileName',
                    'classname' => 'PHPExiftool\Driver\Tag\System\FileName',
                ),
                'filepermissions' => array(
                    'namespace' => 'System',
                    'tagname' => 'FilePermissions',
                    'classname' => 'PHPExiftool\Driver\Tag\System\FilePermissions',
                ),
                'filesize' => array(
                    'namespace' => 'System',
                    'tagname' => 'FileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\System\FileSize',
                ),
                'resourceforksize' => array(
                    'namespace' => 'System',
                    'tagname' => 'ResourceForkSize',
                    'classname' => 'PHPExiftool\Driver\Tag\System\ResourceForkSize',
                ),

            ),
            'exif' => array(
                'exif' => array(
                    'namespace' => 'EXIF',
                    'tagname' => 'EXIF',
                    'classname' => 'PHPExiftool\Driver\Tag\EXIF\EXIF',
                ),

            ),
            'exiftool' => array(
                'error' => array(
                    'namespace' => 'ExifTool',
                    'tagname' => 'Error',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifTool\Error',
                ),
                'exiftoolversion' => array(
                    'namespace' => 'ExifTool',
                    'tagname' => 'ExifToolVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifTool\ExifToolVersion',
                ),
                'filesequence' => array(
                    'namespace' => 'ExifTool',
                    'tagname' => 'FileSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifTool\FileSequence',
                ),
                'newguid' => array(
                    'namespace' => 'ExifTool',
                    'tagname' => 'NewGUID',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifTool\NewGUID',
                ),
                'now' => array(
                    'namespace' => 'ExifTool',
                    'tagname' => 'Now',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifTool\Now',
                ),
                'warning' => array(
                    'namespace' => 'ExifTool',
                    'tagname' => 'Warning',
                    'classname' => 'PHPExiftool\Driver\Tag\ExifTool\Warning',
                ),

            ),
            'icc_profile' => array(
                'icc_profile' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ICC_Profile',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ICCProfile',
                ),
                'atob0' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'AToB0',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\AToB0',
                ),
                'atob1' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'AToB1',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\AToB1',
                ),
                'atob2' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'AToB2',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\AToB2',
                ),
                'btoa0' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BToA0',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BToA0',
                ),
                'btoa1' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BToA1',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BToA1',
                ),
                'btoa2' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BToA2',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BToA2',
                ),
                'btod0' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BToD0',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BToD0',
                ),
                'btod1' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BToD1',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BToD1',
                ),
                'btod2' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BToD2',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BToD2',
                ),
                'btod3' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BToD3',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BToD3',
                ),
                'dtob0' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'DToB0',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\DToB0',
                ),
                'dtob1' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'DToB1',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\DToB1',
                ),
                'dtob2' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'DToB2',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\DToB2',
                ),
                'dtob3' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'DToB3',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\DToB3',
                ),
                'wcsprofiles' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'WCSProfiles',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\WCSProfiles',
                ),
                'bluetrc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BlueTRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BlueTRC',
                ),
                'bluematrixcolumn' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'BlueMatrixColumn',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\BlueMatrixColumn',
                ),
                'ucrbg' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'UCRBG',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\UCRBG',
                ),
                'mediablackpoint' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'MediaBlackPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\MediaBlackPoint',
                ),
                'calibrationdatetime' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'CalibrationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\CalibrationDateTime',
                ),
                'chromaticadaptation' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ChromaticAdaptation',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ChromaticAdaptation',
                ),
                'colorimetricintentimagestate' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ColorimetricIntentImageState',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ColorimetricIntentImageState',
                ),
                'coloranttableout' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ColorantTableOut',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ColorantTableOut',
                ),
                'colorantorder' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ColorantOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ColorantOrder',
                ),
                'profilecopyright' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ProfileCopyright',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ProfileCopyright',
                ),
                'crdinfo' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'CRDInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\CRDInfo',
                ),
                'profiledescription' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ProfileDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ProfileDescription',
                ),
                'devicesettings' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'DeviceSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\DeviceSettings',
                ),
                'devicemodeldesc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'DeviceModelDesc',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\DeviceModelDesc',
                ),
                'devicemfgdesc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'DeviceMfgDesc',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\DeviceMfgDesc',
                ),
                'profiledescriptionml' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ProfileDescriptionML',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ProfileDescriptionML',
                ),
                'focalplanecolorimetryestimates' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'FocalPlaneColorimetryEstimates',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\FocalPlaneColorimetryEstimates',
                ),
                'greentrc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'GreenTRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\GreenTRC',
                ),
                'greenmatrixcolumn' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'GreenMatrixColumn',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\GreenMatrixColumn',
                ),
                'gamut' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'Gamut',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\Gamut',
                ),
                'graytrc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'GrayTRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\GrayTRC',
                ),
                'luminance' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'Luminance',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\Luminance',
                ),
                'makeandmodel' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'MakeAndModel',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\MakeAndModel',
                ),
                'namedcolor2' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'NamedColor2',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\NamedColor2',
                ),
                'namedcolor' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'NamedColor',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\NamedColor',
                ),
                'nativedisplayinfo' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'NativeDisplayInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\NativeDisplayInfo',
                ),
                'preview0' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'Preview0',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\Preview0',
                ),
                'preview1' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'Preview1',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\Preview1',
                ),
                'preview2' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'Preview2',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\Preview2',
                ),
                'ps2renderingintent' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'PS2RenderingIntent',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\PS2RenderingIntent',
                ),
                'postscript2csa' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'PostScript2CSA',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\PostScript2CSA',
                ),
                'postscript2crd0' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'PostScript2CRD0',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\PostScript2CRD0',
                ),
                'postscript2crd1' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'PostScript2CRD1',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\PostScript2CRD1',
                ),
                'postscript2crd2' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'PostScript2CRD2',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\PostScript2CRD2',
                ),
                'profilesequencedesc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ProfileSequenceDesc',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ProfileSequenceDesc',
                ),
                'profilesequenceidentifier' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ProfileSequenceIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ProfileSequenceIdentifier',
                ),
                'ps2crdvmsize' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'PS2CRDVMSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\PS2CRDVMSize',
                ),
                'redtrc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'RedTRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\RedTRC',
                ),
                'redmatrixcolumn' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'RedMatrixColumn',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\RedMatrixColumn',
                ),
                'outputresponse' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'OutputResponse',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\OutputResponse',
                ),
                'reflectionhardcopyorigcolorimetry' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ReflectionHardcopyOrigColorimetry',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ReflectionHardcopyOrigColorimetry',
                ),
                'perceptualrenderingintentgamut' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'PerceptualRenderingIntentGamut',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\PerceptualRenderingIntentGamut',
                ),
                'saturationrenderingintentgamut' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'SaturationRenderingIntentGamut',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\SaturationRenderingIntentGamut',
                ),
                'reflectionprintoutputcolorimetry' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ReflectionPrintOutputColorimetry',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ReflectionPrintOutputColorimetry',
                ),
                'sceneappearanceestimates' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'SceneAppearanceEstimates',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\SceneAppearanceEstimates',
                ),
                'scenecolorimetryestimates' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'SceneColorimetryEstimates',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\SceneColorimetryEstimates',
                ),
                'screeningdesc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ScreeningDesc',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ScreeningDesc',
                ),
                'screening' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'Screening',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\Screening',
                ),
                'chartarget' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'CharTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\CharTarget',
                ),
                'technology' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'Technology',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\Technology',
                ),
                'videocardgamma' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'VideoCardGamma',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\VideoCardGamma',
                ),
                'viewingconddesc' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'ViewingCondDesc',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\ViewingCondDesc',
                ),
                'mediawhitepoint' => array(
                    'namespace' => 'ICC_Profile',
                    'tagname' => 'MediaWhitePoint',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCProfile\MediaWhitePoint',
                ),

            ),
            'iptc' => array(
                'iptc' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'IPTC',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\IPTC',
                ),
                'applicationrecordversion' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ApplicationRecordVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ApplicationRecordVersion',
                ),
                'objecttypereference' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ObjectTypeReference',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ObjectTypeReference',
                ),
                'objectattributereference' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ObjectAttributeReference',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ObjectAttributeReference',
                ),
                'objectname' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ObjectName',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ObjectName',
                ),
                'editstatus' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'EditStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\EditStatus',
                ),
                'editorialupdate' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'EditorialUpdate',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\EditorialUpdate',
                ),
                'urgency' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Urgency',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Urgency',
                ),
                'subjectreference' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'SubjectReference',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SubjectReference',
                ),
                'category' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Category',
                ),
                'supplementalcategories' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'SupplementalCategories',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SupplementalCategories',
                ),
                'fixtureidentifier' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'FixtureIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\FixtureIdentifier',
                ),
                'keywords' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Keywords',
                ),
                'contentlocationcode' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ContentLocationCode',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ContentLocationCode',
                ),
                'contentlocationname' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ContentLocationName',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ContentLocationName',
                ),
                'releasedate' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ReleaseDate',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ReleaseDate',
                ),
                'releasetime' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ReleaseTime',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ReleaseTime',
                ),
                'expirationdate' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ExpirationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ExpirationDate',
                ),
                'expirationtime' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ExpirationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ExpirationTime',
                ),
                'specialinstructions' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'SpecialInstructions',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SpecialInstructions',
                ),
                'actionadvised' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ActionAdvised',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ActionAdvised',
                ),
                'referenceservice' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ReferenceService',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ReferenceService',
                ),
                'referencedate' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ReferenceDate',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ReferenceDate',
                ),
                'referencenumber' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ReferenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ReferenceNumber',
                ),
                'datecreated' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'DateCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\DateCreated',
                ),
                'timecreated' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'TimeCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\TimeCreated',
                ),
                'digitalcreationdate' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'DigitalCreationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\DigitalCreationDate',
                ),
                'digitalcreationtime' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'DigitalCreationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\DigitalCreationTime',
                ),
                'originatingprogram' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'OriginatingProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\OriginatingProgram',
                ),
                'programversion' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ProgramVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ProgramVersion',
                ),
                'objectcycle' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ObjectCycle',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ObjectCycle',
                ),
                'by-line' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'By-line',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ByLine',
                ),
                'by-linetitle' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'By-lineTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ByLineTitle',
                ),
                'city' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'City',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\City',
                ),
                'sub-location' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Sub-location',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SubLocation',
                ),
                'province-state' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Province-State',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ProvinceState',
                ),
                'country-primarylocationcode' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Country-PrimaryLocationCode',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\CountryPrimaryLocationCode',
                ),
                'country-primarylocationname' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Country-PrimaryLocationName',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\CountryPrimaryLocationName',
                ),
                'originaltransmissionreference' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'OriginalTransmissionReference',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\OriginalTransmissionReference',
                ),
                'headline' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Headline',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Headline',
                ),
                'credit' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Credit',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Credit',
                ),
                'source' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Source',
                ),
                'copyrightnotice' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'CopyrightNotice',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\CopyrightNotice',
                ),
                'contact' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Contact',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Contact',
                ),
                'caption-abstract' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Caption-Abstract',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\CaptionAbstract',
                ),
                'localcaption' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'LocalCaption',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\LocalCaption',
                ),
                'writer-editor' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Writer-Editor',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\WriterEditor',
                ),
                'rasterizedcaption' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'RasterizedCaption',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\RasterizedCaption',
                ),
                'imagetype' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ImageType',
                ),
                'imageorientation' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ImageOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ImageOrientation',
                ),
                'languageidentifier' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'LanguageIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\LanguageIdentifier',
                ),
                'audiotype' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'AudioType',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\AudioType',
                ),
                'audiosamplingrate' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'AudioSamplingRate',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\AudioSamplingRate',
                ),
                'audiosamplingresolution' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'AudioSamplingResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\AudioSamplingResolution',
                ),
                'audioduration' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'AudioDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\AudioDuration',
                ),
                'audiooutcue' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'AudioOutcue',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\AudioOutcue',
                ),
                'jobid' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'JobID',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\JobID',
                ),
                'masterdocumentid' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'MasterDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\MasterDocumentID',
                ),
                'shortdocumentid' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ShortDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ShortDocumentID',
                ),
                'uniquedocumentid' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'UniqueDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\UniqueDocumentID',
                ),
                'ownerid' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'OwnerID',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\OwnerID',
                ),
                'objectpreviewfileformat' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ObjectPreviewFileFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ObjectPreviewFileFormat',
                ),
                'objectpreviewfileversion' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ObjectPreviewFileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ObjectPreviewFileVersion',
                ),
                'objectpreviewdata' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ObjectPreviewData',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ObjectPreviewData',
                ),
                'prefs' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Prefs',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Prefs',
                ),
                'classifystate' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ClassifyState',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ClassifyState',
                ),
                'similarityindex' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'SimilarityIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SimilarityIndex',
                ),
                'documentnotes' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'DocumentNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\DocumentNotes',
                ),
                'documenthistory' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'DocumentHistory',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\DocumentHistory',
                ),
                'exifcamerainfo' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ExifCameraInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ExifCameraInfo',
                ),
                'catalogsets' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'CatalogSets',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\CatalogSets',
                ),
                'enveloperecordversion' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'EnvelopeRecordVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\EnvelopeRecordVersion',
                ),
                'destination' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'Destination',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\Destination',
                ),
                'fileformat' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'FileFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\FileFormat',
                ),
                'fileversion' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'FileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\FileVersion',
                ),
                'serviceidentifier' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ServiceIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ServiceIdentifier',
                ),
                'envelopenumber' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'EnvelopeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\EnvelopeNumber',
                ),
                'productid' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ProductID',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ProductID',
                ),
                'envelopepriority' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'EnvelopePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\EnvelopePriority',
                ),
                'datesent' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'DateSent',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\DateSent',
                ),
                'timesent' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'TimeSent',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\TimeSent',
                ),
                'codedcharacterset' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'CodedCharacterSet',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\CodedCharacterSet',
                ),
                'uniqueobjectname' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'UniqueObjectName',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\UniqueObjectName',
                ),
                'armidentifier' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ARMIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ARMIdentifier',
                ),
                'armversion' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ARMVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ARMVersion',
                ),
                'newsphotoversion' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'NewsPhotoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\NewsPhotoVersion',
                ),
                'iptcpicturenumber' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'IPTCPictureNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\IPTCPictureNumber',
                ),
                'iptcimagewidth' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'IPTCImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\IPTCImageWidth',
                ),
                'iptcimageheight' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'IPTCImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\IPTCImageHeight',
                ),
                'iptcpixelwidth' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'IPTCPixelWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\IPTCPixelWidth',
                ),
                'iptcpixelheight' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'IPTCPixelHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\IPTCPixelHeight',
                ),
                'supplementaltype' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'SupplementalType',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SupplementalType',
                ),
                'colorrepresentation' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ColorRepresentation',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ColorRepresentation',
                ),
                'interchangecolorspace' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'InterchangeColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\InterchangeColorSpace',
                ),
                'colorsequence' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ColorSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ColorSequence',
                ),
                'icc_profile' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ICC_Profile',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ICCProfile',
                ),
                'colorcalibrationmatrix' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ColorCalibrationMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ColorCalibrationMatrix',
                ),
                'lookuptable' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'LookupTable',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\LookupTable',
                ),
                'numindexentries' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'NumIndexEntries',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\NumIndexEntries',
                ),
                'colorpalette' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ColorPalette',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ColorPalette',
                ),
                'iptcbitspersample' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'IPTCBitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\IPTCBitsPerSample',
                ),
                'samplestructure' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'SampleStructure',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SampleStructure',
                ),
                'scanningdirection' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ScanningDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ScanningDirection',
                ),
                'iptcimagerotation' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'IPTCImageRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\IPTCImageRotation',
                ),
                'datacompressionmethod' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'DataCompressionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\DataCompressionMethod',
                ),
                'quantizationmethod' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'QuantizationMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\QuantizationMethod',
                ),
                'endpoints' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'EndPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\EndPoints',
                ),
                'excursiontolerance' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ExcursionTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ExcursionTolerance',
                ),
                'bitspercomponent' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'BitsPerComponent',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\BitsPerComponent',
                ),
                'maximumdensityrange' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'MaximumDensityRange',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\MaximumDensityRange',
                ),
                'gammacompensatedvalue' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'GammaCompensatedValue',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\GammaCompensatedValue',
                ),
                'subfile' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'SubFile',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SubFile',
                ),
                'confirmedobjectsize' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ConfirmedObjectSize',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ConfirmedObjectSize',
                ),
                'sizemode' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'SizeMode',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\SizeMode',
                ),
                'maxsubfilesize' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'MaxSubfileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\MaxSubfileSize',
                ),
                'objectsizeannounced' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'ObjectSizeAnnounced',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\ObjectSizeAnnounced',
                ),
                'maximumobjectsize' => array(
                    'namespace' => 'IPTC',
                    'tagname' => 'MaximumObjectSize',
                    'classname' => 'PHPExiftool\Driver\Tag\IPTC\MaximumObjectSize',
                ),

            ),
            'xmp' => array(
                'xmp' => array(
                    'namespace' => 'XMP',
                    'tagname' => 'XMP',
                    'classname' => 'PHPExiftool\Driver\Tag\XMP\XMP',
                ),

            ),
            'flac' => array(
                'padding' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'Padding',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\Padding',
                ),
                'application' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'Application',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\Application',
                ),
                'seektable' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'SeekTable',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\SeekTable',
                ),
                'cuesheet' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'CueSheet',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\CueSheet',
                ),
                'picturetype' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'PictureType',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\PictureType',
                ),
                'picturemimetype' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'PictureMIMEType',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\PictureMIMEType',
                ),
                'picturedescription' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'PictureDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\PictureDescription',
                ),
                'picturewidth' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'PictureWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\PictureWidth',
                ),
                'pictureheight' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'PictureHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\PictureHeight',
                ),
                'picturebitsperpixel' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'PictureBitsPerPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\PictureBitsPerPixel',
                ),
                'pictureindexedcolors' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'PictureIndexedColors',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\PictureIndexedColors',
                ),
                'picturelength' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'PictureLength',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\PictureLength',
                ),
                'picture' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'Picture',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\Picture',
                ),
                'blocksizemin' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'BlockSizeMin',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\BlockSizeMin',
                ),
                'blocksizemax' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'BlockSizeMax',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\BlockSizeMax',
                ),
                'framesizemin' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'FrameSizeMin',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\FrameSizeMin',
                ),
                'framesizemax' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'FrameSizeMax',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\FrameSizeMax',
                ),
                'samplerate' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\SampleRate',
                ),
                'channels' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'Channels',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\Channels',
                ),
                'bitspersample' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\BitsPerSample',
                ),
                'totalsamples' => array(
                    'namespace' => 'FLAC',
                    'tagname' => 'TotalSamples',
                    'classname' => 'PHPExiftool\Driver\Tag\FLAC\TotalSamples',
                ),

            ),
            'flash' => array(
                'audioencoding' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioEncoding',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioEncoding',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioSampleRate',
                ),
                'audiobitspersample' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioBitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioBitsPerSample',
                ),
                'audiochannels' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioChannels',
                ),
                'name' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'Name',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\Name',
                ),
                'time' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'Time',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\Time',
                ),
                'type' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'Type',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\Type',
                ),
                'fileattributes' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'FileAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\FileAttributes',
                ),
                'compressed' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'Compressed',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\Compressed',
                ),
                'duration' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\Duration',
                ),
                'flashversion' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'FlashVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\FlashVersion',
                ),
                'framecount' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'FrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\FrameCount',
                ),
                'framerate' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\FrameRate',
                ),
                'imageheight' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\ImageWidth',
                ),
                'audiocodecid' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioCodecID',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioCodecID',
                ),
                'audiobitrate' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioBitrate',
                ),
                'audiodelay' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioDelay',
                ),
                'audiosamplesize' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioSampleSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioSampleSize',
                ),
                'audiosize' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'AudioSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\AudioSize',
                ),
                'bytelength' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'ByteLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\ByteLength',
                ),
                'canseektoend' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'CanSeekToEnd',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\CanSeekToEnd',
                ),
                'canseekontime' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'CanSeekOnTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\CanSeekOnTime',
                ),
                'createdby' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'CreatedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\CreatedBy',
                ),
                'createdate' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\CreateDate',
                ),
                'datasize' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'DataSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\DataSize',
                ),
                'filesizebytes' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'FileSizeBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\FileSizeBytes',
                ),
                'hasaudio' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'HasAudio',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\HasAudio',
                ),
                'hascuepoints' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'HasCuePoints',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\HasCuePoints',
                ),
                'haskeyframes' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'HasKeyFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\HasKeyFrames',
                ),
                'hasmetadata' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'HasMetadata',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\HasMetadata',
                ),
                'hasvideo' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'HasVideo',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\HasVideo',
                ),
                'httphostheader' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'HTTPHostHeader',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\HTTPHostHeader',
                ),
                'keyframepositions' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'KeyFramePositions',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\KeyFramePositions',
                ),
                'keyframestimes' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'KeyFramesTimes',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\KeyFramesTimes',
                ),
                'lastkeyframetime' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'LastKeyFrameTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\LastKeyFrameTime',
                ),
                'lasttimestamp' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'LastTimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\LastTimeStamp',
                ),
                'metadatacreator' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'MetadataCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\MetadataCreator',
                ),
                'metadatadate' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'MetadataDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\MetadataDate',
                ),
                'message' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'Message',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\Message',
                ),
                'url' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\URL',
                ),
                'sourcedata' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'SourceData',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\SourceData',
                ),
                'starttime' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'StartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\StartTime',
                ),
                'stereo' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'Stereo',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\Stereo',
                ),
                'totaldatarate' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'TotalDataRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\TotalDataRate',
                ),
                'totalduration' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'TotalDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\TotalDuration',
                ),
                'videocodecid' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'VideoCodecID',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\VideoCodecID',
                ),
                'videobitrate' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'VideoBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\VideoBitrate',
                ),
                'videosize' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'VideoSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\VideoSize',
                ),
                'videoencoding' => array(
                    'namespace' => 'Flash',
                    'tagname' => 'VideoEncoding',
                    'classname' => 'PHPExiftool\Driver\Tag\Flash\VideoEncoding',
                ),

            ),
            'flashpix' => array(
                'compobjusertypelen' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CompObjUserTypeLen',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CompObjUserTypeLen',
                ),
                'compobjusertype' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CompObjUserType',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CompObjUserType',
                ),
                'dataobjectid' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DataObjectID',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DataObjectID',
                ),
                'lockedpropertylist' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'LockedPropertyList',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\LockedPropertyList',
                ),
                'dataobjecttitle' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DataObjectTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DataObjectTitle',
                ),
                'lastmodifier' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'LastModifier',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\LastModifier',
                ),
                'revisionnumber' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'RevisionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\RevisionNumber',
                ),
                'datacreatedate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DataCreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DataCreateDate',
                ),
                'datamodifydate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DataModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DataModifyDate',
                ),
                'creatingapplication' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CreatingApplication',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CreatingApplication',
                ),
                'dataobjectstatus' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DataObjectStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DataObjectStatus',
                ),
                'creatingtransform' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CreatingTransform',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CreatingTransform',
                ),
                'usingtransforms' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'UsingTransforms',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\UsingTransforms',
                ),
                'cachedimageheight' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CachedImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CachedImageHeight',
                ),
                'cachedimagewidth' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CachedImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CachedImageWidth',
                ),
                'category' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Category',
                ),
                'presentationtarget' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'PresentationTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\PresentationTarget',
                ),
                'bytes' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Bytes',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Bytes',
                ),
                'lines' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Lines',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Lines',
                ),
                'paragraphs' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Paragraphs',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Paragraphs',
                ),
                'slides' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Slides',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Slides',
                ),
                'notes' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Notes',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Notes',
                ),
                'hiddenslides' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'HiddenSlides',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\HiddenSlides',
                ),
                'mmclips' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'MMClips',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\MMClips',
                ),
                'scalecrop' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScaleCrop',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScaleCrop',
                ),
                'headingpairs' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'HeadingPairs',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\HeadingPairs',
                ),
                'titleofparts' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TitleOfParts',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TitleOfParts',
                ),
                'manager' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Manager',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Manager',
                ),
                'company' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Company',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Company',
                ),
                'linksuptodate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'LinksUpToDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\LinksUpToDate',
                ),
                'charcountwithspaces' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CharCountWithSpaces',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CharCountWithSpaces',
                ),
                'shareddoc' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SharedDoc',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SharedDoc',
                ),
                'hyperlinkschanged' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'HyperlinksChanged',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\HyperlinksChanged',
                ),
                'appversion' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'AppVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\AppVersion',
                ),
                'hyperlinks' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Hyperlinks',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Hyperlinks',
                ),
                'hyperlinkbase' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'HyperlinkBase',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\HyperlinkBase',
                ),
                'extensionname' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExtensionName',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExtensionName',
                ),
                'extensionclassid' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExtensionClassID',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExtensionClassID',
                ),
                'extensionpersistence' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExtensionPersistence',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExtensionPersistence',
                ),
                'extensioncreatedate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExtensionCreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExtensionCreateDate',
                ),
                'extensionmodifydate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExtensionModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExtensionModifyDate',
                ),
                'extensiondescription' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExtensionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExtensionDescription',
                ),
                'storage-streampathname' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Storage-StreamPathname',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\StorageStreamPathname',
                ),
                'flashpixstreampathname' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FlashPixStreamPathname',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FlashPixStreamPathname',
                ),
                'flashpixstreamfieldoffset' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FlashPixStreamFieldOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FlashPixStreamFieldOffset',
                ),
                'propertysetpathname' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'PropertySetPathname',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\PropertySetPathname',
                ),
                'propertysetidcodes' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'PropertySetIDCodes',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\PropertySetIDCodes',
                ),
                'propertyvectorelements' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'PropertyVectorElements',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\PropertyVectorElements',
                ),
                'subimageresolutions' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageResolutions',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageResolutions',
                ),
                'usedextensionnumbers' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'UsedExtensionNumbers',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\UsedExtensionNumbers',
                ),
                'transformedimagetitle' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TransformedImageTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TransformedImageTitle',
                ),
                'visibleoutputs' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'VisibleOutputs',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\VisibleOutputs',
                ),
                'maximumimageindex' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'MaximumImageIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\MaximumImageIndex',
                ),
                'maximumtransformindex' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'MaximumTransformIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\MaximumTransformIndex',
                ),
                'maximumoperationindex' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'MaximumOperationIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\MaximumOperationIndex',
                ),
                'numberofresolutions' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'NumberOfResolutions',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\NumberOfResolutions',
                ),
                'imagewidth' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ImageHeight',
                ),
                'defaultdisplayheight' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DefaultDisplayHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DefaultDisplayHeight',
                ),
                'defaultdisplaywidth' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DefaultDisplayWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DefaultDisplayWidth',
                ),
                'displayunits' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DisplayUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DisplayUnits',
                ),
                'subimagewidth' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageWidth',
                ),
                'subimageheight' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageHeight',
                ),
                'subimagecolor' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageColor',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageColor',
                ),
                'subimagenumericalformat' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageNumericalFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageNumericalFormat',
                ),
                'decimationmethod' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DecimationMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DecimationMethod',
                ),
                'decimationprefilterwidth' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DecimationPrefilterWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DecimationPrefilterWidth',
                ),
                'subimageicc_profile' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageICC_Profile',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageICCProfile',
                ),
                'jpegtables' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'JPEGTables',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\JPEGTables',
                ),
                'maxjpegtableindex' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'MaxJPEGTableIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\MaxJPEGTableIndex',
                ),
                'filesource' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FileSource',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FileSource',
                ),
                'scenetype' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SceneType',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SceneType',
                ),
                'creationpathvector' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CreationPathVector',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CreationPathVector',
                ),
                'softwarerelease' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SoftwareRelease',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SoftwareRelease',
                ),
                'userdefinedid' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'UserDefinedID',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\UserDefinedID',
                ),
                'sharpnessapproximation' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SharpnessApproximation',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SharpnessApproximation',
                ),
                'copyright' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Copyright',
                ),
                'originalimagebroker' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'OriginalImageBroker',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OriginalImageBroker',
                ),
                'digitalimagebroker' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DigitalImageBroker',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DigitalImageBroker',
                ),
                'authorship' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Authorship',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Authorship',
                ),
                'intellectualpropertynotes' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'IntellectualPropertyNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\IntellectualPropertyNotes',
                ),
                'testtarget' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TestTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TestTarget',
                ),
                'groupcaption' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'GroupCaption',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\GroupCaption',
                ),
                'captiontext' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CaptionText',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CaptionText',
                ),
                'people' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'People',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\People',
                ),
                'things' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Things',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Things',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\DateTimeOriginal',
                ),
                'events' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Events',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Events',
                ),
                'places' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Places',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Places',
                ),
                'contentdescriptionnotes' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ContentDescriptionNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ContentDescriptionNotes',
                ),
                'make' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Make',
                ),
                'model' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Model',
                ),
                'serialnumber' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SerialNumber',
                ),
                'createdate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CreateDate',
                ),
                'exposuretime' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExposureTime',
                ),
                'fnumber' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FNumber',
                ),
                'exposureprogram' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExposureProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExposureProgram',
                ),
                'brightnessvalue' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'BrightnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\BrightnessValue',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExposureCompensation',
                ),
                'subjectdistance' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubjectDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubjectDistance',
                ),
                'meteringmode' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\MeteringMode',
                ),
                'lightsource' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'LightSource',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\LightSource',
                ),
                'focallength' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FocalLength',
                ),
                'maxaperturevalue' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'MaxApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\MaxApertureValue',
                ),
                'flash' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Flash',
                ),
                'flashenergy' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FlashEnergy',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FlashEnergy',
                ),
                'flashreturn' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FlashReturn',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FlashReturn',
                ),
                'backlight' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'BackLight',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\BackLight',
                ),
                'subjectlocation' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubjectLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubjectLocation',
                ),
                'exposureindex' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ExposureIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ExposureIndex',
                ),
                'specialeffectsopticalfilter' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SpecialEffectsOpticalFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SpecialEffectsOpticalFilter',
                ),
                'perpicturenotes' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'PerPictureNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\PerPictureNotes',
                ),
                'sensingmethod' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SensingMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SensingMethod',
                ),
                'focalplanexresolution' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FocalPlaneXResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FocalPlaneXResolution',
                ),
                'focalplaneyresolution' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FocalPlaneYResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FocalPlaneYResolution',
                ),
                'focalplaneresolutionunit' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FocalPlaneResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FocalPlaneResolutionUnit',
                ),
                'spatialfrequencyresponse' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SpatialFrequencyResponse',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SpatialFrequencyResponse',
                ),
                'cfapattern' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CFAPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CFAPattern',
                ),
                'iso' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ISO',
                ),
                'opto-electricconvfactor' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Opto-ElectricConvFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OptoElectricConvFactor',
                ),
                'filmbrand' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FilmBrand',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FilmBrand',
                ),
                'filmcategory' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FilmCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FilmCategory',
                ),
                'filmsize' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FilmSize',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FilmSize',
                ),
                'filmrollnumber' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FilmRollNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FilmRollNumber',
                ),
                'filmframenumber' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'FilmFrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\FilmFrameNumber',
                ),
                'scannermake' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScannerMake',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScannerMake',
                ),
                'scannermodel' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScannerModel',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScannerModel',
                ),
                'scannerserialnumber' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScannerSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScannerSerialNumber',
                ),
                'scansoftware' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScanSoftware',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScanSoftware',
                ),
                'scansoftwarerevisiondate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScanSoftwareRevisionDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScanSoftwareRevisionDate',
                ),
                'serviceorganizationname' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ServiceOrganizationName',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ServiceOrganizationName',
                ),
                'scanoperatorid' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScanOperatorID',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScanOperatorID',
                ),
                'scandate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScanDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScanDate',
                ),
                'modifydate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ModifyDate',
                ),
                'scannerpixelsize' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScannerPixelSize',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScannerPixelSize',
                ),
                'originalscannedimagesize' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'OriginalScannedImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OriginalScannedImageSize',
                ),
                'originaldocumentsize' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'OriginalDocumentSize',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OriginalDocumentSize',
                ),
                'originalmedium' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'OriginalMedium',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OriginalMedium',
                ),
                'typeoforiginal' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TypeOfOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TypeOfOriginal',
                ),
                'screennail' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ScreenNail',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ScreenNail',
                ),
                'audiostream' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'AudioStream',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\AudioStream',
                ),
                'currentuser' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CurrentUser',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CurrentUser',
                ),
                'operationid' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'OperationID',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OperationID',
                ),
                'subimagetilecount' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageTileCount',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageTileCount',
                ),
                'subimagetilewidth' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageTileWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageTileWidth',
                ),
                'subimagetileheight' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SubimageTileHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SubimageTileHeight',
                ),
                'numchannels' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'NumChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\NumChannels',
                ),
                'dictionary' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Dictionary',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Dictionary',
                ),
                'codepage' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'CodePage',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\CodePage',
                ),
                'title' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Title',
                ),
                'subject' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Subject',
                ),
                'author' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Author',
                ),
                'keywords' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Keywords',
                ),
                'comments' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Comments',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Comments',
                ),
                'template' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Template',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Template',
                ),
                'lastmodifiedby' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'LastModifiedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\LastModifiedBy',
                ),
                'totaledittime' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TotalEditTime',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TotalEditTime',
                ),
                'lastprinted' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'LastPrinted',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\LastPrinted',
                ),
                'pages' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Pages',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Pages',
                ),
                'words' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Words',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Words',
                ),
                'characters' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Characters',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Characters',
                ),
                'thumbnailclip' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ThumbnailClip',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ThumbnailClip',
                ),
                'software' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Software',
                ),
                'security' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Security',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Security',
                ),
                'localeindicator' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'LocaleIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\LocaleIndicator',
                ),
                'transformnodeid' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TransformNodeID',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TransformNodeID',
                ),
                'operationclassid' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'OperationClassID',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OperationClassID',
                ),
                'transformtitle' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TransformTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TransformTitle',
                ),
                'transformcreatedate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TransformCreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TransformCreateDate',
                ),
                'transformmodifydate' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'TransformModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\TransformModifyDate',
                ),
                'inputdataobjectlist' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'InputDataObjectList',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\InputDataObjectList',
                ),
                'outputdataobjectlist' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'OutputDataObjectList',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OutputDataObjectList',
                ),
                'operationnumber' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'OperationNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\OperationNumber',
                ),
                'resultaspectratio' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ResultAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ResultAspectRatio',
                ),
                'rectangleofinterest' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'RectangleOfInterest',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\RectangleOfInterest',
                ),
                'filtering' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'Filtering',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\Filtering',
                ),
                'spatialorientation' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'SpatialOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\SpatialOrientation',
                ),
                'colortwistmatrix' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ColorTwistMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ColorTwistMatrix',
                ),
                'contrastadjustment' => array(
                    'namespace' => 'FlashPix',
                    'tagname' => 'ContrastAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\FlashPix\ContrastAdjustment',
                ),

            ),
            'font' => array(
                'ascender' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Ascender',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Ascender',
                ),
                'capheight' => array(
                    'namespace' => 'Font',
                    'tagname' => 'CapHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\CapHeight',
                ),
                'characterset' => array(
                    'namespace' => 'Font',
                    'tagname' => 'CharacterSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\CharacterSet',
                ),
                'characters' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Characters',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Characters',
                ),
                'createdate' => array(
                    'namespace' => 'Font',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\CreateDate',
                ),
                'descender' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Descender',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Descender',
                ),
                'encodingscheme' => array(
                    'namespace' => 'Font',
                    'tagname' => 'EncodingScheme',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\EncodingScheme',
                ),
                'escchar' => array(
                    'namespace' => 'Font',
                    'tagname' => 'EscChar',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\EscChar',
                ),
                'fontfamily' => array(
                    'namespace' => 'Font',
                    'tagname' => 'FontFamily',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\FontFamily',
                ),
                'fontname' => array(
                    'namespace' => 'Font',
                    'tagname' => 'FontName',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\FontName',
                ),
                'fullname' => array(
                    'namespace' => 'Font',
                    'tagname' => 'FullName',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\FullName',
                ),
                'isbasefont' => array(
                    'namespace' => 'Font',
                    'tagname' => 'IsBaseFont',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\IsBaseFont',
                ),
                'isfixedv' => array(
                    'namespace' => 'Font',
                    'tagname' => 'IsFixedV',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\IsFixedV',
                ),
                'mappingscheme' => array(
                    'namespace' => 'Font',
                    'tagname' => 'MappingScheme',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\MappingScheme',
                ),
                'notice' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Notice',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Notice',
                ),
                'version' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Version',
                ),
                'weight' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Weight',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Weight',
                ),
                'xheight' => array(
                    'namespace' => 'Font',
                    'tagname' => 'XHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\XHeight',
                ),
                'numfonts' => array(
                    'namespace' => 'Font',
                    'tagname' => 'NumFonts',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\NumFonts',
                ),
                'postscriptfontname' => array(
                    'namespace' => 'Font',
                    'tagname' => 'PostScriptFontName',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\PostScriptFontName',
                ),
                'copyright' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Copyright',
                ),
                'fontsubfamily' => array(
                    'namespace' => 'Font',
                    'tagname' => 'FontSubfamily',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\FontSubfamily',
                ),
                'fontsubfamilyid' => array(
                    'namespace' => 'Font',
                    'tagname' => 'FontSubfamilyID',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\FontSubfamilyID',
                ),
                'nametableversion' => array(
                    'namespace' => 'Font',
                    'tagname' => 'NameTableVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\NameTableVersion',
                ),
                'trademark' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Trademark',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Trademark',
                ),
                'manufacturer' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Manufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Manufacturer',
                ),
                'designer' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Designer',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Designer',
                ),
                'description' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Description',
                ),
                'vendorurl' => array(
                    'namespace' => 'Font',
                    'tagname' => 'VendorURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\VendorURL',
                ),
                'designerurl' => array(
                    'namespace' => 'Font',
                    'tagname' => 'DesignerURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\DesignerURL',
                ),
                'license' => array(
                    'namespace' => 'Font',
                    'tagname' => 'License',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\License',
                ),
                'licenseinfourl' => array(
                    'namespace' => 'Font',
                    'tagname' => 'LicenseInfoURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\LicenseInfoURL',
                ),
                'preferredfamily' => array(
                    'namespace' => 'Font',
                    'tagname' => 'PreferredFamily',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\PreferredFamily',
                ),
                'preferredsubfamily' => array(
                    'namespace' => 'Font',
                    'tagname' => 'PreferredSubfamily',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\PreferredSubfamily',
                ),
                'compatiblefontname' => array(
                    'namespace' => 'Font',
                    'tagname' => 'CompatibleFontName',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\CompatibleFontName',
                ),
                'sampletext' => array(
                    'namespace' => 'Font',
                    'tagname' => 'SampleText',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\SampleText',
                ),
                'wwsfamilyname' => array(
                    'namespace' => 'Font',
                    'tagname' => 'WWSFamilyName',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\WWSFamilyName',
                ),
                'wwssubfamilyname' => array(
                    'namespace' => 'Font',
                    'tagname' => 'WWSSubfamilyName',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\WWSSubfamilyName',
                ),
                'pfmversion' => array(
                    'namespace' => 'Font',
                    'tagname' => 'PFMVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\PFMVersion',
                ),
                'fonttype' => array(
                    'namespace' => 'Font',
                    'tagname' => 'FontType',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\FontType',
                ),
                'pointsize' => array(
                    'namespace' => 'Font',
                    'tagname' => 'PointSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\PointSize',
                ),
                'yresolution' => array(
                    'namespace' => 'Font',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\YResolution',
                ),
                'xresolution' => array(
                    'namespace' => 'Font',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\XResolution',
                ),
                'ascent' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Ascent',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Ascent',
                ),
                'internalleading' => array(
                    'namespace' => 'Font',
                    'tagname' => 'InternalLeading',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\InternalLeading',
                ),
                'externalleading' => array(
                    'namespace' => 'Font',
                    'tagname' => 'ExternalLeading',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\ExternalLeading',
                ),
                'italic' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Italic',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Italic',
                ),
                'underline' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Underline',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Underline',
                ),
                'strikeout' => array(
                    'namespace' => 'Font',
                    'tagname' => 'Strikeout',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\Strikeout',
                ),
                'pixwidth' => array(
                    'namespace' => 'Font',
                    'tagname' => 'PixWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\PixWidth',
                ),
                'pixheight' => array(
                    'namespace' => 'Font',
                    'tagname' => 'PixHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\PixHeight',
                ),
                'pitchandfamily' => array(
                    'namespace' => 'Font',
                    'tagname' => 'PitchAndFamily',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\PitchAndFamily',
                ),
                'avgwidth' => array(
                    'namespace' => 'Font',
                    'tagname' => 'AvgWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\AvgWidth',
                ),
                'maxwidth' => array(
                    'namespace' => 'Font',
                    'tagname' => 'MaxWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\MaxWidth',
                ),
                'firstchar' => array(
                    'namespace' => 'Font',
                    'tagname' => 'FirstChar',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\FirstChar',
                ),
                'lastchar' => array(
                    'namespace' => 'Font',
                    'tagname' => 'LastChar',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\LastChar',
                ),
                'defaultchar' => array(
                    'namespace' => 'Font',
                    'tagname' => 'DefaultChar',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\DefaultChar',
                ),
                'breakchar' => array(
                    'namespace' => 'Font',
                    'tagname' => 'BreakChar',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\BreakChar',
                ),
                'widthbytes' => array(
                    'namespace' => 'Font',
                    'tagname' => 'WidthBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\WidthBytes',
                ),
                'fstype' => array(
                    'namespace' => 'Font',
                    'tagname' => 'FSType',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\FSType',
                ),
                'italicangle' => array(
                    'namespace' => 'Font',
                    'tagname' => 'ItalicAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\ItalicAngle',
                ),
                'underlineposition' => array(
                    'namespace' => 'Font',
                    'tagname' => 'UnderlinePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\UnderlinePosition',
                ),
                'underlinethickness' => array(
                    'namespace' => 'Font',
                    'tagname' => 'UnderlineThickness',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\UnderlineThickness',
                ),
                'isfixedpitch' => array(
                    'namespace' => 'Font',
                    'tagname' => 'IsFixedPitch',
                    'classname' => 'PHPExiftool\Driver\Tag\Font\IsFixedPitch',
                ),

            ),
            'fotostation' => array(
                'thumbnailimage' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\ThumbnailImage',
                ),
                'previewimage' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\PreviewImage',
                ),
                'originalimagewidth' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'OriginalImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\OriginalImageWidth',
                ),
                'originalimageheight' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'OriginalImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\OriginalImageHeight',
                ),
                'colorplanes' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'ColorPlanes',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\ColorPlanes',
                ),
                'xyresolution' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'XYResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\XYResolution',
                ),
                'rotation' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\Rotation',
                ),
                'cropleft' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'CropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\CropLeft',
                ),
                'croptop' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'CropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\CropTop',
                ),
                'cropright' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'CropRight',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\CropRight',
                ),
                'cropbottom' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'CropBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\CropBottom',
                ),
                'croprotation' => array(
                    'namespace' => 'FotoStation',
                    'tagname' => 'CropRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\FotoStation\CropRotation',
                ),

            ),
            'fujifilm' => array(
                'moviestreamname' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'MovieStreamName',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\MovieStreamName',
                ),
                'face1birthday' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face1Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face1Birthday',
                ),
                'face1category' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face1Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face1Category',
                ),
                'face1name' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face1Name',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face1Name',
                ),
                'face2birthday' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face2Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face2Birthday',
                ),
                'face2category' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face2Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face2Category',
                ),
                'face2name' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face2Name',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face2Name',
                ),
                'face3birthday' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face3Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face3Birthday',
                ),
                'face3category' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face3Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face3Category',
                ),
                'face3name' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face3Name',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face3Name',
                ),
                'face4birthday' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face4Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face4Birthday',
                ),
                'face4category' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face4Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face4Category',
                ),
                'face4name' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face4Name',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face4Name',
                ),
                'face5birthday' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face5Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face5Birthday',
                ),
                'face5category' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face5Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face5Category',
                ),
                'face5name' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face5Name',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face5Name',
                ),
                'face6birthday' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face6Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face6Birthday',
                ),
                'face6category' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face6Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face6Category',
                ),
                'face6name' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face6Name',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face6Name',
                ),
                'face7birthday' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face7Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face7Birthday',
                ),
                'face7category' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face7Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face7Category',
                ),
                'face7name' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face7Name',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face7Name',
                ),
                'face8birthday' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face8Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face8Birthday',
                ),
                'face8category' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face8Category',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face8Category',
                ),
                'face8name' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Face8Name',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Face8Name',
                ),
                'version' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Version',
                ),
                'internalserialnumber' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'InternalSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\InternalSerialNumber',
                ),
                'quality' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Quality',
                ),
                'sharpness' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Sharpness',
                ),
                'whitebalance' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\WhiteBalance',
                ),
                'saturation' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Saturation',
                ),
                'contrast' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Contrast',
                ),
                'colortemperature' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\ColorTemperature',
                ),
                'whitebalancefinetune' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'WhiteBalanceFineTune',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\WhiteBalanceFineTune',
                ),
                'noisereduction' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'NoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\NoiseReduction',
                ),
                'highisonoisereduction' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'HighISONoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\HighISONoiseReduction',
                ),
                'fujiflashmode' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FujiFlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FujiFlashMode',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FlashExposureComp',
                ),
                'macro' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Macro',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Macro',
                ),
                'focusmode' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FocusMode',
                ),
                'focuspixel' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FocusPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FocusPixel',
                ),
                'slowsync' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'SlowSync',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\SlowSync',
                ),
                'picturemode' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'PictureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\PictureMode',
                ),
                'exrauto' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'EXRAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\EXRAuto',
                ),
                'exrmode' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'EXRMode',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\EXRMode',
                ),
                'autobracketing' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'AutoBracketing',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\AutoBracketing',
                ),
                'sequencenumber' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'SequenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\SequenceNumber',
                ),
                'colormode' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\ColorMode',
                ),
                'blurwarning' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'BlurWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\BlurWarning',
                ),
                'focuswarning' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FocusWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FocusWarning',
                ),
                'exposurewarning' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'ExposureWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\ExposureWarning',
                ),
                'geimagesize' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'GEImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\GEImageSize',
                ),
                'dynamicrange' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'DynamicRange',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\DynamicRange',
                ),
                'filmmode' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FilmMode',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FilmMode',
                ),
                'dynamicrangesetting' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'DynamicRangeSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\DynamicRangeSetting',
                ),
                'developmentdynamicrange' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'DevelopmentDynamicRange',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\DevelopmentDynamicRange',
                ),
                'minfocallength' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'MinFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\MinFocalLength',
                ),
                'maxfocallength' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'MaxFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\MaxFocalLength',
                ),
                'maxapertureatminfocal' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'MaxApertureAtMinFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\MaxApertureAtMinFocal',
                ),
                'maxapertureatmaxfocal' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'MaxApertureAtMaxFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\MaxApertureAtMaxFocal',
                ),
                'autodynamicrange' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'AutoDynamicRange',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\AutoDynamicRange',
                ),
                'facesdetected' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FacesDetected',
                ),
                'facepositions' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FacePositions',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FacePositions',
                ),
                'filesource' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FileSource',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FileSource',
                ),
                'ordernumber' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'OrderNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\OrderNumber',
                ),
                'framenumber' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'FrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\FrameNumber',
                ),
                'parallax' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'Parallax',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\Parallax',
                ),
                'rawimagewidth' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'RawImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\RawImageWidth',
                ),
                'rawimageheight' => array(
                    'namespace' => 'FujiFilm',
                    'tagname' => 'RawImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiFilm\RawImageHeight',
                ),

            ),
            'fujiifd' => array(
                'rawimagefullwidth' => array(
                    'namespace' => 'FujiIFD',
                    'tagname' => 'RawImageFullWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiIFD\RawImageFullWidth',
                ),
                'rawimagefullheight' => array(
                    'namespace' => 'FujiIFD',
                    'tagname' => 'RawImageFullHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiIFD\RawImageFullHeight',
                ),
                'bitspersample' => array(
                    'namespace' => 'FujiIFD',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiIFD\BitsPerSample',
                ),
                'stripoffsets' => array(
                    'namespace' => 'FujiIFD',
                    'tagname' => 'StripOffsets',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiIFD\StripOffsets',
                ),
                'stripbytecounts' => array(
                    'namespace' => 'FujiIFD',
                    'tagname' => 'StripByteCounts',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiIFD\StripByteCounts',
                ),
                'wb_grblevels' => array(
                    'namespace' => 'FujiIFD',
                    'tagname' => 'WB_GRBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\FujiIFD\WBGRBLevels',
                ),

            ),
            'raf2' => array(
                'rawimagefullsize' => array(
                    'namespace' => 'RAF2',
                    'tagname' => 'RawImageFullSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RAF2\RawImageFullSize',
                ),

            ),
            'raf' => array(
                'rawimagesize' => array(
                    'namespace' => 'RAF',
                    'tagname' => 'RawImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RAF\RawImageSize',
                ),
                'fujilayout' => array(
                    'namespace' => 'RAF',
                    'tagname' => 'FujiLayout',
                    'classname' => 'PHPExiftool\Driver\Tag\RAF\FujiLayout',
                ),
                'wb_grgblevels' => array(
                    'namespace' => 'RAF',
                    'tagname' => 'WB_GRGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\RAF\WBGRGBLevels',
                ),

            ),
            'ge' => array(
                'macro' => array(
                    'namespace' => 'GE',
                    'tagname' => 'Macro',
                    'classname' => 'PHPExiftool\Driver\Tag\GE\Macro',
                ),
                'gemodel' => array(
                    'namespace' => 'GE',
                    'tagname' => 'GEModel',
                    'classname' => 'PHPExiftool\Driver\Tag\GE\GEModel',
                ),
                'gemake' => array(
                    'namespace' => 'GE',
                    'tagname' => 'GEMake',
                    'classname' => 'PHPExiftool\Driver\Tag\GE\GEMake',
                ),

            ),
            'gif' => array(
                'animationiterations' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'AnimationIterations',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\AnimationIterations',
                ),
                'comment' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\Comment',
                ),
                'duration' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\Duration',
                ),
                'framecount' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'FrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\FrameCount',
                ),
                'gifversion' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'GIFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\GIFVersion',
                ),
                'text' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'Text',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\Text',
                ),
                'imagewidth' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\ImageHeight',
                ),
                'hascolormap' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'HasColorMap',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\HasColorMap',
                ),
                'colorresolutiondepth' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'ColorResolutionDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\ColorResolutionDepth',
                ),
                'bitsperpixel' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'BitsPerPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\BitsPerPixel',
                ),
                'backgroundcolor' => array(
                    'namespace' => 'GIF',
                    'tagname' => 'BackgroundColor',
                    'classname' => 'PHPExiftool\Driver\Tag\GIF\BackgroundColor',
                ),

            ),
            'gimp' => array(
                'xcfversion' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'XCFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\XCFVersion',
                ),
                'imagewidth' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\ImageHeight',
                ),
                'colormode' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\ColorMode',
                ),
                'compression' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\Compression',
                ),
                'comment' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\Comment',
                ),
                'iccprofilename' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'ICCProfileName',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\ICCProfileName',
                ),
                'xresolution' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\XResolution',
                ),
                'yresolution' => array(
                    'namespace' => 'GIMP',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\GIMP\YResolution',
                ),

            ),
            'gps' => array(
                'gpsversionid' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSVersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSVersionID',
                ),
                'gpslatituderef' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSLatitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSLatitudeRef',
                ),
                'gpslatitude' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSLatitude',
                ),
                'gpslongituderef' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSLongitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSLongitudeRef',
                ),
                'gpslongitude' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSLongitude',
                ),
                'gpsaltituderef' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSAltitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSAltitudeRef',
                ),
                'gpsaltitude' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSAltitude',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSAltitude',
                ),
                'gpstimestamp' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSTimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSTimeStamp',
                ),
                'gpssatellites' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSSatellites',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSSatellites',
                ),
                'gpsstatus' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSStatus',
                ),
                'gpsmeasuremode' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSMeasureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSMeasureMode',
                ),
                'gpsdop' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDOP',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDOP',
                ),
                'gpsspeedref' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSSpeedRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSSpeedRef',
                ),
                'gpsspeed' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSSpeed',
                ),
                'gpstrackref' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSTrackRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSTrackRef',
                ),
                'gpstrack' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSTrack',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSTrack',
                ),
                'gpsimgdirectionref' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSImgDirectionRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSImgDirectionRef',
                ),
                'gpsimgdirection' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSImgDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSImgDirection',
                ),
                'gpsmapdatum' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSMapDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSMapDatum',
                ),
                'gpsdestlatituderef' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDestLatitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDestLatitudeRef',
                ),
                'gpsdestlatitude' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDestLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDestLatitude',
                ),
                'gpsdestlongituderef' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDestLongitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDestLongitudeRef',
                ),
                'gpsdestlongitude' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDestLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDestLongitude',
                ),
                'gpsdestbearingref' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDestBearingRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDestBearingRef',
                ),
                'gpsdestbearing' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDestBearing',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDestBearing',
                ),
                'gpsdestdistanceref' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDestDistanceRef',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDestDistanceRef',
                ),
                'gpsdestdistance' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDestDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDestDistance',
                ),
                'gpsprocessingmethod' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSProcessingMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSProcessingMethod',
                ),
                'gpsareainformation' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSAreaInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSAreaInformation',
                ),
                'gpsdatestamp' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDateStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDateStamp',
                ),
                'gpsdifferential' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSDifferential',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSDifferential',
                ),
                'gpshpositioningerror' => array(
                    'namespace' => 'GPS',
                    'tagname' => 'GPSHPositioningError',
                    'classname' => 'PHPExiftool\Driver\Tag\GPS\GPSHPositioningError',
                ),

            ),
            'geotiff' => array(
                'geotiffversion' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeoTiffVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeoTiffVersion',
                ),
                'gtmodeltype' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GTModelType',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GTModelType',
                ),
                'gtrastertype' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GTRasterType',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GTRasterType',
                ),
                'gtcitation' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GTCitation',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GTCitation',
                ),
                'geographictype' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeographicType',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeographicType',
                ),
                'geogcitation' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogCitation',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogCitation',
                ),
                'geoggeodeticdatum' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogGeodeticDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogGeodeticDatum',
                ),
                'geogprimemeridian' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogPrimeMeridian',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogPrimeMeridian',
                ),
                'geoglinearunits' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogLinearUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogLinearUnits',
                ),
                'geoglinearunitsize' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogLinearUnitSize',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogLinearUnitSize',
                ),
                'geogangularunits' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogAngularUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogAngularUnits',
                ),
                'geogangularunitsize' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogAngularUnitSize',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogAngularUnitSize',
                ),
                'geogellipsoid' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogEllipsoid',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogEllipsoid',
                ),
                'geogsemimajoraxis' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogSemiMajorAxis',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogSemiMajorAxis',
                ),
                'geogsemiminoraxis' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogSemiMinorAxis',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogSemiMinorAxis',
                ),
                'geoginvflattening' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogInvFlattening',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogInvFlattening',
                ),
                'geogazimuthunits' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogAzimuthUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogAzimuthUnits',
                ),
                'geogprimemeridianlong' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'GeogPrimeMeridianLong',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\GeogPrimeMeridianLong',
                ),
                'projectedcstype' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjectedCSType',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjectedCSType',
                ),
                'pcscitation' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'PCSCitation',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\PCSCitation',
                ),
                'projection' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'Projection',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\Projection',
                ),
                'projcoordtrans' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjCoordTrans',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjCoordTrans',
                ),
                'projlinearunits' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjLinearUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjLinearUnits',
                ),
                'projlinearunitsize' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjLinearUnitSize',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjLinearUnitSize',
                ),
                'projstdparallel1' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjStdParallel1',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjStdParallel1',
                ),
                'projstdparallel2' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjStdParallel2',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjStdParallel2',
                ),
                'projnatoriginlong' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjNatOriginLong',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjNatOriginLong',
                ),
                'projnatoriginlat' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjNatOriginLat',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjNatOriginLat',
                ),
                'projfalseeasting' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjFalseEasting',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjFalseEasting',
                ),
                'projfalsenorthing' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjFalseNorthing',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjFalseNorthing',
                ),
                'projfalseoriginlong' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjFalseOriginLong',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjFalseOriginLong',
                ),
                'projfalseoriginlat' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjFalseOriginLat',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjFalseOriginLat',
                ),
                'projfalseorigineasting' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjFalseOriginEasting',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjFalseOriginEasting',
                ),
                'projfalseoriginnorthing' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjFalseOriginNorthing',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjFalseOriginNorthing',
                ),
                'projcenterlong' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjCenterLong',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjCenterLong',
                ),
                'projcenterlat' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjCenterLat',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjCenterLat',
                ),
                'projcentereasting' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjCenterEasting',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjCenterEasting',
                ),
                'projcenternorthing' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjCenterNorthing',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjCenterNorthing',
                ),
                'projscaleatnatorigin' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjScaleAtNatOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjScaleAtNatOrigin',
                ),
                'projscaleatcenter' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjScaleAtCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjScaleAtCenter',
                ),
                'projazimuthangle' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjAzimuthAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjAzimuthAngle',
                ),
                'projstraightvertpolelong' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjStraightVertPoleLong',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjStraightVertPoleLong',
                ),
                'projrectifiedgridangle' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'ProjRectifiedGridAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\ProjRectifiedGridAngle',
                ),
                'verticalcstype' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'VerticalCSType',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\VerticalCSType',
                ),
                'verticalcitation' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'VerticalCitation',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\VerticalCitation',
                ),
                'verticaldatum' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'VerticalDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\VerticalDatum',
                ),
                'verticalunits' => array(
                    'namespace' => 'GeoTiff',
                    'tagname' => 'VerticalUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\GeoTiff\VerticalUnits',
                ),

            ),
            'h264' => array(
                'aperturesetting' => array(
                    'namespace' => 'H264',
                    'tagname' => 'ApertureSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\ApertureSetting',
                ),
                'gain' => array(
                    'namespace' => 'H264',
                    'tagname' => 'Gain',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\Gain',
                ),
                'exposureprogram' => array(
                    'namespace' => 'H264',
                    'tagname' => 'ExposureProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\ExposureProgram',
                ),
                'whitebalance' => array(
                    'namespace' => 'H264',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\WhiteBalance',
                ),
                'focus' => array(
                    'namespace' => 'H264',
                    'tagname' => 'Focus',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\Focus',
                ),
                'imagestabilization' => array(
                    'namespace' => 'H264',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\ImageStabilization',
                ),
                'captureframerate' => array(
                    'namespace' => 'H264',
                    'tagname' => 'CaptureFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\CaptureFrameRate',
                ),
                'videoframerate' => array(
                    'namespace' => 'H264',
                    'tagname' => 'VideoFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\VideoFrameRate',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'H264',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\DateTimeOriginal',
                ),
                'exposuretime' => array(
                    'namespace' => 'H264',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\ExposureTime',
                ),
                'fnumber' => array(
                    'namespace' => 'H264',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\FNumber',
                ),
                'brightnessvalue' => array(
                    'namespace' => 'H264',
                    'tagname' => 'BrightnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\BrightnessValue',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'H264',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\ExposureCompensation',
                ),
                'maxaperturevalue' => array(
                    'namespace' => 'H264',
                    'tagname' => 'MaxApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\MaxApertureValue',
                ),
                'flash' => array(
                    'namespace' => 'H264',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\Flash',
                ),
                'customrendered' => array(
                    'namespace' => 'H264',
                    'tagname' => 'CustomRendered',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\CustomRendered',
                ),
                'focallengthin35mmformat' => array(
                    'namespace' => 'H264',
                    'tagname' => 'FocalLengthIn35mmFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\FocalLengthIn35mmFormat',
                ),
                'scenecapturetype' => array(
                    'namespace' => 'H264',
                    'tagname' => 'SceneCaptureType',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\SceneCaptureType',
                ),
                'model' => array(
                    'namespace' => 'H264',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\Model',
                ),
                'imageheight' => array(
                    'namespace' => 'H264',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'H264',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\ImageWidth',
                ),
                'make' => array(
                    'namespace' => 'H264',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\Make',
                ),
                'recordingmode' => array(
                    'namespace' => 'H264',
                    'tagname' => 'RecordingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\H264\RecordingMode',
                ),

            ),
            'hp' => array(
                'serialnumber' => array(
                    'namespace' => 'HP',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\SerialNumber',
                ),
                'firmwareversion' => array(
                    'namespace' => 'HP',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\FirmwareVersion',
                ),
                'lensshading' => array(
                    'namespace' => 'HP',
                    'tagname' => 'LensShading',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\LensShading',
                ),
                'previewimage' => array(
                    'namespace' => 'HP',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\PreviewImage',
                ),
                'maxaperture' => array(
                    'namespace' => 'HP',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\MaxAperture',
                ),
                'exposuretime' => array(
                    'namespace' => 'HP',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\ExposureTime',
                ),
                'cameradatetime' => array(
                    'namespace' => 'HP',
                    'tagname' => 'CameraDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\CameraDateTime',
                ),
                'iso' => array(
                    'namespace' => 'HP',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\ISO',
                ),
                'fnumber' => array(
                    'namespace' => 'HP',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\HP\FNumber',
                ),

            ),
            'html' => array(
                'abstract' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Abstract',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Abstract0',
                ),
                'author' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Author',
                ),
                'classification' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Classification',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Classification',
                ),
                'contentlanguage' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'ContentLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\ContentLanguage',
                ),
                'copyright' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Copyright',
                ),
                'description' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Description',
                ),
                'distribution' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Distribution',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Distribution',
                ),
                'docclass' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'DocClass',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\DocClass',
                ),
                'docrights' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'DocRights',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\DocRights',
                ),
                'doctype' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'DocType',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\DocType',
                ),
                'formatter' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Formatter',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Formatter',
                ),
                'generator' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Generator',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Generator',
                ),
                'generatorversion' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'GeneratorVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\GeneratorVersion',
                ),
                'googlebot' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'GoogleBot',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\GoogleBot',
                ),
                'keywords' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Keywords',
                ),
                'nomssmarttags' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'NoMSSmartTags',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\NoMSSmartTags',
                ),
                'originator' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Originator',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Originator',
                ),
                'owner' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Owner',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Owner',
                ),
                'progid' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'ProgID',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\ProgID',
                ),
                'rating' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Rating',
                ),
                'refresh' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Refresh',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Refresh',
                ),
                'resourcetype' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'ResourceType',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\ResourceType',
                ),
                'revisitafter' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'RevisitAfter',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\RevisitAfter',
                ),
                'robots' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Robots',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Robots',
                ),
                'title' => array(
                    'namespace' => 'HTML',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\HTML\Title',
                ),

            ),
            'html-office' => array(
                'author' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Author',
                ),
                'category' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Category',
                ),
                'characters' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Characters',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Characters',
                ),
                'characterswithspaces' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'CharactersWithSpaces',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\CharactersWithSpaces',
                ),
                'company' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Company',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Company',
                ),
                'createdate' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\CreateDate',
                ),
                'description' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Description',
                ),
                'keywords' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Keywords',
                ),
                'lastauthor' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'LastAuthor',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\LastAuthor',
                ),
                'lastprinted' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'LastPrinted',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\LastPrinted',
                ),
                'modifydate' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\ModifyDate',
                ),
                'lines' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Lines',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Lines',
                ),
                'manager' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Manager',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Manager',
                ),
                'pages' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Pages',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Pages',
                ),
                'paragraphs' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Paragraphs',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Paragraphs',
                ),
                'revisionnumber' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'RevisionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\RevisionNumber',
                ),
                'subject' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Subject',
                ),
                'template' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Template',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Template',
                ),
                'totaledittime' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'TotalEditTime',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\TotalEditTime',
                ),
                'words' => array(
                    'namespace' => 'HTML-office',
                    'tagname' => 'Words',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLOffice\Words',
                ),

            ),
            'html-dc' => array(
                'contributor' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Contributor',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Contributor',
                ),
                'coverage' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Coverage',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Coverage',
                ),
                'creator' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Creator',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Creator',
                ),
                'date' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Date',
                ),
                'description' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Description',
                ),
                'format' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Format',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Format',
                ),
                'identifier' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Identifier',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Identifier',
                ),
                'language' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Language',
                ),
                'publisher' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Publisher',
                ),
                'relation' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Relation',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Relation',
                ),
                'rights' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Rights',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Rights',
                ),
                'source' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Source',
                ),
                'subject' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Subject',
                ),
                'title' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Title',
                ),
                'type' => array(
                    'namespace' => 'HTML-dc',
                    'tagname' => 'Type',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLDc\Type',
                ),

            ),
            'http-equiv' => array(
                'cachecontrol' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'CacheControl',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\CacheControl',
                ),
                'contentdisposition' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'ContentDisposition',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\ContentDisposition',
                ),
                'contentlanguage' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'ContentLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\ContentLanguage',
                ),
                'contentscripttype' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'ContentScriptType',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\ContentScriptType',
                ),
                'contentstyletype' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'ContentStyleType',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\ContentStyleType',
                ),
                'contenttype' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'ContentType',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\ContentType',
                ),
                'defaultstyle' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'DefaultStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\DefaultStyle',
                ),
                'expires' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'Expires',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\Expires',
                ),
                'extcache' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'ExtCache',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\ExtCache',
                ),
                'imagetoolbar' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'ImageToolbar',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\ImageToolbar',
                ),
                'lotus' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'Lotus',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\Lotus',
                ),
                'pageenter' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'PageEnter',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\PageEnter',
                ),
                'pageexit' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'PageExit',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\PageExit',
                ),
                'picslabel' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'PicsLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\PicsLabel',
                ),
                'pragma' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'Pragma',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\Pragma',
                ),
                'refresh' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'Refresh',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\Refresh',
                ),
                'replyto' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'ReplyTo',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\ReplyTo',
                ),
                'setcookie' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'SetCookie',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\SetCookie',
                ),
                'siteenter' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'SiteEnter',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\SiteEnter',
                ),
                'siteexit' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'SiteExit',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\SiteExit',
                ),
                'vary' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'Vary',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\Vary',
                ),
                'windowtarget' => array(
                    'namespace' => 'HTTP-equiv',
                    'tagname' => 'WindowTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\HTTPEquiv\WindowTarget',
                ),

            ),
            'html-ncc' => array(
                'characterset' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'CharacterSet',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\CharacterSet',
                ),
                'depth' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Depth',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Depth',
                ),
                'files' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Files',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Files',
                ),
                'footnotes' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Footnotes',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Footnotes',
                ),
                'generator' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Generator',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Generator',
                ),
                'kbytesize' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'KByteSize',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\KByteSize',
                ),
                'maxpagenormal' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'MaxPageNormal',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\MaxPageNormal',
                ),
                'multimediatype' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'MultimediaType',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\MultimediaType',
                ),
                'narrator' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Narrator',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Narrator',
                ),
                'pagefront' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'PageFront',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\PageFront',
                ),
                'pagenormal' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'PageNormal',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\PageNormal',
                ),
                'pagespecial' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'PageSpecial',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\PageSpecial',
                ),
                'prodnotes' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'ProdNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\ProdNotes',
                ),
                'produceddate' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'ProducedDate',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\ProducedDate',
                ),
                'producer' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Producer',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Producer',
                ),
                'revision' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Revision',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Revision',
                ),
                'revisiondate' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'RevisionDate',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\RevisionDate',
                ),
                'setinfo' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'SetInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\SetInfo',
                ),
                'sidebars' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Sidebars',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Sidebars',
                ),
                'sourcedate' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'SourceDate',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\SourceDate',
                ),
                'sourceedition' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'SourceEdition',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\SourceEdition',
                ),
                'sourcepublisher' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'SourcePublisher',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\SourcePublisher',
                ),
                'sourcerights' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'SourceRights',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\SourceRights',
                ),
                'sourcetitle' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'SourceTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\SourceTitle',
                ),
                'tocitems' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'TOCItems',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\TOCItems',
                ),
                'duration' => array(
                    'namespace' => 'HTML-ncc',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLNcc\Duration',
                ),

            ),
            'html-prod' => array(
                'recengineer' => array(
                    'namespace' => 'HTML-prod',
                    'tagname' => 'RecEngineer',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLProd\RecEngineer',
                ),
                'reclocation' => array(
                    'namespace' => 'HTML-prod',
                    'tagname' => 'RecLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLProd\RecLocation',
                ),

            ),
            'html-vw96' => array(
                'objecttype' => array(
                    'namespace' => 'HTML-vw96',
                    'tagname' => 'ObjectType',
                    'classname' => 'PHPExiftool\Driver\Tag\HTMLVw96\ObjectType',
                ),

            ),
            'icc-chrm' => array(
                'chromaticitychannels' => array(
                    'namespace' => 'ICC-chrm',
                    'tagname' => 'ChromaticityChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannels',
                ),
                'chromaticitycolorant' => array(
                    'namespace' => 'ICC-chrm',
                    'tagname' => 'ChromaticityColorant',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCChrm\ChromaticityColorant',
                ),
                'chromaticitychannel1' => array(
                    'namespace' => 'ICC-chrm',
                    'tagname' => 'ChromaticityChannel1',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannel1',
                ),
                'chromaticitychannel2' => array(
                    'namespace' => 'ICC-chrm',
                    'tagname' => 'ChromaticityChannel2',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannel2',
                ),
                'chromaticitychannel3' => array(
                    'namespace' => 'ICC-chrm',
                    'tagname' => 'ChromaticityChannel3',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannel3',
                ),
                'chromaticitychannel4' => array(
                    'namespace' => 'ICC-chrm',
                    'tagname' => 'ChromaticityChannel4',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCChrm\ChromaticityChannel4',
                ),

            ),
            'icc-clrt' => array(
                'colorantcount' => array(
                    'namespace' => 'ICC-clrt',
                    'tagname' => 'ColorantCount',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCClrt\ColorantCount',
                ),
                'colorant1name' => array(
                    'namespace' => 'ICC-clrt',
                    'tagname' => 'Colorant1Name',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCClrt\Colorant1Name',
                ),
                'colorant1coordinates' => array(
                    'namespace' => 'ICC-clrt',
                    'tagname' => 'Colorant1Coordinates',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCClrt\Colorant1Coordinates',
                ),
                'colorant2name' => array(
                    'namespace' => 'ICC-clrt',
                    'tagname' => 'Colorant2Name',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCClrt\Colorant2Name',
                ),
                'colorant2coordinates' => array(
                    'namespace' => 'ICC-clrt',
                    'tagname' => 'Colorant2Coordinates',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCClrt\Colorant2Coordinates',
                ),
                'colorant3name' => array(
                    'namespace' => 'ICC-clrt',
                    'tagname' => 'Colorant3Name',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCClrt\Colorant3Name',
                ),
                'colorant3coordinates' => array(
                    'namespace' => 'ICC-clrt',
                    'tagname' => 'Colorant3Coordinates',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCClrt\Colorant3Coordinates',
                ),

            ),
            'icc-header' => array(
                'profilecmmtype' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ProfileCMMType',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ProfileCMMType',
                ),
                'profileversion' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ProfileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ProfileVersion',
                ),
                'profileclass' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ProfileClass',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ProfileClass',
                ),
                'colorspacedata' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ColorSpaceData',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ColorSpaceData',
                ),
                'profileconnectionspace' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ProfileConnectionSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ProfileConnectionSpace',
                ),
                'profiledatetime' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ProfileDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ProfileDateTime',
                ),
                'profilefilesignature' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ProfileFileSignature',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ProfileFileSignature',
                ),
                'primaryplatform' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'PrimaryPlatform',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\PrimaryPlatform',
                ),
                'cmmflags' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'CMMFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\CMMFlags',
                ),
                'devicemanufacturer' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'DeviceManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\DeviceManufacturer',
                ),
                'devicemodel' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'DeviceModel',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\DeviceModel',
                ),
                'deviceattributes' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'DeviceAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\DeviceAttributes',
                ),
                'renderingintent' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'RenderingIntent',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\RenderingIntent',
                ),
                'connectionspaceilluminant' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ConnectionSpaceIlluminant',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ConnectionSpaceIlluminant',
                ),
                'profilecreator' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ProfileCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ProfileCreator',
                ),
                'profileid' => array(
                    'namespace' => 'ICC-header',
                    'tagname' => 'ProfileID',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCHeader\ProfileID',
                ),

            ),
            'icc-meas' => array(
                'measurementobserver' => array(
                    'namespace' => 'ICC-meas',
                    'tagname' => 'MeasurementObserver',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCMeas\MeasurementObserver',
                ),
                'measurementbacking' => array(
                    'namespace' => 'ICC-meas',
                    'tagname' => 'MeasurementBacking',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCMeas\MeasurementBacking',
                ),
                'measurementgeometry' => array(
                    'namespace' => 'ICC-meas',
                    'tagname' => 'MeasurementGeometry',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCMeas\MeasurementGeometry',
                ),
                'measurementflare' => array(
                    'namespace' => 'ICC-meas',
                    'tagname' => 'MeasurementFlare',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCMeas\MeasurementFlare',
                ),
                'measurementilluminant' => array(
                    'namespace' => 'ICC-meas',
                    'tagname' => 'MeasurementIlluminant',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCMeas\MeasurementIlluminant',
                ),

            ),
            'icc-meta' => array(
                'manufacturername' => array(
                    'namespace' => 'ICC-meta',
                    'tagname' => 'ManufacturerName',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCMeta\ManufacturerName',
                ),
                'mediacolor' => array(
                    'namespace' => 'ICC-meta',
                    'tagname' => 'MediaColor',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCMeta\MediaColor',
                ),
                'mediaweight' => array(
                    'namespace' => 'ICC-meta',
                    'tagname' => 'MediaWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCMeta\MediaWeight',
                ),

            ),
            'icc-view' => array(
                'viewingcondilluminant' => array(
                    'namespace' => 'ICC-view',
                    'tagname' => 'ViewingCondIlluminant',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCView\ViewingCondIlluminant',
                ),
                'viewingcondsurround' => array(
                    'namespace' => 'ICC-view',
                    'tagname' => 'ViewingCondSurround',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCView\ViewingCondSurround',
                ),
                'viewingcondilluminanttype' => array(
                    'namespace' => 'ICC-view',
                    'tagname' => 'ViewingCondIlluminantType',
                    'classname' => 'PHPExiftool\Driver\Tag\ICCView\ViewingCondIlluminantType',
                ),

            ),
            'id3' => array(
                'averagelevel' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'AverageLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\AverageLevel',
                ),
                'peakvalue' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'PeakValue',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\PeakValue',
                ),
                'wm_mediaclassprimaryid' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'WM_MediaClassPrimaryID',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\WMMediaClassPrimaryID',
                ),
                'wm_mediaclasssecondaryid' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'WM_MediaClassSecondaryID',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\WMMediaClassSecondaryID',
                ),
                'wm_provider' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'WM_Provider',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\WMProvider',
                ),
                'wm_collectiongroupid' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'WM_CollectionGroupID',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\WMCollectionGroupID',
                ),
                'wm_collectionid' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'WM_CollectionID',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\WMCollectionID',
                ),
                'wm_contentid' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'WM_ContentID',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\WMContentID',
                ),
                'synchronizedlyricsdescription' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'SynchronizedLyricsDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\SynchronizedLyricsDescription',
                ),
                'synchronizedlyricstext' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'SynchronizedLyricsText',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\SynchronizedLyricsText',
                ),
                'synchronizedlyricstype' => array(
                    'namespace' => 'ID3',
                    'tagname' => 'SynchronizedLyricsType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3\SynchronizedLyricsType',
                ),

            ),
            'id3v1' => array(
                'title' => array(
                    'namespace' => 'ID3v1',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1\Title',
                ),
                'artist' => array(
                    'namespace' => 'ID3v1',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1\Artist',
                ),
                'album' => array(
                    'namespace' => 'ID3v1',
                    'tagname' => 'Album',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1\Album',
                ),
                'year' => array(
                    'namespace' => 'ID3v1',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1\Year',
                ),
                'comment' => array(
                    'namespace' => 'ID3v1',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1\Comment',
                ),
                'track' => array(
                    'namespace' => 'ID3v1',
                    'tagname' => 'Track',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1\Track',
                ),
                'genre' => array(
                    'namespace' => 'ID3v1',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1\Genre',
                ),

            ),
            'id3v1_enh' => array(
                'title2' => array(
                    'namespace' => 'ID3v1_Enh',
                    'tagname' => 'Title2',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1Enh\Title2',
                ),
                'artist2' => array(
                    'namespace' => 'ID3v1_Enh',
                    'tagname' => 'Artist2',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1Enh\Artist2',
                ),
                'album2' => array(
                    'namespace' => 'ID3v1_Enh',
                    'tagname' => 'Album2',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1Enh\Album2',
                ),
                'speed' => array(
                    'namespace' => 'ID3v1_Enh',
                    'tagname' => 'Speed',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1Enh\Speed',
                ),
                'genre' => array(
                    'namespace' => 'ID3v1_Enh',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1Enh\Genre',
                ),
                'starttime' => array(
                    'namespace' => 'ID3v1_Enh',
                    'tagname' => 'StartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1Enh\StartTime',
                ),
                'endtime' => array(
                    'namespace' => 'ID3v1_Enh',
                    'tagname' => 'EndTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v1Enh\EndTime',
                ),

            ),
            'id3v2_2' => array(
                'playcounter' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'PlayCounter',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\PlayCounter',
                ),
                'comment' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Comment',
                ),
                'involvedpeople' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'InvolvedPeople',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\InvolvedPeople',
                ),
                'itunesu' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'iTunesU',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\ITunesU',
                ),
                'podcast' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Podcast',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Podcast',
                ),
                'picture' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Picture',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Picture',
                ),
                'pictureformat' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'PictureFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\PictureFormat',
                ),
                'picturetype' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'PictureType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\PictureType',
                ),
                'picturedescription' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'PictureDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\PictureDescription',
                ),
                'popularimeter' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Popularimeter',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Popularimeter',
                ),
                'relativevolumeadjustment' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'RelativeVolumeAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\RelativeVolumeAdjustment',
                ),
                'album' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Album',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Album',
                ),
                'beatsperminute' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'BeatsPerMinute',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\BeatsPerMinute',
                ),
                'composer' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Composer',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Composer',
                ),
                'genre' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Genre',
                ),
                'compilation' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Compilation',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Compilation',
                ),
                'copyright' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Copyright',
                ),
                'date' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Date',
                ),
                'playlistdelay' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'PlaylistDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\PlaylistDelay',
                ),
                'encodedby' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'EncodedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\EncodedBy',
                ),
                'filetype' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'FileType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\FileType',
                ),
                'time' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Time',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Time',
                ),
                'initialkey' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'InitialKey',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\InitialKey',
                ),
                'language' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Language',
                ),
                'length' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Length',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Length',
                ),
                'media' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Media',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Media',
                ),
                'originalartist' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'OriginalArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\OriginalArtist',
                ),
                'originalfilename' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'OriginalFilename',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\OriginalFilename',
                ),
                'originallyricist' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'OriginalLyricist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\OriginalLyricist',
                ),
                'originalreleaseyear' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'OriginalReleaseYear',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\OriginalReleaseYear',
                ),
                'originalalbum' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'OriginalAlbum',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\OriginalAlbum',
                ),
                'artist' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Artist',
                ),
                'band' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Band',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Band',
                ),
                'conductor' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Conductor',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Conductor',
                ),
                'interpretedby' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'InterpretedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\InterpretedBy',
                ),
                'partofset' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'PartOfSet',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\PartOfSet',
                ),
                'publisher' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Publisher',
                ),
                'isrc' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'ISRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\ISRC',
                ),
                'recordingdates' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'RecordingDates',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\RecordingDates',
                ),
                'track' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Track',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Track',
                ),
                'albumartistsortorder' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'AlbumArtistSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\AlbumArtistSortOrder',
                ),
                'albumsortorder' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'AlbumSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\AlbumSortOrder',
                ),
                'composersortorder' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'ComposerSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\ComposerSortOrder',
                ),
                'size' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Size',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Size',
                ),
                'performersortorder' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'PerformerSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\PerformerSortOrder',
                ),
                'encodersettings' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'EncoderSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\EncoderSettings',
                ),
                'titlesortorder' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'TitleSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\TitleSortOrder',
                ),
                'grouping' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Grouping',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Grouping',
                ),
                'title' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Title',
                ),
                'subtitle' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Subtitle',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Subtitle',
                ),
                'lyricist' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Lyricist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Lyricist',
                ),
                'userdefinedtext' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'UserDefinedText',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\UserDefinedText',
                ),
                'year' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Year',
                ),
                'lyrics' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'Lyrics',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\Lyrics',
                ),
                'fileurl' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'FileURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\FileURL',
                ),
                'artisturl' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'ArtistURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\ArtistURL',
                ),
                'sourceurl' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'SourceURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\SourceURL',
                ),
                'commercialurl' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'CommercialURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\CommercialURL',
                ),
                'copyrighturl' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'CopyrightURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\CopyrightURL',
                ),
                'publisherurl' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'PublisherURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\PublisherURL',
                ),
                'userdefinedurl' => array(
                    'namespace' => 'ID3v2_2',
                    'tagname' => 'UserDefinedURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v22\UserDefinedURL',
                ),

            ),
            'id3v2_3' => array(
                'picture' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Picture',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Picture',
                ),
                'picturemimetype' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'PictureMimeType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\PictureMimeType',
                ),
                'picturetype' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'PictureType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\PictureType',
                ),
                'picturedescription' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'PictureDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\PictureDescription',
                ),
                'comment' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Comment',
                ),
                'involvedpeople' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'InvolvedPeople',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\InvolvedPeople',
                ),
                'musiccdidentifier' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'MusicCDIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\MusicCDIdentifier',
                ),
                'ownership' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Ownership',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Ownership',
                ),
                'playcounter' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'PlayCounter',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\PlayCounter',
                ),
                'popularimeter' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Popularimeter',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Popularimeter',
                ),
                'album' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Album',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Album',
                ),
                'beatsperminute' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'BeatsPerMinute',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\BeatsPerMinute',
                ),
                'compilation' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Compilation',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Compilation',
                ),
                'composer' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Composer',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Composer',
                ),
                'genre' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Genre',
                ),
                'copyright' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Copyright',
                ),
                'date' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Date',
                ),
                'playlistdelay' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'PlaylistDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\PlaylistDelay',
                ),
                'encodedby' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'EncodedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\EncodedBy',
                ),
                'lyricist' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Lyricist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Lyricist',
                ),
                'filetype' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'FileType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\FileType',
                ),
                'time' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Time',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Time',
                ),
                'grouping' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Grouping',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Grouping',
                ),
                'title' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Title',
                ),
                'subtitle' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Subtitle',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Subtitle',
                ),
                'initialkey' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'InitialKey',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\InitialKey',
                ),
                'language' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Language',
                ),
                'length' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Length',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Length',
                ),
                'media' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Media',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Media',
                ),
                'originalalbum' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'OriginalAlbum',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\OriginalAlbum',
                ),
                'originalfilename' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'OriginalFilename',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\OriginalFilename',
                ),
                'originallyricist' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'OriginalLyricist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\OriginalLyricist',
                ),
                'originalartist' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'OriginalArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\OriginalArtist',
                ),
                'originalreleaseyear' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'OriginalReleaseYear',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\OriginalReleaseYear',
                ),
                'fileowner' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'FileOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\FileOwner',
                ),
                'artist' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Artist',
                ),
                'band' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Band',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Band',
                ),
                'conductor' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Conductor',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Conductor',
                ),
                'interpretedby' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'InterpretedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\InterpretedBy',
                ),
                'partofset' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'PartOfSet',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\PartOfSet',
                ),
                'publisher' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Publisher',
                ),
                'track' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Track',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Track',
                ),
                'recordingdates' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'RecordingDates',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\RecordingDates',
                ),
                'internetradiostationname' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'InternetRadioStationName',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\InternetRadioStationName',
                ),
                'internetradiostationowner' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'InternetRadioStationOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\InternetRadioStationOwner',
                ),
                'size' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Size',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Size',
                ),
                'isrc' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'ISRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\ISRC',
                ),
                'encodersettings' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'EncoderSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\EncoderSettings',
                ),
                'userdefinedtext' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'UserDefinedText',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\UserDefinedText',
                ),
                'year' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Year',
                ),
                'termsofuse' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'TermsOfUse',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\TermsOfUse',
                ),
                'lyrics' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'Lyrics',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\Lyrics',
                ),
                'commercialurl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'CommercialURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\CommercialURL',
                ),
                'copyrighturl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'CopyrightURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\CopyrightURL',
                ),
                'fileurl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'FileURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\FileURL',
                ),
                'artisturl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'ArtistURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\ArtistURL',
                ),
                'sourceurl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'SourceURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\SourceURL',
                ),
                'internetradiostationurl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'InternetRadioStationURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\InternetRadioStationURL',
                ),
                'paymenturl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'PaymentURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\PaymentURL',
                ),
                'publisherurl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'PublisherURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\PublisherURL',
                ),
                'userdefinedurl' => array(
                    'namespace' => 'ID3v2_3',
                    'tagname' => 'UserDefinedURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v23\UserDefinedURL',
                ),

            ),
            'id3v2_4' => array(
                'picture' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Picture',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Picture',
                ),
                'picturemimetype' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PictureMimeType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PictureMimeType',
                ),
                'picturetype' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PictureType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PictureType',
                ),
                'picturedescription' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PictureDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PictureDescription',
                ),
                'comment' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Comment',
                ),
                'itunesu' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'iTunesU',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\ITunesU',
                ),
                'musiccdidentifier' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'MusicCDIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\MusicCDIdentifier',
                ),
                'ownership' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Ownership',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Ownership',
                ),
                'playcounter' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PlayCounter',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PlayCounter',
                ),
                'podcast' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Podcast',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Podcast',
                ),
                'popularimeter' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Popularimeter',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Popularimeter',
                ),
                'relativevolumeadjustment' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'RelativeVolumeAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\RelativeVolumeAdjustment',
                ),
                'album' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Album',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Album',
                ),
                'beatsperminute' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'BeatsPerMinute',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\BeatsPerMinute',
                ),
                'compilation' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Compilation',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Compilation',
                ),
                'composer' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Composer',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Composer',
                ),
                'genre' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Genre',
                ),
                'copyright' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Copyright',
                ),
                'encodingtime' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'EncodingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\EncodingTime',
                ),
                'playlistdelay' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PlaylistDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PlaylistDelay',
                ),
                'originalreleasetime' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'OriginalReleaseTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\OriginalReleaseTime',
                ),
                'recordingtime' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'RecordingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\RecordingTime',
                ),
                'releasetime' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'ReleaseTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\ReleaseTime',
                ),
                'taggingtime' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'TaggingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\TaggingTime',
                ),
                'encodedby' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'EncodedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\EncodedBy',
                ),
                'lyricist' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Lyricist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Lyricist',
                ),
                'filetype' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'FileType',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\FileType',
                ),
                'involvedpeople' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'InvolvedPeople',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\InvolvedPeople',
                ),
                'grouping' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Grouping',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Grouping',
                ),
                'title' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Title',
                ),
                'subtitle' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Subtitle',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Subtitle',
                ),
                'initialkey' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'InitialKey',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\InitialKey',
                ),
                'language' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Language',
                ),
                'length' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Length',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Length',
                ),
                'musiciancredits' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'MusicianCredits',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\MusicianCredits',
                ),
                'media' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Media',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Media',
                ),
                'mood' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Mood',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Mood',
                ),
                'originalalbum' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'OriginalAlbum',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\OriginalAlbum',
                ),
                'originalfilename' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'OriginalFilename',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\OriginalFilename',
                ),
                'originallyricist' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'OriginalLyricist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\OriginalLyricist',
                ),
                'originalartist' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'OriginalArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\OriginalArtist',
                ),
                'fileowner' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'FileOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\FileOwner',
                ),
                'artist' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Artist',
                ),
                'band' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Band',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Band',
                ),
                'conductor' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Conductor',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Conductor',
                ),
                'interpretedby' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'InterpretedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\InterpretedBy',
                ),
                'partofset' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PartOfSet',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PartOfSet',
                ),
                'producednotice' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'ProducedNotice',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\ProducedNotice',
                ),
                'publisher' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Publisher',
                ),
                'track' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Track',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Track',
                ),
                'internetradiostationname' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'InternetRadioStationName',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\InternetRadioStationName',
                ),
                'internetradiostationowner' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'InternetRadioStationOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\InternetRadioStationOwner',
                ),
                'albumartistsortorder' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'AlbumArtistSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\AlbumArtistSortOrder',
                ),
                'albumsortorder' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'AlbumSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\AlbumSortOrder',
                ),
                'composersortorder' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'ComposerSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\ComposerSortOrder',
                ),
                'performersortorder' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PerformerSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PerformerSortOrder',
                ),
                'titlesortorder' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'TitleSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\TitleSortOrder',
                ),
                'isrc' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'ISRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\ISRC',
                ),
                'encodersettings' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'EncoderSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\EncoderSettings',
                ),
                'setsubtitle' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'SetSubtitle',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\SetSubtitle',
                ),
                'userdefinedtext' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'UserDefinedText',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\UserDefinedText',
                ),
                'termsofuse' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'TermsOfUse',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\TermsOfUse',
                ),
                'lyrics' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'Lyrics',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\Lyrics',
                ),
                'commercialurl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'CommercialURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\CommercialURL',
                ),
                'copyrighturl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'CopyrightURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\CopyrightURL',
                ),
                'fileurl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'FileURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\FileURL',
                ),
                'artisturl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'ArtistURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\ArtistURL',
                ),
                'sourceurl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'SourceURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\SourceURL',
                ),
                'internetradiostationurl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'InternetRadioStationURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\InternetRadioStationURL',
                ),
                'paymenturl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PaymentURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PaymentURL',
                ),
                'publisherurl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'PublisherURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\PublisherURL',
                ),
                'userdefinedurl' => array(
                    'namespace' => 'ID3v2_4',
                    'tagname' => 'UserDefinedURL',
                    'classname' => 'PHPExiftool\Driver\Tag\ID3v24\UserDefinedURL',
                ),

            ),
            'itc' => array(
                'datatype' => array(
                    'namespace' => 'ITC',
                    'tagname' => 'DataType',
                    'classname' => 'PHPExiftool\Driver\Tag\ITC\DataType',
                ),
                'libraryid' => array(
                    'namespace' => 'ITC',
                    'tagname' => 'LibraryID',
                    'classname' => 'PHPExiftool\Driver\Tag\ITC\LibraryID',
                ),
                'trackid' => array(
                    'namespace' => 'ITC',
                    'tagname' => 'TrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\ITC\TrackID',
                ),
                'datalocation' => array(
                    'namespace' => 'ITC',
                    'tagname' => 'DataLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\ITC\DataLocation',
                ),
                'imagetype' => array(
                    'namespace' => 'ITC',
                    'tagname' => 'ImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\ITC\ImageType',
                ),
                'imagewidth' => array(
                    'namespace' => 'ITC',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\ITC\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'ITC',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\ITC\ImageHeight',
                ),
                'imagedata' => array(
                    'namespace' => 'ITC',
                    'tagname' => 'ImageData',
                    'classname' => 'PHPExiftool\Driver\Tag\ITC\ImageData',
                ),

            ),
            'jfif' => array(
                'thumbnailimage' => array(
                    'namespace' => 'JFIF',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\JFIF\ThumbnailImage',
                ),
                'jfifversion' => array(
                    'namespace' => 'JFIF',
                    'tagname' => 'JFIFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\JFIF\JFIFVersion',
                ),
                'resolutionunit' => array(
                    'namespace' => 'JFIF',
                    'tagname' => 'ResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\JFIF\ResolutionUnit',
                ),
                'xresolution' => array(
                    'namespace' => 'JFIF',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\JFIF\XResolution',
                ),
                'yresolution' => array(
                    'namespace' => 'JFIF',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\JFIF\YResolution',
                ),

            ),
            'avi1' => array(
                'interleavedfield' => array(
                    'namespace' => 'AVI1',
                    'tagname' => 'InterleavedField',
                    'classname' => 'PHPExiftool\Driver\Tag\AVI1\InterleavedField',
                ),

            ),
            'adobecm' => array(
                'adobecmtype' => array(
                    'namespace' => 'AdobeCM',
                    'tagname' => 'AdobeCMType',
                    'classname' => 'PHPExiftool\Driver\Tag\AdobeCM\AdobeCMType',
                ),

            ),
            'eppim' => array(
                'printim' => array(
                    'namespace' => 'EPPIM',
                    'tagname' => 'PrintIM',
                    'classname' => 'PHPExiftool\Driver\Tag\EPPIM\PrintIM',
                ),

            ),
            'graphconv' => array(
                'quality' => array(
                    'namespace' => 'GraphConv',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\GraphConv\Quality',
                ),

            ),
            'jpeg' => array(
                'previewimage' => array(
                    'namespace' => 'JPEG',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\JPEG\PreviewImage',
                ),
                'comment' => array(
                    'namespace' => 'JPEG',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\JPEG\Comment',
                ),
                'adobe' => array(
                    'namespace' => 'JPEG',
                    'tagname' => 'Adobe',
                    'classname' => 'PHPExiftool\Driver\Tag\JPEG\Adobe',
                ),
                'definequantizationtable' => array(
                    'namespace' => 'JPEG',
                    'tagname' => 'DefineQuantizationTable',
                    'classname' => 'PHPExiftool\Driver\Tag\JPEG\DefineQuantizationTable',
                ),

            ),
            'nitf' => array(
                'nitfversion' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'NITFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\NITFVersion',
                ),
                'imageformat' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'ImageFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\ImageFormat',
                ),
                'blocksperrow' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'BlocksPerRow',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\BlocksPerRow',
                ),
                'blockspercolumn' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'BlocksPerColumn',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\BlocksPerColumn',
                ),
                'imagecolor' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'ImageColor',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\ImageColor',
                ),
                'bitdepth' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\BitDepth',
                ),
                'imageclass' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'ImageClass',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\ImageClass',
                ),
                'jpegprocess' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'JPEGProcess',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\JPEGProcess',
                ),
                'quality' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\Quality',
                ),
                'streamcolor' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'StreamColor',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\StreamColor',
                ),
                'streambitdepth' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'StreamBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\StreamBitDepth',
                ),
                'flags' => array(
                    'namespace' => 'NITF',
                    'tagname' => 'Flags',
                    'classname' => 'PHPExiftool\Driver\Tag\NITF\Flags',
                ),

            ),
            'ocad' => array(
                'ocadrevision' => array(
                    'namespace' => 'Ocad',
                    'tagname' => 'OcadRevision',
                    'classname' => 'PHPExiftool\Driver\Tag\Ocad\OcadRevision',
                ),

            ),
            'spiff' => array(
                'spiffversion' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'SPIFFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\SPIFFVersion',
                ),
                'profileid' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'ProfileID',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\ProfileID',
                ),
                'colorcomponents' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'ColorComponents',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\ColorComponents',
                ),
                'imageheight' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\ImageWidth',
                ),
                'colorspace' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\ColorSpace',
                ),
                'bitspersample' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\BitsPerSample',
                ),
                'compression' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\Compression',
                ),
                'resolutionunit' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'ResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\ResolutionUnit',
                ),
                'yresolution' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\YResolution',
                ),
                'xresolution' => array(
                    'namespace' => 'SPIFF',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\SPIFF\XResolution',
                ),

            ),
            'scalado' => array(
                'previewimageheight' => array(
                    'namespace' => 'Scalado',
                    'tagname' => 'PreviewImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Scalado\PreviewImageHeight',
                ),
                'previewquality' => array(
                    'namespace' => 'Scalado',
                    'tagname' => 'PreviewQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Scalado\PreviewQuality',
                ),
                'datalength' => array(
                    'namespace' => 'Scalado',
                    'tagname' => 'DataLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Scalado\DataLength',
                ),
                'previewimagewidth' => array(
                    'namespace' => 'Scalado',
                    'tagname' => 'PreviewImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Scalado\PreviewImageWidth',
                ),

            ),
            'jvc' => array(
                'cpuversions' => array(
                    'namespace' => 'JVC',
                    'tagname' => 'CPUVersions',
                    'classname' => 'PHPExiftool\Driver\Tag\JVC\CPUVersions',
                ),
                'quality' => array(
                    'namespace' => 'JVC',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\JVC\Quality',
                ),
                'makernoteversion' => array(
                    'namespace' => 'JVC',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\JVC\MakerNoteVersion',
                ),

            ),
            'jpeg2000' => array(
                'captureyresolution' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'CaptureYResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\CaptureYResolution',
                ),
                'capturexresolution' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'CaptureXResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\CaptureXResolution',
                ),
                'captureyresolutionunit' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'CaptureYResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\CaptureYResolutionUnit',
                ),
                'capturexresolutionunit' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'CaptureXResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\CaptureXResolutionUnit',
                ),
                'colorspecmethod' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ColorSpecMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ColorSpecMethod',
                ),
                'colorspecprecedence' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ColorSpecPrecedence',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ColorSpecPrecedence',
                ),
                'colorspecapproximation' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ColorSpecApproximation',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ColorSpecApproximation',
                ),
                'colorspace' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ColorSpace',
                ),
                'colorspecdata' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ColorSpecData',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ColorSpecData',
                ),
                'displayyresolution' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'DisplayYResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\DisplayYResolution',
                ),
                'displayxresolution' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'DisplayXResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\DisplayXResolution',
                ),
                'displayyresolutionunit' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'DisplayYResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\DisplayYResolutionUnit',
                ),
                'displayxresolutionunit' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'DisplayXResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\DisplayXResolutionUnit',
                ),
                'majorbrand' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'MajorBrand',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\MajorBrand',
                ),
                'minorversion' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'MinorVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\MinorVersion',
                ),
                'compatiblebrands' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'CompatibleBrands',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\CompatibleBrands',
                ),
                'imageheight' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ImageWidth',
                ),
                'numberofcomponents' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'NumberOfComponents',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\NumberOfComponents',
                ),
                'bitspercomponent' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'BitsPerComponent',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\BitsPerComponent',
                ),
                'compression' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\Compression',
                ),
                'association' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Association',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\Association',
                ),
                'binaryfilter' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'BinaryFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\BinaryFilter',
                ),
                'componentdefinition' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ComponentDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ComponentDefinition',
                ),
                'colorgroup' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ColorGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ColorGroup',
                ),
                'digitalsignature' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'DigitalSignature',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\DigitalSignature',
                ),
                'componentmapping' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ComponentMapping',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ComponentMapping',
                ),
                'composition' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Composition',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\Composition',
                ),
                'compositionoptions' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'CompositionOptions',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\CompositionOptions',
                ),
                'cross-reference' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Cross-Reference',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\CrossReference',
                ),
                'codestreamregistration' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'CodestreamRegistration',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\CodestreamRegistration',
                ),
                'desiredreproductions' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'DesiredReproductions',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\DesiredReproductions',
                ),
                'datareference' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'DataReference',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\DataReference',
                ),
                'fragmentlist' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'FragmentList',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\FragmentList',
                ),
                'free' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Free',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\Free',
                ),
                'fragmenttable' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'FragmentTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\FragmentTable',
                ),
                'graphicstechnologystandardoutput' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'GraphicsTechnologyStandardOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\GraphicsTechnologyStandardOutput',
                ),
                'instructionset' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'InstructionSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\InstructionSet',
                ),
                'jp2signature' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'JP2Signature',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\JP2Signature',
                ),
                'contiguouscodestream' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ContiguousCodestream',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ContiguousCodestream',
                ),
                'label' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Label',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\Label',
                ),
                'mediadata' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'MediaData',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\MediaData',
                ),
                'mpeg7binary' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'MPEG7Binary',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\MPEG7Binary',
                ),
                'numberlist' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'NumberList',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\NumberList',
                ),
                'opacity' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Opacity',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\Opacity',
                ),
                'palette' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Palette',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\Palette',
                ),
                'profile' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'Profile',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\Profile',
                ),
                'roidescription' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ROIDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ROIDescription',
                ),
                'readerrequirements' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'ReaderRequirements',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\ReaderRequirements',
                ),
                'uuidlist' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'UUIDList',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\UUIDList',
                ),
                'url' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\URL',
                ),
                'uuid-unknown' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'UUID-Unknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\UUIDUnknown',
                ),
                'xml' => array(
                    'namespace' => 'Jpeg2000',
                    'tagname' => 'XML',
                    'classname' => 'PHPExiftool\Driver\Tag\Jpeg2000\XML',
                ),

            ),
            'kodakbordersifd' => array(
                'bordersversion' => array(
                    'namespace' => 'KodakBordersIFD',
                    'tagname' => 'BordersVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakBordersIFD\BordersVersion',
                ),
                'bordername' => array(
                    'namespace' => 'KodakBordersIFD',
                    'tagname' => 'BorderName',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakBordersIFD\BorderName',
                ),
                'borderid' => array(
                    'namespace' => 'KodakBordersIFD',
                    'tagname' => 'BorderID',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakBordersIFD\BorderID',
                ),
                'borderlocation' => array(
                    'namespace' => 'KodakBordersIFD',
                    'tagname' => 'BorderLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakBordersIFD\BorderLocation',
                ),
                'bordertype' => array(
                    'namespace' => 'KodakBordersIFD',
                    'tagname' => 'BorderType',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakBordersIFD\BorderType',
                ),
                'watermarktype' => array(
                    'namespace' => 'KodakBordersIFD',
                    'tagname' => 'WatermarkType',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakBordersIFD\WatermarkType',
                ),

            ),
            'kodak' => array(
                'sensorwidth' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SensorWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SensorWidth',
                ),
                'sensorheight' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SensorHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SensorHeight',
                ),
                'bayerpattern' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'BayerPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\BayerPattern',
                ),
                'sensorfullwidth' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SensorFullWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SensorFullWidth',
                ),
                'sensorfullheight' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SensorFullHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SensorFullHeight',
                ),
                'kodakimagewidth' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'KodakImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakImageWidth',
                ),
                'kodakimageheight' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'KodakImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakImageHeight',
                ),
                'kodakinfotype' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'KodakInfoType',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakInfoType',
                ),
                'serialnumber' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SerialNumber',
                ),
                'fnumber' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FNumber',
                ),
                'exposuretime' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ExposureTime',
                ),
                'iso' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ISO',
                ),
                'camerabyteorder' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'CameraByteOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\CameraByteOrder',
                ),
                'aperturevalue' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ApertureValue',
                ),
                'brightnessvalue' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'BrightnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\BrightnessValue',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ExposureCompensation',
                ),
                'focallengthin35mmformat' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FocalLengthIn35mmFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FocalLengthIn35mmFormat',
                ),
                'focallength' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FocalLength',
                ),
                'firmwareversion' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FirmwareVersion',
                ),
                'shutterspeedvalue' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ShutterSpeedValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ShutterSpeedValue',
                ),
                'make' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Make',
                ),
                'model' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Model',
                ),
                'modeltype' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ModelType',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ModelType',
                ),
                'kodakmodel' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'KodakModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakModel',
                ),
                'quality' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Quality',
                ),
                'burstmode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'BurstMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\BurstMode',
                ),
                'yearcreated' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'YearCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\YearCreated',
                ),
                'monthdaycreated' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'MonthDayCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\MonthDayCreated',
                ),
                'timecreated' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'TimeCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\TimeCreated',
                ),
                'burstmode2' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'BurstMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\BurstMode2',
                ),
                'shuttermode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ShutterMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ShutterMode',
                ),
                'meteringmode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\MeteringMode',
                ),
                'sequencenumber' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SequenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SequenceNumber',
                ),
                'variousmodes' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'VariousModes',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\VariousModes',
                ),
                'distance1' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Distance1',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Distance1',
                ),
                'distance2' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Distance2',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Distance2',
                ),
                'distance3' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Distance3',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Distance3',
                ),
                'distance4' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Distance4',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Distance4',
                ),
                'focusmode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FocusMode',
                ),
                'variousmodes2' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'VariousModes2',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\VariousModes2',
                ),
                'panoramamode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'PanoramaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\PanoramaMode',
                ),
                'subjectdistance' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SubjectDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SubjectDistance',
                ),
                'whitebalance' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\WhiteBalance',
                ),
                'flashmode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FlashMode',
                ),
                'flashfired' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FlashFired',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FlashFired',
                ),
                'isosetting' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ISOSetting',
                ),
                'totalzoom' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'TotalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\TotalZoom',
                ),
                'datetimestamp' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'DateTimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\DateTimeStamp',
                ),
                'colormode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ColorMode',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\DigitalZoom',
                ),
                'sharpness' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Sharpness',
                ),
                'wb_rgblevels' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'WB_RGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\WBRGBLevels',
                ),
                'previewimagewidth' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'PreviewImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\PreviewImageWidth',
                ),
                'previewimageheight' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'PreviewImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\PreviewImageHeight',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\PreviewImageLength',
                ),
                'previewimage' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\PreviewImage',
                ),
                'scenemode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SceneMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SceneMode',
                ),
                'opticalzoom' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'OpticalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\OpticalZoom',
                ),
                'thumbnailwidth' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ThumbnailWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ThumbnailWidth',
                ),
                'thumbnailheight' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ThumbnailHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ThumbnailHeight',
                ),
                'scenemodeused' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'SceneModeUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\SceneModeUsed',
                ),
                'maxaperture' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\MaxAperture',
                ),
                'kodak_subifd3_0x2007' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x2007',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x2007',
                ),
                'kodak_subifd3_0x2008' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x2008',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x2008',
                ),
                'kodak_subifd3_0x2009' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x2009',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x2009',
                ),
                'kodak_subifd3_0x200a' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x200a',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x200a',
                ),
                'kodak_subifd3_0x200b' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x200b',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x200b',
                ),
                'kodak_subifd3_0x3020' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x3020',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3020',
                ),
                'kodak_subifd3_0x3030' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x3030',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3030',
                ),
                'kodak_subifd3_0x3040' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x3040',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3040',
                ),
                'kodak_subifd3_0x3050' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x3050',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3050',
                ),
                'kodak_subifd3_0x3060' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x3060',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x3060',
                ),
                'kodak_subifd3_0x8001' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8001',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8001',
                ),
                'kodak_subifd3_0x8002' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8002',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8002',
                ),
                'kodak_subifd3_0x8003' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8003',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8003',
                ),
                'kodak_subifd3_0x8004' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8004',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8004',
                ),
                'kodak_subifd3_0x8005' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8005',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8005',
                ),
                'kodak_subifd3_0x8006' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8006',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8006',
                ),
                'kodak_subifd3_0x8007' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8007',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8007',
                ),
                'kodak_subifd3_0x8008' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8008',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8008',
                ),
                'kodak_subifd3_0x8009' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x8009',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x8009',
                ),
                'kodak_subifd3_0x800a' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x800a',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x800a',
                ),
                'kodak_subifd3_0x800b' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x800b',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x800b',
                ),
                'kodak_subifd3_0x800c' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Kodak_SubIFD3_0x800c',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakSubIFD30x800c',
                ),
                'afmode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'AFMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\AFMode',
                ),
                'actualcompensation' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ActualCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ActualCompensation',
                ),
                'aperture' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Aperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Aperture',
                ),
                'autobracket' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'AutoBracket',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\AutoBracket',
                ),
                'cameramodel' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'CameraModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\CameraModel',
                ),
                'camerabody' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'CameraBody',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\CameraBody',
                ),
                'date' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Date',
                ),
                'exposurebias' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ExposureBias',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ExposureBias',
                ),
                'exposuremode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ExposureMode',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FlashExposureComp',
                ),
                'flashsyncmode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'FlashSyncMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\FlashSyncMode',
                ),
                'imagenumber' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ImageNumber',
                ),
                'metermode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'MeterMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\MeterMode',
                ),
                'minaperture' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'MinAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\MinAperture',
                ),
                'popupflash' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'PopupFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\PopupFlash',
                ),
                'shootingmode' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ShootingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ShootingMode',
                ),
                'shutterspeed' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ShutterSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ShutterSpeed',
                ),
                'temperature' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Temperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Temperature',
                ),
                'time' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Time',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Time',
                ),
                'otherinfo' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'OtherInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\OtherInfo',
                ),
                'previewimagesize' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'PreviewImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\PreviewImageSize',
                ),
                'kodakmaker' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'KodakMaker',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\KodakMaker',
                ),
                'originalfilename' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'OriginalFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\OriginalFileName',
                ),
                'imagerotated' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'ImageRotated',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\ImageRotated',
                ),
                'macro' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Macro',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Macro',
                ),
                'flash' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\Flash',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\DateTimeOriginal',
                ),
                'unknownnumber' => array(
                    'namespace' => 'Kodak',
                    'tagname' => 'UnknownNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Kodak\UnknownNumber',
                ),

            ),
            'kodakifd' => array(
                'unknownev' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'UnknownEV',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\UnknownEV',
                ),
                'exposurevalue' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'ExposureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\ExposureValue',
                ),
                'originalfilename' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'OriginalFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\OriginalFileName',
                ),
                'sensorleftborder' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'SensorLeftBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\SensorLeftBorder',
                ),
                'sensortopborder' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'SensorTopBorder',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\SensorTopBorder',
                ),
                'sensorimagewidth' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'SensorImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\SensorImageWidth',
                ),
                'sensorimageheight' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'SensorImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\SensorImageHeight',
                ),
                'whitebalance' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WhiteBalance',
                ),
                'time' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'Time',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\Time',
                ),
                'ncdfileinfo' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'NCDFileInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\NCDFileInfo',
                ),
                'colortemperature' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\ColorTemperature',
                ),
                'wb_rgbmul0' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WB_RGBMul0',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WBRGBMul0',
                ),
                'wb_rgbmul1' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WB_RGBMul1',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WBRGBMul1',
                ),
                'wb_rgbmul2' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WB_RGBMul2',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WBRGBMul2',
                ),
                'wb_rgbmul3' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WB_RGBMul3',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WBRGBMul3',
                ),
                'wb_rgbcoeffs0' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WB_RGBCoeffs0',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WBRGBCoeffs0',
                ),
                'wb_rgbcoeffs1' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WB_RGBCoeffs1',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WBRGBCoeffs1',
                ),
                'wb_rgbcoeffs2' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WB_RGBCoeffs2',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WBRGBCoeffs2',
                ),
                'wb_rgbcoeffs3' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'WB_RGBCoeffs3',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\WBRGBCoeffs3',
                ),
                'firmwareversion' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\FirmwareVersion',
                ),
                'tonecurvefilename' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'ToneCurveFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\ToneCurveFileName',
                ),
                'iso' => array(
                    'namespace' => 'KodakIFD',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakIFD\ISO',
                ),

            ),
            'kdc_ifd' => array(
                'serialnumber' => array(
                    'namespace' => 'KDC_IFD',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\KDCIFD\SerialNumber',
                ),
                'whitebalance' => array(
                    'namespace' => 'KDC_IFD',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\KDCIFD\WhiteBalance',
                ),
                'wb_rgblevelsauto' => array(
                    'namespace' => 'KDC_IFD',
                    'tagname' => 'WB_RGBLevelsAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsAuto',
                ),
                'wb_rgblevelstungsten' => array(
                    'namespace' => 'KDC_IFD',
                    'tagname' => 'WB_RGBLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsTungsten',
                ),
                'wb_rgblevelsfluorescent' => array(
                    'namespace' => 'KDC_IFD',
                    'tagname' => 'WB_RGBLevelsFluorescent',
                    'classname' => 'PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsFluorescent',
                ),
                'wb_rgblevelsdaylight' => array(
                    'namespace' => 'KDC_IFD',
                    'tagname' => 'WB_RGBLevelsDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsDaylight',
                ),
                'wb_rgblevelsshade' => array(
                    'namespace' => 'KDC_IFD',
                    'tagname' => 'WB_RGBLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\KDCIFD\WBRGBLevelsShade',
                ),

            ),
            'metaifd' => array(
                'filmproductcode' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'FilmProductCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\FilmProductCode',
                ),
                'imagesourceek' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'ImageSourceEK',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\ImageSourceEK',
                ),
                'captureconditionspar' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'CaptureConditionsPAR',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\CaptureConditionsPAR',
                ),
                'cameraowner' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'CameraOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\CameraOwner',
                ),
                'serialnumber' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\SerialNumber',
                ),
                'userselectgrouptitle' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'UserSelectGroupTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\UserSelectGroupTitle',
                ),
                'dealeridnumber' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'DealerIDNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\DealerIDNumber',
                ),
                'capturedevicefid' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'CaptureDeviceFID',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\CaptureDeviceFID',
                ),
                'envelopenumber' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'EnvelopeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\EnvelopeNumber',
                ),
                'framenumber' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'FrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\FrameNumber',
                ),
                'filmcategory' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'FilmCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\FilmCategory',
                ),
                'filmgencode' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'FilmGencode',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\FilmGencode',
                ),
                'modelandversion' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'ModelAndVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\ModelAndVersion',
                ),
                'filmsize' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'FilmSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\FilmSize',
                ),
                'sba_rgbshifts' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'SBA_RGBShifts',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\SBARGBShifts',
                ),
                'sbainputimagecolorspace' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'SBAInputImageColorspace',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\SBAInputImageColorspace',
                ),
                'sbainputimagebitdepth' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'SBAInputImageBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\SBAInputImageBitDepth',
                ),
                'sbaexposurerecord' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'SBAExposureRecord',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\SBAExposureRecord',
                ),
                'useradjsba_rgbshifts' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'UserAdjSBA_RGBShifts',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\UserAdjSBARGBShifts',
                ),
                'imagerotationstatus' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'ImageRotationStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\ImageRotationStatus',
                ),
                'rollguidelements' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'RollGuidElements',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\RollGuidElements',
                ),
                'metadatanumber' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'MetadataNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\MetadataNumber',
                ),
                'edittagarray' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'EditTagArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\EditTagArray',
                ),
                'magnification' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'Magnification',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\Magnification',
                ),
                'nativexresolution' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'NativeXResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\NativeXResolution',
                ),
                'nativeyresolution' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'NativeYResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\NativeYResolution',
                ),
                'nativeresolutionunit' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'NativeResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\NativeResolutionUnit',
                ),
                'sourceimagedirectory' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'SourceImageDirectory',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\SourceImageDirectory',
                ),
                'sourceimagefilename' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'SourceImageFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\SourceImageFileName',
                ),
                'sourceimagevolumename' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'SourceImageVolumeName',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\SourceImageVolumeName',
                ),
                'printquality' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'PrintQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\PrintQuality',
                ),
                'imageprintstatus' => array(
                    'namespace' => 'MetaIFD',
                    'tagname' => 'ImagePrintStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\MetaIFD\ImagePrintStatus',
                ),

            ),
            'kodakeffectsifd' => array(
                'digitaleffectsversion' => array(
                    'namespace' => 'KodakEffectsIFD',
                    'tagname' => 'DigitalEffectsVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakEffectsIFD\DigitalEffectsVersion',
                ),
                'digitaleffectsname' => array(
                    'namespace' => 'KodakEffectsIFD',
                    'tagname' => 'DigitalEffectsName',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakEffectsIFD\DigitalEffectsName',
                ),
                'digitaleffectstype' => array(
                    'namespace' => 'KodakEffectsIFD',
                    'tagname' => 'DigitalEffectsType',
                    'classname' => 'PHPExiftool\Driver\Tag\KodakEffectsIFD\DigitalEffectsType',
                ),

            ),
            'kyoceraraw' => array(
                'firmwareversion' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\FirmwareVersion',
                ),
                'model' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\Model',
                ),
                'make' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\Make',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\DateTimeOriginal',
                ),
                'iso' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\ISO',
                ),
                'exposuretime' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\ExposureTime',
                ),
                'wb_rggblevels' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'WB_RGGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\WBRGGBLevels',
                ),
                'fnumber' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\FNumber',
                ),
                'maxaperture' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\MaxAperture',
                ),
                'focallength' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\FocalLength',
                ),
                'lens' => array(
                    'namespace' => 'KyoceraRaw',
                    'tagname' => 'Lens',
                    'classname' => 'PHPExiftool\Driver\Tag\KyoceraRaw\Lens',
                ),

            ),
            'lnk' => array(
                'fillattributes' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'FillAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\FillAttributes',
                ),
                'popupfillattributes' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'PopupFillAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\PopupFillAttributes',
                ),
                'screenbuffersize' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'ScreenBufferSize',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\ScreenBufferSize',
                ),
                'windowsize' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'WindowSize',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\WindowSize',
                ),
                'windoworigin' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'WindowOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\WindowOrigin',
                ),
                'fontsize' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'FontSize',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\FontSize',
                ),
                'fontfamily' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'FontFamily',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\FontFamily',
                ),
                'fontweight' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'FontWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\FontWeight',
                ),
                'fontname' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'FontName',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\FontName',
                ),
                'cursorsize' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'CursorSize',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\CursorSize',
                ),
                'fullscreen' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'FullScreen',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\FullScreen',
                ),
                'quickedit' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'QuickEdit',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\QuickEdit',
                ),
                'insertmode' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'InsertMode',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\InsertMode',
                ),
                'windoworiginauto' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'WindowOriginAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\WindowOriginAuto',
                ),
                'historybuffersize' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'HistoryBufferSize',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\HistoryBufferSize',
                ),
                'numhistorybuffers' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'NumHistoryBuffers',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\NumHistoryBuffers',
                ),
                'removehistoryduplicates' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'RemoveHistoryDuplicates',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\RemoveHistoryDuplicates',
                ),
                'codepage' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'CodePage',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\CodePage',
                ),
                'targetfiledosname' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'TargetFileDOSName',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\TargetFileDOSName',
                ),
                'commonnetworkrellink' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'CommonNetworkRelLink',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\CommonNetworkRelLink',
                ),
                'commonpathsuffix' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'CommonPathSuffix',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\CommonPathSuffix',
                ),
                'devicename' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'DeviceName',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\DeviceName',
                ),
                'driveserialnumber' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'DriveSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\DriveSerialNumber',
                ),
                'drivetype' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'DriveType',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\DriveType',
                ),
                'localbasepath' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'LocalBasePath',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\LocalBasePath',
                ),
                'netname' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'NetName',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\NetName',
                ),
                'netprovidertype' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'NetProviderType',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\NetProviderType',
                ),
                'volumeid' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'VolumeID',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\VolumeID',
                ),
                'volumelabel' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'VolumeLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\VolumeLabel',
                ),
                'flags' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'Flags',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\Flags',
                ),
                'fileattributes' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'FileAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\FileAttributes',
                ),
                'createdate' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\CreateDate',
                ),
                'accessdate' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'AccessDate',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\AccessDate',
                ),
                'modifydate' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\ModifyDate',
                ),
                'targetfilesize' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'TargetFileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\TargetFileSize',
                ),
                'iconindex' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'IconIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\IconIndex',
                ),
                'runwindow' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'RunWindow',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\RunWindow',
                ),
                'hotkey' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'HotKey',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\HotKey',
                ),
                'description' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\Description',
                ),
                'relativepath' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'RelativePath',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\RelativePath',
                ),
                'workingdirectory' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'WorkingDirectory',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\WorkingDirectory',
                ),
                'commandlinearguments' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'CommandLineArguments',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\CommandLineArguments',
                ),
                'iconfilename' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'IconFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\IconFileName',
                ),
                'machineid' => array(
                    'namespace' => 'LNK',
                    'tagname' => 'MachineID',
                    'classname' => 'PHPExiftool\Driver\Tag\LNK\MachineID',
                ),

            ),
            'leaf' => array(
                'camerabacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CameraBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CameraBackType',
                ),
                'cameraname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CameraName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CameraName',
                ),
                'cameratype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CameraType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CameraType',
                ),
                'cameraprofileversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CameraProfileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CameraProfileVersion',
                ),
                'isospeed' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ISOSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ISOSpeed',
                ),
                'cameraobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CameraObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CameraObjBackType',
                ),
                'lensid' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LensID',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LensID',
                ),
                'lenstype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LensType',
                ),
                'cameraobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CameraObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CameraObjName',
                ),
                'strobe' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Strobe',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Strobe',
                ),
                'cameraobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CameraObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CameraObjType',
                ),
                'cameraobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CameraObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CameraObjVersion',
                ),
                'ccdrect' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CCDRect',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CCDRect',
                ),
                'ccdvalidrect' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CCDValidRect',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CCDValidRect',
                ),
                'ccdvideorect' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CCDVideoRect',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CCDVideoRect',
                ),
                'captprofbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptProfBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptProfBackType',
                ),
                'centerdarkrect' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CenterDarkRect',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CenterDarkRect',
                ),
                'coloraverages' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorAverages',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorAverages',
                ),
                'colormatrix' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorMatrix',
                ),
                'darkcorrectiontype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'DarkCorrectionType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\DarkCorrectionType',
                ),
                'imagebounds' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ImageBounds',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ImageBounds',
                ),
                'imagefields' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ImageFields',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ImageFields',
                ),
                'imageoffset' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ImageOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ImageOffset',
                ),
                'leftdarkrect' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LeftDarkRect',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LeftDarkRect',
                ),
                'luminanceconsts' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LuminanceConsts',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LuminanceConsts',
                ),
                'mosaicpattern' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'MosaicPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\MosaicPattern',
                ),
                'captprofname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptProfName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptProfName',
                ),
                'numberofplanes' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'NumberOfPlanes',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\NumberOfPlanes',
                ),
                'rawdatarotation' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'RawDataRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\RawDataRotation',
                ),
                'reconstructiontype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ReconstructionType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ReconstructionType',
                ),
                'rightdarkrect' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'RightDarkRect',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\RightDarkRect',
                ),
                'captureserial' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptureSerial',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptureSerial',
                ),
                'captproftype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptProfType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptProfType',
                ),
                'captprofversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptProfVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptProfVersion',
                ),
                'xyoffsetinfo' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'XYOffsetInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\XYOffsetInfo',
                ),
                'multiquality' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'MultiQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\MultiQuality',
                ),
                'captureobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptureObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptureObjBackType',
                ),
                'captureobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptureObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptureObjName',
                ),
                'singlequality' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SingleQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SingleQuality',
                ),
                'captureobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptureObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptureObjType',
                ),
                'captureobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'CaptureObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\CaptureObjVersion',
                ),
                'colorobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorObjBackType',
                ),
                'colormode' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorMode',
                ),
                'colortype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorType',
                ),
                'hasicc' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'HasICC',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\HasICC',
                ),
                'inputprofile' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'InputProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\InputProfile',
                ),
                'colorobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorObjName',
                ),
                'outputprofile' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'OutputProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\OutputProfile',
                ),
                'colorobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorObjType',
                ),
                'colorobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorObjVersion',
                ),
                'imgprofbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ImgProfBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ImgProfBackType',
                ),
                'imagestatus' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ImageStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ImageStatus',
                ),
                'imgprofname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ImgProfName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ImgProfName',
                ),
                'rotationangle' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'RotationAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\RotationAngle',
                ),
                'imgproftype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ImgProfType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ImgProfType',
                ),
                'imgprofversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ImgProfVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ImgProfVersion',
                ),
                'lookheadbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LookHeadBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LookHeadBackType',
                ),
                'lookheadname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LookHeadName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LookHeadName',
                ),
                'lookheadtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LookHeadType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LookHeadType',
                ),
                'lookheadversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LookHeadVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LookHeadVersion',
                ),
                'previewimage' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\PreviewImage',
                ),
                'previewinfo' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'PreviewInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\PreviewInfo',
                ),
                'pdahistogram' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'PDAHistogram',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\PDAHistogram',
                ),
                'backserial' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'BackSerial',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\BackSerial',
                ),
                'tonematrix' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ToneMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ToneMatrix',
                ),
                'tonespaceflow' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ToneSpaceFlow',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ToneSpaceFlow',
                ),
                'patternangle' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'PatternAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\PatternAngle',
                ),
                'neutobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'NeutObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\NeutObjBackType',
                ),
                'colorcasts' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ColorCasts',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ColorCasts',
                ),
                'highlightendpoints' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'HighlightEndPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\HighlightEndPoints',
                ),
                'neutobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'NeutObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\NeutObjName',
                ),
                'neutrals' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Neutrals',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Neutrals',
                ),
                'shadowendpoints' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ShadowEndPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ShadowEndPoints',
                ),
                'neutobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'NeutObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\NeutObjType',
                ),
                'neutobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'NeutObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\NeutObjVersion',
                ),
                'saveobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SaveObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SaveObjBackType',
                ),
                'leafautoactive' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LeafAutoActive',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LeafAutoActive',
                ),
                'leafautobasename' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LeafAutoBaseName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LeafAutoBaseName',
                ),
                'leafhotfolder' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LeafHotFolder',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LeafHotFolder',
                ),
                'leafopenprochdr' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LeafOpenProcHDR',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LeafOpenProcHDR',
                ),
                'leafoutputfiletype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LeafOutputFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LeafOutputFileType',
                ),
                'leafsaveselection' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'LeafSaveSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\LeafSaveSelection',
                ),
                'saveobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SaveObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SaveObjName',
                ),
                'stdautoactive' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdAutoActive',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdAutoActive',
                ),
                'stdbasename' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdBaseName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdBaseName',
                ),
                'stdhotfolder' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdHotFolder',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdHotFolder',
                ),
                'stdopeninphotoshop' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdOpenInPhotoshop',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdOpenInPhotoshop',
                ),
                'stdoutputbitdepth' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdOutputBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdOutputBitDepth',
                ),
                'stdoutputcolormode' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdOutputColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdOutputColorMode',
                ),
                'stdoutputfiletype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdOutputFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdOutputFileType',
                ),
                'stdoxygen' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdOxygen',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdOxygen',
                ),
                'stdsaveselection' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdSaveSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdSaveSelection',
                ),
                'stdscaledoutput' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdScaledOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdScaledOutput',
                ),
                'stdsharpenoutput' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'StdSharpenOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\StdSharpenOutput',
                ),
                'saveobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SaveObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SaveObjType',
                ),
                'saveobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SaveObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SaveObjVersion',
                ),
                'selobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SelObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SelObjBackType',
                ),
                'locks' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Locks',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Locks',
                ),
                'selobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SelObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SelObjName',
                ),
                'orientation' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Orientation',
                ),
                'rect' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Rect',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Rect',
                ),
                'resolution' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Resolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Resolution',
                ),
                'scale' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Scale',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Scale',
                ),
                'selobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SelObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SelObjType',
                ),
                'selobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SelObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SelObjVersion',
                ),
                'sharpobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SharpObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SharpObjBackType',
                ),
                'datalen' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'DataLen',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\DataLen',
                ),
                'sharpobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SharpObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SharpObjName',
                ),
                'sharpinfo' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SharpInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SharpInfo',
                ),
                'sharpmethod' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SharpMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SharpMethod',
                ),
                'sharpobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SharpObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SharpObjType',
                ),
                'sharpobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'SharpObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\SharpObjVersion',
                ),
                'shootobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ShootObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ShootObjBackType',
                ),
                'shootobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ShootObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ShootObjName',
                ),
                'shootobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ShootObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ShootObjType',
                ),
                'shootobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ShootObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ShootObjVersion',
                ),
                'toneobjbacktype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ToneObjBackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ToneObjBackType',
                ),
                'gamma' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Gamma',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Gamma',
                ),
                'toneobjname' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ToneObjName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ToneObjName',
                ),
                'npts' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Npts',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Npts',
                ),
                'tones' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'Tones',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\Tones',
                ),
                'toneobjtype' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ToneObjType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ToneObjType',
                ),
                'toneobjversion' => array(
                    'namespace' => 'Leaf',
                    'tagname' => 'ToneObjVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leaf\ToneObjVersion',
                ),

            ),
            'ac3' => array(
                'audiobitrate' => array(
                    'namespace' => 'AC3',
                    'tagname' => 'AudioBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\AC3\AudioBitrate',
                ),
                'audiochannels' => array(
                    'namespace' => 'AC3',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\AC3\AudioChannels',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'AC3',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\AC3\AudioSampleRate',
                ),
                'surroundmode' => array(
                    'namespace' => 'AC3',
                    'tagname' => 'SurroundMode',
                    'classname' => 'PHPExiftool\Driver\Tag\AC3\SurroundMode',
                ),

            ),
            'm2ts' => array(
                'audiostreamtype' => array(
                    'namespace' => 'M2TS',
                    'tagname' => 'AudioStreamType',
                    'classname' => 'PHPExiftool\Driver\Tag\M2TS\AudioStreamType',
                ),
                'duration' => array(
                    'namespace' => 'M2TS',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\M2TS\Duration',
                ),
                'videostreamtype' => array(
                    'namespace' => 'M2TS',
                    'tagname' => 'VideoStreamType',
                    'classname' => 'PHPExiftool\Driver\Tag\M2TS\VideoStreamType',
                ),

            ),
            'mie-audio' => array(
                'relatedaudiofiletype' => array(
                    'namespace' => 'MIE-Audio',
                    'tagname' => 'RelatedAudioFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEAudio\RelatedAudioFileType',
                ),
                'relatedaudiofilename' => array(
                    'namespace' => 'MIE-Audio',
                    'tagname' => 'RelatedAudioFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEAudio\RelatedAudioFileName',
                ),
                'channels' => array(
                    'namespace' => 'MIE-Audio',
                    'tagname' => 'Channels',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEAudio\Channels',
                ),
                'audiocompression' => array(
                    'namespace' => 'MIE-Audio',
                    'tagname' => 'AudioCompression',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEAudio\AudioCompression',
                ),
                'duration' => array(
                    'namespace' => 'MIE-Audio',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEAudio\Duration',
                ),
                'samplebits' => array(
                    'namespace' => 'MIE-Audio',
                    'tagname' => 'SampleBits',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEAudio\SampleBits',
                ),
                'samplerate' => array(
                    'namespace' => 'MIE-Audio',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEAudio\SampleRate',
                ),
                'relatedaudiofile' => array(
                    'namespace' => 'MIE-Audio',
                    'tagname' => 'RelatedAudioFile',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEAudio\RelatedAudioFile',
                ),

            ),
            'mie-camera' => array(
                'brightness' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'Brightness',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\Brightness',
                ),
                'colorbalance' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ColorBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ColorBalance',
                ),
                'colortemperature' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ColorTemperature',
                ),
                'contrast' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\Contrast',
                ),
                'digitalzoom' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\DigitalZoom',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ExposureCompensation',
                ),
                'exposuremode' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ExposureMode',
                ),
                'exposuretime' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ExposureTime',
                ),
                'firmwareversion' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\FirmwareVersion',
                ),
                'focusmode' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\FocusMode',
                ),
                'iso' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ISO',
                ),
                'isosetting' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ISOSetting',
                ),
                'imagenumber' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ImageNumber',
                ),
                'imagequality' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ImageQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ImageQuality',
                ),
                'imagestabilization' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ImageStabilization',
                ),
                'make' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\Make',
                ),
                'measuredev' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'MeasuredEV',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\MeasuredEV',
                ),
                'model' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\Model',
                ),
                'ownername' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'OwnerName',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\OwnerName',
                ),
                'saturation' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\Saturation',
                ),
                'sensorsize' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'SensorSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\SensorSize',
                ),
                'serialnumber' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\SerialNumber',
                ),
                'sharpness' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\Sharpness',
                ),
                'shootingmode' => array(
                    'namespace' => 'MIE-Camera',
                    'tagname' => 'ShootingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MIECamera\ShootingMode',
                ),

            ),
            'mie-doc' => array(
                'author' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\Author',
                ),
                'comment' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\Comment',
                ),
                'contributors' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'Contributors',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\Contributors',
                ),
                'copyright' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\Copyright',
                ),
                'createdate' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\CreateDate',
                ),
                'email' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'EMail',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\EMail',
                ),
                'keywords' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\Keywords',
                ),
                'modifydate' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\ModifyDate',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\DateTimeOriginal',
                ),
                'phonenumber' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'PhoneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\PhoneNumber',
                ),
                'references' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'References',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\References',
                ),
                'software' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\Software',
                ),
                'title' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\Title',
                ),
                'url' => array(
                    'namespace' => 'MIE-Doc',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEDoc\URL',
                ),

            ),
            'mie-extender' => array(
                'extendermagnification' => array(
                    'namespace' => 'MIE-Extender',
                    'tagname' => 'ExtenderMagnification',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEExtender\ExtenderMagnification',
                ),
                'extendermake' => array(
                    'namespace' => 'MIE-Extender',
                    'tagname' => 'ExtenderMake',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEExtender\ExtenderMake',
                ),
                'extendermodel' => array(
                    'namespace' => 'MIE-Extender',
                    'tagname' => 'ExtenderModel',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEExtender\ExtenderModel',
                ),
                'extenderserialnumber' => array(
                    'namespace' => 'MIE-Extender',
                    'tagname' => 'ExtenderSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEExtender\ExtenderSerialNumber',
                ),

            ),
            'mie-flash' => array(
                'flashexposurecomp' => array(
                    'namespace' => 'MIE-Flash',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEFlash\FlashExposureComp',
                ),
                'flashfired' => array(
                    'namespace' => 'MIE-Flash',
                    'tagname' => 'FlashFired',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEFlash\FlashFired',
                ),
                'flashguidenumber' => array(
                    'namespace' => 'MIE-Flash',
                    'tagname' => 'FlashGuideNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEFlash\FlashGuideNumber',
                ),
                'flashmake' => array(
                    'namespace' => 'MIE-Flash',
                    'tagname' => 'FlashMake',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEFlash\FlashMake',
                ),
                'flashmode' => array(
                    'namespace' => 'MIE-Flash',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEFlash\FlashMode',
                ),
                'flashmodel' => array(
                    'namespace' => 'MIE-Flash',
                    'tagname' => 'FlashModel',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEFlash\FlashModel',
                ),
                'flashserialnumber' => array(
                    'namespace' => 'MIE-Flash',
                    'tagname' => 'FlashSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEFlash\FlashSerialNumber',
                ),
                'flashtype' => array(
                    'namespace' => 'MIE-Flash',
                    'tagname' => 'FlashType',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEFlash\FlashType',
                ),

            ),
            'mie-gps' => array(
                'gpsaltitude' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSAltitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSAltitude',
                ),
                'gpsdestbearing' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSDestBearing',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSDestBearing',
                ),
                'gpsdatetime' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSDateTime',
                ),
                'gpsmapdatum' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSMapDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSMapDatum',
                ),
                'gpsdifferential' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSDifferential',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSDifferential',
                ),
                'gpsdestdistance' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSDestDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSDestDistance',
                ),
                'gpstrack' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSTrack',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSTrack',
                ),
                'gpslatitude' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSLatitude',
                ),
                'gpslongitude' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSLongitude',
                ),
                'gpsmeasuremode' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSMeasureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSMeasureMode',
                ),
                'gpssatellites' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSSatellites',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSSatellites',
                ),
                'gpsspeed' => array(
                    'namespace' => 'MIE-GPS',
                    'tagname' => 'GPSSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGPS\GPSSpeed',
                ),

            ),
            'mie-geo' => array(
                'address' => array(
                    'namespace' => 'MIE-Geo',
                    'tagname' => 'Address',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGeo\Address',
                ),
                'city' => array(
                    'namespace' => 'MIE-Geo',
                    'tagname' => 'City',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGeo\City',
                ),
                'country' => array(
                    'namespace' => 'MIE-Geo',
                    'tagname' => 'Country',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGeo\Country',
                ),
                'postalcode' => array(
                    'namespace' => 'MIE-Geo',
                    'tagname' => 'PostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGeo\PostalCode',
                ),
                'state' => array(
                    'namespace' => 'MIE-Geo',
                    'tagname' => 'State',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEGeo\State',
                ),

            ),
            'mie-image' => array(
                'fullsizeimagetype' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'FullSizeImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\FullSizeImageType',
                ),
                'fullsizeimagename' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'FullSizeImageName',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\FullSizeImageName',
                ),
                'bitdepth' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\BitDepth',
                ),
                'colorspace' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\ColorSpace',
                ),
                'componentsconfiguration' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'ComponentsConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\ComponentsConfiguration',
                ),
                'compressionratio' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'CompressionRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\CompressionRatio',
                ),
                'imagesize' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'ImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\ImageSize',
                ),
                'resolution' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'Resolution',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\Resolution',
                ),
                'fullsizeimage' => array(
                    'namespace' => 'MIE-Image',
                    'tagname' => 'FullSizeImage',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEImage\FullSizeImage',
                ),

            ),
            'mie-lens' => array(
                'fnumber' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\FNumber',
                ),
                'focallength' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\FocalLength',
                ),
                'focusdistance' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'FocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\FocusDistance',
                ),
                'lensmake' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'LensMake',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\LensMake',
                ),
                'maxaperture' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\MaxAperture',
                ),
                'maxapertureatmaxfocal' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'MaxApertureAtMaxFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\MaxApertureAtMaxFocal',
                ),
                'maxfocallength' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'MaxFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\MaxFocalLength',
                ),
                'minaperture' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'MinAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\MinAperture',
                ),
                'minfocallength' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'MinFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\MinFocalLength',
                ),
                'lensmodel' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'LensModel',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\LensModel',
                ),
                'opticalzoom' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'OpticalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\OpticalZoom',
                ),
                'lensserialnumber' => array(
                    'namespace' => 'MIE-Lens',
                    'tagname' => 'LensSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MIELens\LensSerialNumber',
                ),

            ),
            'mie-main' => array(
                'subfiletype' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'SubfileType',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\SubfileType',
                ),
                'mieversion' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'MIEVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\MIEVersion',
                ),
                'subfiledirectory' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'SubfileDirectory',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\SubfileDirectory',
                ),
                'subfilename' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'SubfileName',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\SubfileName',
                ),
                'subfilemimetype' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'SubfileMIMEType',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\SubfileMIMEType',
                ),
                'subfiledata' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'SubfileData',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\SubfileData',
                ),
                'subfileresource' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'SubfileResource',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\SubfileResource',
                ),
                'md5digest' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'MD5Digest',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\MD5Digest',
                ),
                'trailersignature' => array(
                    'namespace' => 'MIE-Main',
                    'tagname' => 'TrailerSignature',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEMain\TrailerSignature',
                ),

            ),
            'mie-orient' => array(
                'azimuth' => array(
                    'namespace' => 'MIE-Orient',
                    'tagname' => 'Azimuth',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEOrient\Azimuth',
                ),
                'declination' => array(
                    'namespace' => 'MIE-Orient',
                    'tagname' => 'Declination',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEOrient\Declination',
                ),
                'elevation' => array(
                    'namespace' => 'MIE-Orient',
                    'tagname' => 'Elevation',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEOrient\Elevation',
                ),
                'rightascension' => array(
                    'namespace' => 'MIE-Orient',
                    'tagname' => 'RightAscension',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEOrient\RightAscension',
                ),
                'rotation' => array(
                    'namespace' => 'MIE-Orient',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEOrient\Rotation',
                ),

            ),
            'mie-preview' => array(
                'previewimagetype' => array(
                    'namespace' => 'MIE-Preview',
                    'tagname' => 'PreviewImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEPreview\PreviewImageType',
                ),
                'previewimagename' => array(
                    'namespace' => 'MIE-Preview',
                    'tagname' => 'PreviewImageName',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEPreview\PreviewImageName',
                ),
                'previewimagesize' => array(
                    'namespace' => 'MIE-Preview',
                    'tagname' => 'PreviewImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEPreview\PreviewImageSize',
                ),
                'previewimage' => array(
                    'namespace' => 'MIE-Preview',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEPreview\PreviewImage',
                ),

            ),
            'mie-thumbnail' => array(
                'thumbnailimagetype' => array(
                    'namespace' => 'MIE-Thumbnail',
                    'tagname' => 'ThumbnailImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEThumbnail\ThumbnailImageType',
                ),
                'thumbnailimagename' => array(
                    'namespace' => 'MIE-Thumbnail',
                    'tagname' => 'ThumbnailImageName',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEThumbnail\ThumbnailImageName',
                ),
                'thumbnailimagesize' => array(
                    'namespace' => 'MIE-Thumbnail',
                    'tagname' => 'ThumbnailImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEThumbnail\ThumbnailImageSize',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'MIE-Thumbnail',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEThumbnail\ThumbnailImage',
                ),

            ),
            'mie-utm' => array(
                'utmmapdatum' => array(
                    'namespace' => 'MIE-UTM',
                    'tagname' => 'UTMMapDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEUTM\UTMMapDatum',
                ),
                'utmeasting' => array(
                    'namespace' => 'MIE-UTM',
                    'tagname' => 'UTMEasting',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEUTM\UTMEasting',
                ),
                'utmnorthing' => array(
                    'namespace' => 'MIE-UTM',
                    'tagname' => 'UTMNorthing',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEUTM\UTMNorthing',
                ),
                'utmzone' => array(
                    'namespace' => 'MIE-UTM',
                    'tagname' => 'UTMZone',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEUTM\UTMZone',
                ),

            ),
            'mie-video' => array(
                'relatedvideofiletype' => array(
                    'namespace' => 'MIE-Video',
                    'tagname' => 'RelatedVideoFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEVideo\RelatedVideoFileType',
                ),
                'relatedvideofilename' => array(
                    'namespace' => 'MIE-Video',
                    'tagname' => 'RelatedVideoFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEVideo\RelatedVideoFileName',
                ),
                'codec' => array(
                    'namespace' => 'MIE-Video',
                    'tagname' => 'Codec',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEVideo\Codec',
                ),
                'duration' => array(
                    'namespace' => 'MIE-Video',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEVideo\Duration',
                ),
                'relatedvideofile' => array(
                    'namespace' => 'MIE-Video',
                    'tagname' => 'RelatedVideoFile',
                    'classname' => 'PHPExiftool\Driver\Tag\MIEVideo\RelatedVideoFile',
                ),

            ),
            'miff' => array(
                'backgroundcolor' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'BackgroundColor',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\BackgroundColor',
                ),
                'blueprimary' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'BluePrimary',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\BluePrimary',
                ),
                'bordercolor' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'BorderColor',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\BorderColor',
                ),
                'class' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Class',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Class0',
                ),
                'colors' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Colors',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Colors',
                ),
                'colorspace' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\ColorSpace',
                ),
                'imagewidth' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\ImageWidth',
                ),
                'compression' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Compression',
                ),
                'delay' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Delay',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Delay',
                ),
                'depth' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Depth',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Depth',
                ),
                'dispose' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Dispose',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Dispose',
                ),
                'gamma' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Gamma',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Gamma',
                ),
                'greenprimary' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'GreenPrimary',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\GreenPrimary',
                ),
                'id' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'ID',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\ID',
                ),
                'iterations' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Iterations',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Iterations',
                ),
                'label' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Label',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Label',
                ),
                'mattcolor' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'MattColor',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\MattColor',
                ),
                'matte' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Matte',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Matte',
                ),
                'montage' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Montage',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Montage',
                ),
                'packets' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Packets',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Packets',
                ),
                'page' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Page',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Page',
                ),
                'redprimary' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'RedPrimary',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\RedPrimary',
                ),
                'renderingintent' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'RenderingIntent',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\RenderingIntent',
                ),
                'resolution' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Resolution',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Resolution',
                ),
                'imageheight' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\ImageHeight',
                ),
                'scene' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Scene',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Scene',
                ),
                'signature' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Signature',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Signature',
                ),
                'units' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'Units',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\Units',
                ),
                'whitepoint' => array(
                    'namespace' => 'MIFF',
                    'tagname' => 'WhitePoint',
                    'classname' => 'PHPExiftool\Driver\Tag\MIFF\WhitePoint',
                ),

            ),
            'mng' => array(
                'backgroundcolor' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BackgroundColor',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BackgroundColor',
                ),
                'mandatorybackground' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'MandatoryBackground',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\MandatoryBackground',
                ),
                'backgroundimageid' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BackgroundImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BackgroundImageID',
                ),
                'backgroundtiling' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BackgroundTiling',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BackgroundTiling',
                ),
                'imagewidth' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ImageHeight',
                ),
                'bitdepth' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BitDepth',
                ),
                'colortype' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ColorType',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ColorType',
                ),
                'compression' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\Compression',
                ),
                'filter' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'Filter',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\Filter',
                ),
                'interlace' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'Interlace',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\Interlace',
                ),
                'redsample' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'RedSample',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\RedSample',
                ),
                'greensample' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'GreenSample',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\GreenSample',
                ),
                'bluesample' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BlueSample',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BlueSample',
                ),
                'alphasample' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'AlphaSample',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\AlphaSample',
                ),
                'viewable' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'Viewable',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\Viewable',
                ),
                'firstobject' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'FirstObject',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\FirstObject',
                ),
                'lastobject' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'LastObject',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\LastObject',
                ),
                'deltatype' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'DeltaType',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\DeltaType',
                ),
                'clipboundary' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ClipBoundary',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ClipBoundary',
                ),
                'sourceid' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'SourceID',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\SourceID',
                ),
                'cloneid' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'CloneID',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\CloneID',
                ),
                'clonetype' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'CloneType',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\CloneType',
                ),
                'donotshow' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'DoNotShow',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\DoNotShow',
                ),
                'concreteflag' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ConcreteFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ConcreteFlag',
                ),
                'localdeltatype' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'LocalDeltaType',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\LocalDeltaType',
                ),
                'deltaxy' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'DeltaXY',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\DeltaXY',
                ),
                'objectid' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ObjectID',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ObjectID',
                ),
                'xylocation' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'XYLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\XYLocation',
                ),
                'clippingboundary' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ClippingBoundary',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ClippingBoundary',
                ),
                'imagetype' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ImageType',
                ),
                'blocksize' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BlockSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BlockSize',
                ),
                'blocklocation' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BlockLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BlockLocation',
                ),
                'snapshotid' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'SnapshotID',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\SnapshotID',
                ),
                'snapshotname' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'SnapshotName',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\SnapshotName',
                ),
                'priority' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'Priority',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\Priority',
                ),
                'alphabitdepth' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'AlphaBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\AlphaBitDepth',
                ),
                'alphacompression' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'AlphaCompression',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\AlphaCompression',
                ),
                'alphafilter' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'AlphaFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\AlphaFilter',
                ),
                'alphainterlace' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'AlphaInterlace',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\AlphaInterlace',
                ),
                'nestlevel' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'NestLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\NestLevel',
                ),
                'iterationcount' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'IterationCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\IterationCount',
                ),
                'terminationcondition' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'TerminationCondition',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\TerminationCondition',
                ),
                'iterationminmax' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'IterationMinMax',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\IterationMinMax',
                ),
                'signalnumber' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'SignalNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\SignalNumber',
                ),
                'tickspersecond' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'TicksPerSecond',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\TicksPerSecond',
                ),
                'nominallayercount' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'NominalLayerCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\NominalLayerCount',
                ),
                'nominalframecount' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'NominalFrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\NominalFrameCount',
                ),
                'nominalplaytime' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'NominalPlayTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\NominalPlayTime',
                ),
                'simplicityprofile' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'SimplicityProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\SimplicityProfile',
                ),
                'firstobjectid' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'FirstObjectID',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\FirstObjectID',
                ),
                'lastobjectid' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'LastObjectID',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\LastObjectID',
                ),
                'xmethod' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'XMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\XMethod',
                ),
                'xmag' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'XMag',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\XMag',
                ),
                'ymag' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'YMag',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\YMag',
                ),
                'leftmag' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'LeftMag',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\LeftMag',
                ),
                'rightmag' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'RightMag',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\RightMag',
                ),
                'topmag' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'TopMag',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\TopMag',
                ),
                'bottommag' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BottomMag',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BottomMag',
                ),
                'ymethod' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'YMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\YMethod',
                ),
                'dropbykeyword' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'DropByKeyword',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\DropByKeyword',
                ),
                'discardobjects' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'DiscardObjects',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\DiscardObjects',
                ),
                'dropchunks' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'DropChunks',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\DropChunks',
                ),
                'frame' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'Frame',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\Frame',
                ),
                'orderingrestrictions' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'OrderingRestrictions',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\OrderingRestrictions',
                ),
                'partialpalette' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'PartialPalette',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\PartialPalette',
                ),
                'saveobjects' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'SaveObjects',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\SaveObjects',
                ),
                'seekpoint' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'SeekPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\SeekPoint',
                ),
                'resourcesneeded' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ResourcesNeeded',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ResourcesNeeded',
                ),
                'destinationid' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'DestinationID',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\DestinationID',
                ),
                'targetdeltatype' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'TargetDeltaType',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\TargetDeltaType',
                ),
                'targetxy' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'TargetXY',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\TargetXY',
                ),
                'compositionmode' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'CompositionMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\CompositionMode',
                ),
                'orientation' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\Orientation',
                ),
                'offsetorigin' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'OffsetOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\OffsetOrigin',
                ),
                'offsetxy' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'OffsetXY',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\OffsetXY',
                ),
                'boundaryorigin' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'BoundaryOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\BoundaryOrigin',
                ),
                'pastclippingboundary' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'PastClippingBoundary',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\PastClippingBoundary',
                ),
                'newcolortype' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'NewColorType',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\NewColorType',
                ),
                'newbitdepth' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'NewBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\NewBitDepth',
                ),
                'fillmethod' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'FillMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\FillMethod',
                ),
                'showmode' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'ShowMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\ShowMode',
                ),
                'terminationaction' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'TerminationAction',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\TerminationAction',
                ),
                'iterationendaction' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'IterationEndAction',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\IterationEndAction',
                ),
                'delay' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'Delay',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\Delay',
                ),
                'iterationmax' => array(
                    'namespace' => 'MNG',
                    'tagname' => 'IterationMax',
                    'classname' => 'PHPExiftool\Driver\Tag\MNG\IterationMax',
                ),

            ),
            'mpc' => array(
                'totalframes' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'TotalFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\TotalFrames',
                ),
                'samplerate' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\SampleRate',
                ),
                'quality' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\Quality',
                ),
                'maxband' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'MaxBand',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\MaxBand',
                ),
                'replaygaintrackpeak' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'ReplayGainTrackPeak',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\ReplayGainTrackPeak',
                ),
                'replaygaintrackgain' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'ReplayGainTrackGain',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\ReplayGainTrackGain',
                ),
                'replaygainalbumpeak' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'ReplayGainAlbumPeak',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\ReplayGainAlbumPeak',
                ),
                'replaygainalbumgain' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'ReplayGainAlbumGain',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\ReplayGainAlbumGain',
                ),
                'fastseek' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'FastSeek',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\FastSeek',
                ),
                'gapless' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'Gapless',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\Gapless',
                ),
                'encoderversion' => array(
                    'namespace' => 'MPC',
                    'tagname' => 'EncoderVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MPC\EncoderVersion',
                ),

            ),
            'mpeg' => array(
                'mpegaudioversion' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'MPEGAudioVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\MPEGAudioVersion',
                ),
                'audiolayer' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'AudioLayer',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\AudioLayer',
                ),
                'audiobitrate' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'AudioBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\AudioBitrate',
                ),
                'samplerate' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\SampleRate',
                ),
                'channelmode' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'ChannelMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\ChannelMode',
                ),
                'msstereo' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'MSStereo',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\MSStereo',
                ),
                'modeextension' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'ModeExtension',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\ModeExtension',
                ),
                'intensitystereo' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'IntensityStereo',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\IntensityStereo',
                ),
                'copyrightflag' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'CopyrightFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\CopyrightFlag',
                ),
                'originalmedia' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'OriginalMedia',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\OriginalMedia',
                ),
                'emphasis' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'Emphasis',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\Emphasis',
                ),
                'lamemethod' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'LameMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\LameMethod',
                ),
                'lamelowpassfilter' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'LameLowPassFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\LameLowPassFilter',
                ),
                'lamebitrate' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'LameBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\LameBitrate',
                ),
                'lamestereomode' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'LameStereoMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\LameStereoMode',
                ),
                'imagewidth' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\ImageHeight',
                ),
                'aspectratio' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'AspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\AspectRatio',
                ),
                'framerate' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\FrameRate',
                ),
                'videobitrate' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'VideoBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\VideoBitrate',
                ),
                'vbrframes' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'VBRFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\VBRFrames',
                ),
                'vbrbytes' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'VBRBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\VBRBytes',
                ),
                'vbrscale' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'VBRScale',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\VBRScale',
                ),
                'encoder' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'Encoder',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\Encoder',
                ),
                'lamevbrquality' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'LameVBRQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\LameVBRQuality',
                ),
                'lamequality' => array(
                    'namespace' => 'MPEG',
                    'tagname' => 'LameQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\MPEG\LameQuality',
                ),

            ),
            'mpimage' => array(
                'mpimageflags' => array(
                    'namespace' => 'MPImage',
                    'tagname' => 'MPImageFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\MPImage\MPImageFlags',
                ),
                'mpimageformat' => array(
                    'namespace' => 'MPImage',
                    'tagname' => 'MPImageFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MPImage\MPImageFormat',
                ),
                'mpimagetype' => array(
                    'namespace' => 'MPImage',
                    'tagname' => 'MPImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\MPImage\MPImageType',
                ),
                'mpimagelength' => array(
                    'namespace' => 'MPImage',
                    'tagname' => 'MPImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MPImage\MPImageLength',
                ),
                'mpimagestart' => array(
                    'namespace' => 'MPImage',
                    'tagname' => 'MPImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\MPImage\MPImageStart',
                ),
                'dependentimage1entrynumber' => array(
                    'namespace' => 'MPImage',
                    'tagname' => 'DependentImage1EntryNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MPImage\DependentImage1EntryNumber',
                ),
                'dependentimage2entrynumber' => array(
                    'namespace' => 'MPImage',
                    'tagname' => 'DependentImage2EntryNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MPImage\DependentImage2EntryNumber',
                ),

            ),
            'mpf0' => array(
                'mpfversion' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'MPFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\MPFVersion',
                ),
                'numberofimages' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'NumberOfImages',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\NumberOfImages',
                ),
                'imageuidlist' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'ImageUIDList',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\ImageUIDList',
                ),
                'totalframes' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'TotalFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\TotalFrames',
                ),
                'mpindividualnum' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'MPIndividualNum',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\MPIndividualNum',
                ),
                'panorientation' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'PanOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\PanOrientation',
                ),
                'panoverlaph' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'PanOverlapH',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\PanOverlapH',
                ),
                'panoverlapv' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'PanOverlapV',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\PanOverlapV',
                ),
                'baseviewpointnum' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'BaseViewpointNum',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\BaseViewpointNum',
                ),
                'convergenceangle' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'ConvergenceAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\ConvergenceAngle',
                ),
                'baselinelength' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'BaselineLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\BaselineLength',
                ),
                'verticaldivergence' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'VerticalDivergence',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\VerticalDivergence',
                ),
                'axisdistancex' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'AxisDistanceX',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\AxisDistanceX',
                ),
                'axisdistancey' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'AxisDistanceY',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\AxisDistanceY',
                ),
                'axisdistancez' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'AxisDistanceZ',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\AxisDistanceZ',
                ),
                'yawangle' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'YawAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\YawAngle',
                ),
                'pitchangle' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'PitchAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\PitchAngle',
                ),
                'rollangle' => array(
                    'namespace' => 'MPF0',
                    'tagname' => 'RollAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MPF0\RollAngle',
                ),

            ),
            'mxf' => array(
                'mxfversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MXFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MXFVersion',
                ),
                'footerposition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FooterPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FooterPosition',
                ),
                'headersize' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HeaderSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HeaderSize',
                ),
                'organizationid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OrganizationID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OrganizationID',
                ),
                'upid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UPID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UPID',
                ),
                'upn' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UPN',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UPN',
                ),
                'ibtn' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IBTN',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IBTN',
                ),
                'isan' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISAN',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISAN',
                ),
                'isbn' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISBN',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISBN',
                ),
                'issn' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISSN',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISSN',
                ),
                'iswc' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISWC',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISWC',
                ),
                'ismn' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISMN',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISMN',
                ),
                'isci' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISCI',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISCI',
                ),
                'isrc' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISRC',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISRC',
                ),
                'isrn' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISRN',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISRN',
                ),
                'isbd' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISBD',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISBD',
                ),
                'istc' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISTC',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISTC',
                ),
                'sici' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SICI',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SICI',
                ),
                'bici' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BICI',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BICI',
                ),
                'aici' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AICI',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AICI',
                ),
                'pii' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PII',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PII',
                ),
                'doi' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DOI',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DOI',
                ),
                'instanceuid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InstanceUID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InstanceUID',
                ),
                'packageid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageID',
                ),
                'devicedesignation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceDesignation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceDesignation',
                ),
                'devicemodel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceModel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceModel',
                ),
                'deviceserialnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceSerialNumber',
                ),
                'url' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\URL',
                ),
                'purl' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PURL',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PURL',
                ),
                'urn' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'URN',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\URN',
                ),
                'transmissionid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TransmissionID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TransmissionID',
                ),
                'archiveid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ArchiveID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ArchiveID',
                ),
                'itemid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ItemID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ItemID',
                ),
                'accountingreferencenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AccountingReferenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AccountingReferenceNumber',
                ),
                'trafficid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TrafficID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TrafficID',
                ),
                'reelorrollnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ReelOrRollNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ReelOrRollNumber',
                ),
                'localtapenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalTapeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalTapeNumber',
                ),
                'luid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LUID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LUID',
                ),
                'packagename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageName',
                ),
                'localfilepath' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalFilePath',
                ),
                'edgecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EdgeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EdgeCode',
                ),
                'framecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameCode',
                ),
                'keycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyCode',
                ),
                'inknumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InkNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InkNumber',
                ),
                'keytext' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyText',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyText',
                ),
                'keyframe' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyFrame',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyFrame',
                ),
                'keysound' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeySound',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeySound',
                ),
                'keydataorprogram' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyDataOrProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyDataOrProgram',
                ),
                'titlekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TitleKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TitleKind',
                ),
                'maintitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MainTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MainTitle',
                ),
                'secondarytitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SecondaryTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SecondaryTitle',
                ),
                'seriesnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SeriesNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SeriesNumber',
                ),
                'episodenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EpisodeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EpisodeNumber',
                ),
                'scenenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SceneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SceneNumber',
                ),
                'takenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TakeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TakeNumber',
                ),
                'cisaclegalentityid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CISACLegalEntityID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CISACLegalEntityID',
                ),
                'agicoaid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AGICOAID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AGICOAID',
                ),
                'sourceorganization' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceOrganization',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceOrganization',
                ),
                'supplycontractnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupplyContractNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupplyContractNumber',
                ),
                'originalproducername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OriginalProducerName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OriginalProducerName',
                ),
                'totalepisodecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TotalEpisodeCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TotalEpisodeCount',
                ),
                'copyrightstatus' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CopyrightStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CopyrightStatus',
                ),
                'copyrightownername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CopyrightOwnerName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CopyrightOwnerName',
                ),
                'intellectualpropertydescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IntellectualPropertyDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IntellectualPropertyDescription',
                ),
                'intellectualpropertyrights' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IntellectualPropertyRights',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IntellectualPropertyRights',
                ),
                'rightsholder' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Rightsholder',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Rightsholder',
                ),
                'rightsmanagementauthority' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RightsManagementAuthority',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RightsManagementAuthority',
                ),
                'interestedpartyname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InterestedPartyName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InterestedPartyName',
                ),
                'maximumusecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaximumUseCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaximumUseCount',
                ),
                'licenseoptionsdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LicenseOptionsDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LicenseOptionsDescription',
                ),
                'currencycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CurrencyCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CurrencyCode',
                ),
                'royaltypaymentinformation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoyaltyPaymentInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoyaltyPaymentInformation',
                ),
                'royaltyincomeinformation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoyaltyIncomeInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoyaltyIncomeInformation',
                ),
                'restrictionsonuse' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RestrictionsonUse',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RestrictionsonUse',
                ),
                'exccidata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ExCCIData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ExCCIData',
                ),
                'username' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Username',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Username',
                ),
                'password' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Password',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Password',
                ),
                'scramblingkeykind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ScramblingKeyKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ScramblingKeyKind',
                ),
                'scramblingkeyvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ScramblingKeyValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ScramblingKeyValue',
                ),
                'broadcastorganizationname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcastOrganizationName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcastOrganizationName',
                ),
                'broadcastchannel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcastChannel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcastChannel',
                ),
                'broadcastmediumkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcastMediumKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcastMediumKind',
                ),
                'broadcastregion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcastRegion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcastRegion',
                ),
                'firstbroadcastflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FirstBroadcastFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FirstBroadcastFlag',
                ),
                'currentrepeatnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CurrentRepeatNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CurrentRepeatNumber',
                ),
                'previousrepeatnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PreviousRepeatNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PreviousRepeatNumber',
                ),
                'audiencerating' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudienceRating',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudienceRating',
                ),
                'audiencereach' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudienceReach',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudienceReach',
                ),
                'natureofpersonality' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NatureOfPersonality',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NatureOfPersonality',
                ),
                'contributionstatus' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContributionStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContributionStatus',
                ),
                'supportoradministrationstatus' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupportOrAdministrationStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupportOrAdministrationStatus',
                ),
                'organizationkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OrganizationKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OrganizationKind',
                ),
                'productionorganizationrole' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProductionOrganizationRole',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProductionOrganizationRole',
                ),
                'supportorganizationrole' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupportOrganizationRole',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupportOrganizationRole',
                ),
                'jobfunctionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'JobFunctionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\JobFunctionName',
                ),
                'rolename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoleName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoleName',
                ),
                'contactkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContactKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContactKind',
                ),
                'contactdepartmentname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContactDepartmentName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContactDepartmentName',
                ),
                'familyname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FamilyName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FamilyName',
                ),
                'firstgivenname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FirstGivenName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FirstGivenName',
                ),
                'secondgivenname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SecondGivenName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SecondGivenName',
                ),
                'thirdgivenname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ThirdGivenName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ThirdGivenName',
                ),
                'mainname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MainName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MainName',
                ),
                'supplementaryname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupplementaryName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupplementaryName',
                ),
                'organizationmainname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OrganizationMainName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OrganizationMainName',
                ),
                'supplementaryorganizationname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupplementaryOrganizationName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupplementaryOrganizationName',
                ),
                'iso3166countrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISO3166CountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISO3166CountryCode',
                ),
                'iso639-1languagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISO639-1LanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISO6391LanguageCode',
                ),
                'operatingsysteminterpretations' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OperatingSystemInterpretations',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OperatingSystemInterpretations',
                ),
                'byteorder' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ByteOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ByteOrder',
                ),
                'essenceisidentified' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceIsIdentified',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceIsIdentified',
                ),
                'lengthsystemname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LengthSystemName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LengthSystemName',
                ),
                'lengthunitkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LengthUnitKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LengthUnitKind',
                ),
                'angularunitkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AngularUnitKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AngularUnitKind',
                ),
                'timesystemoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimeSystemOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimeSystemOffset',
                ),
                'timeunitkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimeUnitKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimeUnitKind',
                ),
                'contentcodingsystem' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentCodingSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentCodingSystem',
                ),
                'programkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgramKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgramKind',
                ),
                'genre' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Genre',
                ),
                'targetaudience' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TargetAudience',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TargetAudience',
                ),
                'catalogdatastatus' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CatalogDataStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CatalogDataStatus',
                ),
                'thesaurusname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ThesaurusName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ThesaurusName',
                ),
                'theme' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Theme',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Theme',
                ),
                'contentclassification' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentClassification',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentClassification',
                ),
                'keywords' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Keywords',
                ),
                'keyframes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyFrames',
                ),
                'keysounds' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeySounds',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeySounds',
                ),
                'keydata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyData',
                ),
                'abstract' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Abstract',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Abstract0',
                ),
                'purpose' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Purpose',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Purpose',
                ),
                'description' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Description',
                ),
                'colordescriptor' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ColorDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ColorDescriptor',
                ),
                'formatdescriptor' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FormatDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FormatDescriptor',
                ),
                'stratumkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StratumKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StratumKind',
                ),
                'individualawardname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IndividualAwardName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IndividualAwardName',
                ),
                'programawardname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgramAwardName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgramAwardName',
                ),
                'assetvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AssetValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AssetValue',
                ),
                'contentvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentValue',
                ),
                'culturalvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CulturalValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CulturalValue',
                ),
                'aestheticvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AestheticValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AestheticValue',
                ),
                'historicalvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HistoricalValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HistoricalValue',
                ),
                'technicalvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TechnicalValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TechnicalValue',
                ),
                'othervalues' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OtherValues',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OtherValues',
                ),
                'catalogingsystemname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CatalogingSystemName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CatalogingSystemName',
                ),
                'computedkeywords' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComputedKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComputedKeywords',
                ),
                'computedkeyframes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComputedKeyFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComputedKeyFrames',
                ),
                'computedkeysounds' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComputedKeySounds',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComputedKeySounds',
                ),
                'computedkeydata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComputedKeyData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComputedKeyData',
                ),
                'computedstratumkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComputedStratumKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComputedStratumKind',
                ),
                'presentationaspectratio' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PresentationAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PresentationAspectRatio',
                ),
                'captureaspectratio' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CaptureAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CaptureAspectRatio',
                ),
                'capturegammaequation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CaptureGammaEquation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CaptureGammaEquation',
                ),
                'lumaequation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LumaEquation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LumaEquation',
                ),
                'colorimetrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ColorimetryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ColorimetryCode',
                ),
                'signalformcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SignalFormCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SignalFormCode',
                ),
                'colorfieldcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ColorFieldCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ColorFieldCode',
                ),
                'fieldrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FieldRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FieldRate',
                ),
                'framerate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameRate',
                ),
                'framelayout' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameLayout',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameLayout',
                ),
                'samplingstructurecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SamplingStructureCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SamplingStructureCode',
                ),
                'totallinesperframe' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TotalLinesperFrame',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TotalLinesperFrame',
                ),
                'activelinesperframe' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ActiveLinesperFrame',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ActiveLinesperFrame',
                ),
                'leadinglines' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LeadingLines',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LeadingLines',
                ),
                'trailinglines' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TrailingLines',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TrailingLines',
                ),
                'analogvideosystemname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnalogVideoSystemName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnalogVideoSystemName',
                ),
                'luminancesamplerate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LuminanceSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LuminanceSampleRate',
                ),
                'activesamplesperline' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ActiveSamplesperLine',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ActiveSamplesperLine',
                ),
                'totalsamplesperline' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TotalSamplesperLine',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TotalSamplesperLine',
                ),
                'samplinghierarchycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SamplingHierarchyCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SamplingHierarchyCode',
                ),
                'horizontalsubsampling' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HorizontalSubsampling',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HorizontalSubsampling',
                ),
                'colorsiting' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ColorSiting',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ColorSiting',
                ),
                'sampledheight' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SampledHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SampledHeight',
                ),
                'sampledwidth' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SampledWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SampledWidth',
                ),
                'sampledxoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SampledXOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SampledXOffset',
                ),
                'sampledyoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SampledYOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SampledYOffset',
                ),
                'displayheight' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DisplayHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DisplayHeight',
                ),
                'displaywidth' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DisplayWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DisplayWidth',
                ),
                'displayxoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DisplayXOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DisplayXOffset',
                ),
                'displayyoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DisplayYOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DisplayYOffset',
                ),
                'filteringcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilteringCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilteringCode',
                ),
                'imageheight' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageWidth',
                ),
                'bitsperpixel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BitsperPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BitsperPixel',
                ),
                'roundingmethodcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoundingMethodCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoundingMethodCode',
                ),
                'blackreferencelevel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BlackReferenceLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BlackReferenceLevel',
                ),
                'whitereferencelevel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'WhiteReferenceLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\WhiteReferenceLevel',
                ),
                'fieldframetypecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FieldFrameTypeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FieldFrameTypeCode',
                ),
                'pulldownsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PulldownSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PulldownSequence',
                ),
                'pulldownfielddominance' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PulldownFieldDominance',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PulldownFieldDominance',
                ),
                'videoandfilmframerelationship' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoAndFilmFrameRelationship',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoAndFilmFrameRelationship',
                ),
                'capturefilmframerate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CaptureFilmFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CaptureFilmFrameRate',
                ),
                'transferfilmframerate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TransferFilmFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TransferFilmFrameRate',
                ),
                'videotestparameter' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoTestParameter',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoTestParameter',
                ),
                'videotestresult' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoTestResult',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoTestResult',
                ),
                'filmtestparameter' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmTestParameter',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmTestParameter',
                ),
                'filmtestresult' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmTestResult',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmTestResult',
                ),
                'electrospatialformulation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ElectrospatialFormulation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ElectrospatialFormulation',
                ),
                'filteringapplied' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilteringApplied',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilteringApplied',
                ),
                'audioreferencelevel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioReferenceLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioReferenceLevel',
                ),
                'audiomonochannelcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioMonoChannelCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioMonoChannelCount',
                ),
                'audiostereochannelcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioStereoChannelCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioStereoChannelCount',
                ),
                'analogsystem' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnalogSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnalogSystem',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioSampleRate',
                ),
                'bitspersample' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BitsPerSample',
                ),
                'roundinglaw' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoundingLaw',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoundingLaw',
                ),
                'dither' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Dither',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Dither',
                ),
                'opticaltrack' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OpticalTrack',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OpticalTrack',
                ),
                'magnetictrack' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MagneticTrack',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MagneticTrack',
                ),
                'signal-to-noiseratio' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Signal-to-NoiseRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SignalToNoiseRatio',
                ),
                'weighting' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Weighting',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Weighting',
                ),
                'analogdatacodingkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnalogDataCodingKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnalogDataCodingKind',
                ),
                'timecodekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeKind',
                ),
                'timecodetimebase' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeTimebase',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeTimebase',
                ),
                'timecodeuserbitsflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeUserBitsFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeUserBitsFlag',
                ),
                'includesync' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IncludeSync',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IncludeSync',
                ),
                'dropframe' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DropFrame',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DropFrame',
                ),
                'timecodesourcekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeSourceKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeSourceKind',
                ),
                'analogmetadatacarrier' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnalogMetadataCarrier',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnalogMetadataCarrier',
                ),
                'digitalmetadatacarrier' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DigitalMetadataCarrier',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DigitalMetadataCarrier',
                ),
                'analogmonitoringandcontrolcodingkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnalogMonitoringAndControlCodingKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnalogMonitoringAndControlCodingKind',
                ),
                'samplerate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SampleRate',
                ),
                'essencelength' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceLength',
                ),
                'filmcolorprocess' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmColorProcess',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmColorProcess',
                ),
                'edgecodeformat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EdgeCodeFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EdgeCodeFormat',
                ),
                'filmformatname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmFormatName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmFormatName',
                ),
                'filmstockkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmStockKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmStockKind',
                ),
                'filmstockmanufacturername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmStockManufacturerName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmStockManufacturerName',
                ),
                'physicalmedialength' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PhysicalMediaLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PhysicalMediaLength',
                ),
                'filmcaptureaperture' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmCaptureAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmCaptureAperture',
                ),
                'imagecategory' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageCategory',
                ),
                'imagesourcedevicekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageSourceDeviceKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageSourceDeviceKind',
                ),
                'opticaltestparametername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OpticalTestParameterName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OpticalTestParameterName',
                ),
                'opticaltestresult' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OpticalTestResult',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OpticalTestResult',
                ),
                'sensortype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SensorType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SensorType',
                ),
                'polarcharacteristic' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PolarCharacteristic',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PolarCharacteristic',
                ),
                'integrationindication' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IntegrationIndication',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IntegrationIndication',
                ),
                'eventindication' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventIndication',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventIndication',
                ),
                'qualityflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QualityFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QualityFlag',
                ),
                'physicalinstancekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PhysicalInstanceKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PhysicalInstanceKind',
                ),
                'digitaloranalogorigination' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DigitalOrAnalogOrigination',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DigitalOrAnalogOrigination',
                ),
                'microphoneplacementtechniques' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MicrophonePlacementTechniques',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MicrophonePlacementTechniques',
                ),
                'simpleflaggingcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SimpleFlaggingCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SimpleFlaggingCount',
                ),
                'copycount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CopyCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CopyCount',
                ),
                'clonecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CloneCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CloneCount',
                ),
                'work-in-progressflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Work-in-ProgressFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\WorkInProgressFlag',
                ),
                'videoorimagecompressionalgorithm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoOrImageCompressionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoOrImageCompressionAlgorithm',
                ),
                'splicingmetadata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SplicingMetadata',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SplicingMetadata',
                ),
                'audiocompressionalgorithm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioCompressionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioCompressionAlgorithm',
                ),
                'videonoisereductionalgorithm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoNoiseReductionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoNoiseReductionAlgorithm',
                ),
                'audionoisereductionalgorithm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioNoiseReductionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioNoiseReductionAlgorithm',
                ),
                'enhancementormodificationdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EnhancementOrModificationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EnhancementOrModificationDescription',
                ),
                'videodevicekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoDeviceKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoDeviceKind',
                ),
                'videodeviceparametername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoDeviceParameterName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoDeviceParameterName',
                ),
                'videodeviceparametersetting' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoDeviceParameterSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoDeviceParameterSetting',
                ),
                'audioenhancementormodificationdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioEnhancementOrModificationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioEnhancementOrModificationDescription',
                ),
                'audiofirstmix-downprocess' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioFirstMix-DownProcess',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioFirstMixDownProcess',
                ),
                'audiodevicekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioDeviceKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioDeviceKind',
                ),
                'audiodeviceparameter' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioDeviceParameter',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioDeviceParameter',
                ),
                'audiodeviceparametersetting' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioDeviceParameterSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioDeviceParameterSetting',
                ),
                'dataenhancementormodificationdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DataEnhancementOrModificationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DataEnhancementOrModificationDescription',
                ),
                'datadevicekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DataDeviceKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DataDeviceKind',
                ),
                'datadeviceparametername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DataDeviceParameterName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DataDeviceParameterName',
                ),
                'datadeviceparametersetting' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DataDeviceParameterSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DataDeviceParameterSetting',
                ),
                'defaultfadetype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefaultFadeType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefaultFadeType',
                ),
                'activestate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ActiveState',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ActiveState',
                ),
                'fade-intype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Fade-InType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FadeInType',
                ),
                'fade-outtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Fade-OutType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FadeOutType',
                ),
                'speedchangeeffectflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SpeedChangeEffectFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SpeedChangeEffectFlag',
                ),
                'inputsegmentcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InputSegmentCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InputSegmentCount',
                ),
                'bypass' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Bypass',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Bypass',
                ),
                'videocompressionalgorithm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoCompressionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoCompressionAlgorithm',
                ),
                'mpegvideorecodingdataset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEGVideoRecodingDataset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEGVideoRecodingDataset',
                ),
                'upstreamaudiocompressionalgorithm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UpstreamAudioCompressionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UpstreamAudioCompressionAlgorithm',
                ),
                'mpegaudiorecodingdataset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEGAudioRecodingDataset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEGAudioRecodingDataset',
                ),
                'programsupportmaterialreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgramSupportMaterialReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgramSupportMaterialReference',
                ),
                'advertisingmaterialreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AdvertisingMaterialReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AdvertisingMaterialReference',
                ),
                'programcommercialmaterialreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgramCommercialMaterialReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgramCommercialMaterialReference',
                ),
                'contiguousdataflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContiguousDataFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContiguousDataFlag',
                ),
                'positioninsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PositionInSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PositionInSequence',
                ),
                'relativepositioninsequenceoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RelativePositionInSequenceOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RelativePositionInSequenceOffset',
                ),
                'relativepositioninsequencename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RelativePositionInSequenceName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RelativePositionInSequenceName',
                ),
                'imagecoordinatesystem' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageCoordinateSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageCoordinateSystem',
                ),
                'mapdatumused' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MapDatumUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MapDatumUsed',
                ),
                'localdatumabsolutepositionaccuracy' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalDatumAbsolutePositionAccuracy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalDatumAbsolutePositionAccuracy',
                ),
                'deviceabsolutepositionalaccuracy' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceAbsolutePositionalAccuracy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceAbsolutePositionalAccuracy',
                ),
                'devicealtitude' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceAltitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceAltitude',
                ),
                'devicelatitude' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceLatitude',
                ),
                'devicelongitude' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceLongitude',
                ),
                'devicexdimension' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceXDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceXDimension',
                ),
                'deviceydimension' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceYDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceYDimension',
                ),
                'framepositionalaccuracy' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FramePositionalAccuracy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FramePositionalAccuracy',
                ),
                'framecenterlatitude' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameCenterLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameCenterLatitude',
                ),
                'framecenterlongitude' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameCenterLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameCenterLongitude',
                ),
                'framecenterlatitudelongitude' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameCenterLatitudeLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameCenterLatitudeLongitude',
                ),
                'localdatumrelativepositionaccuracy' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalDatumRelativePositionAccuracy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalDatumRelativePositionAccuracy',
                ),
                'devicerelativepositionalaccuracy' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceRelativePositionalAccuracy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceRelativePositionalAccuracy',
                ),
                'devicerelativepositionx' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceRelativePositionX',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceRelativePositionX',
                ),
                'devicerelativepositiony' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceRelativePositionY',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceRelativePositionY',
                ),
                'devicerelativepositionz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceRelativePositionZ',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceRelativePositionZ',
                ),
                'subjectrelativepositionalaccuracy' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubjectRelativePositionalAccuracy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubjectRelativePositionalAccuracy',
                ),
                'positionwithinviewportimagexcoordinate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PositionWithinViewportImageXCoordinate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PositionWithinViewportImageXCoordinate',
                ),
                'positionwithinviewportimageycoordinate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PositionWithinViewportImageYCoordinate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PositionWithinViewportImageYCoordinate',
                ),
                'sourceimagecenterxcoordinate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceImageCenterXCoordinate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceImageCenterXCoordinate',
                ),
                'sourceimagecenterycoordinate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceImageCenterYCoordinate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceImageCenterYCoordinate',
                ),
                'viewportimagecenterccoordinate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ViewportImageCenterCCoordinate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ViewportImageCenterCCoordinate',
                ),
                'viewportimagecenterycoordinate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ViewportImageCenterYCoordinate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ViewportImageCenterYCoordinate',
                ),
                'deviceabsolutespeed' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceAbsoluteSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceAbsoluteSpeed',
                ),
                'deviceabsoluteheading' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceAbsoluteHeading',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceAbsoluteHeading',
                ),
                'subjectabsolutespeed' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubjectAbsoluteSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubjectAbsoluteSpeed',
                ),
                'subjectabsoluteheading' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubjectAbsoluteHeading',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubjectAbsoluteHeading',
                ),
                'devicerelativespeed' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceRelativeSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceRelativeSpeed',
                ),
                'devicerelativeheading' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceRelativeHeading',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceRelativeHeading',
                ),
                'subjectrelativespeed' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubjectRelativeSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubjectRelativeSpeed',
                ),
                'subjectrelativeheading' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubjectRelativeHeading',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubjectRelativeHeading',
                ),
                'slantrange' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SlantRange',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SlantRange',
                ),
                'targetwidth' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TargetWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TargetWidth',
                ),
                'viewportheight' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ViewportHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ViewportHeight',
                ),
                'viewportwidth' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ViewportWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ViewportWidth',
                ),
                'sensorrollangle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SensorRollAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SensorRollAngle',
                ),
                'angletonorth' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AngleToNorth',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AngleToNorth',
                ),
                'obliquityangle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObliquityAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObliquityAngle',
                ),
                'placekeyword' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlaceKeyword',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlaceKeyword',
                ),
                'objectcountrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectCountryCode',
                ),
                'shootingcountrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShootingCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShootingCountryCode',
                ),
                'settingcountrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingCountryCode',
                ),
                'copyrightlicensecountrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CopyrightLicenseCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CopyrightLicenseCountryCode',
                ),
                'intellectualpropertylicensecountrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IntellectualPropertyLicenseCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IntellectualPropertyLicenseCountryCode',
                ),
                'objectregioncode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectRegionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectRegionCode',
                ),
                'shootingregioncode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShootingRegionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShootingRegionCode',
                ),
                'settingregioncode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingRegionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingRegionCode',
                ),
                'copyrightlicenseregioncode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CopyrightLicenseRegionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CopyrightLicenseRegionCode',
                ),
                'intellectualpropertylicenseregioncode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IntellectualPropertyLicenseRegionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IntellectualPropertyLicenseRegionCode',
                ),
                'roomnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoomNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoomNumber',
                ),
                'streetnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StreetNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StreetNumber',
                ),
                'streetname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StreetName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StreetName',
                ),
                'postaltown' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PostalTown',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PostalTown',
                ),
                'cityname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CityName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CityName',
                ),
                'stateorprovinceorcountyname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StateOrProvinceOrCountyName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StateOrProvinceOrCountyName',
                ),
                'postalcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PostalCode',
                ),
                'countryname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CountryName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CountryName',
                ),
                'settingroomnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingRoomNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingRoomNumber',
                ),
                'settingstreetnumberorbuildingname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingStreetNumberOrBuildingName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingStreetNumberOrBuildingName',
                ),
                'settingstreetname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingStreetName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingStreetName',
                ),
                'settingtownname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingTownName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingTownName',
                ),
                'settingcityname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingCityName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingCityName',
                ),
                'settingstateorprovinceorcountyname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingStateOrProvinceOrCountyName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingStateOrProvinceOrCountyName',
                ),
                'settingpostalcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingPostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingPostalCode',
                ),
                'settingcountryname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingCountryName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingCountryName',
                ),
                'telephonenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TelephoneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TelephoneNumber',
                ),
                'faxnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FaxNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FaxNumber',
                ),
                'e-mailaddress' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'E-MailAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EMailAddress',
                ),
                'settingdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingDescription',
                ),
                'utcuserdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UTCUserDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UTCUserDateTime',
                ),
                'localuserdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalUserDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalUserDateTime',
                ),
                'smpte309muserdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SMPTE309MUserDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SMPTE309MUserDateTime',
                ),
                'smpte12muserdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SMPTE12MUserDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SMPTE12MUserDateTime',
                ),
                'utcstartdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UTCStartDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UTCStartDateTime',
                ),
                'localstartdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalStartDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalStartDateTime',
                ),
                'timecodestartdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeStartDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeStartDateTime',
                ),
                'utcenddatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UTCEndDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UTCEndDateTime',
                ),
                'localenddatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalEndDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalEndDateTime',
                ),
                'timecodeenddatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeEndDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeEndDateTime',
                ),
                'utclastmodifydate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UTCLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UTCLastModifyDate',
                ),
                'locallastmodifydate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalLastModifyDate',
                ),
                'timecodelastmodifydate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeLastModifyDate',
                ),
                'utceventstartdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UTCEventStartDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UTCEventStartDateTime',
                ),
                'localeventstartdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalEventStartDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalEventStartDateTime',
                ),
                'timecodeeventstartdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeEventStartDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeEventStartDateTime',
                ),
                'utceventenddatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UTCEventEndDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UTCEventEndDateTime',
                ),
                'localeventenddatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalEventEndDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalEventEndDateTime',
                ),
                'timecodeeventenddatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeEventEndDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeEventEndDateTime',
                ),
                'starttimerelativetoreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StartTimeRelativeToReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StartTimeRelativeToReference',
                ),
                'starttimecoderelativetoreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StartTimecodeRelativeToReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StartTimecodeRelativeToReference',
                ),
                'materialendtimeoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaterialEndTimeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaterialEndTimeOffset',
                ),
                'materialendtimecodeoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaterialEndTimecodeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaterialEndTimecodeOffset',
                ),
                'eventstarttimeoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventStartTimeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventStartTimeOffset',
                ),
                'eventstarttimecodeoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventStartTimecodeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventStartTimecodeOffset',
                ),
                'eventendtimeoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventEndTimeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventEndTimeOffset',
                ),
                'eventendtimecodeoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventEndTimecodeOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventEndTimecodeOffset',
                ),
                'framecountoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameCountOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameCountOffset',
                ),
                'timeperiodname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimePeriodName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimePeriodName',
                ),
                'localcreationdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalCreationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalCreationDateTime',
                ),
                'timecodecreationdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeCreationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeCreationDateTime',
                ),
                'localmodifydate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalModifyDate',
                ),
                'timecodemodifydate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeModifyDate',
                ),
                'framecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameCount',
                ),
                'materialabsoluteduration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaterialAbsoluteDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaterialAbsoluteDuration',
                ),
                'textlessblackduration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TextlessBlackDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TextlessBlackDuration',
                ),
                'eventabsolutedurationframecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventAbsoluteDurationFrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventAbsoluteDurationFrameCount',
                ),
                'eventabsoluteduration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventAbsoluteDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventAbsoluteDuration',
                ),
                'bufferdelay' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BufferDelay',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BufferDelay',
                ),
                'programidentifier' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgramIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgramIdentifier',
                ),
                'programidentifierstring' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgramIdentifierString',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgramIdentifierString',
                ),
                'shimname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShimName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShimName',
                ),
                'signalstandard' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SignalStandard',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SignalStandard',
                ),
                'intendedafd' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IntendedAFD',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IntendedAFD',
                ),
                'slatetitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SlateTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SlateTitle',
                ),
                'nolacode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NOLACode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NOLACode',
                ),
                'rating' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Rating',
                ),
                'nielsenstreamidentifier' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NielsenStreamIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NielsenStreamIdentifier',
                ),
                'isrecording' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsRecording',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsRecording',
                ),
                'isliveproduction' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsLiveProduction',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsLiveProduction',
                ),
                'islivetransmission' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsLiveTransmission',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsLiveTransmission',
                ),
                'isdubbed' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsDubbed',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsDubbed',
                ),
                'isvoiceover' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsVoiceover',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsVoiceover',
                ),
                'hasaudiowatermark' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HasAudioWatermark',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HasAudioWatermark',
                ),
                'audiowatermarkkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioWatermarkKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioWatermarkKind',
                ),
                'hasvideowatermark' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HasVideoWatermark',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HasVideoWatermark',
                ),
                'videowatermarkkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoWatermarkKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoWatermarkKind',
                ),
                'subtitlespresent' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubtitlesPresent',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubtitlesPresent',
                ),
                'captiontitles' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CaptionTitles',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CaptionTitles',
                ),
                'captionsviateletext' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CaptionsViaTeletext',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CaptionsViaTeletext',
                ),
                'textlessmaterial' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TextlessMaterial',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TextlessMaterial',
                ),
                'storagedevicekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StorageDeviceKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StorageDeviceKind',
                ),
                'storagemediakind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StorageMediaKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StorageMediaKind',
                ),
                'storagemediaid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StorageMediaID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StorageMediaID',
                ),
                'broadcastdate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcastDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcastDate',
                ),
                'broadcasttime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcastTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcastTime',
                ),
                'isrepeat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsRepeat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsRepeat',
                ),
                'firsttransmissioninfo' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FirstTransmissionInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FirstTransmissionInfo',
                ),
                'teletextsubtitlesavailable' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TeletextSubtitlesAvailable',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TeletextSubtitlesAvailable',
                ),
                'seasonepisodenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SeasonEpisodeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SeasonEpisodeNumber',
                ),
                'seasonepisodetitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SeasonEpisodeTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SeasonEpisodeTitle',
                ),
                'epgprogramsynopsis' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EPGProgramSynopsis',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EPGProgramSynopsis',
                ),
                'dvbparentalrating' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DVBParentalRating',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DVBParentalRating',
                ),
                'contentmaturityrating' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentMaturityRating',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentMaturityRating',
                ),
                'contentmaturitydescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentMaturityDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentMaturityDescription',
                ),
                'contentmaturitygraphic' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentMaturityGraphic',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentMaturityGraphic',
                ),
                'contractentity' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractEntity',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractEntity',
                ),
                'contracttypelink' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractTypeLink',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractTypeLink',
                ),
                'consumerrightstocopy' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ConsumerRightsToCopy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ConsumerRightsToCopy',
                ),
                'broadcasterrightstocopy' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcasterRightsToCopy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcasterRightsToCopy',
                ),
                'directorname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DirectorName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DirectorName',
                ),
                'producername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProducerName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProducerName',
                ),
                'femaleleadactressname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FemaleLeadActressName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FemaleLeadActressName',
                ),
                'maleleadactorname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaleLeadActorName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaleLeadActorName',
                ),
                'presentername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PresenterName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PresenterName',
                ),
                'mainsponsorname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MainSponsorName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MainSponsorName',
                ),
                'voicetalentname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VoiceTalentName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VoiceTalentName',
                ),
                'postboxnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PostboxNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PostboxNumber',
                ),
                'postcodeforpostbox' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PostCodeForPostbox',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PostCodeForPostbox',
                ),
                'programnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgramNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgramNumber',
                ),
                'definitionobjectid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefinitionObjectID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefinitionObjectID',
                ),
                'ieeedeviceid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IEEEDeviceID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IEEEDeviceID',
                ),
                'projectnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProjectNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProjectNumber',
                ),
                'edgecodeheader' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EdgeCodeHeader',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EdgeCodeHeader',
                ),
                'channelhandle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ChannelHandle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ChannelHandle',
                ),
                'physicalmedialocation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PhysicalMediaLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PhysicalMediaLocation',
                ),
                'medialocation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MediaLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MediaLocation',
                ),
                'tracknumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TrackNumber',
                ),
                'edgecodestart' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EdgeCodeStart',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EdgeCodeStart',
                ),
                'versiontitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VersionTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VersionTitle',
                ),
                'trackid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TrackID',
                ),
                'trackname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TrackName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TrackName',
                ),
                'definitionobjectname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefinitionObjectName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefinitionObjectName',
                ),
                'contentpackagemetadatalink' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentPackageMetadataLink',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentPackageMetadataLink',
                ),
                'definedname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefinedName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefinedName',
                ),
                'devicemanufacturername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceManufacturerName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceManufacturerName',
                ),
                'manufacturerid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ManufacturerID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ManufacturerID',
                ),
                'ieeemanufacturerid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IEEEManufacturerID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IEEEManufacturerID',
                ),
                'aafmanufacturerid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AAFManufacturerID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AAFManufacturerID',
                ),
                'supplyingdepartmentname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupplyingDepartmentName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupplyingDepartmentName',
                ),
                'audienceshare' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudienceShare',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudienceShare',
                ),
                'audienceappreciation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudienceAppreciation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudienceAppreciation',
                ),
                'salutation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Salutation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Salutation',
                ),
                'honorsandqualifications' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HonorsAndQualifications',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HonorsAndQualifications',
                ),
                'objectmodelversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectModelVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectModelVersion',
                ),
                'sdkversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SDKVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SDKVersion',
                ),
                'isoptional' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsOptional',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsOptional',
                ),
                'issearchable' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsSearchable',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsSearchable',
                ),
                'usedefaultvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UseDefaultValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UseDefaultValue',
                ),
                'defaultdatavalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefaultDataValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefaultDataValue',
                ),
                'size' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Size',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Size',
                ),
                'issigned' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsSigned',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsSigned',
                ),
                'elementcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ElementCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ElementCount',
                ),
                'elementnamelist' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ElementNameList',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ElementNameList',
                ),
                'typedefinitionelementvaluelist' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TypeDefinitionElementValueList',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TypeDefinitionElementValueList',
                ),
                'membernamelist' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MemberNameList',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MemberNameList',
                ),
                'extendibleelementnamelist' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ExtendibleElementNameList',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ExtendibleElementNameList',
                ),
                'typedefinitionextendibleelementvalues' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TypeDefinitionExtendibleElementValues',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TypeDefinitionExtendibleElementValues',
                ),
                'targetset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TargetSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TargetSet',
                ),
                'fillerdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FillerData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FillerData',
                ),
                'klvdatavalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KLVDataValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KLVDataValue',
                ),
                'packageklvdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageKLVData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageKLVData',
                ),
                'componentklvdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComponentKLVData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComponentKLVData',
                ),
                'assignedcategoryname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AssignedCategoryName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AssignedCategoryName',
                ),
                'assignedcategoryvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AssignedCategoryValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AssignedCategoryValue',
                ),
                'shotlist' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotList',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotList',
                ),
                'packageusercomments' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageUserComments',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageUserComments',
                ),
                'cue-inwords' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Cue-InWords',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CueInWords',
                ),
                'cue-outwords' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Cue-OutWords',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CueOutWords',
                ),
                'objectkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectKind',
                ),
                'objectdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectDescription',
                ),
                'objectname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectName',
                ),
                'metadataitemname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MetadataItemName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MetadataItemName',
                ),
                'shotcommentkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotCommentKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotCommentKind',
                ),
                'shotcomment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotComment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotComment',
                ),
                'computedobjectkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComputedObjectKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComputedObjectKind',
                ),
                'versionnumberstring' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VersionNumberString',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VersionNumberString',
                ),
                'versionnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VersionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VersionNumber',
                ),
                'wavesummary' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'WAVESummary',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\WAVESummary',
                ),
                'aifcsummary' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AIFCSummary',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AIFCSummary',
                ),
                'tiffsummary' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TIFFSummary',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TIFFSummary',
                ),
                'viewportaspectratio' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ViewportAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ViewportAspectRatio',
                ),
                'presentationgammaequation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PresentationGammaEquation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PresentationGammaEquation',
                ),
                'fielddominance' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FieldDominance',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FieldDominance',
                ),
                'videolinemap' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoLineMap',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoLineMap',
                ),
                'verticalsub-sampling' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VerticalSub-sampling',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VerticalSubSampling',
                ),
                'colorrangelevels' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ColorRangeLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ColorRangeLevels',
                ),
                'pixellayout' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PixelLayout',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PixelLayout',
                ),
                'alphasampledepth' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AlphaSampleDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AlphaSampleDepth',
                ),
                'palette' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Palette',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Palette',
                ),
                'palettelayout' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PaletteLayout',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PaletteLayout',
                ),
                'componentdepth' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComponentDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComponentDepth',
                ),
                'videocodingschemeid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoCodingSchemeID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoCodingSchemeID',
                ),
                'roundedcapturefilmframerate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoundedCaptureFilmFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoundedCaptureFilmFrameRate',
                ),
                'audioaveragebitrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioAverageBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioAverageBitrate',
                ),
                'audiofixedbitrateflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioFixedBitrateFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioFixedBitrateFlag',
                ),
                'codinglawkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CodingLawKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CodingLawKind',
                ),
                'audiocodingschemeid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioCodingSchemeID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioCodingSchemeID',
                ),
                'layernumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LayerNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LayerNumber',
                ),
                'roundedtimecodetimebase' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoundedTimecodeTimebase',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoundedTimecodeTimebase',
                ),
                'componentdatadefinition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComponentDataDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComponentDataDefinition',
                ),
                'streamdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StreamData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StreamData',
                ),
                'timecodestreamdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeStreamData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeStreamData',
                ),
                'recordedformat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RecordedFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RecordedFormat',
                ),
                'tapeshellkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TapeShellKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TapeShellKind',
                ),
                'tapeformulation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TapeFormulation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TapeFormulation',
                ),
                'tapecapacity' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TapeCapacity',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TapeCapacity',
                ),
                'tapemanufacturer' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TapeManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TapeManufacturer',
                ),
                'tapestock' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TapeStock',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TapeStock',
                ),
                'tapebatchnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TapeBatchNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TapeBatchNumber',
                ),
                'perforationsperframe' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PerforationsPerFrame',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PerforationsPerFrame',
                ),
                'filmbatchnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmBatchNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmBatchNumber',
                ),
                'filmgauge' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmGauge',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmGauge',
                ),
                'edgecodefilmgauge' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EdgeCodeFilmGauge',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EdgeCodeFilmGauge',
                ),
                'exposedaspectratio' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ExposedAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ExposedAspectRatio',
                ),
                'imagealignmentoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageAlignmentOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageAlignmentOffset',
                ),
                'imagestartoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageStartOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageStartOffset',
                ),
                'imageendoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageEndOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageEndOffset',
                ),
                'paddingbits' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PaddingBits',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PaddingBits',
                ),
                'focallength' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FocalLength',
                ),
                'sensorsize' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SensorSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SensorSize',
                ),
                'fnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FNumber',
                ),
                'sensortypecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SensorTypeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SensorTypeCode',
                ),
                'fieldofviewhorizontal' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FieldOfViewHorizontal',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FieldOfViewHorizontal',
                ),
                'anamorphiclenscharacteristic' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnamorphicLensCharacteristic',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnamorphicLensCharacteristic',
                ),
                'uniformdataflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UniformDataFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UniformDataFlag',
                ),
                'jpegtableid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'JPEGTableID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\JPEGTableID',
                ),
                'alphatransparency' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AlphaTransparency',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AlphaTransparency',
                ),
                'generationid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GenerationID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GenerationID',
                ),
                'applicationsuppliername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationSupplierName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationSupplierName',
                ),
                'applicationname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationName',
                ),
                'applicationversionnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationVersionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationVersionNumber',
                ),
                'applicationversionstring' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationVersionString',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationVersionString',
                ),
                'applicationplatform' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationPlatform',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationPlatform',
                ),
                'applicationproductid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationProductID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationProductID',
                ),
                'linkedgenerationid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LinkedGenerationID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LinkedGenerationID',
                ),
                'containerversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContainerVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContainerVersion',
                ),
                'toolkitversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ToolkitVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ToolkitVersion',
                ),
                'plug-incategoryid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Plug-InCategoryID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlugInCategoryID',
                ),
                'plug-inplatformid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Plug-InPlatformID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlugInPlatformID',
                ),
                'minimumsupportedplatformversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MinimumSupportedPlatformVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MinimumSupportedPlatformVersion',
                ),
                'maximumsupportedplatformversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaximumSupportedPlatformVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaximumSupportedPlatformVersion',
                ),
                'plug-inengineid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Plug-InEngineID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlugInEngineID',
                ),
                'minimumsupportedengineversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MinimumSupportedEngineVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MinimumSupportedEngineVersion',
                ),
                'maximumsupportedengineversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaximumSupportedEngineVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaximumSupportedEngineVersion',
                ),
                'plug-inapiid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Plug-InAPIID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlugInAPIID',
                ),
                'minimumapiversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MinimumAPIVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MinimumAPIVersion',
                ),
                'maximumapiversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaximumAPIVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaximumAPIVersion',
                ),
                'software-onlysupportflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Software-OnlySupportFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SoftwareOnlySupportFlag',
                ),
                'hardwareacceleratorflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HardwareAcceleratorFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HardwareAcceleratorFlag',
                ),
                'plug-inlocatorset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Plug-InLocatorSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlugInLocatorSet',
                ),
                'authenticationflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AuthenticationFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AuthenticationFlag',
                ),
                'associatedmetadatadefinition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AssociatedMetadataDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AssociatedMetadataDefinition',
                ),
                'eventtrackeditrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventTrackEditRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventTrackEditRate',
                ),
                'defaultfadeeditrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefaultFadeEditRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefaultFadeEditRate',
                ),
                'editingeventcomment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EditingEventComment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EditingEventComment',
                ),
                'editrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EditRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EditRate',
                ),
                'operationdefinitionid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OperationDefinitionID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OperationDefinitionID',
                ),
                'value' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Value',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Value',
                ),
                'edithint' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EditHint',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EditHint',
                ),
                'operationdatadefinition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OperationDataDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OperationDataDefinition',
                ),
                'operationcategory' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OperationCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OperationCategory',
                ),
                'displayunits' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DisplayUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DisplayUnits',
                ),
                'bypassoverride' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BypassOverride',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BypassOverride',
                ),
                'timepointvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimepointValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimepointValue',
                ),
                'beginanchor' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BeginAnchor',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BeginAnchor',
                ),
                'endanchor' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EndAnchor',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EndAnchor',
                ),
                'filmtovideotransferdirection' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmToVideoTransferDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmToVideoTransferDirection',
                ),
                'filmtovideotransferkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmToVideoTransferKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmToVideoTransferKind',
                ),
                'filmtovideotransferphase' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FilmToVideoTransferPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FilmToVideoTransferPhase',
                ),
                'teletextsubtitlesflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TeletextSubtitlesFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TeletextSubtitlesFlag',
                ),
                'subtitledatafileflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubtitleDatafileFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubtitleDatafileFlag',
                ),
                'closedcaptionsubtitlesflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClosedCaptionSubtitlesFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClosedCaptionSubtitlesFlag',
                ),
                'sampleindex' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SampleIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SampleIndex',
                ),
                'sourcepackageid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourcePackageID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourcePackageID',
                ),
                'sourcetrackid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceTrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceTrackID',
                ),
                'relativescope' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RelativeScope',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RelativeScope',
                ),
                'relativetrack' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RelativeTrack',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RelativeTrack',
                ),
                'objectclass' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectClass',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectClass',
                ),
                'essencecontainerformat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceContainerFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceContainerFormat',
                ),
                'codecdefinition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CodecDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CodecDefinition',
                ),
                'parameterdefinition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ParameterDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ParameterDefinition',
                ),
                'interpolation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Interpolation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Interpolation',
                ),
                'parameterdatatype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ParameterDataType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ParameterDataType',
                ),
                'codecessencedescriptor' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CodecEssenceDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CodecEssenceDescriptor',
                ),
                'contentstorage' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentStorage',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentStorage',
                ),
                'dictionary' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Dictionary',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Dictionary',
                ),
                'essencedescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceDescription',
                ),
                'sequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Sequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Sequence',
                ),
                'transitioneffect' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TransitionEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TransitionEffect',
                ),
                'effectrendering' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EffectRendering',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EffectRendering',
                ),
                'inputsegment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InputSegment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InputSegment',
                ),
                'stillframe' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StillFrame',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StillFrame',
                ),
                'selected' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Selected',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Selected',
                ),
                'annotation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Annotation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Annotation',
                ),
                'manufacturerinformationobject' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ManufacturerInformationObject',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ManufacturerInformationObject',
                ),
                'codecessencekinds' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CodecEssenceKinds',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CodecEssenceKinds',
                ),
                'operationparameters' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OperationParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OperationParameters',
                ),
                'degradedeffects' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DegradedEffects',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DegradedEffects',
                ),
                'packages' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Packages',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Packages',
                ),
                'essencedata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceData',
                ),
                'operationdefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OperationDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OperationDefinitions',
                ),
                'parameterdefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ParameterDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ParameterDefinitions',
                ),
                'datadefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DataDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DataDefinitions',
                ),
                'plug-indefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Plug-InDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlugInDefinitions',
                ),
                'codecdefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CodecDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CodecDefinitions',
                ),
                'containerdefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContainerDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContainerDefinitions',
                ),
                'interpolationdefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InterpolationDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InterpolationDefinitions',
                ),
                'availablerepresentations' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AvailableRepresentations',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AvailableRepresentations',
                ),
                'inputsegments' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InputSegments',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InputSegments',
                ),
                'essencelocators' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceLocators',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceLocators',
                ),
                'identificationlist' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IdentificationList',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IdentificationList',
                ),
                'tracks' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Tracks',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Tracks',
                ),
                'controlpointlist' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ControlPointList',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ControlPointList',
                ),
                'packagetracks' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageTracks',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageTracks',
                ),
                'alternates' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Alternates',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Alternates',
                ),
                'componentsinsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComponentsInSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComponentsInSequence',
                ),
                'parameters' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Parameters',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Parameters',
                ),
                'linkedpackageid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LinkedPackageID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LinkedPackageID',
                ),
                'parentclass' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ParentClass',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ParentClass',
                ),
                'properties' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Properties',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Properties',
                ),
                'isconcrete' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsConcrete',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsConcrete',
                ),
                'propertytype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PropertyType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PropertyType',
                ),
                'localid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalID',
                ),
                'isuniqueidentifier' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IsUniqueIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IsUniqueIdentifier',
                ),
                'classdefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClassDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClassDefinitions',
                ),
                'typedefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TypeDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TypeDefinitions',
                ),
                'targetclassofstrongreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TargetClassOfStrongReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TargetClassOfStrongReference',
                ),
                'targetclassofweakreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TargetClassOfWeakReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TargetClassOfWeakReference',
                ),
                'enumerationunderlyingintegertype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EnumerationUnderlyingIntegerType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EnumerationUnderlyingIntegerType',
                ),
                'fixedarrayelementtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FixedArrayElementType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FixedArrayElementType',
                ),
                'variablearrayelementtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VariableArrayElementType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VariableArrayElementType',
                ),
                'setelementtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SetElementType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SetElementType',
                ),
                'stringelementtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StringElementType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StringElementType',
                ),
                'streamelementtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StreamElementType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StreamElementType',
                ),
                'membertypes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MemberTypes',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MemberTypes',
                ),
                'renamedtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RenamedType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RenamedType',
                ),
                'dictionaryidentifier' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DictionaryIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DictionaryIdentifier',
                ),
                'dictionarydescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DictionaryDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DictionaryDescription',
                ),
                'blockcontinuitycount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BlockContinuityCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BlockContinuityCount',
                ),
                'streampositionindicator' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StreamPositionIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StreamPositionIndicator',
                ),
                'origin' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Origin',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Origin',
                ),
                'starttimecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StartTimecode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StartTimecode',
                ),
                'cutpoint' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CutPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CutPoint',
                ),
                'eventstart' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventStart',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventStart',
                ),
                'controlpointtime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ControlPointTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ControlPointTime',
                ),
                'createdate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CreateDate',
                ),
                'modifydate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ModifyDate',
                ),
                'containerlastmodifydate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContainerLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContainerLastModifyDate',
                ),
                'packagelastmodifydate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageLastModifyDate',
                ),
                'duration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Duration',
                ),
                'defaultfadeduration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefaultFadeDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefaultFadeDuration',
                ),
                'fade-induration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Fade-InDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FadeInDuration',
                ),
                'fade-outduration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Fade-OutDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FadeOutDuration',
                ),
                'tapeformat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TapeFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TapeFormat',
                ),
                'globalnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GlobalNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GlobalNumber',
                ),
                'deviceidkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceIDKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceIDKind',
                ),
                'devicekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceKind',
                ),
                'devicekindcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceKindCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceKindCode',
                ),
                'platformdesignation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlatformDesignation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlatformDesignation',
                ),
                'platformmodel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlatformModel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlatformModel',
                ),
                'platformserialnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlatformSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlatformSerialNumber',
                ),
                'localtargetid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalTargetID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalTargetID',
                ),
                'magneticdisknumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MagneticDiskNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MagneticDiskNumber',
                ),
                'opticaldiscnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OpticalDiscNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OpticalDiscNumber',
                ),
                'streamid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StreamID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StreamID',
                ),
                'transportstreamid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TransportStreamID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TransportStreamID',
                ),
                'organizationalprogramnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OrganizationalProgramNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OrganizationalProgramNumber',
                ),
                'itemdesignatorid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ItemDesignatorID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ItemDesignatorID',
                ),
                'missionid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MissionID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MissionID',
                ),
                'recordinglabelname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RecordingLabelName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RecordingLabelName',
                ),
                'collectionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CollectionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CollectionName',
                ),
                'origincode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OriginCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OriginCode',
                ),
                'maincatalognumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MainCatalogNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MainCatalogNumber',
                ),
                'catalogprefixnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CatalogPrefixNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CatalogPrefixNumber',
                ),
                'sidenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SideNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SideNumber',
                ),
                'recordedtracknumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RecordedTrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RecordedTrackNumber',
                ),
                'seriesinaseriesgroupcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SeriesinaSeriesGroupCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SeriesinaSeriesGroupCount',
                ),
                'programminggroupkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgrammingGroupKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgrammingGroupKind',
                ),
                'purchasingorganizationname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PurchasingOrganizationName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PurchasingOrganizationName',
                ),
                'salescontractnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SalesContractNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SalesContractNumber',
                ),
                'purchasingdepartment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PurchasingDepartment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PurchasingDepartment',
                ),
                'contracttype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractType',
                ),
                'contracttypecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractTypeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractTypeCode',
                ),
                'contractclausedescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractClauseDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractClauseDescription',
                ),
                'contractlinecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractLineCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractLineCode',
                ),
                'contractlinename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractLineName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractLineName',
                ),
                'contracttermsofbusiness' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractTermsOfBusiness',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractTermsOfBusiness',
                ),
                'contractinstallmentpercentage' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractInstallmentPercentage',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractInstallmentPercentage',
                ),
                'jurisdiction' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Jurisdiction',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Jurisdiction',
                ),
                'rightsconditiondescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RightsConditionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RightsConditionDescription',
                ),
                'currencyname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CurrencyName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CurrencyName',
                ),
                'totalpayment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TotalPayment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TotalPayment',
                ),
                'payeeaccountname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PayeeAccountName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PayeeAccountName',
                ),
                'payeeaccountnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PayeeAccountNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PayeeAccountNumber',
                ),
                'payeeaccountsortcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PayeeAccountSortCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PayeeAccountSortCode',
                ),
                'totalincome' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TotalIncome',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TotalIncome',
                ),
                'payeraccountname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PayerAccountName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PayerAccountName',
                ),
                'payeraccountnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PayerAccountNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PayerAccountNumber',
                ),
                'payeraccountsortcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PayerAccountSortCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PayerAccountSortCode',
                ),
                'securityclassification' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SecurityClassification',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SecurityClassification',
                ),
                'securityclassificationcaveats' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SecurityClassificationCaveats',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SecurityClassificationCaveats',
                ),
                'classifiedby' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClassifiedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClassifiedBy',
                ),
                'classificationreason' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClassificationReason',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClassificationReason',
                ),
                'declassificationdate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeclassificationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeclassificationDate',
                ),
                'derivedfrom' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DerivedFrom',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DerivedFrom',
                ),
                'classificationcomment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClassificationComment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClassificationComment',
                ),
                'classificationandmarkingsystem' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClassificationAndMarkingSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClassificationAndMarkingSystem',
                ),
                'broadcastservicename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcastServiceName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcastServiceName',
                ),
                'broadcastmediumcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BroadcastMediumCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BroadcastMediumCode',
                ),
                'jobfunctioncode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'JobFunctionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\JobFunctionCode',
                ),
                'jobtitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'JobTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\JobTitle',
                ),
                'persondescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PersonDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PersonDescription',
                ),
                'regioncode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegionCode',
                ),
                'regionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegionName',
                ),
                'languagename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LanguageName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LanguageName',
                ),
                'terminatingfillerdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TerminatingFillerData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TerminatingFillerData',
                ),
                'timingbiascorrection' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimingBiasCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimingBiasCorrection',
                ),
                'timingbiascorrectiondescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimingBiasCorrectionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimingBiasCorrectionDescription',
                ),
                'programmaterialclassificationcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgramMaterialClassificationCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgramMaterialClassificationCode',
                ),
                'subjectname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubjectName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubjectName',
                ),
                'keyframesamplecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyFrameSampleCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyFrameSampleCount',
                ),
                'intentdescriptor' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IntentDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IntentDescriptor',
                ),
                'textualdescriptionkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TextualDescriptionKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TextualDescriptionKind',
                ),
                'festivalname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FestivalName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FestivalName',
                ),
                'objectdescriptioncode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectDescriptionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectDescriptionCode',
                ),
                'descriptionkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptionKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptionKind',
                ),
                'descriptivecomment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveComment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveComment',
                ),
                'contextdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContextDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContextDescription',
                ),
                'objectidentificationconfidence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectIdentificationConfidence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectIdentificationConfidence',
                ),
                'objecthorizontalaveragedimension' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectHorizontalAverageDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectHorizontalAverageDimension',
                ),
                'objectverticalaveragedimension' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectVerticalAverageDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectVerticalAverageDimension',
                ),
                'objectareadimension' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectAreaDimension',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectAreaDimension',
                ),
                'horizontalactionsafepercentage' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HorizontalActionSafePercentage',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HorizontalActionSafePercentage',
                ),
                'verticalactionsafepercentage' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VerticalActionSafePercentage',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VerticalActionSafePercentage',
                ),
                'horizontalgraphicssafepercentage' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HorizontalGraphicsSafePercentage',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HorizontalGraphicsSafePercentage',
                ),
                'verticalgraphicssafepercentage' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VerticalGraphicsSafePercentage',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VerticalGraphicsSafePercentage',
                ),
                'perceiveddisplayformatname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PerceivedDisplayFormatName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PerceivedDisplayFormatName',
                ),
                'perceiveddisplayformatcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PerceivedDisplayFormatCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PerceivedDisplayFormatCode',
                ),
                'videocolorkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoColorKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoColorKind',
                ),
                'picturedisplayrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PictureDisplayRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PictureDisplayRate',
                ),
                'videoaveragebitrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoAverageBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoAverageBitrate',
                ),
                'videofixedbitrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoFixedBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoFixedBitrate',
                ),
                'digitalvideofileformat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DigitalVideoFileFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DigitalVideoFileFormat',
                ),
                'codinglawname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CodingLawName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CodingLawName',
                ),
                'audiocodingschemecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioCodingSchemeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioCodingSchemeCode',
                ),
                'audiocodingschemename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AudioCodingSchemeName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AudioCodingSchemeName',
                ),
                'digitalencodingbitrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DigitalEncodingBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DigitalEncodingBitrate',
                ),
                'dataessencecodingid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DataEssenceCodingID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DataEssenceCodingID',
                ),
                'storagekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StorageKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StorageKind',
                ),
                'storagekindcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StorageKindCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StorageKindCode',
                ),
                'tapepartitioncapacity' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TapePartitionCapacity',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TapePartitionCapacity',
                ),
                'discpartitioncapacity' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DiscPartitionCapacity',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DiscPartitionCapacity',
                ),
                'fieldofviewvertical' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FieldOfViewVertical',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FieldOfViewVertical',
                ),
                'systemnameornumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SystemNameOrNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SystemNameOrNumber',
                ),
                'logoflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LogoFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LogoFlag',
                ),
                'graphickind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GraphicKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GraphicKind',
                ),
                'graphicusagekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GraphicUsageKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GraphicUsageKind',
                ),
                'signaturetuneflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SignatureTuneFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SignatureTuneFlag',
                ),
                'backgroundmusicflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BackgroundMusicFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BackgroundMusicFlag',
                ),
                'productionscriptreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProductionScriptReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProductionScriptReference',
                ),
                'transcriptreference' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TranscriptReference',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TranscriptReference',
                ),
                'horizontaldatum' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HorizontalDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HorizontalDatum',
                ),
                'verticaldatum' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VerticalDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VerticalDatum',
                ),
                'cornerlatitudepoint1' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CornerLatitudePoint1',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CornerLatitudePoint1',
                ),
                'cornerlatitudepoint2' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CornerLatitudePoint2',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CornerLatitudePoint2',
                ),
                'cornerlatitudepoint3' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CornerLatitudePoint3',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CornerLatitudePoint3',
                ),
                'cornerlatitudepoint4' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CornerLatitudePoint4',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CornerLatitudePoint4',
                ),
                'cornerlongitudepoint1' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CornerLongitudePoint1',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CornerLongitudePoint1',
                ),
                'cornerlongitudepoint2' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CornerLongitudePoint2',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CornerLongitudePoint2',
                ),
                'cornerlongitudepoint3' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CornerLongitudePoint3',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CornerLongitudePoint3',
                ),
                'cornerlongitudepoint4' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CornerLongitudePoint4',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CornerLongitudePoint4',
                ),
                'subjectdistance' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubjectDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubjectDistance',
                ),
                'objectcountrycodemethod' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectCountryCodeMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectCountryCodeMethod',
                ),
                'countrycodemethod' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CountryCodeMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CountryCodeMethod',
                ),
                'non-usclassifyingcountrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Non-USClassifyingCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NonUSClassifyingCountryCode',
                ),
                'releasablecountrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ReleasableCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ReleasableCountryCode',
                ),
                'objectregionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectRegionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectRegionName',
                ),
                'shootingregionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShootingRegionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShootingRegionName',
                ),
                'settingregionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingRegionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingRegionName',
                ),
                'copyrightlicenseregionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CopyrightLicenseRegionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CopyrightLicenseRegionName',
                ),
                'intellectualpropertylicenseregionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IntellectualPropertyLicenseRegionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IntellectualPropertyLicenseRegionName',
                ),
                'posixmicroseconds' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'POSIXMicroseconds',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\POSIXMicroseconds',
                ),
                'eventelapsedtimetostart' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventElapsedTimeToStart',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventElapsedTimeToStart',
                ),
                'eventelapsedtimetoend' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventElapsedTimeToEnd',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventElapsedTimeToEnd',
                ),
                'organizationidkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OrganizationIDKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OrganizationIDKind',
                ),
                'smpteul' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SMPTEUL',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SMPTEUL',
                ),
                'essencecontainerarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceContainerArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceContainerArray',
                ),
                'essencestreamid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceStreamID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceStreamID',
                ),
                'indexstreamid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IndexStreamID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IndexStreamID',
                ),
                'workingtitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'WorkingTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\WorkingTitle',
                ),
                'originaltitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OriginalTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OriginalTitle',
                ),
                'clipnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClipNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClipNumber',
                ),
                'descriptivemetadatatrackids' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveMetadataTrackIDs',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataTrackIDs',
                ),
                'identifierkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IdentifierKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IdentifierKind',
                ),
                'identifiervalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IdentifierValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IdentifierValue',
                ),
                'organizationcode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OrganizationCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OrganizationCode',
                ),
                'supplieridentificationkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupplierIdentificationKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupplierIdentificationKind',
                ),
                'supplieridentificationvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupplierIdentificationValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupplierIdentificationValue',
                ),
                'supplieraccountnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupplierAccountNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupplierAccountNumber',
                ),
                'supplieraccountname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SupplierAccountName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SupplierAccountName',
                ),
                'episodestartnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EpisodeStartNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EpisodeStartNumber',
                ),
                'episodeendnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EpisodeEndNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EpisodeEndNumber',
                ),
                'purchaseridentificationkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PurchaserIdentificationKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PurchaserIdentificationKind',
                ),
                'purchaseridentificationvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PurchaserIdentificationValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PurchaserIdentificationValue',
                ),
                'purchaseraccountnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PurchaserAccountNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PurchaserAccountNumber',
                ),
                'purchaseraccountname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PurchaserAccountName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PurchaserAccountName',
                ),
                'totalcurrencyamount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TotalCurrencyAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TotalCurrencyAmount',
                ),
                'installmentnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InstallmentNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InstallmentNumber',
                ),
                'identifierissuingauthority' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IdentifierIssuingAuthority',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IdentifierIssuingAuthority',
                ),
                'publishingorganizationname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PublishingOrganizationName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PublishingOrganizationName',
                ),
                'publishingservicename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PublishingServiceName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PublishingServiceName',
                ),
                'publishingmediumname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PublishingMediumName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PublishingMediumName',
                ),
                'publishingregionname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PublishingRegionName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PublishingRegionName',
                ),
                'othergivennames' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OtherGivenNames',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OtherGivenNames',
                ),
                'alternatename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AlternateName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AlternateName',
                ),
                'iso639textlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISO639TextLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISO639TextLanguageCode',
                ),
                'iso639captionslanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ISO639CaptionsLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ISO639CaptionsLanguageCode',
                ),
                'primaryspokenlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PrimarySpokenLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PrimarySpokenLanguageCode',
                ),
                'secondaryspokenlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SecondarySpokenLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SecondarySpokenLanguageCode',
                ),
                'primaryoriginallanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PrimaryOriginalLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PrimaryOriginalLanguageCode',
                ),
                'secondaryoriginallanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SecondaryOriginalLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SecondaryOriginalLanguageCode',
                ),
                'majorversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MajorVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MajorVersion',
                ),
                'minorversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MinorVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MinorVersion',
                ),
                'sectorsize' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SectorSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SectorSize',
                ),
                'elementlength' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ElementLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ElementLength',
                ),
                'keypointkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeypointKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeypointKind',
                ),
                'keypointvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeypointValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeypointValue',
                ),
                'awardname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AwardName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AwardName',
                ),
                'awardcategory' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AwardCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AwardCategory',
                ),
                'slateinformation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SlateInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SlateInformation',
                ),
                'lockedindicator' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LockedIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LockedIndicator',
                ),
                'bitsperaudiosample' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BitsPerAudioSample',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BitsPerAudioSample',
                ),
                'captionkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CaptionKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CaptionKind',
                ),
                'slicecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SliceCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SliceCount',
                ),
                'slicenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SliceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SliceNumber',
                ),
                'elementdelta' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ElementDelta',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ElementDelta',
                ),
                'positiontableindexing' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PositionTableIndexing',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PositionTableIndexing',
                ),
                'sliceoffsetlist' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SliceOffsetList',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SliceOffsetList',
                ),
                'postablearray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PosTableArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PosTableArray',
                ),
                'streamoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StreamOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StreamOffset',
                ),
                'editunitflags' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EditUnitFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EditUnitFlags',
                ),
                'temporaloffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TemporalOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TemporalOffset',
                ),
                'anchoroffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnchorOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnchorOffset',
                ),
                'editunitlength' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EditUnitLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EditUnitLength',
                ),
                'headerbytecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HeaderByteCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HeaderByteCount',
                ),
                'indexbytecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IndexByteCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IndexByteCount',
                ),
                'packlength' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackLength',
                ),
                'primarypackage' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PrimaryPackage',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PrimaryPackage',
                ),
                'descriptivemetadatasets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveMetadataSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataSets',
                ),
                'descriptivemetadatasetreferences' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveMetadataSetReferences',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataSetReferences',
                ),
                'filedescriptors' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FileDescriptors',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FileDescriptors',
                ),
                'offsettometadata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OffsetToMetadata',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OffsetToMetadata',
                ),
                'offsettoindextable' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OffsetToIndexTable',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OffsetToIndexTable',
                ),
                'byteoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ByteOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ByteOffset',
                ),
                'reverseplay' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ReversePlay',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ReversePlay',
                ),
                'firstnumberinsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FirstNumberInSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FirstNumberInSequence',
                ),
                'previousnumberinsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PreviousNumberInSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PreviousNumberInSequence',
                ),
                'currentnumberinsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CurrentNumberInSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CurrentNumberInSequence',
                ),
                'nextnumberinsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NextNumberInSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NextNumberInSequence',
                ),
                'lastnumberinsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LastNumberInSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LastNumberInSequence',
                ),
                'centraltelephonenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CentralTelephoneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CentralTelephoneNumber',
                ),
                'mobiletelephonenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MobileTelephoneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MobileTelephoneNumber',
                ),
                'locationdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocationDescription',
                ),
                'locationkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocationKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocationKind',
                ),
                'keytimepoint' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyTimePoint',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyTimePoint',
                ),
                'settingdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingDateTime',
                ),
                'contractdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractDateTime',
                ),
                'rightsstartdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RightsStartDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RightsStartDateTime',
                ),
                'rightsstopdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RightsStopDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RightsStopDateTime',
                ),
                'paymentduedatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PaymentDueDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PaymentDueDateTime',
                ),
                'clipid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClipID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClipID',
                ),
                'deviceassetnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceAssetNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceAssetNumber',
                ),
                'identificationul' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IdentificationUL',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IdentificationUL',
                ),
                'operationalpatternul' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OperationalPatternUL',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OperationalPatternUL',
                ),
                'essencecontainers' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EssenceContainers',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EssenceContainers',
                ),
                'descriptivemetadataschemes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveMetadataSchemes',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataSchemes',
                ),
                'projectname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProjectName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProjectName',
                ),
                'localtagvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalTagValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalTagValue',
                ),
                'localtaguniqueid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalTagUniqueID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalTagUniqueID',
                ),
                'brandmaintitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BrandMainTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BrandMainTitle',
                ),
                'brandoriginaltitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BrandOriginalTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BrandOriginalTitle',
                ),
                'frameworktitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameworkTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameworkTitle',
                ),
                'sourcetrackids' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceTrackIDs',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceTrackIDs',
                ),
                'shottrackids' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotTrackIDs',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotTrackIDs',
                ),
                'programminggrouptitle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProgrammingGroupTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProgrammingGroupTitle',
                ),
                'linkingname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LinkingName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LinkingName',
                ),
                'namesuffix' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NameSuffix',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NameSuffix',
                ),
                'formerfamilyname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FormerFamilyName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FormerFamilyName',
                ),
                'nationality' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Nationality',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Nationality',
                ),
                'citizenship' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Citizenship',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Citizenship',
                ),
                'frameworktextlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameworkTextLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameworkTextLanguageCode',
                ),
                'kagsize' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KAGSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KAGSize',
                ),
                'reversedbyteorder' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ReversedByteOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ReversedByteOrder',
                ),
                'itemname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ItemName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ItemName',
                ),
                'itemvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ItemValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ItemValue',
                ),
                'xmldocumenttext' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'XMLDocumentText',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\XMLDocumentText',
                ),
                'frameworkthesaurusname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameworkThesaurusName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameworkThesaurusName',
                ),
                'groupsynopsis' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GroupSynopsis',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GroupSynopsis',
                ),
                'annotationsynopsis' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnnotationSynopsis',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnnotationSynopsis',
                ),
                'annotationdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnnotationDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnnotationDescription',
                ),
                'scriptingkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ScriptingKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ScriptingKind',
                ),
                'scriptingtext' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ScriptingText',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ScriptingText',
                ),
                'shotdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotDescription',
                ),
                'annotationkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnnotationKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnnotationKind',
                ),
                'relatedmaterialdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RelatedMaterialDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RelatedMaterialDescription',
                ),
                'clipkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClipKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClipKind',
                ),
                'deviceusagedescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceUsageDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceUsageDescription',
                ),
                'displayf2offset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DisplayF2Offset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DisplayF2Offset',
                ),
                'storedf2offset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StoredF2Offset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StoredF2Offset',
                ),
                'activeformatdescriptor' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ActiveFormatDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ActiveFormatDescriptor',
                ),
                'linenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LineNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LineNumber',
                ),
                'scanningdirection' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ScanningDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ScanningDirection',
                ),
                'componentmaximumref' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComponentMaximumRef',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComponentMaximumRef',
                ),
                'componentminimumref' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComponentMinimumRef',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComponentMinimumRef',
                ),
                'alphamaximumref' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AlphaMaximumRef',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AlphaMaximumRef',
                ),
                'alphaminimumref' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AlphaMinimumRef',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AlphaMinimumRef',
                ),
                'videopayloadidentifier' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoPayloadIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoPayloadIdentifier',
                ),
                'videopayloadidentifier2002' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoPayloadIdentifier2002',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoPayloadIdentifier2002',
                ),
                'singlesequenceflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SingleSequenceFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SingleSequenceFlag',
                ),
                'constantbpictureflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ConstantBPictureFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ConstantBPictureFlag',
                ),
                'codedcontentscanningkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CodedContentScanningKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CodedContentScanningKind',
                ),
                'lowdelayindicator' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LowDelayIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LowDelayIndicator',
                ),
                'closedgopindicator' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClosedGOPIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClosedGOPIndicator',
                ),
                'identicalgopindicator' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IdenticalGOPIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IdenticalGOPIndicator',
                ),
                'maximumgopsize' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaximumGOPSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaximumGOPSize',
                ),
                'maximumbpicturecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MaximumBPictureCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MaximumBPictureCount',
                ),
                'profileandlevel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProfileAndLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProfileAndLevel',
                ),
                'bitrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Bitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Bitrate',
                ),
                'channelcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ChannelCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ChannelCount',
                ),
                'peakenvelope' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakEnvelope',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakEnvelope',
                ),
                'peakenvelopedata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakEnvelopeData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakEnvelopeData',
                ),
                'blockalign' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BlockAlign',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BlockAlign',
                ),
                'sequenceoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SequenceOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SequenceOffset',
                ),
                'blockstartoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BlockStartOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BlockStartOffset',
                ),
                'filesecurityreport' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FileSecurityReport',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FileSecurityReport',
                ),
                'filesecuritywave' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FileSecurityWave',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FileSecurityWave',
                ),
                'averagebytespersecond' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AverageBytesPerSecond',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AverageBytesPerSecond',
                ),
                'auxiliarybitsmode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AuxiliaryBitsMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AuxiliaryBitsMode',
                ),
                'channelstatusmode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ChannelStatusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ChannelStatusMode',
                ),
                'fixedchannelstatusdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FixedChannelStatusData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FixedChannelStatusData',
                ),
                'userdatamode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UserDataMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UserDataMode',
                ),
                'fixeduserdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FixedUserData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FixedUserData',
                ),
                'emphasis' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Emphasis',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Emphasis',
                ),
                'bextcodinghistory' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BextCodingHistory',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BextCodingHistory',
                ),
                'qltybasicdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QltyBasicData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QltyBasicData',
                ),
                'qltystartofmodulation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QltyStartOfModulation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QltyStartOfModulation',
                ),
                'qltyqualityevent' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QltyQualityEvent',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QltyQualityEvent',
                ),
                'qltyendofmodulation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QltyEndOfModulation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QltyEndOfModulation',
                ),
                'qltyqualityparameter' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QltyQualityParameter',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QltyQualityParameter',
                ),
                'qltyoperatorcomment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QltyOperatorComment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QltyOperatorComment',
                ),
                'qltycuesheet' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QltyCueSheet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QltyCueSheet',
                ),
                'dialnorm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DialNorm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DialNorm',
                ),
                'dataessencecoding' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DataEssenceCoding',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DataEssenceCoding',
                ),
                'datetimerate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DateTimeRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DateTimeRate',
                ),
                'datetimedropframeflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DateTimeDropFrameFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DateTimeDropFrameFlag',
                ),
                'datetimeembeddedflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DateTimeEmbeddedFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DateTimeEmbeddedFlag',
                ),
                'datetimekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DateTimeKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DateTimeKind',
                ),
                'deltaentryarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeltaEntryArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeltaEntryArray',
                ),
                'positiontablecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PositionTableCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PositionTableCount',
                ),
                'positiontable' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PositionTable',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PositionTable',
                ),
                'indexentryarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IndexEntryArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IndexEntryArray',
                ),
                'datadefinition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DataDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DataDefinition',
                ),
                'generationcopynumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GenerationCopyNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GenerationCopyNumber',
                ),
                'generationclonenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GenerationCloneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GenerationCloneNumber',
                ),
                'thememusicflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ThemeMusicFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ThemeMusicFlag',
                ),
                'insertmusicflag' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'InsertMusicFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\InsertMusicFlag',
                ),
                'indexeditrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IndexEditRate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IndexEditRate',
                ),
                'linkedtrackid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LinkedTrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LinkedTrackID',
                ),
                'descriptivemetadataframework' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveMetadataFramework',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataFramework',
                ),
                'groupset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GroupSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GroupSet',
                ),
                'bankdetailsset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BankDetailsSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BankDetailsSet',
                ),
                'imageformatset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ImageFormatSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ImageFormatSet',
                ),
                'processingset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProcessingSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProcessingSet',
                ),
                'projectset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProjectSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProjectSet',
                ),
                'contactslistset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContactsListSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContactsListSet',
                ),
                'annotationcuewordsset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnnotationCueWordsSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnnotationCueWordsSet',
                ),
                'shotcuewordsset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotCueWordsSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotCueWordsSet',
                ),
                'awardparticipantsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AwardParticipantSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AwardParticipantSets',
                ),
                'contractparticipantsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractParticipantSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractParticipantSets',
                ),
                'personsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PersonSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PersonSets',
                ),
                'participantorganizationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ParticipantOrganizationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ParticipantOrganizationSets',
                ),
                'personorganizationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PersonOrganizationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PersonOrganizationSets',
                ),
                'locationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocationSets',
                ),
                'titlessets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TitlesSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TitlesSets',
                ),
                'groupsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GroupSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GroupSets',
                ),
                'identificationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IdentificationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IdentificationSets',
                ),
                'episodicitemsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EpisodicItemSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EpisodicItemSets',
                ),
                'brandingsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BrandingSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BrandingSets',
                ),
                'eventsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventSets',
                ),
                'publicationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PublicationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PublicationSets',
                ),
                'awardsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AwardSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AwardSets',
                ),
                'captiondescriptionsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CaptionDescriptionSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CaptionDescriptionSets',
                ),
                'annotationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnnotationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnnotationSets',
                ),
                'productionsettingperiodsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProductionSettingPeriodSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProductionSettingPeriodSets',
                ),
                'scenesettingperiodsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SceneSettingPeriodSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SceneSettingPeriodSets',
                ),
                'scriptingsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ScriptingSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ScriptingSets',
                ),
                'classificationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClassificationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClassificationSets',
                ),
                'sceneshotsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SceneShotSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SceneShotSets',
                ),
                'clipshotsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClipShotSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClipShotSets',
                ),
                'keypointsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KeyPointSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KeyPointSets',
                ),
                'shotparticipantrolesets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotParticipantRoleSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotParticipantRoleSets',
                ),
                'shotpersonsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotPersonSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotPersonSets',
                ),
                'organizationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OrganizationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OrganizationSets',
                ),
                'shotlocationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotLocationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotLocationSets',
                ),
                'addresssets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AddressSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AddressSets',
                ),
                'communicationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CommunicationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CommunicationSets',
                ),
                'contractsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContractSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContractSets',
                ),
                'rightssets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RightsSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RightsSets',
                ),
                'paymentssets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PaymentsSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PaymentsSets',
                ),
                'deviceparameterssets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceParametersSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceParametersSets',
                ),
                'classificationnamevaluesets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClassificationNameValueSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClassificationNameValueSets',
                ),
                'contactnamevaluesets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContactNameValueSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContactNameValueSets',
                ),
                'deviceparameternamevaluesets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DeviceParameterNameValueSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DeviceParameterNameValueSets',
                ),
                'metadataserverlocators' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MetadataServerLocators',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MetadataServerLocators',
                ),
                'relatedmateriallocators' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RelatedMaterialLocators',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RelatedMaterialLocators',
                ),
                'localtagentries' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalTagEntries',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalTagEntries',
                ),
                'totalnumberinsequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TotalNumberInSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TotalNumberInSequence',
                ),
                'roomorsuitename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RoomOrSuiteName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RoomOrSuiteName',
                ),
                'buildingname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BuildingName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BuildingName',
                ),
                'localfestivaldatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LocalFestivalDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LocalFestivalDateTime',
                ),
                'shotstartposition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotStartPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotStartPosition',
                ),
                'indexingstartposition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IndexingStartPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IndexingStartPosition',
                ),
                'eventorigin' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventOrigin',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventOrigin',
                ),
                'settingperioddescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SettingPeriodDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SettingPeriodDescription',
                ),
                'indexduration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IndexDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IndexDuration',
                ),
                'shotduration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ShotDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ShotDuration',
                ),
                'extendedclipid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ExtendedClipID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ExtendedClipID',
                ),
                'clipidarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClipIDArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClipIDArray',
                ),
                'extendedclipidarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ExtendedClipIDArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ExtendedClipIDArray',
                ),
                'tracknumberbatch' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TrackNumberBatch',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TrackNumberBatch',
                ),
                'extendedtextlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ExtendedTextLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ExtendedTextLanguageCode',
                ),
                'extendedcaptionslanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ExtendedCaptionsLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ExtendedCaptionsLanguageCode',
                ),
                'frameworkextendedtextlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameworkExtendedTextLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameworkExtendedTextLanguageCode',
                ),
                'primaryextendedspokenlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PrimaryExtendedSpokenLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PrimaryExtendedSpokenLanguageCode',
                ),
                'secondaryextendedspokenlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SecondaryExtendedSpokenLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SecondaryExtendedSpokenLanguageCode',
                ),
                'originalextendedspokenprimarylanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OriginalExtendedSpokenPrimaryLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OriginalExtendedSpokenPrimaryLanguageCode',
                ),
                'secondaryoriginalextendedspokenlanguagecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SecondaryOriginalExtendedSpokenLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SecondaryOriginalExtendedSpokenLanguageCode',
                ),
                'klvmetadatasequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KLVMetadataSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KLVMetadataSequence',
                ),
                'packageattributes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageAttributes',
                ),
                'componentattributes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComponentAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComponentAttributes',
                ),
                'mpeg7bimdecoderinitframe1' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMDecoderInitFrame1',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame1',
                ),
                'mpeg7bimdecoderinitframe2' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMDecoderInitFrame2',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame2',
                ),
                'mpeg7bimdecoderinitframe3' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMDecoderInitFrame3',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame3',
                ),
                'mpeg7bimdecoderinitframe4' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMDecoderInitFrame4',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame4',
                ),
                'mpeg7bimdecoderinitframe5' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMDecoderInitFrame5',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame5',
                ),
                'mpeg7bimdecoderinitframe6' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMDecoderInitFrame6',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame6',
                ),
                'mpeg7bimdecoderinitframe7' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMDecoderInitFrame7',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame7',
                ),
                'mpeg7bimdecoderinitframe8' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMDecoderInitFrame8',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMDecoderInitFrame8',
                ),
                'mpeg7bimaccessunitframe1' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMAccessUnitFrame1',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame1',
                ),
                'mpeg7bimaccessunitframe2' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMAccessUnitFrame2',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame2',
                ),
                'mpeg7bimaccessunitframe3' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMAccessUnitFrame3',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame3',
                ),
                'mpeg7bimaccessunitframe4' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMAccessUnitFrame4',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame4',
                ),
                'mpeg7bimaccessunitframe5' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMAccessUnitFrame5',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame5',
                ),
                'mpeg7bimaccessunitframe6' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMAccessUnitFrame6',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame6',
                ),
                'mpeg7bimaccessunitframe7' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMAccessUnitFrame7',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame7',
                ),
                'mpeg7bimaccessunitframe8' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEG7BiMAccessUnitFrame8',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEG7BiMAccessUnitFrame8',
                ),
                'componentusercomments' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ComponentUserComments',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ComponentUserComments',
                ),
                'sensormode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SensorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SensorMode',
                ),
                'channelassignment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ChannelAssignment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ChannelAssignment',
                ),
                'contentpackageindexarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContentPackageIndexArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContentPackageIndexArray',
                ),
                'videoindexarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoIndexArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoIndexArray',
                ),
                'approximateimagecontainersize' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApproximateImageContainerSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApproximateImageContainerSize',
                ),
                'metadataencodingschemecode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MetadataEncodingSchemeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MetadataEncodingSchemeCode',
                ),
                'mimemediatype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MIMEMediaType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MIMEMediaType',
                ),
                'fieldofviewverticalfp' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FieldOfViewVerticalFP',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FieldOfViewVerticalFP',
                ),
                'packageusagekind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageUsageKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageUsageKind',
                ),
                'channelid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ChannelID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ChannelID',
                ),
                'channelids' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ChannelIDs',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ChannelIDs',
                ),
                'klvdatatype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KLVDataType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KLVDataType',
                ),
                'klvdataparentproperties' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KLVDataParentProperties',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KLVDataParentProperties',
                ),
                'taggedvalueparentproperties' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TaggedValueParentProperties',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TaggedValueParentProperties',
                ),
                'annotationparticipantsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AnnotationParticipantSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AnnotationParticipantSets',
                ),
                'klvdatadefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'KLVDataDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\KLVDataDefinitions',
                ),
                'taggedvaluedefinitions' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TaggedValueDefinitions',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TaggedValueDefinitions',
                ),
                'addressnamevaluesets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AddressNameValueSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AddressNameValueSets',
                ),
                'nmeadocumenttext' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NMEADocumentText',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NMEADocumentText',
                ),
                'platformrollangle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlatformRollAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlatformRollAngle',
                ),
                'platformpitchangle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlatformPitchAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlatformPitchAngle',
                ),
                'platformheadingangle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlatformHeadingAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlatformHeadingAngle',
                ),
                'addressline' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AddressLine',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AddressLine',
                ),
                'placename' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlaceName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlaceName',
                ),
                'geographicalcoordinates' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GeographicalCoordinates',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GeographicalCoordinates',
                ),
                'astronomicalbodyname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AstronomicalBodyName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AstronomicalBodyName',
                ),
                'timecodearray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimecodeArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimecodeArray',
                ),
                'markin' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MarkIn',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MarkIn',
                ),
                'userposition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UserPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UserPosition',
                ),
                'markout' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MarkOut',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MarkOut',
                ),
                'clipcreationdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClipCreationDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClipCreationDateTime',
                ),
                'videoclipduration' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VideoClipDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VideoClipDuration',
                ),
                'participantid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ParticipantID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ParticipantID',
                ),
                'contactid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ContactID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ContactID',
                ),
                'defaultnamespaceuri' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefaultNamespaceURI',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefaultNamespaceURI',
                ),
                'namespaceuri' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NamespaceURI',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NamespaceURI',
                ),
                'namespaceuris' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NamespaceURIs',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NamespaceURIs',
                ),
                'htmldoctype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HTMLDOCTYPE',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HTMLDOCTYPE',
                ),
                'namespaceprefix' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NamespacePrefix',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NamespacePrefix',
                ),
                'namespaceprefixes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NamespacePrefixes',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NamespacePrefixes',
                ),
                'rightscomment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RightsComment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RightsComment',
                ),
                'nominationcategory' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NominationCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NominationCategory',
                ),
                'peakenvelopeversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakEnvelopeVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakEnvelopeVersion',
                ),
                'peakenvelopeformat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakEnvelopeFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakEnvelopeFormat',
                ),
                'pointsperpeakvalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PointsPerPeakValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PointsPerPeakValue',
                ),
                'peakenvelopeblocksize' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakEnvelopeBlockSize',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakEnvelopeBlockSize',
                ),
                'peakchannelcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakChannelCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakChannelCount',
                ),
                'peakframecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakFrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakFrameCount',
                ),
                'peakofpeaksposition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakOfPeaksPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakOfPeaksPosition',
                ),
                'peakenvelopetimestamp' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PeakEnvelopeTimestamp',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PeakEnvelopeTimestamp',
                ),
                'riffchunkid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RIFFChunkID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RIFFChunkID',
                ),
                'riffchunklength' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RIFFChunkLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RIFFChunkLength',
                ),
                'riffchunkdata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RIFFChunkData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RIFFChunkData',
                ),
                'mimecharset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MIMECharSet',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MIMECharSet',
                ),
                'mimeencoding' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MIMEEncoding',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MIMEEncoding',
                ),
                'monosourcetrackids' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MonoSourceTrackIDs',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MonoSourceTrackIDs',
                ),
                'compositionrendering' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CompositionRendering',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CompositionRendering',
                ),
                'captionsdescriptionparticipantsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CaptionsDescriptionParticipantSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CaptionsDescriptionParticipantSets',
                ),
                'eventannotationsets' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EventAnnotationSets',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EventAnnotationSets',
                ),
                'scriptinglocators' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ScriptingLocators',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ScriptingLocators',
                ),
                'unknownbwfchunks' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UnknownBWFChunks',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UnknownBWFChunks',
                ),
                'cryptographiccontextid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CryptographicContextID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CryptographicContextID',
                ),
                'nitflayertargetid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'NITFLayerTargetID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\NITFLayerTargetID',
                ),
                'rp217datastreampid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RP217DataStreamPID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RP217DataStreamPID',
                ),
                'rp217videostreampid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RP217VideoStreamPID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RP217VideoStreamPID',
                ),
                'cipheralgorithm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CipherAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CipherAlgorithm',
                ),
                'cryptographickeyid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CryptographicKeyID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CryptographicKeyID',
                ),
                'encryptedsourcevalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EncryptedSourceValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EncryptedSourceValue',
                ),
                'micalgorithm' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MICAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MICAlgorithm',
                ),
                'mic' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MIC',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MIC',
                ),
                'jfifmarkerdescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'JFIFMarkerDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\JFIFMarkerDescription',
                ),
                'htmlmetadescription' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HTMLMetaDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HTMLMetaDescription',
                ),
                'colorprimaries' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ColorPrimaries',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ColorPrimaries',
                ),
                'productformat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ProductFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ProductFormat',
                ),
                'sourcelength' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceLength',
                ),
                'sourcecontainerformat' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceContainerFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceContainerFormat',
                ),
                'sourcekey' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceKey',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceKey',
                ),
                'dynamicsourcepackageid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DynamicSourcePackageID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DynamicSourcePackageID',
                ),
                'dynamicsourcetrackids' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DynamicSourceTrackIDs',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DynamicSourceTrackIDs',
                ),
                'sourceindex' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceIndex',
                ),
                'sourcespecies' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceSpecies',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceSpecies',
                ),
                'sourcevalue' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceValue',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceValue',
                ),
                'cryptographiccontextobject' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CryptographicContextObject',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CryptographicContextObject',
                ),
                'mixed' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'mixed',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubDescriptors',
                ),
                'encryptedtrackfileid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EncryptedTrackFileID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EncryptedTrackFileID',
                ),
                'cryptographiccontextlink' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CryptographicContextLink',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CryptographicContextLink',
                ),
                'plaintextoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PlaintextOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PlaintextOffset',
                ),
                'tripletsequencenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TripletSequenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TripletSequenceNumber',
                ),
                'boundingrectangle' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'BoundingRectangle',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\BoundingRectangle',
                ),
                'geographiclocation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GeographicLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GeographicLocation',
                ),
                'geographicpolygoncoordinates' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GeographicPolygonCoordinates',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GeographicPolygonCoordinates',
                ),
                'geographicareanorthwest' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GeographicAreaNorthwest',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GeographicAreaNorthwest',
                ),
                'geographicareasoutheast' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GeographicAreaSoutheast',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GeographicAreaSoutheast',
                ),
                'geographicareasourcedatum' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GeographicAreaSourceDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GeographicAreaSourceDatum',
                ),
                'geographicpolygonsourcedatum' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GeographicPolygonSourceDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GeographicPolygonSourceDatum',
                ),
                'classifyingcountrycode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClassifyingCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClassifyingCountryCode',
                ),
                'utcinstantdatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UTCInstantDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UTCInstantDateTime',
                ),
                'tolerancemode' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ToleranceMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ToleranceMode',
                ),
                'tolerancewindow' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ToleranceWindow',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ToleranceWindow',
                ),
                'toleranceinterpolationmethod' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ToleranceInterpolationMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ToleranceInterpolationMethod',
                ),
                'vbilinecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VBILineCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VBILineCount',
                ),
                'storedvbilinenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StoredVBILineNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StoredVBILineNumber',
                ),
                'vbiwrappingtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VBIWrappingType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VBIWrappingType',
                ),
                'vbipayloadsamplecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VBIPayloadSampleCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VBIPayloadSampleCount',
                ),
                'vbipayloadbytearray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VBIPayloadByteArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VBIPayloadByteArray',
                ),
                'ancpacketcount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ANCPacketCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ANCPacketCount',
                ),
                'storedanclinenumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'StoredANCLineNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\StoredANCLineNumber',
                ),
                'ancwrappingtype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ANCWrappingType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ANCWrappingType',
                ),
                'ancpayloadsamplecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ANCPayloadSampleCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ANCPayloadSampleCount',
                ),
                'ancpayloadbytearray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ANCPayloadByteArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ANCPayloadByteArray',
                ),
                'vbipayloadsamplecoding' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VBIPayloadSampleCoding',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VBIPayloadSampleCoding',
                ),
                'ancpayloadsamplecoding' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ANCPayloadSampleCoding',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ANCPayloadSampleCoding',
                ),
                'rsiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Rsiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Rsiz',
                ),
                'xsiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Xsiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Xsiz',
                ),
                'ysiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Ysiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Ysiz',
                ),
                'xosiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'XOsiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\XOsiz',
                ),
                'yosiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'YOsiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\YOsiz',
                ),
                'xtsiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'XTsiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\XTsiz',
                ),
                'ytsiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'YTsiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\YTsiz',
                ),
                'xtosiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'XTOsiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\XTOsiz',
                ),
                'ytosiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'YTOsiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\YTOsiz',
                ),
                'csiz' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Csiz',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Csiz',
                ),
                'picturecomponentsizing' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PictureComponentSizing',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PictureComponentSizing',
                ),
                'codingstyledefault' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CodingStyleDefault',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CodingStyleDefault',
                ),
                'quantizationdefault' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'QuantizationDefault',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\QuantizationDefault',
                ),
                'mpegaudiobitrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'MPEGAudioBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\MPEGAudioBitrate',
                ),
                'cbestartoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CBEStartOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CBEStartOffset',
                ),
                'vbeendoffset' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VBEEndOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VBEEndOffset',
                ),
                'subdescriptor' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SubDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SubDescriptor',
                ),
                'rootmetadictionary' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RootMetaDictionary',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RootMetaDictionary',
                ),
                'rootpreface' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RootPreface',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RootPreface',
                ),
                'rootobjectdirectory' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RootObjectDirectory',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RootObjectDirectory',
                ),
                'rootformatversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RootFormatVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RootFormatVersion',
                ),
                'framecenterelevation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'FrameCenterElevation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\FrameCenterElevation',
                ),
                'packagemarkinposition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageMarkInPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageMarkInPosition',
                ),
                'packagemarkoutposition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageMarkOutPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageMarkOutPosition',
                ),
                'ad-id' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Ad-ID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AdID',
                ),
                'resourceid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ResourceID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ResourceID',
                ),
                'ancillaryresourceid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AncillaryResourceID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AncillaryResourceID',
                ),
                'applicationschemebatch' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationSchemeBatch',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationSchemeBatch',
                ),
                'registerkind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterKind',
                ),
                'registerversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterVersion',
                ),
                'registereditorname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterEditorName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterEditorName',
                ),
                'registerstatuskind' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterStatusKind',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterStatusKind',
                ),
                'registeritemname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemName',
                ),
                'registeritemdefinition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemDefinition',
                ),
                'registeritemsymbol' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemSymbol',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemSymbol',
                ),
                'registeritemdefiningdocumentname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemDefiningDocumentName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemDefiningDocumentName',
                ),
                'registeritemul' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemUL',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemUL',
                ),
                'registeritemnotes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemNotes',
                ),
                'registeritemintroductionversion' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemIntroductionVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemIntroductionVersion',
                ),
                'registeritemhierarchylevel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemHierarchyLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemHierarchyLevel',
                ),
                'registerentrystatus' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterEntryStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterEntryStatus',
                ),
                'registeraction' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterAction',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterAction',
                ),
                'registerapprovername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterApproverName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterApproverName',
                ),
                'registercreationtime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterCreationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterCreationTime',
                ),
                'registrantname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegistrantName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegistrantName',
                ),
                'registeritemoriginatorname' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemOriginatorName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemOriginatorName',
                ),
                'registerusername' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterUserName',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterUserName',
                ),
                'registerusertime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterUserTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterUserTime',
                ),
                'registeradministrationnotes' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterAdministrationNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterAdministrationNotes',
                ),
                'afdandbardata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'AFDAndBarData',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\AFDAndBarData',
                ),
                'panscaninformation' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PanScanInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PanScanInformation',
                ),
                'vc-1initializationmetadata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1InitializationMetadata',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1InitializationMetadata',
                ),
                'vc-1singlesequence' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1SingleSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1SingleSequence',
                ),
                'vc-1codedcontenttype' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1CodedContentType',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1CodedContentType',
                ),
                'vc-1identicalgop' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1IdenticalGOP',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1IdenticalGOP',
                ),
                'vc-1maximumgop' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1MaximumGOP',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1MaximumGOP',
                ),
                'vc-1bpicturecount' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1BPictureCount',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1BPictureCount',
                ),
                'vc-1averagebitrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1AverageBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1AverageBitrate',
                ),
                'vc-1maximumbitrate' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1MaximumBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1MaximumBitrate',
                ),
                'vc-1profile' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1Profile',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1Profile',
                ),
                'vc-1level' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'VC-1Level',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\VC1Level',
                ),
                'linkedtimecodetrackid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LinkedTimecodeTrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LinkedTimecodeTrackID',
                ),
                'smpte337mdatastreamnumber' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SMPTE337MDataStreamNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SMPTE337MDataStreamNumber',
                ),
                'applicationscheme' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationScheme',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationScheme',
                ),
                'descriptivemetadatascheme' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveMetadataScheme',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataScheme',
                ),
                'ucsencoding' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'UCSEncoding',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\UCSEncoding',
                ),
                'linkedapplicationplug-ininstanceid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LinkedApplicationPlug-InInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LinkedApplicationPlugInInstanceID',
                ),
                'linkeddescriptiveframeworkplug-inid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LinkedDescriptiveFrameworkPlug-InID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LinkedDescriptiveFrameworkPlugInID',
                ),
                'applicationplug-ininstanceid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationPlug-InInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationPlugInInstanceID',
                ),
                'descriptivemetadataplug-inid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveMetadataPlug-InID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataPlugInID',
                ),
                'applicationenvironmentid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationEnvironmentID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationEnvironmentID',
                ),
                'descriptivemetadataapplicationenvironmentid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DescriptiveMetadataApplicationEnvironmentID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DescriptiveMetadataApplicationEnvironmentID',
                ),
                'linkeddescriptiveobjectplug-inid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'LinkedDescriptiveObjectPlug-InID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\LinkedDescriptiveObjectPlugInID',
                ),
                'timebasereferencetrackid' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'TimebaseReferenceTrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\TimebaseReferenceTrackID',
                ),
                'objectclassdefinition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ObjectClassDefinition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ObjectClassDefinition',
                ),
                'applicationplug-inbatch' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationPlug-InBatch',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationPlugInBatch',
                ),
                'packagemarker' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageMarker',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageMarker',
                ),
                'packagetimelinemarkerref' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PackageTimelineMarkerRef',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PackageTimelineMarkerRef',
                ),
                'registeradministrationobject' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterAdministrationObject',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterAdministrationObject',
                ),
                'registerentryadministrationobject' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterEntryAdministrationObject',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterEntryAdministrationObject',
                ),
                'genericpayloads' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'GenericPayloads',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\GenericPayloads',
                ),
                'registerentryarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterEntryArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterEntryArray',
                ),
                'registeradministrationarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterAdministrationArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterAdministrationArray',
                ),
                'applicationinformationarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ApplicationInformationArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ApplicationInformationArray',
                ),
                'registerchildentryarray' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterChildEntryArray',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterChildEntryArray',
                ),
                'registerreleasedatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterReleaseDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterReleaseDateTime',
                ),
                'registeritemstatuschangedatetime' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RegisterItemStatusChangeDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RegisterItemStatusChangeDateTime',
                ),
                'openbodypartition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OpenBodyPartition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OpenBodyPartition',
                ),
                'closedbodypartition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClosedBodyPartition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClosedBodyPartition',
                ),
                'opencompletebodypartition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'OpenCompleteBodyPartition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\OpenCompleteBodyPartition',
                ),
                'closedcompletebodypartition' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'ClosedCompleteBodyPartition',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\ClosedCompleteBodyPartition',
                ),
                'footer' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'Footer',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\Footer',
                ),
                'completefooter' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CompleteFooter',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CompleteFooter',
                ),
                'randomindexmetadatav10' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RandomIndexMetadataV10',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RandomIndexMetadataV10',
                ),
                'randomindexmetadata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'RandomIndexMetadata',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\RandomIndexMetadata',
                ),
                'partitionmetadata' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'PartitionMetadata',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\PartitionMetadata',
                ),
                'sourceclip' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'SourceClip',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\SourceClip',
                ),
                'v10indextablesegment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'V10IndexTableSegment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\V10IndexTableSegment',
                ),
                'indextablesegment' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'IndexTableSegment',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\IndexTableSegment',
                ),
                'defaultobject' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'DefaultObject',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\DefaultObject',
                ),
                'cipheralgorithmaes128cbc' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CipherAlgorithmAES128CBC',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CipherAlgorithmAES128CBC',
                ),
                'hmacalgorithmsha1128' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'HMACAlgorithmSHA1128',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\HMACAlgorithmSHA1128',
                ),
                'encryptedcontainerlabel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'EncryptedContainerLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\EncryptedContainerLabel',
                ),
                'cryptographicframeworklabel' => array(
                    'namespace' => 'MXF',
                    'tagname' => 'CryptographicFrameworkLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\MXF\CryptographicFrameworkLabel',
                ),

            ),
            'matroska' => array(
                'tracktype' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackType',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackType',
                ),
                'chapterstring' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterString',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterString',
                ),
                'videocodecid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'VideoCodecID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\VideoCodecID',
                ),
                'audiocodecid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AudioCodecID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AudioCodecID',
                ),
                'codecid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CodecID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CodecID',
                ),
                'trackdefault' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackDefault',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackDefault',
                ),
                'chaptertracknumber' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterTrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterTrackNumber',
                ),
                'chaptertimestart' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterTimeStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterTimeStart',
                ),
                'chaptertimeend' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterTimeEnd',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterTimeEnd',
                ),
                'cuereftime' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueRefTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueRefTime',
                ),
                'cuerefcluster' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueRefCluster',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueRefCluster',
                ),
                'chapterflaghidden' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterFlagHidden',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterFlagHidden',
                ),
                'videoscantype' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'VideoScanType',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\VideoScanType',
                ),
                'blockduration' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'BlockDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\BlockDuration',
                ),
                'tracklacing' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackLacing',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackLacing',
                ),
                'audiochannels' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AudioChannels',
                ),
                'block' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Block',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Block',
                ),
                'blockvirtual' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'BlockVirtual',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\BlockVirtual',
                ),
                'simpleblock' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SimpleBlock',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SimpleBlock',
                ),
                'codecstate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CodecState',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CodecState',
                ),
                'blockadditional' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'BlockAdditional',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\BlockAdditional',
                ),
                'position' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Position',
                ),
                'codecdecodeall' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CodecDecodeAll',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CodecDecodeAll',
                ),
                'prevsize' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'PrevSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\PrevSize',
                ),
                'encryptedblock' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EncryptedBlock',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EncryptedBlock',
                ),
                'imagewidth' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ImageWidth',
                ),
                'cuetime' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueTime',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AudioSampleRate',
                ),
                'trackused' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackUsed',
                ),
                'imageheight' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ImageHeight',
                ),
                'crc-32' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CRC-32',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CRC32',
                ),
                'blockadditionalid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'BlockAdditionalID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\BlockAdditionalID',
                ),
                'lacenumber' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'LaceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\LaceNumber',
                ),
                'framenumber' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'FrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\FrameNumber',
                ),
                'delay' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Delay',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Delay',
                ),
                'clusterduration' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ClusterDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ClusterDuration',
                ),
                'tracknumber' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackNumber',
                ),
                'timecode' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Timecode',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Timecode',
                ),
                'cuecodecstate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueCodecState',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueCodecState',
                ),
                'cuerefcodecstate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueRefCodecState',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueRefCodecState',
                ),
                'void' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Void',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Void',
                ),
                'blockaddid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'BlockAddID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\BlockAddID',
                ),
                'cueclusterposition' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueClusterPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueClusterPosition',
                ),
                'cuetrack' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueTrack',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueTrack',
                ),
                'referencepriority' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ReferencePriority',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ReferencePriority',
                ),
                'referenceblock' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ReferenceBlock',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ReferenceBlock',
                ),
                'referencevirtual' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ReferenceVirtual',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ReferenceVirtual',
                ),
                'contentcompressionalgorithm' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentCompressionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentCompressionAlgorithm',
                ),
                'contentcompressionsettings' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentCompressionSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentCompressionSettings',
                ),
                'doctype' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'DocType',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\DocType',
                ),
                'doctypereadversion' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'DocTypeReadVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\DocTypeReadVersion',
                ),
                'ebmlversion' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EBMLVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EBMLVersion',
                ),
                'doctypeversion' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'DocTypeVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\DocTypeVersion',
                ),
                'ebmlmaxidlength' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EBMLMaxIDLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EBMLMaxIDLength',
                ),
                'ebmlmaxsizelength' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EBMLMaxSizeLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EBMLMaxSizeLength',
                ),
                'ebmlreadversion' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EBMLReadVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EBMLReadVersion',
                ),
                'chapterlanguage' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterLanguage',
                ),
                'chaptercountry' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterCountry',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterCountry',
                ),
                'segmentfamily' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SegmentFamily',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SegmentFamily',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\DateTimeOriginal',
                ),
                'taglanguage' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagLanguage',
                ),
                'tagdefault' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagDefault',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagDefault',
                ),
                'tagbinary' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagBinary',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagBinary',
                ),
                'tagstring' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagString',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagString',
                ),
                'duration' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Duration',
                ),
                'chapterprocessprivate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterProcessPrivate',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterProcessPrivate',
                ),
                'chapterflagenabled' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterFlagEnabled',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterFlagEnabled',
                ),
                'tagname' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagName',
                ),
                'editionuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EditionUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EditionUID',
                ),
                'editionflaghidden' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EditionFlagHidden',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EditionFlagHidden',
                ),
                'editionflagdefault' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EditionFlagDefault',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EditionFlagDefault',
                ),
                'editionflagordered' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'EditionFlagOrdered',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\EditionFlagOrdered',
                ),
                'attachedfiledata' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AttachedFileData',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AttachedFileData',
                ),
                'attachedfilemimetype' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AttachedFileMIMEType',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AttachedFileMIMEType',
                ),
                'attachedfilename' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AttachedFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AttachedFileName',
                ),
                'attachedfilereferral' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AttachedFileReferral',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AttachedFileReferral',
                ),
                'attachedfiledescription' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AttachedFileDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AttachedFileDescription',
                ),
                'attachedfileuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AttachedFileUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AttachedFileUID',
                ),
                'contentencryptionalgorithm' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentEncryptionAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentEncryptionAlgorithm',
                ),
                'contentencryptionkeyid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentEncryptionKeyID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentEncryptionKeyID',
                ),
                'contentsignature' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentSignature',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentSignature',
                ),
                'contentsignaturekeyid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentSignatureKeyID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentSignatureKeyID',
                ),
                'contentsignaturealgorithm' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentSignatureAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentSignatureAlgorithm',
                ),
                'contentsignaturehashalgorithm' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentSignatureHashAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentSignatureHashAlgorithm',
                ),
                'muxingapp' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'MuxingApp',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\MuxingApp',
                ),
                'contentencodingorder' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentEncodingOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentEncodingOrder',
                ),
                'contentencodingscope' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentEncodingScope',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentEncodingScope',
                ),
                'contentencodingtype' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ContentEncodingType',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ContentEncodingType',
                ),
                'cuerefnumber' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueRefNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueRefNumber',
                ),
                'trackname' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackName',
                ),
                'cueblocknumber' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CueBlockNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CueBlockNumber',
                ),
                'trackoffset' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackOffset',
                ),
                'seekid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SeekID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SeekID',
                ),
                'seekposition' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SeekPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SeekPosition',
                ),
                'stereo3dmode' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Stereo3DMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Stereo3DMode',
                ),
                'cropbottom' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CropBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CropBottom',
                ),
                'displaywidth' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'DisplayWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\DisplayWidth',
                ),
                'displayunit' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'DisplayUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\DisplayUnit',
                ),
                'aspectratiotype' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AspectRatioType',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AspectRatioType',
                ),
                'displayheight' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'DisplayHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\DisplayHeight',
                ),
                'croptop' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CropTop',
                ),
                'cropleft' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CropLeft',
                ),
                'cropright' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CropRight',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CropRight',
                ),
                'trackforced' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackForced',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackForced',
                ),
                'maxblockadditionid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'MaxBlockAdditionID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\MaxBlockAdditionID',
                ),
                'writingapp' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'WritingApp',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\WritingApp',
                ),
                'silenttracknumber' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SilentTrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SilentTrackNumber',
                ),
                'audiobitspersample' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AudioBitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AudioBitsPerSample',
                ),
                'codecprivate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CodecPrivate',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CodecPrivate',
                ),
                'chapterphysicalequivalent' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterPhysicalEquivalent',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterPhysicalEquivalent',
                ),
                'tagchapteruid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagChapterUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagChapterUID',
                ),
                'tagtrackuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagTrackUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagTrackUID',
                ),
                'tagattachmentuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagAttachmentUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagAttachmentUID',
                ),
                'tageditionuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TagEditionUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TagEditionUID',
                ),
                'targettype' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TargetType',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TargetType',
                ),
                'signedelement' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SignedElement',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SignedElement',
                ),
                'tracktranslatetrackid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackTranslateTrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackTranslateTrackID',
                ),
                'tracktranslatecodec' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackTranslateCodec',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackTranslateCodec',
                ),
                'tracktranslateeditionuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackTranslateEditionUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackTranslateEditionUID',
                ),
                'targettypevalue' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TargetTypeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TargetTypeValue',
                ),
                'chapterprocesstime' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterProcessTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterProcessTime',
                ),
                'chapterprocessdata' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterProcessData',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterProcessData',
                ),
                'chapterprocesscodecid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterProcessCodecID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterProcessCodecID',
                ),
                'chaptertranslateid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterTranslateID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterTranslateID',
                ),
                'chaptertranslatecodec' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterTranslateCodec',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterTranslateCodec',
                ),
                'chaptertranslateeditionuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterTranslateEditionUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterTranslateEditionUID',
                ),
                'mincache' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'MinCache',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\MinCache',
                ),
                'maxcache' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'MaxCache',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\MaxCache',
                ),
                'chaptersegmentuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterSegmentUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterSegmentUID',
                ),
                'chaptersegmenteditionuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterSegmentEditionUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterSegmentEditionUID',
                ),
                'trackoverlay' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackOverlay',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackOverlay',
                ),
                'segmentfilename' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SegmentFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SegmentFileName',
                ),
                'segmentuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SegmentUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SegmentUID',
                ),
                'chapteruid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChapterUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChapterUID',
                ),
                'trackuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackUID',
                ),
                'trackattachmentuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackAttachmentUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackAttachmentUID',
                ),
                'outputaudiosamplerate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'OutputAudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\OutputAudioSampleRate',
                ),
                'title' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Title',
                ),
                'channelpositions' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ChannelPositions',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ChannelPositions',
                ),
                'signaturealgo' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SignatureAlgo',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SignatureAlgo',
                ),
                'signaturehash' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SignatureHash',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SignatureHash',
                ),
                'signaturepublickey' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'SignaturePublicKey',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\SignaturePublicKey',
                ),
                'signature' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Signature',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Signature',
                ),
                'tracklanguage' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackLanguage',
                ),
                'tracktimecodescale' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TrackTimecodeScale',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TrackTimecodeScale',
                ),
                'framerate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\FrameRate',
                ),
                'videoframerate' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'VideoFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\VideoFrameRate',
                ),
                'defaultduration' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'DefaultDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\DefaultDuration',
                ),
                'videocodecname' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'VideoCodecName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\VideoCodecName',
                ),
                'audiocodecname' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'AudioCodecName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\AudioCodecName',
                ),
                'codecname' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CodecName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CodecName',
                ),
                'codecdownloadurl' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CodecDownloadURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CodecDownloadURL',
                ),
                'timecodescale' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'TimecodeScale',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\TimecodeScale',
                ),
                'colorspace' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\ColorSpace',
                ),
                'gamma' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'Gamma',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\Gamma',
                ),
                'codecsettings' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CodecSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CodecSettings',
                ),
                'codecinfourl' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'CodecInfoURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\CodecInfoURL',
                ),
                'prevfilename' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'PrevFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\PrevFileName',
                ),
                'prevuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'PrevUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\PrevUID',
                ),
                'nextfilename' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'NextFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\NextFileName',
                ),
                'nextuid' => array(
                    'namespace' => 'Matroska',
                    'tagname' => 'NextUID',
                    'classname' => 'PHPExiftool\Driver\Tag\Matroska\NextUID',
                ),

            ),
            'xmp-mp' => array(
                'regioninfomp' => array(
                    'namespace' => 'XMP-MP',
                    'tagname' => 'RegionInfoMP',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP\RegionInfoMP',
                ),
                'regioninfodateregionsvalid' => array(
                    'namespace' => 'XMP-MP',
                    'tagname' => 'RegionInfoDateRegionsValid',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP\RegionInfoDateRegionsValid',
                ),
                'regioninforegions' => array(
                    'namespace' => 'XMP-MP',
                    'tagname' => 'RegionInfoRegions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP\RegionInfoRegions',
                ),
                'regionpersondisplayname' => array(
                    'namespace' => 'XMP-MP',
                    'tagname' => 'RegionPersonDisplayName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP\RegionPersonDisplayName',
                ),
                'regionpersonemaildigest' => array(
                    'namespace' => 'XMP-MP',
                    'tagname' => 'RegionPersonEmailDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP\RegionPersonEmailDigest',
                ),
                'regionpersonliveidcid' => array(
                    'namespace' => 'XMP-MP',
                    'tagname' => 'RegionPersonLiveIdCID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP\RegionPersonLiveIdCID',
                ),
                'regionpersonsourceid' => array(
                    'namespace' => 'XMP-MP',
                    'tagname' => 'RegionPersonSourceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP\RegionPersonSourceID',
                ),
                'regionrectangle' => array(
                    'namespace' => 'XMP-MP',
                    'tagname' => 'RegionRectangle',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP\RegionRectangle',
                ),

            ),
            'xmp-mp1' => array(
                'panoramicstitchcameramotion' => array(
                    'namespace' => 'XMP-MP1',
                    'tagname' => 'PanoramicStitchCameraMotion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchCameraMotion',
                ),
                'panoramicstitchmaptype' => array(
                    'namespace' => 'XMP-MP1',
                    'tagname' => 'PanoramicStitchMapType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchMapType',
                ),
                'panoramicstitchphi0' => array(
                    'namespace' => 'XMP-MP1',
                    'tagname' => 'PanoramicStitchPhi0',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchPhi0',
                ),
                'panoramicstitchphi1' => array(
                    'namespace' => 'XMP-MP1',
                    'tagname' => 'PanoramicStitchPhi1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchPhi1',
                ),
                'panoramicstitchtheta0' => array(
                    'namespace' => 'XMP-MP1',
                    'tagname' => 'PanoramicStitchTheta0',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchTheta0',
                ),
                'panoramicstitchtheta1' => array(
                    'namespace' => 'XMP-MP1',
                    'tagname' => 'PanoramicStitchTheta1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMP1\PanoramicStitchTheta1',
                ),

            ),
            'microsoft' => array(
                'panoramicstitchversion' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PanoramicStitchVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchVersion',
                ),
                'panoramicstitchcameramotion' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PanoramicStitchCameraMotion',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchCameraMotion',
                ),
                'panoramicstitchmaptype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PanoramicStitchMapType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchMapType',
                ),
                'panoramicstitchtheta0' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PanoramicStitchTheta0',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchTheta0',
                ),
                'panoramicstitchtheta1' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PanoramicStitchTheta1',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchTheta1',
                ),
                'panoramicstitchphi0' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PanoramicStitchPhi0',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchPhi0',
                ),
                'panoramicstitchphi1' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PanoramicStitchPhi1',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PanoramicStitchPhi1',
                ),
                'abstract' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Abstract',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Abstract0',
                ),
                'acquisitiontime' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AcquisitionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AcquisitionTime',
                ),
                'acquisitiontimeday' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AcquisitionTimeDay',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeDay',
                ),
                'acquisitiontimemonth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AcquisitionTimeMonth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeMonth',
                ),
                'acquisitiontimeyear' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AcquisitionTimeYear',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeYear',
                ),
                'acquisitiontimeyearmonth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AcquisitionTimeYearMonth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeYearMonth',
                ),
                'acquisitiontimeyearmonthday' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AcquisitionTimeYearMonthDay',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AcquisitionTimeYearMonthDay',
                ),
                'albumartistsortorder' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AlbumArtistSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AlbumArtistSortOrder',
                ),
                'albumid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AlbumID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AlbumID',
                ),
                'albumidalbumartist' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AlbumIDAlbumArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AlbumIDAlbumArtist',
                ),
                'albumtitlesortorder' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AlbumTitleSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AlbumTitleSortOrder',
                ),
                'alternatesourceurl' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AlternateSourceURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AlternateSourceURL',
                ),
                'audiobitrate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AudioBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AudioBitrate',
                ),
                'audioformat' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AudioFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AudioFormat',
                ),
                'author' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Author',
                ),
                'authorsortorder' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AuthorSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AuthorSortOrder',
                ),
                'averagelevel' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AverageLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AverageLevel',
                ),
                'bitrate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Bitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Bitrate',
                ),
                'buynow' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BuyNow',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BuyNow',
                ),
                'buytickets' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BuyTickets',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BuyTickets',
                ),
                'cdtrackenabled' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CDTrackEnabled',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CDTrackEnabled',
                ),
                'callletters' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CallLetters',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CallLetters',
                ),
                'cameramanufacturer' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CameraManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CameraManufacturer',
                ),
                'cameramodel' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CameraModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CameraModel',
                ),
                'channels' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Channels',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Channels',
                ),
                'comment' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Comment',
                ),
                'contentdistributorduration' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ContentDistributorDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ContentDistributorDuration',
                ),
                'copyright' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Copyright',
                ),
                'count' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Count',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Count',
                ),
                'currentbitrate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CurrentBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CurrentBitrate',
                ),
                'dlnaserverudn' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DLNAServerUDN',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DLNAServerUDN',
                ),
                'dlnasourceuri' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DLNASourceURI',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DLNASourceURI',
                ),
                'drmindividualizedversion' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DRMIndividualizedVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DRMIndividualizedVersion',
                ),
                'drmkeyid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DRMKeyID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DRMKeyID',
                ),
                'dtcpiphost' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DTCPIPHost',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DTCPIPHost',
                ),
                'dtcpipport' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DTCPIPPort',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DTCPIPPort',
                ),
                'dvdid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DVDID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DVDID',
                ),
                'description' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Description',
                ),
                'displayartist' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DisplayArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DisplayArtist',
                ),
                'duration' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Duration',
                ),
                'event' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Event',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Event',
                ),
                'filesize' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FileSize',
                ),
                'filetype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FileType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FileType',
                ),
                'formattag' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FormatTag',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FormatTag',
                ),
                'fourcc' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FourCC',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FourCC',
                ),
                'framerate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FrameRate',
                ),
                'frequency' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Frequency',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Frequency',
                ),
                'isnetworkfeed' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IsNetworkFeed',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IsNetworkFeed',
                ),
                'isvbr' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IsVBR',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IsVBR',
                ),
                'isprotected' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IsProtected',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IsProtected',
                ),
                'leadperformer' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LeadPerformer',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LeadPerformer',
                ),
                'libraryid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LibraryID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LibraryID',
                ),
                'libraryname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LibraryName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LibraryName',
                ),
                'location' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Location',
                ),
                'mediacontenttypes' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MediaContentTypes',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MediaContentTypes',
                ),
                'mediatype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MediaType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MediaType',
                ),
                'modifiedby' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ModifiedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ModifiedBy',
                ),
                'moreinfo' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MoreInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MoreInfo',
                ),
                'partofset' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PartOfSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PartOfSet',
                ),
                'peakvalue' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PeakValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PeakValue',
                ),
                'pixelaspectratiox' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PixelAspectRatioX',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PixelAspectRatioX',
                ),
                'pixelaspectratioy' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PixelAspectRatioY',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PixelAspectRatioY',
                ),
                'playlistindex' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PlaylistIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PlaylistIndex',
                ),
                'provider' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Provider',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Provider',
                ),
                'providerlogourl' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProviderLogoURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProviderLogoURL',
                ),
                'providerurl' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProviderURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProviderURL',
                ),
                'radioband' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RadioBand',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RadioBand',
                ),
                'radioformat' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RadioFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RadioFormat',
                ),
                'ratingorg' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RatingOrg',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RatingOrg',
                ),
                'recordingtime' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RecordingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RecordingTime',
                ),
                'recordingtimeday' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RecordingTimeDay',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RecordingTimeDay',
                ),
                'recordingtimemonth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RecordingTimeMonth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RecordingTimeMonth',
                ),
                'recordingtimeyear' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RecordingTimeYear',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RecordingTimeYear',
                ),
                'recordingtimeyearmonth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RecordingTimeYearMonth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RecordingTimeYearMonth',
                ),
                'recordingtimeyearmonthday' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RecordingTimeYearMonthDay',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RecordingTimeYearMonthDay',
                ),
                'releasedate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ReleaseDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ReleaseDate',
                ),
                'releasedateday' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ReleaseDateDay',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ReleaseDateDay',
                ),
                'releasedatemonth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ReleaseDateMonth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ReleaseDateMonth',
                ),
                'releasedateyear' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ReleaseDateYear',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ReleaseDateYear',
                ),
                'releasedateyearmonth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ReleaseDateYearMonth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ReleaseDateYearMonth',
                ),
                'releasedateyearmonthday' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ReleaseDateYearMonthDay',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ReleaseDateYearMonthDay',
                ),
                'requeststate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RequestState',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RequestState',
                ),
                'shadowfilepath' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ShadowFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ShadowFilePath',
                ),
                'sourceurl' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SourceURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SourceURL',
                ),
                'subject' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Subject',
                ),
                'sync01' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync01',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync01',
                ),
                'sync02' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync02',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync02',
                ),
                'sync03' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync03',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync03',
                ),
                'sync04' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync04',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync04',
                ),
                'sync05' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync05',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync05',
                ),
                'sync06' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync06',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync06',
                ),
                'sync07' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync07',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync07',
                ),
                'sync08' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync08',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync08',
                ),
                'sync09' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync09',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync09',
                ),
                'sync10' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync10',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync10',
                ),
                'sync11' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync11',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync11',
                ),
                'sync12' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync12',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync12',
                ),
                'sync13' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync13',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync13',
                ),
                'sync14' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync14',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync14',
                ),
                'sync15' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync15',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync15',
                ),
                'sync16' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sync16',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sync16',
                ),
                'synconly' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SyncOnly',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SyncOnly',
                ),
                'syncstate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SyncState',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SyncState',
                ),
                'temporary' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Temporary',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Temporary',
                ),
                'title' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Title',
                ),
                'titlesortorder' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TitleSortOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TitleSortOrder',
                ),
                'totalduration' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TotalDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TotalDuration',
                ),
                'trackingid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TrackingID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TrackingID',
                ),
                'usercustom1' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserCustom1',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserCustom1',
                ),
                'usercustom2' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserCustom2',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserCustom2',
                ),
                'usereffectiverating' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserEffectiveRating',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserEffectiveRating',
                ),
                'userlastplayedtime' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserLastPlayedTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserLastPlayedTime',
                ),
                'userplaycount' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserPlayCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserPlayCount',
                ),
                'userplaycountafternoon' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserPlaycountAfternoon',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserPlaycountAfternoon',
                ),
                'userplaycountevening' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserPlaycountEvening',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserPlaycountEvening',
                ),
                'userplaycountmorning' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserPlaycountMorning',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserPlaycountMorning',
                ),
                'userplaycountnight' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserPlaycountNight',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserPlaycountNight',
                ),
                'userplaycountweekday' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserPlaycountWeekday',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserPlaycountWeekday',
                ),
                'userplaycountweekend' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserPlaycountWeekend',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserPlaycountWeekend',
                ),
                'userrating' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserRating',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserRating',
                ),
                'userservicerating' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserServiceRating',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserServiceRating',
                ),
                'videobitrate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'VideoBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\VideoBitrate',
                ),
                'videoformat' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'VideoFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\VideoFormat',
                ),
                'albumartist' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AlbumArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AlbumArtist',
                ),
                'albumcoverurl' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AlbumCoverURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AlbumCoverURL',
                ),
                'albumtitle' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AlbumTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AlbumTitle',
                ),
                'mixed' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'mixed',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BeatsPerMinute',
                ),
                'category' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Category',
                ),
                'composer' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Composer',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Composer',
                ),
                'conductor' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Conductor',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Conductor',
                ),
                'contentdistributor' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ContentDistributor',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ContentDistributor',
                ),
                'contentdistributortype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ContentDistributorType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ContentDistributorType',
                ),
                'contentgroupdescription' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ContentGroupDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ContentGroupDescription',
                ),
                'director' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Director',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Director',
                ),
                'encodingtime' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'EncodingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EncodingTime',
                ),
                'genre' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Genre',
                ),
                'genreid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'GenreID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\GenreID',
                ),
                'initialkey' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'InitialKey',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\InitialKey',
                ),
                'language' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Language',
                ),
                'lyrics' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Lyrics',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Lyrics',
                ),
                'mcdi' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MCDI',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MCDI',
                ),
                'mediaclassprimaryid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MediaClassPrimaryID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MediaClassPrimaryID',
                ),
                'mediaclasssecondaryid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MediaClassSecondaryID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MediaClassSecondaryID',
                ),
                'mediaoriginalbroadcastdatetime' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MediaOriginalBroadcastDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MediaOriginalBroadcastDateTime',
                ),
                'mediaoriginalchannel' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MediaOriginalChannel',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MediaOriginalChannel',
                ),
                'mediastationname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MediaStationName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MediaStationName',
                ),
                'mood' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Mood',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Mood',
                ),
                'originalalbumtitle' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OriginalAlbumTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OriginalAlbumTitle',
                ),
                'originalartist' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OriginalArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OriginalArtist',
                ),
                'originallyricist' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OriginalLyricist',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OriginalLyricist',
                ),
                'parentalrating' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ParentalRating',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ParentalRating',
                ),
                'period' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Period',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Period',
                ),
                'producer' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Producer',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Producer',
                ),
                'protectiontype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProtectionType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProtectionType',
                ),
                'providerrating' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProviderRating',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProviderRating',
                ),
                'providerstyle' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProviderStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProviderStyle',
                ),
                'publisher' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Publisher',
                ),
                'subtitle' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SubTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SubTitle',
                ),
                'subtitledescription' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SubTitleDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SubTitleDescription',
                ),
                'subscriptioncontentid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SubscriptionContentID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SubscriptionContentID',
                ),
                'tracknumber' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TrackNumber',
                ),
                'uniquefileidentifier' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UniqueFileIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UniqueFileIdentifier',
                ),
                'videoframerate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'VideoFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\VideoFrameRate',
                ),
                'videoheight' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'VideoHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\VideoHeight',
                ),
                'videowidth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'VideoWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\VideoWidth',
                ),
                'wmcollectiongroupid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'WMCollectionGroupID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\WMCollectionGroupID',
                ),
                'wmcollectionid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'WMCollectionID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\WMCollectionID',
                ),
                'wmcontentid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'WMContentID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\WMContentID',
                ),
                'wmshadowfilesourcedrmtype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'WMShadowFileSourceDRMType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\WMShadowFileSourceDRMType',
                ),
                'wmshadowfilesourcefiletype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'WMShadowFileSourceFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\WMShadowFileSourceFileType',
                ),
                'writer' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Writer',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Writer',
                ),
                'year' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Year',
                ),
                'chapternum' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ChapterNum',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ChapterNum',
                ),
                'titlenum' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TitleNum',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TitleNum',
                ),
                'resources' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Resources',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Resources',
                ),
                'complete' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Complete',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Complete',
                ),
                'homecountry-region' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomeCountry-Region',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomeCountryRegion',
                ),
                'taskowner' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TaskOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TaskOwner',
                ),
                'maxaperture' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MaxAperture',
                ),
                'optionalattendees' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OptionalAttendees',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OptionalAttendees',
                ),
                'homestreet' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomeStreet',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomeStreet',
                ),
                'requiredattendeeaddresses' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RequiredAttendeeAddresses',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RequiredAttendeeAddresses',
                ),
                'senderaddress' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SenderAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SenderAddress',
                ),
                'fileversion' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FileVersion',
                ),
                'productname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProductName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProductName',
                ),
                'productversion' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProductVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProductVersion',
                ),
                'legaltrademarks' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LegalTrademarks',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LegalTrademarks',
                ),
                'sendername' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SenderName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SenderName',
                ),
                'parentalratingreason' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ParentalRatingReason',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ParentalRatingReason',
                ),
                'firstname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FirstName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FirstName',
                ),
                'dateimported' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateImported',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateImported',
                ),
                'cameramaker' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CameraMaker',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CameraMaker',
                ),
                'orientation' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Orientation',
                ),
                'exposuretime' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ExposureTime',
                ),
                'f-stop' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'F-stop',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FStop',
                ),
                'exposureprogram' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ExposureProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ExposureProgram',
                ),
                'isospeed' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ISOSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ISOSpeed',
                ),
                'datepicturetaken' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DatePictureTaken',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DatePictureTaken',
                ),
                'exposurebias' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ExposureBias',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ExposureBias',
                ),
                'subjectdistance' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SubjectDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SubjectDistance',
                ),
                'meteringmode' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MeteringMode',
                ),
                'lightsource' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LightSource',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LightSource',
                ),
                'flashmode' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FlashMode',
                ),
                'focallength' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FocalLength',
                ),
                'homephone' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomePhone',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomePhone',
                ),
                'primaryphone' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PrimaryPhone',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PrimaryPhone',
                ),
                'cellphone' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CellPhone',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CellPhone',
                ),
                'birthday' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Birthday',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Birthday',
                ),
                'primarye-mail' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PrimaryE-mail',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PrimaryEMail',
                ),
                'jobtitle' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'JobTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\JobTitle',
                ),
                'homecity' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomeCity',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomeCity',
                ),
                'personaltitle' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PersonalTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PersonalTitle',
                ),
                'officelocation' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OfficeLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OfficeLocation',
                ),
                'givenname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'GivenName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\GivenName',
                ),
                'middlename' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MiddleName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MiddleName',
                ),
                'suffix' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Suffix',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Suffix',
                ),
                'nickname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Nickname',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Nickname',
                ),
                'postalcode' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PostalCode',
                ),
                'stationname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'StationName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\StationName',
                ),
                'division' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Division',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Division',
                ),
                'kinds' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Kinds',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Kinds',
                ),
                'clientid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ClientID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ClientID',
                ),
                'type' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Type',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Type',
                ),
                'filecount' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FileCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FileCount',
                ),
                'totalfilesize' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TotalFileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TotalFileSize',
                ),
                'computer' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Computer',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Computer',
                ),
                'perceivedtype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'PerceivedType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\PerceivedType',
                ),
                'dateacquired' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateAcquired',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateAcquired',
                ),
                'mediacreated' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MediaCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MediaCreated',
                ),
                'isrecurring' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IsRecurring',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IsRecurring',
                ),
                'incomplete' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Incomplete',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Incomplete',
                ),
                'e-mail2' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'E-mail2',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EMail2',
                ),
                'project' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Project',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Project',
                ),
                'gender' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Gender',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Gender',
                ),
                'duedate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DueDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DueDate',
                ),
                'businesscity' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessCity',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessCity',
                ),
                'filename' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Filename',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Filename',
                ),
                'datearchived' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateArchived',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateArchived',
                ),
                'businessstateorprovince' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessStateOrProvince',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessStateOrProvince',
                ),
                'broadcastdate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BroadcastDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BroadcastDate',
                ),
                'color' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Color',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Color',
                ),
                'startdate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'StartDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\StartDate',
                ),
                'saturation' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Saturation',
                ),
                'searchranking' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SearchRanking',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SearchRanking',
                ),
                'otheraddress' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OtherAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OtherAddress',
                ),
                'autosummary' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AutoSummary',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AutoSummary',
                ),
                'summary' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Summary',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Summary',
                ),
                'businesshomepage' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessHomePage',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessHomePage',
                ),
                'artist' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Artist',
                ),
                'conductors' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Conductors',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Conductors',
                ),
                'free-busystatus' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Free-busyStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FreeBusyStatus',
                ),
                'url' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\URL',
                ),
                'datevisited' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateVisited',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateVisited',
                ),
                'isdeleted' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IsDeleted',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IsDeleted',
                ),
                'hasflag' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HasFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HasFlag',
                ),
                'hobbies' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Hobbies',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Hobbies',
                ),
                'fullname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FullName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FullName',
                ),
                'street' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Street',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Street',
                ),
                'dimensions' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Dimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Dimensions',
                ),
                'untitled0' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Untitled0',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Untitled0',
                ),
                'untitled1' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Untitled1',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Untitled1',
                ),
                'horizontalresolution' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HorizontalResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HorizontalResolution',
                ),
                'verticalresolution' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'VerticalResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\VerticalResolution',
                ),
                'bitdepth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BitDepth',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AudioSampleRate',
                ),
                'audiosamplesize' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AudioSampleSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AudioSampleSize',
                ),
                'videocompression' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'VideoCompression',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\VideoCompression',
                ),
                'framewidth' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FrameWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FrameWidth',
                ),
                'frameheight' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FrameHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FrameHeight',
                ),
                'totalbitrate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TotalBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TotalBitrate',
                ),
                'datarate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DataRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DataRate',
                ),
                'composers' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Composers',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Composers',
                ),
                'directors' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Directors',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Directors',
                ),
                'producers' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Producers',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Producers',
                ),
                'writers' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Writers',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Writers',
                ),
                'userweburl' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'UserWebURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\UserWebURL',
                ),
                'encodedby' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'EncodedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EncodedBy',
                ),
                'rating' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Rating',
                ),
                'e-mail3' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'E-mail3',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EMail3',
                ),
                'homefax' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomeFax',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomeFax',
                ),
                'source' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Source',
                ),
                'flagcolor' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FlagColor',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FlagColor',
                ),
                'businessphone' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessPhone',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessPhone',
                ),
                'programmode' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProgramMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProgramMode',
                ),
                'offlinestatus' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OfflineStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OfflineStatus',
                ),
                'closedcaptioning' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ClosedCaptioning',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ClosedCaptioning',
                ),
                'rerun' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Rerun',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Rerun',
                ),
                'sap' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SAP',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SAP',
                ),
                'episodename' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'EpisodeName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EpisodeName',
                ),
                'programdescription' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProgramDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProgramDescription',
                ),
                'stationcallsign' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'StationCallSign',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\StationCallSign',
                ),
                'channelnumber' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ChannelNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ChannelNumber',
                ),
                'othercity' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OtherCity',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OtherCity',
                ),
                'otherstateorprovince' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OtherStateOrProvince',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OtherStateOrProvince',
                ),
                'profession' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Profession',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Profession',
                ),
                'datecompleted' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateCompleted',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateCompleted',
                ),
                'remindertime' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ReminderTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ReminderTime',
                ),
                'businessaddress' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessAddress',
                ),
                'organizeraddress' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OrganizerAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OrganizerAddress',
                ),
                'homepobox' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomePOBox',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomePOBox',
                ),
                'e-maillist' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'E-mailList',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EMailList',
                ),
                'companymainphone' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CompanyMainPhone',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CompanyMainPhone',
                ),
                'homepostalcode' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomePostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomePostalCode',
                ),
                'otherpobox' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OtherPOBox',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OtherPOBox',
                ),
                'othercountry-region' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OtherCountry-Region',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OtherCountryRegion',
                ),
                'lastname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LastName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LastName',
                ),
                'carphone' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CarPhone',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CarPhone',
                ),
                'businessfax' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessFax',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessFax',
                ),
                'entrytype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'EntryType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EntryType',
                ),
                'otherpostalcode' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OtherPostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OtherPostalCode',
                ),
                'label' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Label',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Label',
                ),
                'homeaddress' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomeAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomeAddress',
                ),
                'assistantsphone' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AssistantsPhone',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AssistantsPhone',
                ),
                'anniversary' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Anniversary',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Anniversary',
                ),
                'owner' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Owner',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Owner',
                ),
                'spacefree' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SpaceFree',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SpaceFree',
                ),
                'totalsize' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TotalSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TotalSize',
                ),
                'spaceused' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SpaceUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SpaceUsed',
                ),
                'priority' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Priority',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Priority',
                ),
                'hasattachments' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HasAttachments',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HasAttachments',
                ),
                'spouse' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Spouse',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Spouse',
                ),
                'focallength35mm' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FocalLength35mm',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FocalLength35mm',
                ),
                'iscompleted' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IsCompleted',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IsCompleted',
                ),
                'offlineavailability' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OfflineAvailability',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OfflineAvailability',
                ),
                'organizername' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OrganizerName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OrganizerName',
                ),
                'tty-ttdphone' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TTY-TTDPhone',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TTYTTDPhone',
                ),
                'protected' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Protected',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Protected0',
                ),
                'businesscountry-region' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessCountry-Region',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessCountryRegion',
                ),
                'requiredattendees' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'RequiredAttendees',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\RequiredAttendees',
                ),
                'name' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Name',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Name',
                ),
                'size' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Size',
                ),
                'attributes' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Attributes',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Attributes',
                ),
                'datemodified' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateModified',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateModified',
                ),
                'datecreated' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateCreated',
                ),
                'dateaccessed' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateAccessed',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateAccessed',
                ),
                'foldername' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FolderName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FolderName',
                ),
                'linktarget' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LinkTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LinkTarget',
                ),
                'linkstatus' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LinkStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LinkStatus',
                ),
                'businesspobox' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessPOBox',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessPOBox',
                ),
                'todotitle' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ToDoTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ToDoTitle',
                ),
                'callbacknumber' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CallbackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CallbackNumber',
                ),
                'isonline' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IsOnline',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IsOnline',
                ),
                'mailingaddress' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'MailingAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\MailingAddress',
                ),
                'telex' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Telex',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Telex',
                ),
                'enddate' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'EndDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EndDate',
                ),
                'homestateorprovince' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'HomeStateOrProvince',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\HomeStateOrProvince',
                ),
                'city' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'City',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\City',
                ),
                'e-maildisplayname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'E-mailDisplayName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EMailDisplayName',
                ),
                'assistantsname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AssistantsName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AssistantsName',
                ),
                'creator' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Creator',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Creator',
                ),
                'exifversion' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'EXIFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EXIFVersion',
                ),
                'billinginformation' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BillingInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BillingInformation',
                ),
                'children' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Children',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Children',
                ),
                'participants' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Participants',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Participants',
                ),
                'optionalattendeeaddresses' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OptionalAttendeeAddresses',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OptionalAttendeeAddresses',
                ),
                'company' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Company',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Company',
                ),
                'contenttype' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ContentType',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ContentType',
                ),
                'status' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Status',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Status',
                ),
                'slides' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Slides',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Slides',
                ),
                'pager' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Pager',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Pager',
                ),
                'imaddresses' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IMAddresses',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IMAddresses',
                ),
                'folder' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Folder',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Folder',
                ),
                'conversationid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ConversationID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ConversationID',
                ),
                'businessstreet' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessStreet',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessStreet',
                ),
                'datereleased' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateReleased',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateReleased',
                ),
                'pobox' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'POBox',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\POBox',
                ),
                'contactnames' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ContactNames',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ContactNames',
                ),
                'documentid' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DocumentID',
                ),
                'lensmodel' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LensModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LensModel',
                ),
                'businesspostalcode' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BusinessPostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BusinessPostalCode',
                ),
                'readstatus' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ReadStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ReadStatus',
                ),
                'importance' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Importance',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Importance',
                ),
                'flagstatus' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FlagStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FlagStatus',
                ),
                'fromaddresses' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FromAddresses',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FromAddresses',
                ),
                'fromnames' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FromNames',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FromNames',
                ),
                'store' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Store',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Store',
                ),
                'toaddresses' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ToAddresses',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ToAddresses',
                ),
                'tonames' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ToNames',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ToNames',
                ),
                'webpage' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Webpage',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Webpage',
                ),
                'datesent' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateSent',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateSent',
                ),
                'bccaddresses' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BccAddresses',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BccAddresses',
                ),
                'datereceived' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateReceived',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateReceived',
                ),
                'attachments' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Attachments',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Attachments',
                ),
                'bccnames' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'BccNames',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\BccNames',
                ),
                'ccaddresses' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CcAddresses',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CcAddresses',
                ),
                'ccnames' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'CcNames',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CcNames',
                ),
                'folderpath' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FolderPath',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FolderPath',
                ),
                'path' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Path',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Path',
                ),
                'accountname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'AccountName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\AccountName',
                ),
                'country-region' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Country-Region',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\CountryRegion',
                ),
                'lensmaker' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LensMaker',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LensMaker',
                ),
                'whitebalance' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\WhiteBalance',
                ),
                'shared' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Shared',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Shared',
                ),
                'sharedwith' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'SharedWith',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\SharedWith',
                ),
                'stateorprovince' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'StateOrProvince',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\StateOrProvince',
                ),
                'fileas' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'FileAs',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\FileAs',
                ),
                'isattachment' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'IsAttachment',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\IsAttachment',
                ),
                'totaleditingtime' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'TotalEditingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\TotalEditingTime',
                ),
                'lastprinted' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'LastPrinted',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\LastPrinted',
                ),
                'untitled2' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Untitled2',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Untitled2',
                ),
                'datelastsaved' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'DateLastSaved',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\DateLastSaved',
                ),
                'pages' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Pages',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Pages',
                ),
                'wordcount' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'WordCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\WordCount',
                ),
                'programname' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'ProgramName',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\ProgramName',
                ),
                'keywords' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Keywords',
                ),
                'comments' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Comments',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Comments',
                ),
                'contributors' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Contributors',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Contributors',
                ),
                'initials' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Initials',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Initials',
                ),
                'date' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Date',
                ),
                'sensitivity' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Sensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Sensitivity',
                ),
                'e-mailaddress' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'E-mailAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\EMailAddress',
                ),
                'department' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Department',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Department',
                ),
                'mileage' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'Mileage',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\Mileage',
                ),
                'otherstreet' => array(
                    'namespace' => 'Microsoft',
                    'tagname' => 'OtherStreet',
                    'classname' => 'PHPExiftool\Driver\Tag\Microsoft\OtherStreet',
                ),

            ),
            'xmp-microsoft' => array(
                'cameraserialnumber' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'CameraSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\CameraSerialNumber',
                ),
                'dateacquired' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'DateAcquired',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\DateAcquired',
                ),
                'flashmanufacturer' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'FlashManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\FlashManufacturer',
                ),
                'flashmodel' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'FlashModel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\FlashModel',
                ),
                'lastkeywordiptc' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'LastKeywordIPTC',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\LastKeywordIPTC',
                ),
                'lastkeywordxmp' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'LastKeywordXMP',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\LastKeywordXMP',
                ),
                'lensmanufacturer' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'LensManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\LensManufacturer',
                ),
                'lensmodel' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'LensModel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\LensModel',
                ),
                'ratingpercent' => array(
                    'namespace' => 'XMP-microsoft',
                    'tagname' => 'RatingPercent',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMicrosoft\RatingPercent',
                ),

            ),
            'minolta' => array(
                'afsensoractive' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFSensorActive',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFSensorActive',
                ),
                'afstatusactivesensor' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusActiveSensor',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusActiveSensor',
                ),
                'afstatustop-right' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusTop-Right',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusTopRight',
                ),
                'afstatusbottom-right' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusBottom-Right',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusBottomRight',
                ),
                'afstatusbottom' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusBottom',
                ),
                'afstatusmiddlehorizontal' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusMiddleHorizontal',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusMiddleHorizontal',
                ),
                'afstatuscentervertical' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusCenterVertical',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusCenterVertical',
                ),
                'afstatustop' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusTop',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusTop',
                ),
                'afstatustop-left' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusTop-Left',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusTopLeft',
                ),
                'afstatusbottom-left' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusBottom-Left',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusBottomLeft',
                ),
                'focuslocked' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FocusLocked',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FocusLocked',
                ),
                'afpoint' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFPoint',
                ),
                'afmode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFMode',
                ),
                'afstatusleft' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusLeft',
                ),
                'afstatuscenterhorizontal' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusCenterHorizontal',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusCenterHorizontal',
                ),
                'afstatusright' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFStatusRight',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFStatusRight',
                ),
                'afareamode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFAreaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFAreaMode',
                ),
                'exposuremode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ExposureMode',
                ),
                'flashmode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashMode',
                ),
                'whitebalance' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WhiteBalance',
                ),
                'minoltaimagesize' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MinoltaImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MinoltaImageSize',
                ),
                'minoltaquality' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MinoltaQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MinoltaQuality',
                ),
                'drivemode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\DriveMode',
                ),
                'meteringmode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MeteringMode',
                ),
                'iso' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ISO',
                ),
                'exposuretime' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ExposureTime',
                ),
                'fnumber' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FNumber',
                ),
                'macromode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MacroMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MacroMode',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\DigitalZoom',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ExposureCompensation',
                ),
                'bracketstep' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'BracketStep',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\BracketStep',
                ),
                'intervallength' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'IntervalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\IntervalLength',
                ),
                'intervalnumber' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'IntervalNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\IntervalNumber',
                ),
                'focallength' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FocalLength',
                ),
                'focusdistance' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FocusDistance',
                ),
                'flashfired' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashFired',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashFired',
                ),
                'minoltadate' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MinoltaDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MinoltaDate',
                ),
                'minoltatime' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MinoltaTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MinoltaTime',
                ),
                'maxaperture' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MaxAperture',
                ),
                'filenumbermemory' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FileNumberMemory',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FileNumberMemory',
                ),
                'lastfilenumber' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'LastFileNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\LastFileNumber',
                ),
                'colorbalancered' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorBalanceRed',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorBalanceRed',
                ),
                'colorbalancegreen' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorBalanceGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorBalanceGreen',
                ),
                'colorbalanceblue' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorBalanceBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorBalanceBlue',
                ),
                'saturation' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\Saturation',
                ),
                'contrast' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\Contrast',
                ),
                'sharpness' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\Sharpness',
                ),
                'subjectprogram' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SubjectProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SubjectProgram',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashExposureComp',
                ),
                'isosetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ISOSetting',
                ),
                'minoltamodelid' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MinoltaModelID',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MinoltaModelID',
                ),
                'intervalmode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'IntervalMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\IntervalMode',
                ),
                'foldername' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FolderName',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FolderName',
                ),
                'colormode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorMode',
                ),
                'colorfilter' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorFilter',
                ),
                'bwfilter' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'BWFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\BWFilter',
                ),
                'internalflash' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'InternalFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\InternalFlash',
                ),
                'brightness' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'Brightness',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\Brightness',
                ),
                'spotfocuspointx' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SpotFocusPointX',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SpotFocusPointX',
                ),
                'spotfocuspointy' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SpotFocusPointY',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SpotFocusPointY',
                ),
                'widefocuszone' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WideFocusZone',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WideFocusZone',
                ),
                'focusmode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FocusMode',
                ),
                'focusarea' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FocusArea',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FocusArea',
                ),
                'decposition' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'DECPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\DECPosition',
                ),
                'colorprofile' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorProfile',
                ),
                'dataimprint' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'DataImprint',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\DataImprint',
                ),
                'flashmetering' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashMetering',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashMetering',
                ),
                'flash' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\Flash',
                ),
                'colorspace' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorSpace',
                ),
                'freememorycardimages' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FreeMemoryCardImages',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FreeMemoryCardImages',
                ),
                'colortemperature' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorTemperature',
                ),
                'hueadjustment' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'HueAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\HueAdjustment',
                ),
                'rotation' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\Rotation',
                ),
                'picturefinish' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'PictureFinish',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\PictureFinish',
                ),
                'imagenumber' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ImageNumber',
                ),
                'noisereduction' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'NoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\NoiseReduction',
                ),
                'imagestabilization' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ImageStabilization',
                ),
                'afpoints' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFPoints',
                ),
                'imagenumber2' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ImageNumber2',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ImageNumber2',
                ),
                'zonematchingon' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ZoneMatchingOn',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ZoneMatchingOn',
                ),
                'exposurecompensationsetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ExposureCompensationSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ExposureCompensationSetting',
                ),
                'highspeedsync' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'HighSpeedSync',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\HighSpeedSync',
                ),
                'shutterspeedsetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ShutterSpeedSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ShutterSpeedSetting',
                ),
                'aperturesetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ApertureSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ApertureSetting',
                ),
                'drivemode2' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'DriveMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\DriveMode2',
                ),
                'afpointselected' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFPointSelected',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFPointSelected',
                ),
                'flashexposurecompset' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashExposureCompSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashExposureCompSet',
                ),
                'zonematchingmode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ZoneMatchingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ZoneMatchingMode',
                ),
                'dynamicrangeoptimizer' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'DynamicRangeOptimizer',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\DynamicRangeOptimizer',
                ),
                'prioritysetupshutterrelease' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'PrioritySetupShutterRelease',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\PrioritySetupShutterRelease',
                ),
                'selftimertime' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SelfTimerTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SelfTimerTime',
                ),
                'continuousbracketing' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ContinuousBracketing',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ContinuousBracketing',
                ),
                'singleframebracketing' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SingleFrameBracketing',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SingleFrameBracketing',
                ),
                'whitebalancebracketing' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WhiteBalanceBracketing',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WhiteBalanceBracketing',
                ),
                'whitebalancesetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WhiteBalanceSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WhiteBalanceSetting',
                ),
                'presetwhitebalance' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'PresetWhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\PresetWhiteBalance',
                ),
                'colortemperaturesetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorTemperatureSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorTemperatureSetting',
                ),
                'customwbsetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'CustomWBSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\CustomWBSetting',
                ),
                'dynamicrangeoptimizersetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'DynamicRangeOptimizerSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\DynamicRangeOptimizerSetting',
                ),
                'customwbredlevel' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'CustomWBRedLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\CustomWBRedLevel',
                ),
                'customwbgreenlevel' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'CustomWBGreenLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\CustomWBGreenLevel',
                ),
                'customwbbluelevel' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'CustomWBBlueLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\CustomWBBlueLevel',
                ),
                'customwberror' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'CustomWBError',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\CustomWBError',
                ),
                'whitebalancefinetune' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WhiteBalanceFineTune',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WhiteBalanceFineTune',
                ),
                'colorcompensationfilter' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ColorCompensationFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ColorCompensationFilter',
                ),
                'sonyimagesize' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SonyImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SonyImageSize',
                ),
                'sonyquality' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SonyQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SonyQuality',
                ),
                'instantplaybacktime' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'InstantPlaybackTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\InstantPlaybackTime',
                ),
                'instantplaybacksetup' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'InstantPlaybackSetup',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\InstantPlaybackSetup',
                ),
                'eyestartaf' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'EyeStartAF',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\EyeStartAF',
                ),
                'redeyereduction' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'RedEyeReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\RedEyeReduction',
                ),
                'flashdefault' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashDefault',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashDefault',
                ),
                'autobracketorder' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AutoBracketOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AutoBracketOrder',
                ),
                'focusholdbutton' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FocusHoldButton',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FocusHoldButton',
                ),
                'aelbutton' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AELButton',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AELButton',
                ),
                'controldialset' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ControlDialSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ControlDialSet',
                ),
                'exposurecompensationmode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ExposureCompensationMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ExposureCompensationMode',
                ),
                'afassist' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFAssist',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFAssist',
                ),
                'cardshutterlock' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'CardShutterLock',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\CardShutterLock',
                ),
                'lensshutterlock' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'LensShutterLock',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\LensShutterLock',
                ),
                'afareaillumination' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AFAreaIllumination',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AFAreaIllumination',
                ),
                'monitordisplayoff' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MonitorDisplayOff',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MonitorDisplayOff',
                ),
                'recorddisplay' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'RecordDisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\RecordDisplay',
                ),
                'playdisplay' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'PlayDisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\PlayDisplay',
                ),
                'exposureindicator' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ExposureIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ExposureIndicator',
                ),
                'aelexposureindicator' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AELExposureIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AELExposureIndicator',
                ),
                'exposurebracketingindicatorlast' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ExposureBracketingIndicatorLast',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ExposureBracketingIndicatorLast',
                ),
                'meteringoffscaleindicator' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MeteringOffScaleIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MeteringOffScaleIndicator',
                ),
                'flashexposureindicator' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashExposureIndicator',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashExposureIndicator',
                ),
                'flashexposureindicatornext' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashExposureIndicatorNext',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashExposureIndicatorNext',
                ),
                'flashexposureindicatorlast' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashExposureIndicatorLast',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashExposureIndicatorLast',
                ),
                'focusmodeswitch' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FocusModeSwitch',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FocusModeSwitch',
                ),
                'flashtype' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashType',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashType',
                ),
                'aelock' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AELock',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AELock',
                ),
                'batterystate' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'BatteryState',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\BatteryState',
                ),
                'make' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\Make',
                ),
                'softwareversion' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SoftwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SoftwareVersion',
                ),
                'modeltype' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ModelType',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ModelType',
                ),
                'makernoteversion' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MakerNoteVersion',
                ),
                'compressedimagesize' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'CompressedImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\CompressedImageSize',
                ),
                'previewimage' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\PreviewImage',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\PreviewImageStart',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\PreviewImageLength',
                ),
                'scenemode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'SceneMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\SceneMode',
                ),
                'teleconverter' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'Teleconverter',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\Teleconverter',
                ),
                'rawandjpgrecording' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'RawAndJpgRecording',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\RawAndJpgRecording',
                ),
                'zonematching' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ZoneMatching',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ZoneMatching',
                ),
                'lenstype' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\LensType',
                ),
                'minoltacamerasettings2' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MinoltaCameraSettings2',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MinoltaCameraSettings2',
                ),
                'imagestabilizationsetting' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ImageStabilizationSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ImageStabilizationSetting',
                ),
                'dynamicrangeoptimizermode' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'DynamicRangeOptimizerMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\DynamicRangeOptimizerMode',
                ),
                'wbbracketshotnumber' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WBBracketShotNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBracketShotNumber',
                ),
                'exposurebracketshotnumber' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'ExposureBracketShotNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\ExposureBracketShotNumber',
                ),
                'flashfunction' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FlashFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FlashFunction',
                ),
                'averagelv' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AverageLV',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AverageLV',
                ),
                'framenumber' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'FrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\FrameNumber',
                ),
                'wb_rgblevels' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRGBLevels',
                ),
                'wb_gbrglevels' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_GBRGLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBGBRGLevels',
                ),
                'wb_redlevelstungsten' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevelsTungsten',
                ),
                'wb_bluelevelstungsten' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsTungsten',
                ),
                'wb_redlevelsdaylight' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevelsDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevelsDaylight',
                ),
                'wb_bluelevelsdaylight' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevelsDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsDaylight',
                ),
                'wb_redlevelscloudy' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevelsCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevelsCloudy',
                ),
                'wb_bluelevelscloudy' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevelsCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsCloudy',
                ),
                'wb_redlevelsflash' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevelsFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevelsFlash',
                ),
                'wb_bluelevelsflash' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevelsFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsFlash',
                ),
                'wb_redlevelsfluorescent' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevelsFluorescent',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevelsFluorescent',
                ),
                'wb_bluelevelsfluorescent' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevelsFluorescent',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsFluorescent',
                ),
                'wb_redlevelsshade' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevelsShade',
                ),
                'wb_bluelevelsshade' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsShade',
                ),
                'wb_redlevel6500k' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevel6500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevel6500K',
                ),
                'wb_bluelevel6500k' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevel6500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevel6500K',
                ),
                'wb_redlevelcustom' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevelCustom',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevelCustom',
                ),
                'wb_bluelevelcustom' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevelCustom',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevelCustom',
                ),
                'wb_redlevel3500k' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevel3500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevel3500K',
                ),
                'wb_bluelevel3500k' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevel3500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevel3500K',
                ),
                'wb_redlevelskelvin' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RedLevelsKelvin',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRedLevelsKelvin',
                ),
                'wb_bluelevelskelvin' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_BlueLevelsKelvin',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBBlueLevelsKelvin',
                ),
                'wb_rblevelsflash' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevelsFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevelsFlash',
                ),
                'wb_rblevelscoolwhitef' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevelsCoolWhiteF',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevelsCoolWhiteF',
                ),
                'wb_rblevelstungsten' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevelsTungsten',
                ),
                'wb_rblevelsdaylight' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevelsDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevelsDaylight',
                ),
                'wb_rblevelscloudy' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevelsCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevelsCloudy',
                ),
                'wb_rblevelsshade' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevelsShade',
                ),
                'wb_rblevels6500k' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevels6500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevels6500K',
                ),
                'wb_rblevelscustom' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevelsCustom',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevelsCustom',
                ),
                'wb_rblevels3500k' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'WB_RBLevels3500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\WBRBLevels3500K',
                ),
                'aemeteringsegments' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'AEMeteringSegments',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\AEMeteringSegments',
                ),
                'measuredlv' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'MeasuredLV',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\MeasuredLV',
                ),
                'brightnessvalue' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'BrightnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\BrightnessValue',
                ),
                'internalserialnumber' => array(
                    'namespace' => 'Minolta',
                    'tagname' => 'InternalSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Minolta\InternalSerialNumber',
                ),

            ),
            'minoltaraw' => array(
                'firmwareid' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'FirmwareID',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\FirmwareID',
                ),
                'sensorheight' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'SensorHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\SensorHeight',
                ),
                'sensorwidth' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'SensorWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\SensorWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\ImageWidth',
                ),
                'rawdepth' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'RawDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\RawDepth',
                ),
                'bitdepth' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\BitDepth',
                ),
                'storagemethod' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'StorageMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\StorageMethod',
                ),
                'bayerpattern' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'BayerPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\BayerPattern',
                ),
                'saturation' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\Saturation',
                ),
                'contrast' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\Contrast',
                ),
                'sharpness' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\Sharpness',
                ),
                'wbmode' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WBMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBMode',
                ),
                'programmode' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'ProgramMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\ProgramMode',
                ),
                'isosetting' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'ISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\ISOSetting',
                ),
                'colormode' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\ColorMode',
                ),
                'wb_rblevelstungsten' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsTungsten',
                ),
                'wb_rblevelsdaylight' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsDaylight',
                ),
                'wb_rblevelscloudy' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsCloudy',
                ),
                'wb_rblevelscoolwhitef' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsCoolWhiteF',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsCoolWhiteF',
                ),
                'wb_rblevelsflash' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsFlash',
                ),
                'wb_rblevelsunknown' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsUnknown',
                ),
                'wb_rblevelsshade' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsShade',
                ),
                'wb_rblevelsdaylightf' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsDaylightF',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsDaylightF',
                ),
                'wb_rblevelsdaywhitef' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsDayWhiteF',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsDayWhiteF',
                ),
                'wb_rblevelswhitef' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RBLevelsWhiteF',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRBLevelsWhiteF',
                ),
                'colorfilter' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'ColorFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\ColorFilter',
                ),
                'bwfilter' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'BWFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\BWFilter',
                ),
                'zonematching' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'ZoneMatching',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\ZoneMatching',
                ),
                'hue' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'Hue',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\Hue',
                ),
                'colortemperature' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\ColorTemperature',
                ),
                'rawdatalength' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'RawDataLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\RawDataLength',
                ),
                'wbscale' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WBScale',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBScale',
                ),
                'wb_gbrglevels' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_GBRGLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBGBRGLevels',
                ),
                'wb_rggblevels' => array(
                    'namespace' => 'MinoltaRaw',
                    'tagname' => 'WB_RGGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\MinoltaRaw\WBRGGBLevels',
                ),

            ),
            'nikon' => array(
                'afareamode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFAreaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFAreaMode',
                ),
                'afpoint' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFPoint',
                ),
                'afpointsinfocus' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFPointsInFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFPointsInFocus',
                ),
                'afinfo2version' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFInfo2Version',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFInfo2Version',
                ),
                'contrastdetectaf' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ContrastDetectAF',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ContrastDetectAF',
                ),
                'phasedetectaf' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PhaseDetectAF',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PhaseDetectAF',
                ),
                'primaryafpoint' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PrimaryAFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PrimaryAFPoint',
                ),
                'afpointsused' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFPointsUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFPointsUsed',
                ),
                'afimagewidth' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFImageWidth',
                ),
                'afimageheight' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFImageHeight',
                ),
                'afareaxposition' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFAreaXPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFAreaXPosition',
                ),
                'afareayposition' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFAreaYPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFAreaYPosition',
                ),
                'afareawidth' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFAreaWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFAreaWidth',
                ),
                'afareaheight' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFAreaHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFAreaHeight',
                ),
                'contrastdetectafinfocus' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ContrastDetectAFInFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ContrastDetectAFInFocus',
                ),
                'affinetune' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFFineTune',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFFineTune',
                ),
                'affinetuneindex' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFFineTuneIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFFineTuneIndex',
                ),
                'affinetuneadj' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFFineTuneAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFFineTuneAdj',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ThumbnailImage',
                ),
                'previewimage' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PreviewImage',
                ),
                'make' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Make',
                ),
                'model' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Model',
                ),
                'software' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Software',
                ),
                'equipment' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Equipment',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Equipment',
                ),
                'orientation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Orientation',
                ),
                'exposuretime' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExposureTime',
                ),
                'fnumber' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FNumber',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExposureCompensation',
                ),
                'maxaperturevalue' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MaxApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MaxApertureValue',
                ),
                'meteringmode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MeteringMode',
                ),
                'nikon_avitags_0x000d' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Nikon_AVITags_0x000d',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x000d',
                ),
                'nikon_avitags_0x000e' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Nikon_AVITags_0x000e',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x000e',
                ),
                'focallength' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FocalLength',
                ),
                'xresolution' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\XResolution',
                ),
                'yresolution' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\YResolution',
                ),
                'resolutionunit' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ResolutionUnit',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DateTimeOriginal',
                ),
                'createdate' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\CreateDate',
                ),
                'nikon_avitags_0x0015' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Nikon_AVITags_0x0015',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x0015',
                ),
                'duration' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Duration',
                ),
                'nikon_avitags_0x0017' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Nikon_AVITags_0x0017',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x0017',
                ),
                'focusmode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FocusMode',
                ),
                'nikon_avitags_0x0019' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Nikon_AVITags_0x0019',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x0019',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DigitalZoom',
                ),
                'nikon_avitags_0x001c' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Nikon_AVITags_0x001c',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x001c',
                ),
                'colormode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ColorMode',
                ),
                'sharpness' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Sharpness',
                ),
                'whitebalance' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\WhiteBalance',
                ),
                'noisereduction' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NoiseReduction',
                ),
                'nikon_avitags_0x801a' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Nikon_AVITags_0x801a',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonAVITags0x801a',
                ),
                'makernotetype' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MakerNoteType',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MakerNoteType',
                ),
                'makernoteversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MakerNoteVersion',
                ),
                'ifd0_offset' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'IFD0_Offset',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\IFD0Offset',
                ),
                'previewifd_offset' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PreviewIFD_Offset',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PreviewIFDOffset',
                ),
                'subifd_offset' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'SubIFD_Offset',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\SubIFDOffset',
                ),
                'outputimagewidth' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'OutputImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\OutputImageWidth',
                ),
                'outputimageheight' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'OutputImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\OutputImageHeight',
                ),
                'outputresolution' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'OutputResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\OutputResolution',
                ),
                'wb_rbgglevels' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'WB_RBGGLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\WBRBGGLevels',
                ),
                'wb_rggblevels' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'WB_RGGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\WBRGGBLevels',
                ),
                'wb_rgbglevels' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'WB_RGBGLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\WBRGBGLevels',
                ),
                'wb_grbglevels' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'WB_GRBGLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\WBGRBGLevels',
                ),
                'redbalance' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'RedBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\RedBalance',
                ),
                'bluebalance' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'BlueBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\BlueBalance',
                ),
                'distortionversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DistortionVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DistortionVersion',
                ),
                'autodistortioncontrol' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AutoDistortionControl',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AutoDistortionControl',
                ),
                'facedetectframesize' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FaceDetectFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FaceDetectFrameSize',
                ),
                'facesdetected' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FacesDetected',
                ),
                'face1position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face1Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face1Position',
                ),
                'face2position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face2Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face2Position',
                ),
                'face3position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face3Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face3Position',
                ),
                'face4position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face4Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face4Position',
                ),
                'face5position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face5Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face5Position',
                ),
                'face6position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face6Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face6Position',
                ),
                'face7position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face7Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face7Position',
                ),
                'face8position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face8Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face8Position',
                ),
                'face9position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face9Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face9Position',
                ),
                'face10position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face10Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face10Position',
                ),
                'face11position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face11Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face11Position',
                ),
                'face12position' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Face12Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Face12Position',
                ),
                'fileinfoversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FileInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FileInfoVersion',
                ),
                'directorynumber' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DirectoryNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DirectoryNumber',
                ),
                'filenumber' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FileNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FileNumber',
                ),
                'flashinfoversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashInfoVersion',
                ),
                'flashsource' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashSource',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashSource',
                ),
                'externalflashfirmware' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExternalFlashFirmware',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExternalFlashFirmware',
                ),
                'externalflashflags' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExternalFlashFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExternalFlashFlags',
                ),
                'flashcommandermode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashCommanderMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashCommanderMode',
                ),
                'flashcontrolmode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashControlMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashControlMode',
                ),
                'flashoutput' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashOutput',
                ),
                'flashcompensation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashCompensation',
                ),
                'flashfocallength' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashFocalLength',
                ),
                'repeatingflashrate' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'RepeatingFlashRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\RepeatingFlashRate',
                ),
                'repeatingflashcount' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'RepeatingFlashCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\RepeatingFlashCount',
                ),
                'flashgndistance' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGNDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGNDistance',
                ),
                'flashgroupacontrolmode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupAControlMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupAControlMode',
                ),
                'flashgroupbcontrolmode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupBControlMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupBControlMode',
                ),
                'flashgroupaoutput' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupAOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupAOutput',
                ),
                'flashgroupacompensation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupACompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupACompensation',
                ),
                'flashgroupboutput' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupBOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupBOutput',
                ),
                'flashgroupbcompensation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupBCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupBCompensation',
                ),
                'flashgroupccontrolmode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupCControlMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupCControlMode',
                ),
                'flashgroupcoutput' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupCOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupCOutput',
                ),
                'flashgroupccompensation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashGroupCCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashGroupCCompensation',
                ),
                'flashcolorfilter' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashColorFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashColorFilter',
                ),
                'hdr' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'HDR',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\HDR',
                ),
                'hdrlevel' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'HDRLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\HDRLevel',
                ),
                'hdrsmoothing' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'HDRSmoothing',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\HDRSmoothing',
                ),
                'iso' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ISO',
                ),
                'isoexpansion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ISOExpansion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ISOExpansion',
                ),
                'iso2' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ISO2',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ISO2',
                ),
                'isoexpansion2' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ISOExpansion2',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ISOExpansion2',
                ),
                'lensdataversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'LensDataVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\LensDataVersion',
                ),
                'lensidnumber' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'LensIDNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\LensIDNumber',
                ),
                'lensfstops' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'LensFStops',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\LensFStops',
                ),
                'minfocallength' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MinFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MinFocalLength',
                ),
                'maxfocallength' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MaxFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MaxFocalLength',
                ),
                'maxapertureatminfocal' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MaxApertureAtMinFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MaxApertureAtMinFocal',
                ),
                'maxapertureatmaxfocal' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MaxApertureAtMaxFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MaxApertureAtMaxFocal',
                ),
                'mcuversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MCUVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MCUVersion',
                ),
                'exitpupilposition' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExitPupilPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExitPupilPosition',
                ),
                'afaperture' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFAperture',
                ),
                'focusposition' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FocusPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FocusPosition',
                ),
                'focusdistance' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FocusDistance',
                ),
                'effectivemaxaperture' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'EffectiveMaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\EffectiveMaxAperture',
                ),
                'lensmodel' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'LensModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\LensModel',
                ),
                'locationinfoversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'LocationInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\LocationInfoVersion',
                ),
                'textencoding' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'TextEncoding',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\TextEncoding',
                ),
                'countrycode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'CountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\CountryCode',
                ),
                'location' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Location',
                ),
                'quality' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Quality',
                ),
                'flashsetting' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashSetting',
                ),
                'flashtype' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashType',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashType',
                ),
                'whitebalancefinetune' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'WhiteBalanceFineTune',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\WhiteBalanceFineTune',
                ),
                'wb_rblevels' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'WB_RBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\WBRBLevels',
                ),
                'programshift' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ProgramShift',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ProgramShift',
                ),
                'exposuredifference' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExposureDifference',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExposureDifference',
                ),
                'isoselection' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ISOSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ISOSelection',
                ),
                'datadump' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DataDump',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DataDump',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashExposureComp',
                ),
                'isosetting' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ISOSetting',
                ),
                'nrwdata' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NRWData',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NRWData',
                ),
                'imageboundary' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageBoundary',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageBoundary',
                ),
                'externalflashexposurecomp' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExternalFlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExternalFlashExposureComp',
                ),
                'flashexposurebracketvalue' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashExposureBracketValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashExposureBracketValue',
                ),
                'exposurebracketvalue' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExposureBracketValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExposureBracketValue',
                ),
                'imageprocessing' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageProcessing',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageProcessing',
                ),
                'crophispeed' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'CropHiSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\CropHiSpeed',
                ),
                'exposuretuning' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExposureTuning',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExposureTuning',
                ),
                'serialnumber' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\SerialNumber',
                ),
                'colorspace' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ColorSpace',
                ),
                'imageauthentication' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageAuthentication',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageAuthentication',
                ),
                'actived-lighting' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ActiveD-Lighting',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ActiveDLighting',
                ),
                'picturecontroldata' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PictureControlData',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PictureControlData',
                ),
                'vignettecontrol' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'VignetteControl',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\VignetteControl',
                ),
                'imageadjustment' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageAdjustment',
                ),
                'tonecomp' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ToneComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ToneComp',
                ),
                'auxiliarylens' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AuxiliaryLens',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AuxiliaryLens',
                ),
                'lenstype' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\LensType',
                ),
                'lens' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Lens',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Lens',
                ),
                'manualfocusdistance' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ManualFocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ManualFocusDistance',
                ),
                'flashmode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashMode',
                ),
                'shootingmode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ShootingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ShootingMode',
                ),
                'contrastcurve' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ContrastCurve',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ContrastCurve',
                ),
                'colorhue' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ColorHue',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ColorHue',
                ),
                'scenemode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'SceneMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\SceneMode',
                ),
                'lightsource' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'LightSource',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\LightSource',
                ),
                'hueadjustment' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'HueAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\HueAdjustment',
                ),
                'nefcompression' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NEFCompression',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NEFCompression',
                ),
                'saturation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Saturation',
                ),
                'neflinearizationtable' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NEFLinearizationTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NEFLinearizationTable',
                ),
                'colorbalanceunknown' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ColorBalanceUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ColorBalanceUnknown',
                ),
                'rawimagecenter' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'RawImageCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\RawImageCenter',
                ),
                'sensorpixelsize' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'SensorPixelSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\SensorPixelSize',
                ),
                'sceneassist' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'SceneAssist',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\SceneAssist',
                ),
                'retouchhistory' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'RetouchHistory',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\RetouchHistory',
                ),
                'imagedatasize' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageDataSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageDataSize',
                ),
                'imagecount' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageCount',
                ),
                'deletedimagecount' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DeletedImageCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DeletedImageCount',
                ),
                'shuttercount' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ShutterCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ShutterCount',
                ),
                'imageoptimization' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageOptimization',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageOptimization',
                ),
                'variprogram' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'VariProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\VariProgram',
                ),
                'imagestabilization' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageStabilization',
                ),
                'afresponse' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AFResponse',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AFResponse',
                ),
                'highisonoisereduction' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'HighISONoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\HighISONoiseReduction',
                ),
                'toningeffect' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ToningEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ToningEffect',
                ),
                'poweruptime' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PowerUpTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PowerUpTime',
                ),
                'nikoncapturedata' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NikonCaptureData',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonCaptureData',
                ),
                'nikoncaptureversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NikonCaptureVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonCaptureVersion',
                ),
                'nikoncaptureeditversions' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NikonCaptureEditVersions',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonCaptureEditVersions',
                ),
                'nikoniccprofile' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NikonICCProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonICCProfile',
                ),
                'nikoncaptureoutput' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NikonCaptureOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonCaptureOutput',
                ),
                'nefbitdepth' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NEFBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NEFBitDepth',
                ),
                'multiexposureversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MultiExposureVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MultiExposureVersion',
                ),
                'multiexposuremode' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MultiExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MultiExposureMode',
                ),
                'multiexposureshots' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MultiExposureShots',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MultiExposureShots',
                ),
                'multiexposureautogain' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'MultiExposureAutoGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\MultiExposureAutoGain',
                ),
                'framecount' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FrameCount',
                ),
                'framerate' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FrameRate',
                ),
                'framewidth' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FrameWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FrameWidth',
                ),
                'frameheight' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FrameHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FrameHeight',
                ),
                'audiochannels' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AudioChannels',
                ),
                'audiobitspersample' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AudioBitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AudioBitsPerSample',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\AudioSampleRate',
                ),
                'exposureprogram' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ExposureProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ExposureProgram',
                ),
                'gpsversionid' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSVersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSVersionID',
                ),
                'gpslatituderef' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSLatitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSLatitudeRef',
                ),
                'gpslatitude' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSLatitude',
                ),
                'gpslongituderef' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSLongitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSLongitudeRef',
                ),
                'gpslongitude' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSLongitude',
                ),
                'gpsaltituderef' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSAltitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSAltitudeRef',
                ),
                'gpsaltitude' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSAltitude',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSAltitude',
                ),
                'gpstimestamp' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSTimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSTimeStamp',
                ),
                'gpssatellites' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSSatellites',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSSatellites',
                ),
                'gpsimgdirectionref' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSImgDirectionRef',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSImgDirectionRef',
                ),
                'gpsimgdirection' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSImgDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSImgDirection',
                ),
                'gpsmapdatum' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSMapDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSMapDatum',
                ),
                'gpsdatestamp' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'GPSDateStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\GPSDateStamp',
                ),
                'picturecontrolversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PictureControlVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PictureControlVersion',
                ),
                'picturecontrolname' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PictureControlName',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PictureControlName',
                ),
                'picturecontrolbase' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PictureControlBase',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PictureControlBase',
                ),
                'picturecontroladjust' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PictureControlAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PictureControlAdjust',
                ),
                'picturecontrolquickadjust' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PictureControlQuickAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PictureControlQuickAdjust',
                ),
                'contrast' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Contrast',
                ),
                'brightness' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Brightness',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Brightness',
                ),
                'filtereffect' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FilterEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FilterEffect',
                ),
                'toningsaturation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ToningSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ToningSaturation',
                ),
                'shotinfoversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ShotInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ShotInfoVersion',
                ),
                'firmwareversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FirmwareVersion',
                ),
                'distortioncontrol' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DistortionControl',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DistortionControl',
                ),
                'vr_0x66' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'VR_0x66',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\VR0x66',
                ),
                'vibrationreduction' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'VibrationReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\VibrationReduction',
                ),
                'imagearea' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageArea',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageArea',
                ),
                'nikonimagesize' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'NikonImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\NikonImageSize',
                ),
                'imagequality' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'ImageQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\ImageQuality',
                ),
                'preflashreturnstrength' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'PreFlashReturnStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\PreFlashReturnStrength',
                ),
                'rotation' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Rotation',
                ),
                'flashfired' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'FlashFired',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\FlashFired',
                ),
                'ccdsensitivity' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'CCDSensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\CCDSensitivity',
                ),
                'focus' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Focus',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Focus',
                ),
                'converter' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Converter',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Converter',
                ),
                'unknowninfoversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'UnknownInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\UnknownInfoVersion',
                ),
                'unknowninfo2version' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'UnknownInfo2Version',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\UnknownInfo2Version',
                ),
                'vrinfoversion' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'VRInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\VRInfoVersion',
                ),
                'timezone' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'Timezone',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\Timezone',
                ),
                'daylightsavings' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DaylightSavings',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DaylightSavings',
                ),
                'datedisplayformat' => array(
                    'namespace' => 'Nikon',
                    'tagname' => 'DateDisplayFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Nikon\DateDisplayFormat',
                ),

            ),
            'nikonscan' => array(
                'digitalgem' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'DigitalGEM',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\DigitalGEM',
                ),
                'digitalroc' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'DigitalROC',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\DigitalROC',
                ),
                'filmtype' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'FilmType',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\FilmType',
                ),
                'multisample' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'MultiSample',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\MultiSample',
                ),
                'bitdepth' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\BitDepth',
                ),
                'mastergain' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'MasterGain',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\MasterGain',
                ),
                'colorgain' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'ColorGain',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\ColorGain',
                ),
                'scanimageenhancer' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'ScanImageEnhancer',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\ScanImageEnhancer',
                ),
                'digitalice' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'DigitalICE',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\DigitalICE',
                ),
                'digitaldeeshadowadj' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'DigitalDEEShadowAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\DigitalDEEShadowAdj',
                ),
                'digitaldeethreshold' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'DigitalDEEThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\DigitalDEEThreshold',
                ),
                'digitaldeehighlightadj' => array(
                    'namespace' => 'NikonScan',
                    'tagname' => 'DigitalDEEHighlightAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonScan\DigitalDEEHighlightAdj',
                ),

            ),
            'previewifd' => array(
                'subfiletype' => array(
                    'namespace' => 'PreviewIFD',
                    'tagname' => 'SubfileType',
                    'classname' => 'PHPExiftool\Driver\Tag\PreviewIFD\SubfileType',
                ),
                'compression' => array(
                    'namespace' => 'PreviewIFD',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\PreviewIFD\Compression',
                ),
                'xresolution' => array(
                    'namespace' => 'PreviewIFD',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\PreviewIFD\XResolution',
                ),
                'yresolution' => array(
                    'namespace' => 'PreviewIFD',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\PreviewIFD\YResolution',
                ),
                'resolutionunit' => array(
                    'namespace' => 'PreviewIFD',
                    'tagname' => 'ResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\PreviewIFD\ResolutionUnit',
                ),
                'previewimagestart' => array(
                    'namespace' => 'PreviewIFD',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\PreviewIFD\PreviewImageStart',
                ),
                'previewimagelength' => array(
                    'namespace' => 'PreviewIFD',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\PreviewIFD\PreviewImageLength',
                ),
                'ycbcrpositioning' => array(
                    'namespace' => 'PreviewIFD',
                    'tagname' => 'YCbCrPositioning',
                    'classname' => 'PHPExiftool\Driver\Tag\PreviewIFD\YCbCrPositioning',
                ),

            ),
            'nikoncapture' => array(
                'brightnessadj' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'BrightnessAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\BrightnessAdj',
                ),
                'enhancedarktones' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'EnhanceDarkTones',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\EnhanceDarkTones',
                ),
                'colorboosttype' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorBoostType',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorBoostType',
                ),
                'colorboostlevel' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorBoostLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorBoostLevel',
                ),
                'cropleft' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropLeft',
                ),
                'croptop' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropTop',
                ),
                'cropright' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropRight',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropRight',
                ),
                'cropbottom' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropBottom',
                ),
                'cropoutputwidthinches' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropOutputWidthInches',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropOutputWidthInches',
                ),
                'cropoutputheightinches' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropOutputHeightInches',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropOutputHeightInches',
                ),
                'cropscaledresolution' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropScaledResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropScaledResolution',
                ),
                'cropsourceresolution' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropSourceResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropSourceResolution',
                ),
                'cropoutputresolution' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropOutputResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropOutputResolution',
                ),
                'cropoutputscale' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropOutputScale',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropOutputScale',
                ),
                'cropoutputwidth' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropOutputWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropOutputWidth',
                ),
                'cropoutputheight' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropOutputHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropOutputHeight',
                ),
                'cropoutputpixels' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'CropOutputPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\CropOutputPixels',
                ),
                'd-lightinghqshadow' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'D-LightingHQShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\DLightingHQShadow',
                ),
                'd-lightinghqhighlight' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'D-LightingHQHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\DLightingHQHighlight',
                ),
                'd-lightinghqcolorboost' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'D-LightingHQColorBoost',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\DLightingHQColorBoost',
                ),
                'd-lightinghsadjustment' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'D-LightingHSAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\DLightingHSAdjustment',
                ),
                'd-lightinghscolorboost' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'D-LightingHSColorBoost',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\DLightingHSColorBoost',
                ),
                'exposureadj' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ExposureAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ExposureAdj',
                ),
                'exposureadj2' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ExposureAdj2',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ExposureAdj2',
                ),
                'actived-lighting' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ActiveD-Lighting',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ActiveDLighting',
                ),
                'actived-lightingmode' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ActiveD-LightingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ActiveDLightingMode',
                ),
                'shadowprotection' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ShadowProtection',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ShadowProtection',
                ),
                'saturationadj' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'SaturationAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\SaturationAdj',
                ),
                'highlightprotection' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'HighlightProtection',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\HighlightProtection',
                ),
                'lcheditor' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'LCHEditor',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\LCHEditor',
                ),
                'histogramxml' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'HistogramXML',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\HistogramXML',
                ),
                'coloraberrationcontrol' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorAberrationControl',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorAberrationControl',
                ),
                'd-lightinghq' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'D-LightingHQ',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\DLightingHQ',
                ),
                'straightenangle' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'StraightenAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\StraightenAngle',
                ),
                'editversionname' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'EditVersionName',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\EditVersionName',
                ),
                'colorbooster' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorBooster',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorBooster',
                ),
                'd-lightinghqselected' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'D-LightingHQSelected',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\DLightingHQSelected',
                ),
                'noisereduction' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'NoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\NoiseReduction',
                ),
                'unsharpmask' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'UnsharpMask',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\UnsharpMask',
                ),
                'curves' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Curves',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Curves',
                ),
                'colorbalanceadj' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorBalanceAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorBalanceAdj',
                ),
                'advancedraw' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'AdvancedRaw',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\AdvancedRaw',
                ),
                'whitebalanceadj' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'WhiteBalanceAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\WhiteBalanceAdj',
                ),
                'vignettecontrol' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'VignetteControl',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\VignetteControl',
                ),
                'fliphorizontal' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'FlipHorizontal',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\FlipHorizontal',
                ),
                'rotation' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Rotation',
                ),
                'photoeffects' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PhotoEffects',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PhotoEffects',
                ),
                'vignettecontrolintensity' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'VignetteControlIntensity',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\VignetteControlIntensity',
                ),
                'd-lightinghs' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'D-LightingHS',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\DLightingHS',
                ),
                'picturecontrol' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PictureControl',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PictureControl',
                ),
                'photoeffecthistoryxml' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PhotoEffectHistoryXML',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectHistoryXML',
                ),
                'autoredeye' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'AutoRedEye',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\AutoRedEye',
                ),
                'imagedustoff' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ImageDustOff',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ImageDustOff',
                ),
                'edgenoisereduction' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'EdgeNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\EdgeNoiseReduction',
                ),
                'colormoirereductionmode' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorMoireReductionMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorMoireReductionMode',
                ),
                'noisereductionintensity' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'NoiseReductionIntensity',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\NoiseReductionIntensity',
                ),
                'noisereductionsharpness' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'NoiseReductionSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\NoiseReductionSharpness',
                ),
                'noisereductionmethod' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'NoiseReductionMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\NoiseReductionMethod',
                ),
                'colormoirereduction' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorMoireReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorMoireReduction',
                ),
                'colornoisereductionintensity' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorNoiseReductionIntensity',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorNoiseReductionIntensity',
                ),
                'colornoisereductionsharpness' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ColorNoiseReductionSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ColorNoiseReductionSharpness',
                ),
                'photoeffectstype' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PhotoEffectsType',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectsType',
                ),
                'photoeffectsred' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PhotoEffectsRed',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectsRed',
                ),
                'photoeffectsgreen' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PhotoEffectsGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectsGreen',
                ),
                'photoeffectsblue' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PhotoEffectsBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PhotoEffectsBlue',
                ),
                'picturecontrolactive' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PictureControlActive',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PictureControlActive',
                ),
                'picturecontrolmode' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'PictureControlMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\PictureControlMode',
                ),
                'quickadjust' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'QuickAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\QuickAdjust',
                ),
                'sharpeningadj' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'SharpeningAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\SharpeningAdj',
                ),
                'contrastadj' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'ContrastAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\ContrastAdj',
                ),
                'hueadj' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'HueAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\HueAdj',
                ),
                'redeyecorrection' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'RedEyeCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\RedEyeCorrection',
                ),
                'unsharpcount' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'UnsharpCount',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\UnsharpCount',
                ),
                'unsharp1color' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp1Color',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp1Color',
                ),
                'unsharp1intensity' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp1Intensity',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp1Intensity',
                ),
                'unsharp1halowidth' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp1HaloWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp1HaloWidth',
                ),
                'unsharp1threshold' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp1Threshold',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp1Threshold',
                ),
                'unsharp2color' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp2Color',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp2Color',
                ),
                'unsharp2intensity' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp2Intensity',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp2Intensity',
                ),
                'unsharp2halowidth' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp2HaloWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp2HaloWidth',
                ),
                'unsharp2threshold' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp2Threshold',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp2Threshold',
                ),
                'unsharp3color' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp3Color',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp3Color',
                ),
                'unsharp3intensity' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp3Intensity',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp3Intensity',
                ),
                'unsharp3halowidth' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp3HaloWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp3HaloWidth',
                ),
                'unsharp3threshold' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp3Threshold',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp3Threshold',
                ),
                'unsharp4color' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp4Color',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp4Color',
                ),
                'unsharp4intensity' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp4Intensity',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp4Intensity',
                ),
                'unsharp4halowidth' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp4HaloWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp4HaloWidth',
                ),
                'unsharp4threshold' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'Unsharp4Threshold',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\Unsharp4Threshold',
                ),
                'wbadjredbalance' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'WBAdjRedBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\WBAdjRedBalance',
                ),
                'wbadjbluebalance' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'WBAdjBlueBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\WBAdjBlueBalance',
                ),
                'wbadjmode' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'WBAdjMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\WBAdjMode',
                ),
                'wbadjlightingsubtype' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'WBAdjLightingSubtype',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\WBAdjLightingSubtype',
                ),
                'wbadjlighting' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'WBAdjLighting',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\WBAdjLighting',
                ),
                'wbadjtemperature' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'WBAdjTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\WBAdjTemperature',
                ),
                'wbadjtint' => array(
                    'namespace' => 'NikonCapture',
                    'tagname' => 'WBAdjTint',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCapture\WBAdjTint',
                ),

            ),
            'nikoncustom' => array(
                'customsettingsbank' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CustomSettingsBank',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CustomSettingsBank',
                ),
                'customsettingsalldefault' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CustomSettingsAllDefault',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CustomSettingsAllDefault',
                ),
                'af-cpriorityselection' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AF-CPrioritySelection',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFCPrioritySelection',
                ),
                'af-spriorityselection' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AF-SPrioritySelection',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFSPrioritySelection',
                ),
                'afpointselection' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AFPointSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFPointSelection',
                ),
                'dynamicafarea' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'DynamicAFArea',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\DynamicAFArea',
                ),
                'focustrackinglockon' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FocusTrackingLockOn',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FocusTrackingLockOn',
                ),
                'afactivation' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AFActivation',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFActivation',
                ),
                'focuspointwrap' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FocusPointWrap',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FocusPointWrap',
                ),
                'afpointillumination' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AFPointIllumination',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFPointIllumination',
                ),
                'afpointbrightness' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AFPointBrightness',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFPointBrightness',
                ),
                'afassist' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AFAssist',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFAssist',
                ),
                'afonbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AFOnButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFOnButton',
                ),
                'verticalafonbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'VerticalAFOnButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\VerticalAFOnButton',
                ),
                'af-onformb-d10' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AF-OnForMB-D10',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFOnForMBD10',
                ),
                'assignbktbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AssignBktButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AssignBktButton',
                ),
                'multiselectorliveview' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MultiSelectorLiveView',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MultiSelectorLiveView',
                ),
                'initialzoomliveview' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'InitialZoomLiveView',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\InitialZoomLiveView',
                ),
                'isostepsize' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ISOStepSize',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ISOStepSize',
                ),
                'exposurecontrolstepsize' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ExposureControlStepSize',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ExposureControlStepSize',
                ),
                'exposurecompstepsize' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ExposureCompStepSize',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ExposureCompStepSize',
                ),
                'easyexposurecompensation' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'EasyExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\EasyExposureCompensation',
                ),
                'centerweightedareasize' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CenterWeightedAreaSize',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CenterWeightedAreaSize',
                ),
                'finetuneoptcenterweighted' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FineTuneOptCenterWeighted',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FineTuneOptCenterWeighted',
                ),
                'finetuneoptmatrixmetering' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FineTuneOptMatrixMetering',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FineTuneOptMatrixMetering',
                ),
                'finetuneoptspotmetering' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FineTuneOptSpotMetering',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FineTuneOptSpotMetering',
                ),
                'multiselectorshootmode' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MultiSelectorShootMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MultiSelectorShootMode',
                ),
                'multiselectorplaybackmode' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MultiSelectorPlaybackMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MultiSelectorPlaybackMode',
                ),
                'initialzoomsetting' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'InitialZoomSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\InitialZoomSetting',
                ),
                'multiselector' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MultiSelector',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MultiSelector',
                ),
                'exposuredelaymode' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ExposureDelayMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ExposureDelayMode',
                ),
                'clmodeshootingspeed' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CLModeShootingSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CLModeShootingSpeed',
                ),
                'chmodeshootingspeed' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CHModeShootingSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CHModeShootingSpeed',
                ),
                'maxcontinuousrelease' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MaxContinuousRelease',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MaxContinuousRelease',
                ),
                'reverseindicators' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ReverseIndicators',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ReverseIndicators',
                ),
                'filenumbersequence' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FileNumberSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FileNumberSequence',
                ),
                'reardisplay' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'RearDisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\RearDisplay',
                ),
                'viewfinderdisplay' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ViewfinderDisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ViewfinderDisplay',
                ),
                'batteryorder' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'BatteryOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\BatteryOrder',
                ),
                'mb-d10batteries' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MB-D10Batteries',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MBD10Batteries',
                ),
                'screentips' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ScreenTips',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ScreenTips',
                ),
                'beep' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'Beep',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\Beep',
                ),
                'shootinginfodisplay' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ShootingInfoDisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ShootingInfoDisplay',
                ),
                'griddisplay' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'GridDisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\GridDisplay',
                ),
                'viewfinderwarning' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ViewfinderWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ViewfinderWarning',
                ),
                'previewbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'PreviewButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\PreviewButton',
                ),
                'funcbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FuncButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FuncButton',
                ),
                'previewbuttonplusdials' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'PreviewButtonPlusDials',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\PreviewButtonPlusDials',
                ),
                'funcbuttonplusdials' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FuncButtonPlusDials',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FuncButtonPlusDials',
                ),
                'aelockbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AELockButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AELockButton',
                ),
                'aelockbuttonplusdials' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AELockButtonPlusDials',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AELockButtonPlusDials',
                ),
                'commanddialsreverserotation' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommandDialsReverseRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommandDialsReverseRotation',
                ),
                'commanddialschangemainsub' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommandDialsChangeMainSub',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommandDialsChangeMainSub',
                ),
                'commanddialsaperturesetting' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommandDialsApertureSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommandDialsApertureSetting',
                ),
                'commanddialsmenuandplayback' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommandDialsMenuAndPlayback',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommandDialsMenuAndPlayback',
                ),
                'lcdillumination' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'LCDIllumination',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\LCDIllumination',
                ),
                'photoinfoplayback' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'PhotoInfoPlayback',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\PhotoInfoPlayback',
                ),
                'shutterreleasebuttonae-l' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ShutterReleaseButtonAE-L',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ShutterReleaseButtonAEL',
                ),
                'releasebuttontousedial' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ReleaseButtonToUseDial',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ReleaseButtonToUseDial',
                ),
                'selftimertime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'SelfTimerTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\SelfTimerTime',
                ),
                'monitorofftime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MonitorOffTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MonitorOffTime',
                ),
                'flashsyncspeed' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FlashSyncSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FlashSyncSpeed',
                ),
                'flashshutterspeed' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FlashShutterSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FlashShutterSpeed',
                ),
                'autobracketset' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AutoBracketSet',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AutoBracketSet',
                ),
                'autobracketmodem' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AutoBracketModeM',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AutoBracketModeM',
                ),
                'autobracketorder' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AutoBracketOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AutoBracketOrder',
                ),
                'modelingflash' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ModelingFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ModelingFlash',
                ),
                'nomemorycard' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'NoMemoryCard',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\NoMemoryCard',
                ),
                'meteringtime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MeteringTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MeteringTime',
                ),
                'internalflash' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'InternalFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\InternalFlash',
                ),
                'imagereview' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ImageReview',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ImageReview',
                ),
                'autoiso' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AutoISO',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AutoISO',
                ),
                'autoisomax' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AutoISOMax',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AutoISOMax',
                ),
                'autoisominshutterspeed' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AutoISOMinShutterSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AutoISOMinShutterSpeed',
                ),
                'imagereviewtime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ImageReviewTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ImageReviewTime',
                ),
                'remoteonduration' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'RemoteOnDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\RemoteOnDuration',
                ),
                'aelock' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AELock',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AELock',
                ),
                'shootingmodesetting' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ShootingModeSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ShootingModeSetting',
                ),
                'timerfunctionbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'TimerFunctionButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\TimerFunctionButton',
                ),
                'metering' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'Metering',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\Metering',
                ),
                'manualflashoutput' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ManualFlashOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ManualFlashOutput',
                ),
                'flashlevel' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FlashLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FlashLevel',
                ),
                'focusmodesetting' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FocusModeSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FocusModeSetting',
                ),
                'afareamodesetting' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AFAreaModeSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFAreaModeSetting',
                ),
                'isodisplay' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ISODisplay',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ISODisplay',
                ),
                'rangefinder' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'RangeFinder',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\RangeFinder',
                ),
                'dateimprint' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'DateImprint',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\DateImprint',
                ),
                'evstepsize' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'EVStepSize',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\EVStepSize',
                ),
                'selftimershotcount' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'SelfTimerShotCount',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\SelfTimerShotCount',
                ),
                'playbackmenustime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'PlaybackMenusTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\PlaybackMenusTime',
                ),
                'liveviewaf' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'LiveViewAF',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\LiveViewAF',
                ),
                'playbackmonitorofftime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'PlaybackMonitorOffTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\PlaybackMonitorOffTime',
                ),
                'menumonitorofftime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MenuMonitorOffTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MenuMonitorOffTime',
                ),
                'shootinginfomonitorofftime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ShootingInfoMonitorOffTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ShootingInfoMonitorOffTime',
                ),
                'mb-d10batterytype' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MB-D10BatteryType',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MBD10BatteryType',
                ),
                'flashcontrolbuilt-in' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FlashControlBuilt-in',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FlashControlBuiltIn',
                ),
                'repeatingflashoutput' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'RepeatingFlashOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\RepeatingFlashOutput',
                ),
                'repeatingflashcount' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'RepeatingFlashCount',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\RepeatingFlashCount',
                ),
                'repeatingflashrate' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'RepeatingFlashRate',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\RepeatingFlashRate',
                ),
                'commanderinternalttlchannel' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderInternalTTLChannel',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLChannel',
                ),
                'commanderinternalttlcompbuiltin' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderInternalTTLCompBuiltin',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLCompBuiltin',
                ),
                'commanderinternalttlcompgroupa' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderInternalTTLCompGroupA',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLCompGroupA',
                ),
                'commanderinternalttlcompgroupb' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderInternalTTLCompGroupB',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLCompGroupB',
                ),
                'numberoffocuspoints' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'NumberOfFocusPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\NumberOfFocusPoints',
                ),
                'af-onformb-d11' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AF-OnForMB-D11',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFOnForMBD11',
                ),
                'mb-d11batterytype' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MB-D11BatteryType',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MBD11BatteryType',
                ),
                'beeppitch' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'BeepPitch',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\BeepPitch',
                ),
                'beepvolume' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'BeepVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\BeepVolume',
                ),
                'exposurecontrolstep' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ExposureControlStep',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ExposureControlStep',
                ),
                'isosensitivitystep' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'ISOSensitivityStep',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\ISOSensitivityStep',
                ),
                'okbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'OKButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\OKButton',
                ),
                'selftimerinterval' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'SelfTimerInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\SelfTimerInterval',
                ),
                'liveviewmonitorofftime' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'LiveViewMonitorOffTime',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\LiveViewMonitorOffTime',
                ),
                'flashwarning' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FlashWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FlashWarning',
                ),
                'liveviewafareamode' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'LiveViewAFAreaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\LiveViewAFAreaMode',
                ),
                'liveviewafmode' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'LiveViewAFMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\LiveViewAFMode',
                ),
                'illumination' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'Illumination',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\Illumination',
                ),
                'maindialexposurecomp' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MainDialExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MainDialExposureComp',
                ),
                'commanddials' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommandDials',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommandDials',
                ),
                'functionbutton' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FunctionButton',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FunctionButton',
                ),
                'mb-d80batteries' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MB-D80Batteries',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MBD80Batteries',
                ),
                'autofp' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AutoFP',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AutoFP',
                ),
                'commanderchannel' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderChannel',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderChannel',
                ),
                'commanderinternalflash' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderInternalFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalFlash',
                ),
                'commandergroupamode' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderGroupAMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupAMode',
                ),
                'commandergroupbmode' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderGroupBMode',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupBMode',
                ),
                'commanderinternalttlcomp' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderInternalTTLComp',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalTTLComp',
                ),
                'commanderinternalmanualoutput' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderInternalManualOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderInternalManualOutput',
                ),
                'commandergroupa_ttl-aacomp' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderGroupA_TTL-AAComp',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupATTLAAComp',
                ),
                'commandergroupamanualoutput' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderGroupAManualOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupAManualOutput',
                ),
                'commandergroupb_ttl-aacomp' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderGroupB_TTL-AAComp',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupBTTLAAComp',
                ),
                'commandergroupbmanualoutput' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderGroupBManualOutput',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupBManualOutput',
                ),
                'centerafarea' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CenterAFArea',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CenterAFArea',
                ),
                'focusareaselection' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'FocusAreaSelection',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\FocusAreaSelection',
                ),
                'afareaillumination' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AFAreaIllumination',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AFAreaIllumination',
                ),
                'lightswitch' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'LightSwitch',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\LightSwitch',
                ),
                'centerfocuspoint' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CenterFocusPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CenterFocusPoint',
                ),
                'aelockformb-d80' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'AELockForMB-D80',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\AELockForMBD80',
                ),
                'mb-d80batterytype' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'MB-D80BatteryType',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\MBD80BatteryType',
                ),
                'easyexposurecomp' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'EasyExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\EasyExposureComp',
                ),
                'commandergroupa_ttlcomp' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderGroupA_TTLComp',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupATTLComp',
                ),
                'commandergroupb_ttlcomp' => array(
                    'namespace' => 'NikonCustom',
                    'tagname' => 'CommanderGroupB_TTLComp',
                    'classname' => 'PHPExiftool\Driver\Tag\NikonCustom\CommanderGroupBTTLComp',
                ),

            ),
            'xml' => array(
                'appversion' => array(
                    'namespace' => 'XML',
                    'tagname' => 'AppVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\AppVersion',
                ),
                'application' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Application',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Application',
                ),
                'characters' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Characters',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Characters',
                ),
                'characterswithspaces' => array(
                    'namespace' => 'XML',
                    'tagname' => 'CharactersWithSpaces',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\CharactersWithSpaces',
                ),
                'checkedby' => array(
                    'namespace' => 'XML',
                    'tagname' => 'CheckedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\CheckedBy',
                ),
                'client' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Client',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Client',
                ),
                'company' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Company',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Company',
                ),
                'datecompleted' => array(
                    'namespace' => 'XML',
                    'tagname' => 'DateCompleted',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\DateCompleted',
                ),
                'department' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Department',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Department',
                ),
                'destination' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Destination',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Destination',
                ),
                'disposition' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Disposition',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Disposition',
                ),
                'division' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Division',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Division',
                ),
                'docsecurity' => array(
                    'namespace' => 'XML',
                    'tagname' => 'DocSecurity',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\DocSecurity',
                ),
                'documentnumber' => array(
                    'namespace' => 'XML',
                    'tagname' => 'DocumentNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\DocumentNumber',
                ),
                'editor' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Editor',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Editor',
                ),
                'forwardto' => array(
                    'namespace' => 'XML',
                    'tagname' => 'ForwardTo',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\ForwardTo',
                ),
                'group' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Group',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Group',
                ),
                'headingpairs' => array(
                    'namespace' => 'XML',
                    'tagname' => 'HeadingPairs',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\HeadingPairs',
                ),
                'hiddenslides' => array(
                    'namespace' => 'XML',
                    'tagname' => 'HiddenSlides',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\HiddenSlides',
                ),
                'hyperlinkbase' => array(
                    'namespace' => 'XML',
                    'tagname' => 'HyperlinkBase',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\HyperlinkBase',
                ),
                'hyperlinkschanged' => array(
                    'namespace' => 'XML',
                    'tagname' => 'HyperlinksChanged',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\HyperlinksChanged',
                ),
                'language' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Language',
                ),
                'lines' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Lines',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Lines',
                ),
                'linksuptodate' => array(
                    'namespace' => 'XML',
                    'tagname' => 'LinksUpToDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\LinksUpToDate',
                ),
                'mmclips' => array(
                    'namespace' => 'XML',
                    'tagname' => 'MMClips',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\MMClips',
                ),
                'mailstop' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Mailstop',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Mailstop',
                ),
                'manager' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Manager',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Manager',
                ),
                'matter' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Matter',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Matter',
                ),
                'notes' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Notes',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Notes',
                ),
                'office' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Office',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Office',
                ),
                'owner' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Owner',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Owner',
                ),
                'pages' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Pages',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Pages',
                ),
                'paragraphs' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Paragraphs',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Paragraphs',
                ),
                'presentationformat' => array(
                    'namespace' => 'XML',
                    'tagname' => 'PresentationFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\PresentationFormat',
                ),
                'project' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Project',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Project',
                ),
                'publisher' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Publisher',
                ),
                'purpose' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Purpose',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Purpose',
                ),
                'receivedfrom' => array(
                    'namespace' => 'XML',
                    'tagname' => 'ReceivedFrom',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\ReceivedFrom',
                ),
                'recordedby' => array(
                    'namespace' => 'XML',
                    'tagname' => 'RecordedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\RecordedBy',
                ),
                'recordeddate' => array(
                    'namespace' => 'XML',
                    'tagname' => 'RecordedDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\RecordedDate',
                ),
                'reference' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Reference',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Reference',
                ),
                'scalecrop' => array(
                    'namespace' => 'XML',
                    'tagname' => 'ScaleCrop',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\ScaleCrop',
                ),
                'shareddoc' => array(
                    'namespace' => 'XML',
                    'tagname' => 'SharedDoc',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\SharedDoc',
                ),
                'slides' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Slides',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Slides',
                ),
                'source' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Source',
                ),
                'status' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Status',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Status',
                ),
                'telephonenumber' => array(
                    'namespace' => 'XML',
                    'tagname' => 'TelephoneNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\TelephoneNumber',
                ),
                'template' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Template',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Template',
                ),
                'titlesofparts' => array(
                    'namespace' => 'XML',
                    'tagname' => 'TitlesOfParts',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\TitlesOfParts',
                ),
                'totaledittime' => array(
                    'namespace' => 'XML',
                    'tagname' => 'TotalEditTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\TotalEditTime',
                ),
                'typist' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Typist',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Typist',
                ),
                'words' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Words',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Words',
                ),
                'category' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Category',
                ),
                'createdate' => array(
                    'namespace' => 'XML',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\CreateDate',
                ),
                'createdtype' => array(
                    'namespace' => 'XML',
                    'tagname' => 'CreatedType',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\CreatedType',
                ),
                'keywords' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Keywords',
                ),
                'lastmodifiedby' => array(
                    'namespace' => 'XML',
                    'tagname' => 'LastModifiedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\LastModifiedBy',
                ),
                'lastprinted' => array(
                    'namespace' => 'XML',
                    'tagname' => 'LastPrinted',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\LastPrinted',
                ),
                'modifydate' => array(
                    'namespace' => 'XML',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\ModifyDate',
                ),
                'modifiedtype' => array(
                    'namespace' => 'XML',
                    'tagname' => 'ModifiedType',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\ModifiedType',
                ),
                'revisionnumber' => array(
                    'namespace' => 'XML',
                    'tagname' => 'RevisionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\RevisionNumber',
                ),
                'author' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Author',
                ),
                'comment' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Comment',
                ),
                'copyright' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Copyright',
                ),
                'projects' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Projects',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Projects',
                ),
                'title' => array(
                    'namespace' => 'XML',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\XML\Title',
                ),

            ),
            'olympus' => array(
                'make' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Make',
                ),
                'model' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Model',
                ),
                'fnumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FNumber',
                ),
                'datetime1' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DateTime1',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DateTime1',
                ),
                'datetime2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DateTime2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DateTime2',
                ),
                'camerasettingsversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CameraSettingsVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CameraSettingsVersion',
                ),
                'previewimagevalid' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PreviewImageValid',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PreviewImageValid',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PreviewImageStart',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PreviewImageLength',
                ),
                'exposuremode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExposureMode',
                ),
                'aelock' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AELock',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AELock',
                ),
                'meteringmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MeteringMode',
                ),
                'exposureshift' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExposureShift',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExposureShift',
                ),
                'macromode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MacroMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MacroMode',
                ),
                'focusmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocusMode',
                ),
                'focusprocess' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocusProcess',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocusProcess',
                ),
                'afsearch' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AFSearch',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AFSearch',
                ),
                'afareas' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AFAreas',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AFAreas',
                ),
                'afpointselected' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AFPointSelected',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AFPointSelected',
                ),
                'affinetune' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AFFineTune',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AFFineTune',
                ),
                'affinetuneadj' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AFFineTuneAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AFFineTuneAdj',
                ),
                'flashmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashMode',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashExposureComp',
                ),
                'flashremotecontrol' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashRemoteControl',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashRemoteControl',
                ),
                'flashcontrolmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashControlMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashControlMode',
                ),
                'flashintensity' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashIntensity',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashIntensity',
                ),
                'manualflashstrength' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ManualFlashStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ManualFlashStrength',
                ),
                'whitebalance2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WhiteBalance2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WhiteBalance2',
                ),
                'whitebalancetemperature' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WhiteBalanceTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WhiteBalanceTemperature',
                ),
                'whitebalancebracket' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WhiteBalanceBracket',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WhiteBalanceBracket',
                ),
                'customsaturation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CustomSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CustomSaturation',
                ),
                'modifiedsaturation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ModifiedSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ModifiedSaturation',
                ),
                'contrastsetting' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ContrastSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ContrastSetting',
                ),
                'sharpnesssetting' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SharpnessSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SharpnessSetting',
                ),
                'colorspace' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ColorSpace',
                ),
                'scenemode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SceneMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SceneMode',
                ),
                'noisereduction' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'NoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\NoiseReduction',
                ),
                'distortioncorrection' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DistortionCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DistortionCorrection',
                ),
                'shadingcompensation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ShadingCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ShadingCompensation',
                ),
                'compressionfactor' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CompressionFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CompressionFactor',
                ),
                'gradation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Gradation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Gradation',
                ),
                'picturemode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PictureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PictureMode',
                ),
                'picturemodesaturation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PictureModeSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PictureModeSaturation',
                ),
                'picturemodehue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PictureModeHue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PictureModeHue',
                ),
                'picturemodecontrast' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PictureModeContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PictureModeContrast',
                ),
                'picturemodesharpness' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PictureModeSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PictureModeSharpness',
                ),
                'picturemodebwfilter' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PictureModeBWFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PictureModeBWFilter',
                ),
                'picturemodetone' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PictureModeTone',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PictureModeTone',
                ),
                'noisefilter' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'NoiseFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\NoiseFilter',
                ),
                'artfilter' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ArtFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ArtFilter',
                ),
                'magicfilter' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MagicFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MagicFilter',
                ),
                'picturemodeeffect' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PictureModeEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PictureModeEffect',
                ),
                'artfiltereffect' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ArtFilterEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ArtFilterEffect',
                ),
                'drivemode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DriveMode',
                ),
                'panoramamode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PanoramaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PanoramaMode',
                ),
                'imagequality2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ImageQuality2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ImageQuality2',
                ),
                'imagestabilization' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ImageStabilization',
                ),
                'manometerpressure' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ManometerPressure',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ManometerPressure',
                ),
                'manometerreading' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ManometerReading',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ManometerReading',
                ),
                'extendedwbdetect' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExtendedWBDetect',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExtendedWBDetect',
                ),
                'levelgaugeroll' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LevelGaugeRoll',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LevelGaugeRoll',
                ),
                'levelgaugepitch' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LevelGaugePitch',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LevelGaugePitch',
                ),
                'equipmentversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'EquipmentVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\EquipmentVersion',
                ),
                'cameratype2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CameraType2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CameraType2',
                ),
                'serialnumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SerialNumber',
                ),
                'internalserialnumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'InternalSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\InternalSerialNumber',
                ),
                'focalplanediagonal' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocalPlaneDiagonal',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocalPlaneDiagonal',
                ),
                'bodyfirmwareversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'BodyFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\BodyFirmwareVersion',
                ),
                'lenstype' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LensType',
                ),
                'lensserialnumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LensSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LensSerialNumber',
                ),
                'lensmodel' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LensModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LensModel',
                ),
                'lensfirmwareversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LensFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LensFirmwareVersion',
                ),
                'maxapertureatminfocal' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MaxApertureAtMinFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MaxApertureAtMinFocal',
                ),
                'maxapertureatmaxfocal' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MaxApertureAtMaxFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MaxApertureAtMaxFocal',
                ),
                'minfocallength' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MinFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MinFocalLength',
                ),
                'maxfocallength' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MaxFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MaxFocalLength',
                ),
                'maxaperture' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MaxAperture',
                ),
                'lensproperties' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LensProperties',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LensProperties',
                ),
                'extender' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Extender',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Extender',
                ),
                'extenderserialnumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExtenderSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExtenderSerialNumber',
                ),
                'extendermodel' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExtenderModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExtenderModel',
                ),
                'extenderfirmwareversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExtenderFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExtenderFirmwareVersion',
                ),
                'conversionlens' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ConversionLens',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ConversionLens',
                ),
                'flashtype' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashType',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashType',
                ),
                'flashmodel' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashModel',
                ),
                'flashfirmwareversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashFirmwareVersion',
                ),
                'flashserialnumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashSerialNumber',
                ),
                'focusinfoversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocusInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocusInfoVersion',
                ),
                'autofocus' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AutoFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AutoFocus',
                ),
                'scenedetect' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SceneDetect',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SceneDetect',
                ),
                'scenearea' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SceneArea',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SceneArea',
                ),
                'scenedetectdata' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SceneDetectData',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SceneDetectData',
                ),
                'zoomstepcount' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ZoomStepCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ZoomStepCount',
                ),
                'focusstepcount' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocusStepCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocusStepCount',
                ),
                'focusstepinfinity' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocusStepInfinity',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocusStepInfinity',
                ),
                'focusstepnear' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocusStepNear',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocusStepNear',
                ),
                'focusdistance' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocusDistance',
                ),
                'afpoint' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AFPoint',
                ),
                'externalflash' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlash',
                ),
                'externalflashguidenumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashGuideNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashGuideNumber',
                ),
                'externalflashbounce' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashBounce',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashBounce',
                ),
                'externalflashzoom' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashZoom',
                ),
                'internalflash' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'InternalFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\InternalFlash',
                ),
                'manualflash' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ManualFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ManualFlash',
                ),
                'macroled' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MacroLED',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MacroLED',
                ),
                'sensortemperature' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SensorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SensorTemperature',
                ),
                'imageprocessingversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ImageProcessingVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ImageProcessingVersion',
                ),
                'wb_rblevels' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels',
                ),
                'wb_rblevels3000k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels3000K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels3000K',
                ),
                'wb_rblevels3300k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels3300K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels3300K',
                ),
                'wb_rblevels3600k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels3600K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels3600K',
                ),
                'wb_rblevels3900k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels3900K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels3900K',
                ),
                'wb_rblevels4000k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels4000K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels4000K',
                ),
                'wb_rblevels4300k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels4300K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels4300K',
                ),
                'wb_rblevels4500k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels4500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels4500K',
                ),
                'wb_rblevels4800k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels4800K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels4800K',
                ),
                'wb_rblevels5300k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels5300K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels5300K',
                ),
                'wb_rblevels6000k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels6000K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels6000K',
                ),
                'wb_rblevels6600k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels6600K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels6600K',
                ),
                'wb_rblevels7500k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevels7500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevels7500K',
                ),
                'wb_rblevelscwb1' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsCWB1',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCWB1',
                ),
                'wb_rblevelscwb2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsCWB2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCWB2',
                ),
                'wb_rblevelscwb3' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsCWB3',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCWB3',
                ),
                'wb_rblevelscwb4' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsCWB4',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCWB4',
                ),
                'wb_glevel3000k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel3000K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel3000K',
                ),
                'wb_glevel3300k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel3300K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel3300K',
                ),
                'wb_glevel3600k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel3600K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel3600K',
                ),
                'wb_glevel3900k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel3900K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel3900K',
                ),
                'wb_glevel4000k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel4000K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel4000K',
                ),
                'wb_glevel4300k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel4300K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel4300K',
                ),
                'wb_glevel4500k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel4500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel4500K',
                ),
                'wb_glevel4800k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel4800K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel4800K',
                ),
                'wb_glevel5300k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel5300K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel5300K',
                ),
                'wb_glevel6000k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel6000K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel6000K',
                ),
                'wb_glevel6600k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel6600K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel6600K',
                ),
                'wb_glevel7500k' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel7500K',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel7500K',
                ),
                'wb_glevel' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_GLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBGLevel',
                ),
                'colormatrix' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ColorMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ColorMatrix',
                ),
                'enhancer' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Enhancer',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Enhancer',
                ),
                'enhancervalues' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'EnhancerValues',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\EnhancerValues',
                ),
                'coringfilter' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CoringFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CoringFilter',
                ),
                'coringvalues' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CoringValues',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CoringValues',
                ),
                'blacklevel2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'BlackLevel2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\BlackLevel2',
                ),
                'gainbase' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'GainBase',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\GainBase',
                ),
                'validbits' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ValidBits',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ValidBits',
                ),
                'cropleft' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CropLeft',
                ),
                'croptop' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CropTop',
                ),
                'cropwidth' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CropWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CropWidth',
                ),
                'cropheight' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CropHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CropHeight',
                ),
                'noisereduction2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'NoiseReduction2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\NoiseReduction2',
                ),
                'distortioncorrection2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DistortionCorrection2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DistortionCorrection2',
                ),
                'shadingcompensation2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ShadingCompensation2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ShadingCompensation2',
                ),
                'multipleexposuremode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MultipleExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MultipleExposureMode',
                ),
                'unknownblock' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'UnknownBlock',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\UnknownBlock',
                ),
                'aspectratio' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AspectRatio',
                ),
                'aspectframe' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AspectFrame',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AspectFrame',
                ),
                'facesdetected' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FacesDetected',
                ),
                'facedetectarea' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FaceDetectArea',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FaceDetectArea',
                ),
                'maxfaces' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MaxFaces',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MaxFaces',
                ),
                'facedetectframesize' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FaceDetectFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FaceDetectFrameSize',
                ),
                'facedetectframecrop' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FaceDetectFrameCrop',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FaceDetectFrameCrop',
                ),
                'exposureunknown' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExposureUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExposureUnknown',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExposureCompensation',
                ),
                'focallength' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocalLength',
                ),
                'exposuretime' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExposureTime',
                ),
                'iso' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ISO',
                ),
                'makernoteversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\MakerNoteVersion',
                ),
                'compressedimagesize' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CompressedImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CompressedImageSize',
                ),
                'previewimagedata' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PreviewImageData',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PreviewImageData',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ThumbnailImage',
                ),
                'specialmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SpecialMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SpecialMode',
                ),
                'quality' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Quality',
                ),
                'macro' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Macro',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Macro',
                ),
                'bwmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'BWMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\BWMode',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DigitalZoom',
                ),
                'lensdistortionparams' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LensDistortionParams',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LensDistortionParams',
                ),
                'cameratype' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CameraType',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CameraType',
                ),
                'cameraid' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CameraID',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CameraID',
                ),
                'epsonimagewidth' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'EpsonImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\EpsonImageWidth',
                ),
                'epsonimageheight' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'EpsonImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\EpsonImageHeight',
                ),
                'epsonsoftware' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'EpsonSoftware',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\EpsonSoftware',
                ),
                'previewimage' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PreviewImage',
                ),
                'precaptureframes' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'PreCaptureFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\PreCaptureFrames',
                ),
                'whiteboard' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WhiteBoard',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WhiteBoard',
                ),
                'onetouchwb' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'OneTouchWB',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\OneTouchWB',
                ),
                'whitebalancebias' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WhiteBalanceBias',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WhiteBalanceBias',
                ),
                'firmware' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Firmware',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Firmware',
                ),
                'datadump' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DataDump',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DataDump',
                ),
                'datadump2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DataDump2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DataDump2',
                ),
                'zoomedpreviewstart' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ZoomedPreviewStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ZoomedPreviewStart',
                ),
                'zoomedpreviewlength' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ZoomedPreviewLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ZoomedPreviewLength',
                ),
                'zoomedpreviewsize' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ZoomedPreviewSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ZoomedPreviewSize',
                ),
                'shutterspeedvalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ShutterSpeedValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ShutterSpeedValue',
                ),
                'isovalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ISOValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ISOValue',
                ),
                'aperturevalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ApertureValue',
                ),
                'brightnessvalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'BrightnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\BrightnessValue',
                ),
                'flashdevice' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashDevice',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashDevice',
                ),
                'lenstemperature' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LensTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LensTemperature',
                ),
                'lightcondition' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LightCondition',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LightCondition',
                ),
                'focusrange' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FocusRange',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FocusRange',
                ),
                'manualfocusdistance' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ManualFocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ManualFocusDistance',
                ),
                'sharpness' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Sharpness',
                ),
                'flashchargelevel' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FlashChargeLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FlashChargeLevel',
                ),
                'blacklevel' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'BlackLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\BlackLevel',
                ),
                'colortemperaturebg' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ColorTemperatureBG',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ColorTemperatureBG',
                ),
                'colortemperaturerg' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ColorTemperatureRG',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ColorTemperatureRG',
                ),
                'wbmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WBMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBMode',
                ),
                'redbalance' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RedBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RedBalance',
                ),
                'bluebalance' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'BlueBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\BlueBalance',
                ),
                'colormatrixnumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ColorMatrixNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ColorMatrixNumber',
                ),
                'externalflashae1_0' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashAE1_0',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashAE10',
                ),
                'externalflashae2_0' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashAE2_0',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashAE20',
                ),
                'internalflashae1_0' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'InternalFlashAE1_0',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\InternalFlashAE10',
                ),
                'internalflashae2_0' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'InternalFlashAE2_0',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\InternalFlashAE20',
                ),
                'externalflashae1' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashAE1',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashAE1',
                ),
                'externalflashae2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashAE2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashAE2',
                ),
                'internalflashae1' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'InternalFlashAE1',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\InternalFlashAE1',
                ),
                'internalflashae2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'InternalFlashAE2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\InternalFlashAE2',
                ),
                'internalflashtable' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'InternalFlashTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\InternalFlashTable',
                ),
                'externalflashgvalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashGValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashGValue',
                ),
                'externalflashmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ExternalFlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ExternalFlashMode',
                ),
                'contrast' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Contrast',
                ),
                'sharpnessfactor' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SharpnessFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SharpnessFactor',
                ),
                'colorcontrol' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ColorControl',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ColorControl',
                ),
                'olympusimagewidth' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'OlympusImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\OlympusImageWidth',
                ),
                'olympusimageheight' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'OlympusImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\OlympusImageHeight',
                ),
                'compressionratio' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CompressionRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CompressionRatio',
                ),
                'afresult' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'AFResult',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\AFResult',
                ),
                'ccdscanmode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CCDScanMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CCDScanMode',
                ),
                'lightvaluecenter' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LightValueCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LightValueCenter',
                ),
                'lightvalueperiphery' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LightValuePeriphery',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LightValuePeriphery',
                ),
                'fieldcount' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FieldCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FieldCount',
                ),
                'cameraparameters' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CameraParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CameraParameters',
                ),
                'encoderversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'EncoderVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\EncoderVersion',
                ),
                'decoderversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DecoderVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DecoderVersion',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DateTimeOriginal',
                ),
                'thumbnailwidth' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ThumbnailWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ThumbnailWidth',
                ),
                'thumbnailheight' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ThumbnailHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ThumbnailHeight',
                ),
                'rawdevversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevVersion',
                ),
                'rawdevexposurebiasvalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevExposureBiasValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevExposureBiasValue',
                ),
                'rawdevwhitebalancevalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevWhiteBalanceValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevWhiteBalanceValue',
                ),
                'rawdevwbfineadjustment' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevWBFineAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevWBFineAdjustment',
                ),
                'rawdevgraypoint' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevGrayPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevGrayPoint',
                ),
                'rawdevsaturationemphasis' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevSaturationEmphasis',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevSaturationEmphasis',
                ),
                'rawdevmemorycoloremphasis' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevMemoryColorEmphasis',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevMemoryColorEmphasis',
                ),
                'rawdevcontrastvalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevContrastValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevContrastValue',
                ),
                'rawdevsharpnessvalue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevSharpnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevSharpnessValue',
                ),
                'rawdevcolorspace' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevColorSpace',
                ),
                'rawdevengine' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevEngine',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevEngine',
                ),
                'rawdevnoisereduction' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevNoiseReduction',
                ),
                'rawdeveditstatus' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevEditStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevEditStatus',
                ),
                'rawdevsettings' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevSettings',
                ),
                'rawdevwhitebalance' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevWhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevWhiteBalance',
                ),
                'rawdevpicturemode' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevPictureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevPictureMode',
                ),
                'rawdevpmsaturation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevPMSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevPMSaturation',
                ),
                'rawdevpmcontrast' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevPMContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevPMContrast',
                ),
                'rawdevpmsharpness' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevPMSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevPMSharpness',
                ),
                'rawdevpm_bwfilter' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevPM_BWFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevPMBWFilter',
                ),
                'rawdevpmpicturetone' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevPMPictureTone',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevPMPictureTone',
                ),
                'rawdevgradation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevGradation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevGradation',
                ),
                'rawdevsaturation3' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevSaturation3',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevSaturation3',
                ),
                'rawdevautogradation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevAutoGradation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevAutoGradation',
                ),
                'rawdevpmnoisefilter' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawDevPMNoiseFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawDevPMNoiseFilter',
                ),
                'rawinfoversion' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RawInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RawInfoVersion',
                ),
                'wb_rblevelsused' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsUsed',
                ),
                'wb_rblevelsauto' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsAuto',
                ),
                'wb_rblevelsshade' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsShade',
                ),
                'wb_rblevelscloudy' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCloudy',
                ),
                'wb_rblevelsfineweather' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsFineWeather',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsFineWeather',
                ),
                'wb_rblevelstungsten' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsTungsten',
                ),
                'wb_rblevelseveningsunlight' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsEveningSunlight',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsEveningSunlight',
                ),
                'wb_rblevelsdaylightfluor' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsDaylightFluor',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsDaylightFluor',
                ),
                'wb_rblevelsdaywhitefluor' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsDayWhiteFluor',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsDayWhiteFluor',
                ),
                'wb_rblevelscoolwhitefluor' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsCoolWhiteFluor',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsCoolWhiteFluor',
                ),
                'wb_rblevelswhitefluorescent' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WB_RBLevelsWhiteFluorescent',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WBRBLevelsWhiteFluorescent',
                ),
                'colormatrix2' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ColorMatrix2',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ColorMatrix2',
                ),
                'ycbcrcoefficients' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'YCbCrCoefficients',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\YCbCrCoefficients',
                ),
                'validpixeldepth' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ValidPixelDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ValidPixelDepth',
                ),
                'lightsource' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'LightSource',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\LightSource',
                ),
                'whitebalancecomp' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'WhiteBalanceComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\WhiteBalanceComp',
                ),
                'saturationsetting' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'SaturationSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\SaturationSetting',
                ),
                'huesetting' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'HueSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\HueSetting',
                ),
                'cmexposurecompensation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CMExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CMExposureCompensation',
                ),
                'cmwhitebalance' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CMWhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CMWhiteBalance',
                ),
                'cmwhitebalancecomp' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CMWhiteBalanceComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CMWhiteBalanceComp',
                ),
                'cmwhitebalancegraypoint' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CMWhiteBalanceGrayPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CMWhiteBalanceGrayPoint',
                ),
                'cmsaturation' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CMSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CMSaturation',
                ),
                'cmhue' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CMHue',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CMHue',
                ),
                'cmcontrast' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CMContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CMContrast',
                ),
                'cmsharpness' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'CMSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\CMSharpness',
                ),
                'resolution' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Resolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Resolution',
                ),
                'thumbnaillength' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ThumbnailLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ThumbnailLength',
                ),
                'thumbnailoffset' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'ThumbnailOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\ThumbnailOffset',
                ),
                'filenumber' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'FileNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\FileNumber',
                ),
                'datetimeend' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'DateTimeEnd',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\DateTimeEnd',
                ),
                'recordingtime' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'RecordingTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\RecordingTime',
                ),
                'duration' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Duration',
                ),
                'index01' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index01',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index01',
                ),
                'index02' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index02',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index02',
                ),
                'index03' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index03',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index03',
                ),
                'index04' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index04',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index04',
                ),
                'index05' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index05',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index05',
                ),
                'index06' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index06',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index06',
                ),
                'index07' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index07',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index07',
                ),
                'index08' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index08',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index08',
                ),
                'index09' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index09',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index09',
                ),
                'index10' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index10',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index10',
                ),
                'index11' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index11',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index11',
                ),
                'index12' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index12',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index12',
                ),
                'index13' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index13',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index13',
                ),
                'index14' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index14',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index14',
                ),
                'index15' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index15',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index15',
                ),
                'index16' => array(
                    'namespace' => 'Olympus',
                    'tagname' => 'Index16',
                    'classname' => 'PHPExiftool\Driver\Tag\Olympus\Index16',
                ),

            ),
            'openexr' => array(
                'layout' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Layout',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Layout',
                ),
                'exrversion' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'EXRVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\EXRVersion',
                ),
                'adoptedneutral' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'AdoptedNeutral',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\AdoptedNeutral',
                ),
                'gpsaltitude' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'GPSAltitude',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\GPSAltitude',
                ),
                'aperture' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Aperture',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Aperture',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\DateTimeOriginal',
                ),
                'channels' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Channels',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Channels',
                ),
                'chromaticities' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Chromaticities',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Chromaticities',
                ),
                'comments' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Comments',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Comments',
                ),
                'compression' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Compression',
                ),
                'datawindow' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'DataWindow',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\DataWindow',
                ),
                'displaywindow' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'DisplayWindow',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\DisplayWindow',
                ),
                'environmentmap' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'EnvironmentMap',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\EnvironmentMap',
                ),
                'exposuretime' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\ExposureTime',
                ),
                'focusdistance' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'FocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\FocusDistance',
                ),
                'framespersecond' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'FramesPerSecond',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\FramesPerSecond',
                ),
                'iso' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\ISO',
                ),
                'keycode' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'KeyCode',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\KeyCode',
                ),
                'gpslatitude' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'GPSLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\GPSLatitude',
                ),
                'lineorder' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'LineOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\LineOrder',
                ),
                'gpslongitude' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'GPSLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\GPSLongitude',
                ),
                'lookmodtransform' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'LookModTransform',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\LookModTransform',
                ),
                'multiview' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'MultiView',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\MultiView',
                ),
                'owner' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Owner',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Owner',
                ),
                'pixelaspectratio' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'PixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\PixelAspectRatio',
                ),
                'preview' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Preview',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Preview',
                ),
                'renderingtransform' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'RenderingTransform',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\RenderingTransform',
                ),
                'screenwindowcenter' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'ScreenWindowCenter',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\ScreenWindowCenter',
                ),
                'screenwindowwidth' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'ScreenWindowWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\ScreenWindowWidth',
                ),
                'tiles' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'Tiles',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\Tiles',
                ),
                'timecode' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'TimeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\TimeCode',
                ),
                'timezone' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'TimeZone',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\TimeZone',
                ),
                'whiteluminance' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'WhiteLuminance',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\WhiteLuminance',
                ),
                'worldtocamera' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'WorldToCamera',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\WorldToCamera',
                ),
                'worldtondc' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'WorldToNDC',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\WorldToNDC',
                ),
                'wrapmodes' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'WrapModes',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\WrapModes',
                ),
                'xresolution' => array(
                    'namespace' => 'OpenEXR',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\OpenEXR\XResolution',
                ),

            ),
            'pdf' => array(
                'containerversion' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'ContainerVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\ContainerVersion',
                ),
                'creatorversion' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'CreatorVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\CreatorVersion',
                ),
                'roundtripversion' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'RoundTripVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\RoundTripVersion',
                ),
                'hasxfa' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'HasXFA',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\HasXFA',
                ),
                'encryption' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Encryption',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Encryption',
                ),
                'useraccess' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'UserAccess',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\UserAccess',
                ),
                'applekeywords' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'AppleKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\AppleKeywords',
                ),
                'author' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Author',
                ),
                'createdate' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\CreateDate',
                ),
                'creator' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Creator',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Creator',
                ),
                'keywords' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Keywords',
                ),
                'modifydate' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\ModifyDate',
                ),
                'producer' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Producer',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Producer',
                ),
                'subject' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Subject',
                ),
                'title' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Title',
                ),
                'trapped' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Trapped',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Trapped',
                ),
                'linearized' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Linearized',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Linearized',
                ),
                'taggedpdf' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'TaggedPDF',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\TaggedPDF',
                ),
                'pagecount' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'PageCount',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\PageCount',
                ),
                'language' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\Language',
                ),
                'pagelayout' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'PageLayout',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\PageLayout',
                ),
                'pagemode' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'PageMode',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\PageMode',
                ),
                'pdfversion' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'PDFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\PDFVersion',
                ),
                'signercontactinfo' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'SignerContactInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\SignerContactInfo',
                ),
                'signinglocation' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'SigningLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\SigningLocation',
                ),
                'signingdate' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'SigningDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\SigningDate',
                ),
                'signingauthority' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'SigningAuthority',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\SigningAuthority',
                ),
                'authenticationtime' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'AuthenticationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\AuthenticationTime',
                ),
                'authenticationtype' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'AuthenticationType',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\AuthenticationType',
                ),
                'signingreason' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'SigningReason',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\SigningReason',
                ),
                'fieldpermissions' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'FieldPermissions',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\FieldPermissions',
                ),
                'annotationusagerights' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'AnnotationUsageRights',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\AnnotationUsageRights',
                ),
                'documentusagerights' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'DocumentUsageRights',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\DocumentUsageRights',
                ),
                'embeddedfileusagerights' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'EmbeddedFileUsageRights',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\EmbeddedFileUsageRights',
                ),
                'formfields' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'FormFields',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\FormFields',
                ),
                'formusagerights' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'FormUsageRights',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\FormUsageRights',
                ),
                'formextrausagerights' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'FormExtraUsageRights',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\FormExtraUsageRights',
                ),
                'usagerightsmessage' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'UsageRightsMessage',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\UsageRightsMessage',
                ),
                'modificationpermissions' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'ModificationPermissions',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\ModificationPermissions',
                ),
                'signatureusagerights' => array(
                    'namespace' => 'PDF',
                    'tagname' => 'SignatureUsageRights',
                    'classname' => 'PHPExiftool\Driver\Tag\PDF\SignatureUsageRights',
                ),

            ),
            'pict' => array(
                'nop' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'Nop',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\Nop',
                ),
                'cliprgn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'ClipRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\ClipRgn',
                ),
                'bkpat' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'BkPat',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\BkPat',
                ),
                'txfont' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'TxFont',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\TxFont',
                ),
                'txface' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'TxFace',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\TxFace',
                ),
                'txmode' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'TxMode',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\TxMode',
                ),
                'spextra' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'SpExtra',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\SpExtra',
                ),
                'pnsize' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PnSize',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PnSize',
                ),
                'pnmode' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PnMode',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PnMode',
                ),
                'pnpat' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PnPat',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PnPat',
                ),
                'fillpat' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillPat',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillPat',
                ),
                'ovsize' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'OvSize',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\OvSize',
                ),
                'origin' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'Origin',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\Origin',
                ),
                'txsize' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'TxSize',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\TxSize',
                ),
                'fgcolor' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FgColor',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FgColor',
                ),
                'bkcolor' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'BkColor',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\BkColor',
                ),
                'txratio' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'TxRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\TxRatio',
                ),
                'versionop' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'VersionOp',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\VersionOp',
                ),
                'bkpixpat' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'BkPixPat',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\BkPixPat',
                ),
                'pnpixpat' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PnPixPat',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PnPixPat',
                ),
                'fillpixpat' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillPixPat',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillPixPat',
                ),
                'pnlochfrac' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PnLocHFrac',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PnLocHFrac',
                ),
                'chextra' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'ChExtra',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\ChExtra',
                ),
                'rgbfgcol' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'RGBFgCol',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\RGBFgCol',
                ),
                'rgbbkcol' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'RGBBkCol',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\RGBBkCol',
                ),
                'hilitemode' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'HiliteMode',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\HiliteMode',
                ),
                'hilitecolor' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'HiliteColor',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\HiliteColor',
                ),
                'defhilite' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'DefHilite',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\DefHilite',
                ),
                'opcolor' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'OpColor',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\OpColor',
                ),
                'line' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'Line',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\Line',
                ),
                'linefrom' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'LineFrom',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\LineFrom',
                ),
                'shortline' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'ShortLine',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\ShortLine',
                ),
                'shortlinefrom' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'ShortLineFrom',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\ShortLineFrom',
                ),
                'longtext' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'LongText',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\LongText',
                ),
                'dhtext' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'DHText',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\DHText',
                ),
                'dvtext' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'DVText',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\DVText',
                ),
                'dhdvtext' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'DHDVText',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\DHDVText',
                ),
                'fontname' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FontName',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FontName',
                ),
                'linejustify' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'LineJustify',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\LineJustify',
                ),
                'glyphstate' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'GlyphState',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\GlyphState',
                ),
                'framerect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameRect',
                ),
                'paintrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintRect',
                ),
                'eraserect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseRect',
                ),
                'invertrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertRect',
                ),
                'fillrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillRect',
                ),
                'framesamerect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameSameRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameSameRect',
                ),
                'paintsamerect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintSameRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintSameRect',
                ),
                'erasesamerect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseSameRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseSameRect',
                ),
                'invertsamerect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertSameRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertSameRect',
                ),
                'fillsamerect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillSameRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillSameRect',
                ),
                'framerrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameRRect',
                ),
                'paintrrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintRRect',
                ),
                'eraserrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseRRect',
                ),
                'invertrrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertRRect',
                ),
                'fillrrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillRRect',
                ),
                'framesamerrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameSameRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameSameRRect',
                ),
                'paintsamerrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintSameRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintSameRRect',
                ),
                'erasesamerrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseSameRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseSameRRect',
                ),
                'invertsamerrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertSameRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertSameRRect',
                ),
                'fillsamerrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillSameRRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillSameRRect',
                ),
                'frameoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameOval',
                ),
                'paintoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintOval',
                ),
                'eraseoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseOval',
                ),
                'invertoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertOval',
                ),
                'filloval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillOval',
                ),
                'framesameoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameSameOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameSameOval',
                ),
                'paintsameoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintSameOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintSameOval',
                ),
                'erasesameoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseSameOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseSameOval',
                ),
                'invertsameoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertSameOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertSameOval',
                ),
                'fillsameoval' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillSameOval',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillSameOval',
                ),
                'framearc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameArc',
                ),
                'paintarc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintArc',
                ),
                'erasearc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseArc',
                ),
                'invertarc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertArc',
                ),
                'fillarc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillArc',
                ),
                'framesamearc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameSameArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameSameArc',
                ),
                'paintsamearc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintSameArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintSameArc',
                ),
                'erasesamearc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseSameArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseSameArc',
                ),
                'invertsamearc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertSameArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertSameArc',
                ),
                'fillsamearc' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillSameArc',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillSameArc',
                ),
                'framepoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FramePoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FramePoly',
                ),
                'paintpoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintPoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintPoly',
                ),
                'erasepoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'ErasePoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\ErasePoly',
                ),
                'invertpoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertPoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertPoly',
                ),
                'fillpoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillPoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillPoly',
                ),
                'framesamepoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameSamePoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameSamePoly',
                ),
                'paintsamepoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintSamePoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintSamePoly',
                ),
                'erasesamepoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseSamePoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseSamePoly',
                ),
                'invertsamepoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertSamePoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertSamePoly',
                ),
                'fillsamepoly' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillSamePoly',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillSamePoly',
                ),
                'framergn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameRgn',
                ),
                'paintrgn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintRgn',
                ),
                'erasergn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseRgn',
                ),
                'invertrgn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertRgn',
                ),
                'fillrgn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillRgn',
                ),
                'framesamergn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FrameSameRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FrameSameRgn',
                ),
                'paintsamergn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PaintSameRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PaintSameRgn',
                ),
                'erasesamergn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'EraseSameRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\EraseSameRgn',
                ),
                'invertsamergn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'InvertSameRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\InvertSameRgn',
                ),
                'fillsamergn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'FillSameRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\FillSameRgn',
                ),
                'bitsrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'BitsRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\BitsRect',
                ),
                'bitsrgn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'BitsRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\BitsRgn',
                ),
                'packbitsrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PackBitsRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PackBitsRect',
                ),
                'packbitsrgn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'PackBitsRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\PackBitsRgn',
                ),
                'directbitsrect' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'DirectBitsRect',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\DirectBitsRect',
                ),
                'directbitsrgn' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'DirectBitsRgn',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\DirectBitsRgn',
                ),
                'shortcomment' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'ShortComment',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\ShortComment',
                ),
                'opendpic' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'OpEndPic',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\OpEndPic',
                ),
                'version' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\Version',
                ),
                'headerop' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'HeaderOp',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\HeaderOp',
                ),
                'compressedquicktime' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'CompressedQuickTime',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\CompressedQuickTime',
                ),
                'uncompressedquicktime' => array(
                    'namespace' => 'PICT',
                    'tagname' => 'UncompressedQuickTime',
                    'classname' => 'PHPExiftool\Driver\Tag\PICT\UncompressedQuickTime',
                ),

            ),
            'png' => array(
                'imagewidth' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\ImageHeight',
                ),
                'bitdepth' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\BitDepth',
                ),
                'colortype' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'ColorType',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\ColorType',
                ),
                'compression' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Compression',
                ),
                'filter' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Filter',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Filter',
                ),
                'interlace' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Interlace',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Interlace',
                ),
                'palette' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Palette',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Palette',
                ),
                'backgroundcolor' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'BackgroundColor',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\BackgroundColor',
                ),
                'digitalsignature' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'DigitalSignature',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\DigitalSignature',
                ),
                'fractalparameters' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'FractalParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\FractalParameters',
                ),
                'gamma' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Gamma',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Gamma',
                ),
                'gifgraphiccontrolextension' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'GIFGraphicControlExtension',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\GIFGraphicControlExtension',
                ),
                'gifplaintextextension' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'GIFPlainTextExtension',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\GIFPlainTextExtension',
                ),
                'gifapplicationextension' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'GIFApplicationExtension',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\GIFApplicationExtension',
                ),
                'palettehistogram' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'PaletteHistogram',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\PaletteHistogram',
                ),
                'imageoffset' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'ImageOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\ImageOffset',
                ),
                'pixelcalibration' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'PixelCalibration',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\PixelCalibration',
                ),
                'significantbits' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'SignificantBits',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\SignificantBits',
                ),
                'suggestedpalette' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'SuggestedPalette',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\SuggestedPalette',
                ),
                'srgbrendering' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'SRGBRendering',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\SRGBRendering',
                ),
                'modifydate' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\ModifyDate',
                ),
                'transparency' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Transparency',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Transparency',
                ),
                'pixelsperunitx' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'PixelsPerUnitX',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\PixelsPerUnitX',
                ),
                'pixelsperunity' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'PixelsPerUnitY',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\PixelsPerUnitY',
                ),
                'pixelunits' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'PixelUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\PixelUnits',
                ),
                'whitepointx' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'WhitePointX',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\WhitePointX',
                ),
                'whitepointy' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'WhitePointY',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\WhitePointY',
                ),
                'redx' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'RedX',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\RedX',
                ),
                'redy' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'RedY',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\RedY',
                ),
                'greenx' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'GreenX',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\GreenX',
                ),
                'greeny' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'GreenY',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\GreenY',
                ),
                'bluex' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'BlueX',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\BlueX',
                ),
                'bluey' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'BlueY',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\BlueY',
                ),
                'stereomode' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'StereoMode',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\StereoMode',
                ),
                'subjectunits' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'SubjectUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\SubjectUnits',
                ),
                'subjectpixelwidth' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'SubjectPixelWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\SubjectPixelWidth',
                ),
                'subjectpixelheight' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'SubjectPixelHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\SubjectPixelHeight',
                ),
                'artist' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Artist',
                ),
                'author' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Author',
                ),
                'comment' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Comment',
                ),
                'copyright' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Copyright',
                ),
                'creationtime' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'CreationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\CreationTime',
                ),
                'description' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Description',
                ),
                'disclaimer' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Disclaimer',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Disclaimer',
                ),
                'document' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Document',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Document',
                ),
                'label' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Label',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Label',
                ),
                'make' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Make',
                ),
                'model' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Model',
                ),
                'software' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Software',
                ),
                'source' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Source',
                ),
                'timestamp' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'TimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\TimeStamp',
                ),
                'title' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\Title',
                ),
                'url' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\URL',
                ),
                'pngwarning' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'PNGWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\PNGWarning',
                ),
                'createdate' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\CreateDate',
                ),
                'moddate' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'ModDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\ModDate',
                ),
                'virtualimagewidth' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'VirtualImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\VirtualImageWidth',
                ),
                'virtualimageheight' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'VirtualImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\VirtualImageHeight',
                ),
                'virtualpageunits' => array(
                    'namespace' => 'PNG',
                    'tagname' => 'VirtualPageUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\PNG\VirtualPageUnits',
                ),

            ),
            'psp' => array(
                'title' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\Title',
                ),
                'createdate' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\CreateDate',
                ),
                'modifydate' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\ModifyDate',
                ),
                'artist' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\Artist',
                ),
                'copyright' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\Copyright',
                ),
                'description' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\Description',
                ),
                'creatorappid' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'CreatorAppID',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\CreatorAppID',
                ),
                'creatorappversion' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'CreatorAppVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\CreatorAppVersion',
                ),
                'imagewidth' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\ImageHeight',
                ),
                'imageresolution' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'ImageResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\ImageResolution',
                ),
                'resolutionunit' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'ResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\ResolutionUnit',
                ),
                'compression' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\Compression',
                ),
                'bitspersample' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\BitsPerSample',
                ),
                'planes' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'Planes',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\Planes',
                ),
                'numcolors' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'NumColors',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\NumColors',
                ),
                'fileversion' => array(
                    'namespace' => 'PSP',
                    'tagname' => 'FileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PSP\FileVersion',
                ),

            ),
            'leica' => array(
                'lenstype' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\LensType',
                ),
                'quality' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\Quality',
                ),
                'userprofile' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'UserProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\UserProfile',
                ),
                'serialnumber' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\SerialNumber',
                ),
                'whitebalance' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\WhiteBalance',
                ),
                'externalsensorbrightnessvalue' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'ExternalSensorBrightnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\ExternalSensorBrightnessValue',
                ),
                'measuredlv' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'MeasuredLV',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\MeasuredLV',
                ),
                'approximatefnumber' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'ApproximateFNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\ApproximateFNumber',
                ),
                'cameratemperature' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'CameraTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\CameraTemperature',
                ),
                'colortemperature' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\ColorTemperature',
                ),
                'wbredlevel' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'WBRedLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\WBRedLevel',
                ),
                'wbgreenlevel' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'WBGreenLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\WBGreenLevel',
                ),
                'wbbluelevel' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'WBBlueLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\WBBlueLevel',
                ),
                'uv-irfiltercorrection' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'UV-IRFilterCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\UVIRFilterCorrection',
                ),
                'ccdversion' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'CCDVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\CCDVersion',
                ),
                'ccdboardversion' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'CCDBoardVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\CCDBoardVersion',
                ),
                'controllerboardversion' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'ControllerBoardVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\ControllerBoardVersion',
                ),
                'm16cversion' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'M16CVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\M16CVersion',
                ),
                'imageidnumber' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'ImageIDNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\ImageIDNumber',
                ),
                'wb_rgblevels' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'WB_RGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\WBRGBLevels',
                ),
                'originalfilename' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'OriginalFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\OriginalFileName',
                ),
                'originaldirectory' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'OriginalDirectory',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\OriginalDirectory',
                ),
                'exposuremode' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\ExposureMode',
                ),
                'filmmode' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'FilmMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\FilmMode',
                ),
                'previewimage' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\PreviewImage',
                ),
                'unknownblock' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'UnknownBlock',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\UnknownBlock',
                ),
                'fileindex' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'FileIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\FileIndex',
                ),
                'contrast' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\Contrast',
                ),
                'sharpening' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'Sharpening',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\Sharpening',
                ),
                'saturation' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\Saturation',
                ),
                'jpegquality' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'JPEGQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\JPEGQuality',
                ),
                'jpegsize' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'JPEGSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\JPEGSize',
                ),
                'firmwareversion' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\FirmwareVersion',
                ),
                'baseiso' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'BaseISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\BaseISO',
                ),
                'sensorwidth' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'SensorWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\SensorWidth',
                ),
                'sensorheight' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'SensorHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\SensorHeight',
                ),
                'sensorbitdepth' => array(
                    'namespace' => 'Leica',
                    'tagname' => 'SensorBitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\Leica\SensorBitDepth',
                ),

            ),
            'panasonic' => array(
                'numfacepositions' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'NumFacePositions',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\NumFacePositions',
                ),
                'face1position' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Face1Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Face1Position',
                ),
                'face2position' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Face2Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Face2Position',
                ),
                'face3position' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Face3Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Face3Position',
                ),
                'face4position' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Face4Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Face4Position',
                ),
                'face5position' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Face5Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Face5Position',
                ),
                'facesrecognized' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'FacesRecognized',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\FacesRecognized',
                ),
                'recognizedface1name' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace1Name',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace1Name',
                ),
                'recognizedface1position' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace1Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace1Position',
                ),
                'recognizedface1age' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace1Age',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace1Age',
                ),
                'recognizedface2name' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace2Name',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace2Name',
                ),
                'recognizedface2position' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace2Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace2Position',
                ),
                'recognizedface2age' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace2Age',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace2Age',
                ),
                'recognizedface3name' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace3Name',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace3Name',
                ),
                'recognizedface3position' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace3Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace3Position',
                ),
                'recognizedface3age' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFace3Age',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFace3Age',
                ),
                'imagequality' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ImageQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ImageQuality',
                ),
                'firmwareversion' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\FirmwareVersion',
                ),
                'whitebalance' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\WhiteBalance',
                ),
                'focusmode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\FocusMode',
                ),
                'afareamode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'AFAreaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\AFAreaMode',
                ),
                'imagestabilization' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ImageStabilization',
                ),
                'macromode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'MacroMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\MacroMode',
                ),
                'shootingmode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ShootingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ShootingMode',
                ),
                'audio' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Audio',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Audio',
                ),
                'datadump' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'DataDump',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\DataDump',
                ),
                'whitebalancebias' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'WhiteBalanceBias',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\WhiteBalanceBias',
                ),
                'flashbias' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'FlashBias',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\FlashBias',
                ),
                'internalserialnumber' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'InternalSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\InternalSerialNumber',
                ),
                'panasonicexifversion' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'PanasonicExifVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\PanasonicExifVersion',
                ),
                'coloreffect' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ColorEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ColorEffect',
                ),
                'timesincepoweron' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'TimeSincePowerOn',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\TimeSincePowerOn',
                ),
                'burstmode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'BurstMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\BurstMode',
                ),
                'sequencenumber' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'SequenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\SequenceNumber',
                ),
                'contrastmode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ContrastMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ContrastMode',
                ),
                'noisereduction' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'NoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\NoiseReduction',
                ),
                'selftimer' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'SelfTimer',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\SelfTimer',
                ),
                'rotation' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Rotation',
                ),
                'afassistlamp' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'AFAssistLamp',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\AFAssistLamp',
                ),
                'colormode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ColorMode',
                ),
                'babyage' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'BabyAge',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\BabyAge',
                ),
                'opticalzoommode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'OpticalZoomMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\OpticalZoomMode',
                ),
                'conversionlens' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ConversionLens',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ConversionLens',
                ),
                'travelday' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'TravelDay',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\TravelDay',
                ),
                'contrast' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Contrast',
                ),
                'worldtimelocation' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'WorldTimeLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\WorldTimeLocation',
                ),
                'textstamp' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'TextStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\TextStamp',
                ),
                'programiso' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ProgramISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ProgramISO',
                ),
                'advancedscenetype' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'AdvancedSceneType',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\AdvancedSceneType',
                ),
                'facesdetected' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\FacesDetected',
                ),
                'saturation' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Saturation',
                ),
                'sharpness' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Sharpness',
                ),
                'filmmode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'FilmMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\FilmMode',
                ),
                'colortempkelvin' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ColorTempKelvin',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ColorTempKelvin',
                ),
                'wbshiftab' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'WBShiftAB',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\WBShiftAB',
                ),
                'wbshiftgm' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'WBShiftGM',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\WBShiftGM',
                ),
                'panasonicimagewidth' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'PanasonicImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\PanasonicImageWidth',
                ),
                'panasonicimageheight' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'PanasonicImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\PanasonicImageHeight',
                ),
                'afpointposition' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'AFPointPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\AFPointPosition',
                ),
                'lenstype' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\LensType',
                ),
                'lensserialnumber' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'LensSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\LensSerialNumber',
                ),
                'accessorytype' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'AccessoryType',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\AccessoryType',
                ),
                'transform' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Transform',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Transform',
                ),
                'intelligentexposure' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'IntelligentExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\IntelligentExposure',
                ),
                'flashwarning' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'FlashWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\FlashWarning',
                ),
                'recognizedfaceflags' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'RecognizedFaceFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\RecognizedFaceFlags',
                ),
                'title' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Title',
                ),
                'babyname' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'BabyName',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\BabyName',
                ),
                'location' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Location',
                ),
                'country' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Country',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Country',
                ),
                'state' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'State',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\State',
                ),
                'city' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'City',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\City',
                ),
                'landmark' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Landmark',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Landmark',
                ),
                'intelligentresolution' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'IntelligentResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\IntelligentResolution',
                ),
                'intelligentd-range' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'IntelligentD-Range',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\IntelligentDRange',
                ),
                'manometerpressure' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ManometerPressure',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ManometerPressure',
                ),
                'makernoteversion' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\MakerNoteVersion',
                ),
                'scenemode' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'SceneMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\SceneMode',
                ),
                'wbredlevel' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'WBRedLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\WBRedLevel',
                ),
                'wbgreenlevel' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'WBGreenLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\WBGreenLevel',
                ),
                'wbbluelevel' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'WBBlueLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\WBBlueLevel',
                ),
                'flashfired' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'FlashFired',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\FlashFired',
                ),
                'model' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Model',
                ),
                'thumbnailwidth' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ThumbnailWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ThumbnailWidth',
                ),
                'thumbnailheight' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ThumbnailHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ThumbnailHeight',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\ThumbnailImage',
                ),
                'makernotetype' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'MakerNoteType',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\MakerNoteType',
                ),
                'gain' => array(
                    'namespace' => 'Panasonic',
                    'tagname' => 'Gain',
                    'classname' => 'PHPExiftool\Driver\Tag\Panasonic\Gain',
                ),

            ),
            'panasonicraw' => array(
                'distortionparam02' => array(
                    'namespace' => 'PanasonicRaw',
                    'tagname' => 'DistortionParam02',
                    'classname' => 'PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam02',
                ),
                'distortionparam04' => array(
                    'namespace' => 'PanasonicRaw',
                    'tagname' => 'DistortionParam04',
                    'classname' => 'PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam04',
                ),
                'distortionscale' => array(
                    'namespace' => 'PanasonicRaw',
                    'tagname' => 'DistortionScale',
                    'classname' => 'PHPExiftool\Driver\Tag\PanasonicRaw\DistortionScale',
                ),
                'distortioncorrection' => array(
                    'namespace' => 'PanasonicRaw',
                    'tagname' => 'DistortionCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\PanasonicRaw\DistortionCorrection',
                ),
                'distortionparam08' => array(
                    'namespace' => 'PanasonicRaw',
                    'tagname' => 'DistortionParam08',
                    'classname' => 'PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam08',
                ),
                'distortionparam09' => array(
                    'namespace' => 'PanasonicRaw',
                    'tagname' => 'DistortionParam09',
                    'classname' => 'PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam09',
                ),
                'distortionparam11' => array(
                    'namespace' => 'PanasonicRaw',
                    'tagname' => 'DistortionParam11',
                    'classname' => 'PHPExiftool\Driver\Tag\PanasonicRaw\DistortionParam11',
                ),
                'distortionn' => array(
                    'namespace' => 'PanasonicRaw',
                    'tagname' => 'DistortionN',
                    'classname' => 'PHPExiftool\Driver\Tag\PanasonicRaw\DistortionN',
                ),

            ),
            'pentax' => array(
                'aeexposuretime' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEExposureTime',
                ),
                'aeaperture' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEAperture',
                ),
                'ae_iso' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AE_ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEISO',
                ),
                'aexv' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEXv',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEXv',
                ),
                'aebxv' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEBXv',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEBXv',
                ),
                'aeminexposuretime' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEMinExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEMinExposureTime',
                ),
                'aeprogrammode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEProgramMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEProgramMode',
                ),
                'aeflags' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEFlags',
                ),
                'aeunknown' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEUnknown',
                ),
                'aemaxaperture' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEMaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEMaxAperture',
                ),
                'aemaxaperture2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEMaxAperture2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEMaxAperture2',
                ),
                'aeminaperture' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEMinAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEMinAperture',
                ),
                'aemeteringmode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEMeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEMeteringMode',
                ),
                'flashexposurecompset' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FlashExposureCompSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FlashExposureCompSet',
                ),
                'afpointsunknown1' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFPointsUnknown1',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFPointsUnknown1',
                ),
                'afpointsunknown2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFPointsUnknown2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFPointsUnknown2',
                ),
                'afpredictor' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFPredictor',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFPredictor',
                ),
                'afdefocus' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFDefocus',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFDefocus',
                ),
                'afintegrationtime' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFIntegrationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFIntegrationTime',
                ),
                'afpointsinfocus' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFPointsInFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFPointsInFocus',
                ),
                'whitebalanceautoadjustment' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WhiteBalanceAutoAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WhiteBalanceAutoAdjustment',
                ),
                'tungstenawb' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'TungstenAWB',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\TungstenAWB',
                ),
                'powersource' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PowerSource',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PowerSource',
                ),
                'bodybatterystate' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BodyBatteryState',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BodyBatteryState',
                ),
                'gripbatterystate' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'GripBatteryState',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\GripBatteryState',
                ),
                'bodybatteryadnoload' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BodyBatteryADNoLoad',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BodyBatteryADNoLoad',
                ),
                'bodybatteryvoltage1' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BodyBatteryVoltage1',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BodyBatteryVoltage1',
                ),
                'bodybatteryadload' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BodyBatteryADLoad',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BodyBatteryADLoad',
                ),
                'gripbatteryadnoload' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'GripBatteryADNoLoad',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\GripBatteryADNoLoad',
                ),
                'bodybatteryvoltage2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BodyBatteryVoltage2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BodyBatteryVoltage2',
                ),
                'gripbatteryadload' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'GripBatteryADLoad',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\GripBatteryADLoad',
                ),
                'bodybatteryvoltage3' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BodyBatteryVoltage3',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BodyBatteryVoltage3',
                ),
                'bodybatteryvoltage4' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BodyBatteryVoltage4',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BodyBatteryVoltage4',
                ),
                'pentaxmodelid' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PentaxModelID',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PentaxModelID',
                ),
                'manufacturedate' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ManufactureDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ManufactureDate',
                ),
                'productioncode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ProductionCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ProductionCode',
                ),
                'internalserialnumber' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'InternalSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\InternalSerialNumber',
                ),
                'picturemode2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PictureMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PictureMode2',
                ),
                'programline' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ProgramLine',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ProgramLine',
                ),
                'evsteps' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'EVSteps',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\EVSteps',
                ),
                'e-dialinprogram' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'E-DialInProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\EDialInProgram',
                ),
                'apertureringuse' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ApertureRingUse',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ApertureRingUse',
                ),
                'flashoptions' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FlashOptions',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FlashOptions',
                ),
                'meteringmode2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MeteringMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MeteringMode2',
                ),
                'afpointmode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFPointMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFPointMode',
                ),
                'focusmode2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FocusMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FocusMode2',
                ),
                'afpointselected2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFPointSelected2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFPointSelected2',
                ),
                'isofloor' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ISOFloor',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ISOFloor',
                ),
                'drivemode2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DriveMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DriveMode2',
                ),
                'exposurebracketstepsize' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ExposureBracketStepSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ExposureBracketStepSize',
                ),
                'bracketshotnumber' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BracketShotNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BracketShotNumber',
                ),
                'whitebalanceset' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WhiteBalanceSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WhiteBalanceSet',
                ),
                'multipleexposureset' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MultipleExposureSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MultipleExposureSet',
                ),
                'rawandjpgrecording' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'RawAndJpgRecording',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\RawAndJpgRecording',
                ),
                'jpgrecordedpixels' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'JpgRecordedPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\JpgRecordedPixels',
                ),
                'linkaetoafpoint' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LinkAEToAFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LinkAEToAFPoint',
                ),
                'sensitivitysteps' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SensitivitySteps',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SensitivitySteps',
                ),
                'isoauto' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ISOAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ISOAuto',
                ),
                'flashoptions2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FlashOptions2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FlashOptions2',
                ),
                'meteringmode3' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MeteringMode3',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MeteringMode3',
                ),
                'sractive' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SRActive',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SRActive',
                ),
                'rotation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Rotation',
                ),
                'isosetting' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ISOSetting',
                ),
                'tvexposuretimesetting' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'TvExposureTimeSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\TvExposureTimeSetting',
                ),
                'avaperturesetting' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AvApertureSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AvApertureSetting',
                ),
                'svisosetting' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SvISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SvISOSetting',
                ),
                'baseexposurecompensation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BaseExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BaseExposureCompensation',
                ),
                'wbshiftab' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WBShiftAB',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBShiftAB',
                ),
                'wbshiftgm' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WBShiftGM',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBShiftGM',
                ),
                'facesdetected' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FacesDetected',
                ),
                'faceposition' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FacePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FacePosition',
                ),
                'face1position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face1Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face1Position',
                ),
                'face2position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face2Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face2Position',
                ),
                'face3position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face3Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face3Position',
                ),
                'face4position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face4Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face4Position',
                ),
                'face5position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face5Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face5Position',
                ),
                'face6position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face6Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face6Position',
                ),
                'face7position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face7Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face7Position',
                ),
                'face8position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face8Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face8Position',
                ),
                'face9position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face9Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face9Position',
                ),
                'face10position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face10Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face10Position',
                ),
                'face11position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face11Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face11Position',
                ),
                'face12position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face12Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face12Position',
                ),
                'face13position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face13Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face13Position',
                ),
                'face14position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face14Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face14Position',
                ),
                'face15position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face15Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face15Position',
                ),
                'face16position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face16Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face16Position',
                ),
                'face17position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face17Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face17Position',
                ),
                'face18position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face18Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face18Position',
                ),
                'face19position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face19Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face19Position',
                ),
                'face20position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face20Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face20Position',
                ),
                'face21position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face21Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face21Position',
                ),
                'face22position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face22Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face22Position',
                ),
                'face23position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face23Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face23Position',
                ),
                'face24position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face24Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face24Position',
                ),
                'face25position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face25Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face25Position',
                ),
                'face26position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face26Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face26Position',
                ),
                'face27position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face27Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face27Position',
                ),
                'face28position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face28Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face28Position',
                ),
                'face29position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face29Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face29Position',
                ),
                'face30position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face30Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face30Position',
                ),
                'face31position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face31Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face31Position',
                ),
                'face32position' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face32Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face32Position',
                ),
                'face1size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face1Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face1Size',
                ),
                'face2size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face2Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face2Size',
                ),
                'face3size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face3Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face3Size',
                ),
                'face4size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face4Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face4Size',
                ),
                'face5size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face5Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face5Size',
                ),
                'face6size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face6Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face6Size',
                ),
                'face7size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face7Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face7Size',
                ),
                'face8size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face8Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face8Size',
                ),
                'face9size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face9Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face9Size',
                ),
                'face10size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face10Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face10Size',
                ),
                'face11size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face11Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face11Size',
                ),
                'face12size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face12Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face12Size',
                ),
                'face13size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face13Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face13Size',
                ),
                'face14size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face14Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face14Size',
                ),
                'face15size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face15Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face15Size',
                ),
                'face16size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face16Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face16Size',
                ),
                'face17size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face17Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face17Size',
                ),
                'face18size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face18Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face18Size',
                ),
                'face19size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face19Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face19Size',
                ),
                'face20size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face20Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face20Size',
                ),
                'face21size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face21Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face21Size',
                ),
                'face22size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face22Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face22Size',
                ),
                'face23size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face23Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face23Size',
                ),
                'face24size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face24Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face24Size',
                ),
                'face25size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face25Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face25Size',
                ),
                'face26size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face26Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face26Size',
                ),
                'face27size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face27Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face27Size',
                ),
                'face28size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face28Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face28Size',
                ),
                'face29size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face29Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face29Size',
                ),
                'face30size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face30Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face30Size',
                ),
                'face31size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face31Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face31Size',
                ),
                'face32size' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Face32Size',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Face32Size',
                ),
                'sourcedirectoryindex' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SourceDirectoryIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SourceDirectoryIndex',
                ),
                'sourcefileindex' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SourceFileIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SourceFileIndex',
                ),
                'digitalfilter01' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter01',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter01',
                ),
                'digitalfilter02' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter02',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter02',
                ),
                'digitalfilter03' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter03',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter03',
                ),
                'digitalfilter04' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter04',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter04',
                ),
                'digitalfilter05' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter05',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter05',
                ),
                'digitalfilter06' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter06',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter06',
                ),
                'digitalfilter07' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter07',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter07',
                ),
                'digitalfilter08' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter08',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter08',
                ),
                'digitalfilter09' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter09',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter09',
                ),
                'digitalfilter10' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter10',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter10',
                ),
                'digitalfilter11' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter11',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter11',
                ),
                'digitalfilter12' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter12',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter12',
                ),
                'digitalfilter13' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter13',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter13',
                ),
                'digitalfilter14' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter14',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter14',
                ),
                'digitalfilter15' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter15',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter15',
                ),
                'digitalfilter16' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter16',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter16',
                ),
                'digitalfilter17' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter17',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter17',
                ),
                'digitalfilter18' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter18',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter18',
                ),
                'digitalfilter19' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter19',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter19',
                ),
                'digitalfilter20' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalFilter20',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalFilter20',
                ),
                'flashstatus' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FlashStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FlashStatus',
                ),
                'internalflashmode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'InternalFlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\InternalFlashMode',
                ),
                'externalflashmode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ExternalFlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ExternalFlashMode',
                ),
                'internalflashstrength' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'InternalFlashStrength',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\InternalFlashStrength',
                ),
                'ttl_da_aup' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'TTL_DA_AUp',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\TTLDAAUp',
                ),
                'ttl_da_adown' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'TTL_DA_ADown',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\TTLDAADown',
                ),
                'ttl_da_bup' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'TTL_DA_BUp',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\TTLDABUp',
                ),
                'ttl_da_bdown' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'TTL_DA_BDown',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\TTLDABDown',
                ),
                'externalflashguidenumber' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ExternalFlashGuideNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ExternalFlashGuideNumber',
                ),
                'externalflashexposurecomp' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ExternalFlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ExternalFlashExposureComp',
                ),
                'externalflashbounce' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ExternalFlashBounce',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ExternalFlashBounce',
                ),
                'model' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Model',
                ),
                'make' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Make',
                ),
                'fnumber' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FNumber',
                ),
                'datetime1' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DateTime1',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DateTime1',
                ),
                'datetime2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DateTime2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DateTime2',
                ),
                'thumbnailwidth' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ThumbnailWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ThumbnailWidth',
                ),
                'thumbnailheight' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ThumbnailHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ThumbnailHeight',
                ),
                'thumbnaillength' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ThumbnailLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ThumbnailLength',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ThumbnailImage',
                ),
                'distortioncorrection' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DistortionCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DistortionCorrection',
                ),
                'chromaticaberrationcorrection' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ChromaticAberrationCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ChromaticAberrationCorrection',
                ),
                'autoaperture' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AutoAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AutoAperture',
                ),
                'minaperture' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MinAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MinAperture',
                ),
                'lensfstops' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LensFStops',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LensFStops',
                ),
                'lenskind' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LensKind',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LensKind',
                ),
                'lc1' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC1',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC1',
                ),
                'lc2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC2',
                ),
                'lc3' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC3',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC3',
                ),
                'lc4' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC4',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC4',
                ),
                'lc5' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC5',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC5',
                ),
                'lc6' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC6',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC6',
                ),
                'lc7' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC7',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC7',
                ),
                'focallength' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FocalLength',
                ),
                'nominalmaxaperture' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'NominalMaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\NominalMaxAperture',
                ),
                'nominalminaperture' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'NominalMinAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\NominalMinAperture',
                ),
                'lc10' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC10',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC10',
                ),
                'lc11' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC11',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC11',
                ),
                'lc12' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC12',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC12',
                ),
                'maxaperture' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MaxAperture',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MaxAperture',
                ),
                'lc14' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC14',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC14',
                ),
                'lc15' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LC15',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LC15',
                ),
                'lenstype' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LensType',
                ),
                'lensmodel' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LensModel',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LensModel',
                ),
                'lensinfo' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LensInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LensInfo',
                ),
                'levelorientation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LevelOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LevelOrientation',
                ),
                'compositionadjust' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CompositionAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CompositionAdjust',
                ),
                'rollangle' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'RollAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\RollAngle',
                ),
                'pitchangle' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PitchAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PitchAngle',
                ),
                'compositionadjustx' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CompositionAdjustX',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CompositionAdjustX',
                ),
                'compositionadjusty' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CompositionAdjustY',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CompositionAdjustY',
                ),
                'compositionadjustrotation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CompositionAdjustRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CompositionAdjustRotation',
                ),
                'exposuretime' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ExposureTime',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ExposureCompensation',
                ),
                'whitebalance' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WhiteBalance',
                ),
                'iso' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ISO',
                ),
                'pentaxversion' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PentaxVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PentaxVersion',
                ),
                'pentaxmodeltype' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PentaxModelType',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PentaxModelType',
                ),
                'previewimagesize' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PreviewImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PreviewImageSize',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PreviewImageLength',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PreviewImageStart',
                ),
                'date' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Date',
                ),
                'time' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Time',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Time',
                ),
                'quality' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Quality',
                ),
                'pentaximagesize' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PentaxImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PentaxImageSize',
                ),
                'picturemode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PictureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PictureMode',
                ),
                'flashmode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FlashMode',
                ),
                'focusmode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FocusMode',
                ),
                'afpointselected' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFPointSelected',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFPointSelected',
                ),
                'focusposition' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FocusPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FocusPosition',
                ),
                'lightreading' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'LightReading',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\LightReading',
                ),
                'meteringmode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MeteringMode',
                ),
                'autobracketing' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AutoBracketing',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AutoBracketing',
                ),
                'whitebalancemode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WhiteBalanceMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WhiteBalanceMode',
                ),
                'bluebalance' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BlueBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BlueBalance',
                ),
                'redbalance' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'RedBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\RedBalance',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DigitalZoom',
                ),
                'saturation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Saturation',
                ),
                'contrast' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Contrast',
                ),
                'sharpness' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Sharpness',
                ),
                'worldtimelocation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WorldTimeLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WorldTimeLocation',
                ),
                'hometowncity' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'HometownCity',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\HometownCity',
                ),
                'destinationcity' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DestinationCity',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DestinationCity',
                ),
                'hometowndst' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'HometownDST',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\HometownDST',
                ),
                'destinationdst' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DestinationDST',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DestinationDST',
                ),
                'dspfirmwareversion' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DSPFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DSPFirmwareVersion',
                ),
                'cpufirmwareversion' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CPUFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CPUFirmwareVersion',
                ),
                'framenumber' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FrameNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FrameNumber',
                ),
                'effectivelv' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'EffectiveLV',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\EffectiveLV',
                ),
                'imageediting' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ImageEditing',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ImageEditing',
                ),
                'drivemode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DriveMode',
                ),
                'sensorsize' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SensorSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SensorSize',
                ),
                'colorspace' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ColorSpace',
                ),
                'imageareaoffset' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ImageAreaOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ImageAreaOffset',
                ),
                'rawimagesize' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'RawImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\RawImageSize',
                ),
                'previewimageborders' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PreviewImageBorders',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PreviewImageBorders',
                ),
                'sensitivityadjust' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SensitivityAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SensitivityAdjust',
                ),
                'imageeditcount' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ImageEditCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ImageEditCount',
                ),
                'cameratemperature' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CameraTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CameraTemperature',
                ),
                'aelock' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AELock',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AELock',
                ),
                'noisereduction' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'NoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\NoiseReduction',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FlashExposureComp',
                ),
                'imagetone' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ImageTone',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ImageTone',
                ),
                'colortemperature' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ColorTemperature',
                ),
                'shuttercount' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ShutterCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ShutterCount',
                ),
                'hue' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Hue',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Hue',
                ),
                'dynamicrangeexpansion' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DynamicRangeExpansion',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DynamicRangeExpansion',
                ),
                'highlowkeyadj' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'HighLowKeyAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\HighLowKeyAdj',
                ),
                'contrasthighlight' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ContrastHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ContrastHighlight',
                ),
                'contrastshadow' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ContrastShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ContrastShadow',
                ),
                'contrasthighlightshadowadj' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ContrastHighlightShadowAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ContrastHighlightShadowAdj',
                ),
                'finesharpness' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FineSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FineSharpness',
                ),
                'highisonoisereduction' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'HighISONoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\HighISONoiseReduction',
                ),
                'afadjustment' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AFAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AFAdjustment',
                ),
                'monochromefiltereffect' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MonochromeFilterEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MonochromeFilterEffect',
                ),
                'monochrometoning' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MonochromeToning',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MonochromeToning',
                ),
                'facedetect' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FaceDetect',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FaceDetect',
                ),
                'facedetectframesize' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FaceDetectFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FaceDetectFrameSize',
                ),
                'shadowcompensation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ShadowCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ShadowCompensation',
                ),
                'isoautoparameters' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ISOAutoParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ISOAutoParameters',
                ),
                'crossprocess' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CrossProcess',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CrossProcess',
                ),
                'bleachbypasstoning' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BleachBypassToning',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BleachBypassToning',
                ),
                'aspectratio' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AspectRatio',
                ),
                'blurcontrol' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BlurControl',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BlurControl',
                ),
                'neutraldensityfilter' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'NeutralDensityFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\NeutralDensityFilter',
                ),
                'blackpoint' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'BlackPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\BlackPoint',
                ),
                'whitepoint' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WhitePoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WhitePoint',
                ),
                'colormatrixa' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ColorMatrixA',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ColorMatrixA',
                ),
                'colormatrixb' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ColorMatrixB',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ColorMatrixB',
                ),
                'aemeteringsegments' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AEMeteringSegments',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AEMeteringSegments',
                ),
                'flashmeteringsegments' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FlashMeteringSegments',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FlashMeteringSegments',
                ),
                'slaveflashmeteringsegments' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SlaveFlashMeteringSegments',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SlaveFlashMeteringSegments',
                ),
                'wb_rggblevelsdaylight' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WB_RGGBLevelsDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsDaylight',
                ),
                'wb_rggblevelsshade' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WB_RGGBLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsShade',
                ),
                'wb_rggblevelscloudy' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WB_RGGBLevelsCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsCloudy',
                ),
                'wb_rggblevelstungsten' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WB_RGGBLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsTungsten',
                ),
                'wb_rggblevelsfluorescentd' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WB_RGGBLevelsFluorescentD',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsFluorescentD',
                ),
                'wb_rggblevelsfluorescentn' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WB_RGGBLevelsFluorescentN',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsFluorescentN',
                ),
                'wb_rggblevelsfluorescentw' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WB_RGGBLevelsFluorescentW',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsFluorescentW',
                ),
                'wb_rggblevelsflash' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'WB_RGGBLevelsFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\WBRGGBLevelsFlash',
                ),
                'saturationinfo' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SaturationInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SaturationInfo',
                ),
                'huffmantable' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'HuffmanTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\HuffmanTable',
                ),
                'serialnumber' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SerialNumber',
                ),
                'artist' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Artist',
                ),
                'copyright' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\Copyright',
                ),
                'firmwareversion' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\FirmwareVersion',
                ),
                'contrastdetectafarea' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ContrastDetectAFArea',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ContrastDetectAFArea',
                ),
                'crossprocessparams' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CrossProcessParams',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CrossProcessParams',
                ),
                'datadump' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DataDump',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DataDump',
                ),
                'tonecurve' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ToneCurve',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ToneCurve',
                ),
                'tonecurves' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ToneCurves',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ToneCurves',
                ),
                'audiocodecid' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'AudioCodecID',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\AudioCodecID',
                ),
                'previewimage' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\PreviewImage',
                ),
                'makernoteversion' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\MakerNoteVersion',
                ),
                'srresult' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SRResult',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SRResult',
                ),
                'shakereduction' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ShakeReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ShakeReduction',
                ),
                'srhalfpresstime' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SRHalfPressTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SRHalfPressTime',
                ),
                'srfocallength' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'SRFocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\SRFocalLength',
                ),
                'cameraorientation' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CameraOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CameraOrientation',
                ),
                'cameratemperature2' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CameraTemperature2',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CameraTemperature2',
                ),
                'cameratemperature3' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CameraTemperature3',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CameraTemperature3',
                ),
                'cameratemperature4' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CameraTemperature4',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CameraTemperature4',
                ),
                'cameratemperature5' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'CameraTemperature5',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\CameraTemperature5',
                ),
                'recordingmode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'RecordingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\RecordingMode',
                ),
                'colorfilter' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'ColorFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\ColorFilter',
                ),
                'hometowncitycode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'HometownCityCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\HometownCityCode',
                ),
                'destinationcitycode' => array(
                    'namespace' => 'Pentax',
                    'tagname' => 'DestinationCityCode',
                    'classname' => 'PHPExiftool\Driver\Tag\Pentax\DestinationCityCode',
                ),

            ),
            'photocd' => array(
                'specificationversion' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'SpecificationVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\SpecificationVersion',
                ),
                'authoringsoftwarerelease' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'AuthoringSoftwareRelease',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\AuthoringSoftwareRelease',
                ),
                'imagemagnificationdescriptor' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ImageMagnificationDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ImageMagnificationDescriptor',
                ),
                'createdate' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\CreateDate',
                ),
                'modifydate' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ModifyDate',
                ),
                'imagemedium' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ImageMedium',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ImageMedium',
                ),
                'producttype' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ProductType',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ProductType',
                ),
                'scannervendorid' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ScannerVendorID',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ScannerVendorID',
                ),
                'scannerproductid' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ScannerProductID',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ScannerProductID',
                ),
                'scannerfirmwareversion' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ScannerFirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ScannerFirmwareVersion',
                ),
                'scannerfirmwaredate' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ScannerFirmwareDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ScannerFirmwareDate',
                ),
                'scannerserialnumber' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ScannerSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ScannerSerialNumber',
                ),
                'scannerpixelsize' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ScannerPixelSize',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ScannerPixelSize',
                ),
                'imageworkstationmake' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ImageWorkstationMake',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ImageWorkstationMake',
                ),
                'characterset' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'CharacterSet',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\CharacterSet',
                ),
                'characterescapesequence' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'CharacterEscapeSequence',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\CharacterEscapeSequence',
                ),
                'photofinishername' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'PhotoFinisherName',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\PhotoFinisherName',
                ),
                'hassba' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'HasSBA',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\HasSBA',
                ),
                'scenebalancealgorithmrevision' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'SceneBalanceAlgorithmRevision',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\SceneBalanceAlgorithmRevision',
                ),
                'scenebalancealgorithmcommand' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'SceneBalanceAlgorithmCommand',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\SceneBalanceAlgorithmCommand',
                ),
                'scenebalancealgorithmfilmid' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'SceneBalanceAlgorithmFilmID',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\SceneBalanceAlgorithmFilmID',
                ),
                'copyrightstatus' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'CopyrightStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\CopyrightStatus',
                ),
                'copyrightfilename' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'CopyrightFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\CopyrightFileName',
                ),
                'orientation' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\Orientation',
                ),
                'imagewidth' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\ImageHeight',
                ),
                'compressionclass' => array(
                    'namespace' => 'PhotoCD',
                    'tagname' => 'CompressionClass',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoCD\CompressionClass',
                ),

            ),
            'photomechanic' => array(
                'rawcropleft' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'RawCropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\RawCropLeft',
                ),
                'rawcroptop' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'RawCropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\RawCropTop',
                ),
                'rawcropright' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'RawCropRight',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\RawCropRight',
                ),
                'rawcropbottom' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'RawCropBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\RawCropBottom',
                ),
                'constrainedcropwidth' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'ConstrainedCropWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\ConstrainedCropWidth',
                ),
                'constrainedcropheight' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'ConstrainedCropHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\ConstrainedCropHeight',
                ),
                'framenum' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'FrameNum',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\FrameNum',
                ),
                'rotation' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\Rotation',
                ),
                'cropleft' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'CropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\CropLeft',
                ),
                'croptop' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'CropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\CropTop',
                ),
                'cropright' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'CropRight',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\CropRight',
                ),
                'cropbottom' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'CropBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\CropBottom',
                ),
                'tagged' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'Tagged',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\Tagged',
                ),
                'colorclass' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'ColorClass',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\ColorClass',
                ),
                'rating' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\Rating',
                ),
                'previewcropleft' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'PreviewCropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\PreviewCropLeft',
                ),
                'previewcroptop' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'PreviewCropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\PreviewCropTop',
                ),
                'previewcropright' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'PreviewCropRight',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\PreviewCropRight',
                ),
                'previewcropbottom' => array(
                    'namespace' => 'PhotoMechanic',
                    'tagname' => 'PreviewCropBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\PhotoMechanic\PreviewCropBottom',
                ),

            ),
            'xmp-photomech' => array(
                'colorclass' => array(
                    'namespace' => 'XMP-photomech',
                    'tagname' => 'ColorClass',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotomech\ColorClass',
                ),
                'countrycode' => array(
                    'namespace' => 'XMP-photomech',
                    'tagname' => 'CountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotomech\CountryCode',
                ),
                'editstatus' => array(
                    'namespace' => 'XMP-photomech',
                    'tagname' => 'EditStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotomech\EditStatus',
                ),
                'pmversion' => array(
                    'namespace' => 'XMP-photomech',
                    'tagname' => 'PMVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotomech\PMVersion',
                ),
                'prefs' => array(
                    'namespace' => 'XMP-photomech',
                    'tagname' => 'Prefs',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotomech\Prefs',
                ),
                'tagged' => array(
                    'namespace' => 'XMP-photomech',
                    'tagname' => 'Tagged',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotomech\Tagged',
                ),
                'timecreated' => array(
                    'namespace' => 'XMP-photomech',
                    'tagname' => 'TimeCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotomech\TimeCreated',
                ),

            ),
            'photoshop' => array(
                'numchannels' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'NumChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\NumChannels',
                ),
                'imageheight' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ImageWidth',
                ),
                'bitdepth' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\BitDepth',
                ),
                'colormode' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ColorMode',
                ),
                'photoshopquality' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PhotoshopQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PhotoshopQuality',
                ),
                'photoshopformat' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PhotoshopFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PhotoshopFormat',
                ),
                'progressivescans' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ProgressiveScans',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ProgressiveScans',
                ),
                'photoshop2info' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'Photoshop2Info',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\Photoshop2Info',
                ),
                'macintoshprintinfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'MacintoshPrintInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\MacintoshPrintInfo',
                ),
                'xmldata' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'XMLData',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\XMLData',
                ),
                'photoshop2colortable' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'Photoshop2ColorTable',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\Photoshop2ColorTable',
                ),
                'alphachannelsnames' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'AlphaChannelsNames',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\AlphaChannelsNames',
                ),
                'displayinfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'DisplayInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\DisplayInfo',
                ),
                'pstringcaption' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PStringCaption',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PStringCaption',
                ),
                'borderinformation' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'BorderInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\BorderInformation',
                ),
                'backgroundcolor' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'BackgroundColor',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\BackgroundColor',
                ),
                'printflags' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PrintFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PrintFlags',
                ),
                'bw_halftoninginfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'BW_HalftoningInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\BWHalftoningInfo',
                ),
                'colorhalftoninginfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ColorHalftoningInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ColorHalftoningInfo',
                ),
                'duotonehalftoninginfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'DuotoneHalftoningInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\DuotoneHalftoningInfo',
                ),
                'bw_transferfunc' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'BW_TransferFunc',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\BWTransferFunc',
                ),
                'colortransferfuncs' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ColorTransferFuncs',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ColorTransferFuncs',
                ),
                'duotonetransferfuncs' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'DuotoneTransferFuncs',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\DuotoneTransferFuncs',
                ),
                'duotoneimageinfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'DuotoneImageInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\DuotoneImageInfo',
                ),
                'effectivebw' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'EffectiveBW',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\EffectiveBW',
                ),
                'obsoletephotoshoptag1' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ObsoletePhotoshopTag1',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ObsoletePhotoshopTag1',
                ),
                'epsoptions' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'EPSOptions',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\EPSOptions',
                ),
                'quickmaskinfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'QuickMaskInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\QuickMaskInfo',
                ),
                'obsoletephotoshoptag2' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ObsoletePhotoshopTag2',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ObsoletePhotoshopTag2',
                ),
                'layerstateinfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'LayerStateInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\LayerStateInfo',
                ),
                'workingpath' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'WorkingPath',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\WorkingPath',
                ),
                'layersgroupinfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'LayersGroupInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\LayersGroupInfo',
                ),
                'obsoletephotoshoptag3' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ObsoletePhotoshopTag3',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ObsoletePhotoshopTag3',
                ),
                'rawimagemode' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'RawImageMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\RawImageMode',
                ),
                'gridguidesinfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'GridGuidesInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\GridGuidesInfo',
                ),
                'photoshopbgrthumbnail' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PhotoshopBGRThumbnail',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PhotoshopBGRThumbnail',
                ),
                'copyrightflag' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'CopyrightFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\CopyrightFlag',
                ),
                'url' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\URL',
                ),
                'photoshopthumbnail' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PhotoshopThumbnail',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PhotoshopThumbnail',
                ),
                'globalangle' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'GlobalAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\GlobalAngle',
                ),
                'colorsamplersresource' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ColorSamplersResource',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ColorSamplersResource',
                ),
                'watermark' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'Watermark',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\Watermark',
                ),
                'icc_untagged' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ICC_Untagged',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ICCUntagged',
                ),
                'effectsvisible' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'EffectsVisible',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\EffectsVisible',
                ),
                'spothalftone' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'SpotHalftone',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\SpotHalftone',
                ),
                'idsbasevalue' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'IDsBaseValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\IDsBaseValue',
                ),
                'unicodealphanames' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'UnicodeAlphaNames',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\UnicodeAlphaNames',
                ),
                'indexedcolourtablecount' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'IndexedColourTableCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\IndexedColourTableCount',
                ),
                'transparentindex' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'TransparentIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\TransparentIndex',
                ),
                'globalaltitude' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'GlobalAltitude',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\GlobalAltitude',
                ),
                'slices' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'Slices',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\Slices',
                ),
                'workflowurl' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'WorkflowURL',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\WorkflowURL',
                ),
                'jumptoxpep' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'JumpToXPEP',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\JumpToXPEP',
                ),
                'alphaidentifiers' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'AlphaIdentifiers',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\AlphaIdentifiers',
                ),
                'url_list' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'URL_List',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\URLList',
                ),
                'versioninfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'VersionInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\VersionInfo',
                ),
                'exifinfo2' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ExifInfo2',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ExifInfo2',
                ),
                'iptcdigest' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'IPTCDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\IPTCDigest',
                ),
                'printscale' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PrintScale',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PrintScale',
                ),
                'pixelaspectratio' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PixelAspectRatio',
                ),
                'layercomps' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'LayerComps',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\LayerComps',
                ),
                'alternateduotonecolors' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'AlternateDuotoneColors',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\AlternateDuotoneColors',
                ),
                'alternatespotcolors' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'AlternateSpotColors',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\AlternateSpotColors',
                ),
                'clippingpathname' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'ClippingPathName',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\ClippingPathName',
                ),
                'printflagsinfo' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'PrintFlagsInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\PrintFlagsInfo',
                ),
                'xresolution' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\XResolution',
                ),
                'displayedunitsx' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'DisplayedUnitsX',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\DisplayedUnitsX',
                ),
                'yresolution' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\YResolution',
                ),
                'displayedunitsy' => array(
                    'namespace' => 'Photoshop',
                    'tagname' => 'DisplayedUnitsY',
                    'classname' => 'PHPExiftool\Driver\Tag\Photoshop\DisplayedUnitsY',
                ),

            ),
            'postscript' => array(
                'author' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Author',
                ),
                'boundingbox' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'BoundingBox',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\BoundingBox',
                ),
                'copyright' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Copyright',
                ),
                'createdate' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\CreateDate',
                ),
                'creator' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Creator',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Creator',
                ),
                'embeddedfilename' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'EmbeddedFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\EmbeddedFileName',
                ),
                'for' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'For',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\For0',
                ),
                'imagedata' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'ImageData',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\ImageData',
                ),
                'keywords' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Keywords',
                ),
                'modifydate' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\ModifyDate',
                ),
                'pages' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Pages',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Pages',
                ),
                'routing' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Routing',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Routing',
                ),
                'subject' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Subject',
                ),
                'tiffpreview' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'TIFFPreview',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\TIFFPreview',
                ),
                'title' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Title',
                ),
                'version' => array(
                    'namespace' => 'PostScript',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\PostScript\Version',
                ),

            ),
            'printim' => array(
                'printimversion' => array(
                    'namespace' => 'PrintIM',
                    'tagname' => 'PrintIMVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\PrintIM\PrintIMVersion',
                ),

            ),
            'qualcomm' => array(
                'hjrenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'HJREnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\HJREnable',
                ),
                'hjrmaxnumframes' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'HJRMaxNumFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\HJRMaxNumFrames',
                ),
                'hjr_nreductionflat' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'HJR_NReductionFlat',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\HJRNReductionFlat',
                ),
                'hjr_nreductiontexture' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'HJR_NReductionTexture',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\HJRNReductionTexture',
                ),
                'hjronetotwooffset' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'HJROneToTwoOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\HJROneToTwoOffset',
                ),
                'hjrtexturethreshold' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'HJRTextureThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\HJRTextureThreshold',
                ),
                'aecaggressiveness' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECAggressiveness',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECAggressiveness',
                ),
                'aeccurrentexpindex' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECCurrentExpIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECCurrentExpIndex',
                ),
                'aeccurrentsensorluma' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECCurrentSensorLuma',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECCurrentSensorLuma',
                ),
                'aecenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECEnable',
                ),
                'aecexposureindexadjstep' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECExposureIndexAdjStep',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECExposureIndexAdjStep',
                ),
                'aechighlumaregioncount' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECHighLumaRegionCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECHighLumaRegionCount',
                ),
                'aechighlumaregionthreshold' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECHighLumaRegionThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECHighLumaRegionThreshold',
                ),
                'aecindooridx' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECIndoorIdx',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECIndoorIdx',
                ),
                'aeclumatarget' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECLumaTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECLumaTarget',
                ),
                'aeclumatolerance' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECLumaTolerance',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECLumaTolerance',
                ),
                'aecmode' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECMode',
                ),
                'aecodooridx' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECOdoorIdx',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECOdoorIdx',
                ),
                'aecoutdoorbrightdiscarded' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECOutdoorBrightDiscarded',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightDiscarded',
                ),
                'aecoutdoorbrightenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECOutdoorBrightEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightEnable',
                ),
                'aecoutdoorbrightreduction' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECOutdoorBrightReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightReduction',
                ),
                'aecoutdoorbrightthresholdhi' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECOutdoorBrightThresholdHI',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightThresholdHI',
                ),
                'aecoutdoorbrightthresholdlo' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECOutdoorBrightThresholdLO',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorBrightThresholdLO',
                ),
                'aecoutdoorgammaindex' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECOutdoorGammaIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECOutdoorGammaIndex',
                ),
                'aecsnapshotdigitalgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECSnapshotDigitalGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECSnapshotDigitalGain',
                ),
                'aecsnapshotexposuretimems' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECSnapshotExposureTimeMs',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECSnapshotExposureTimeMs',
                ),
                'aecsnapshotlinecount' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECSnapshotLineCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECSnapshotLineCount',
                ),
                'aecsnapshotsensorgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECSnapshotSensorGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECSnapshotSensorGain',
                ),
                'aecvfeluma' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AECVfeLuma',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AECVfeLuma',
                ),
                'afboundary' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFBoundary',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFBoundary',
                ),
                'afcollectendstat' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFCollectEndStat',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFCollectEndStat',
                ),
                'afenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFEnable',
                ),
                'affarend' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFFarEnd',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFFarEnd',
                ),
                'affinesrchpoints' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFFineSrchPoints',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFFineSrchPoints',
                ),
                'affinestep' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFFineStep',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFFineStep',
                ),
                'affocustime' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFFocusTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFFocusTime',
                ),
                'afgrossstep' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFGrossStep',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFGrossStep',
                ),
                'afmode' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFMode',
                ),
                'afnearend' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFNearEnd',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFNearEnd',
                ),
                'afposdefmacro' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFPosDefMacro',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFPosDefMacro',
                ),
                'afposdefnorm' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFPosDefNorm',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFPosDefNorm',
                ),
                'afposition' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFPosition',
                ),
                'afprocess' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFProcess',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFProcess',
                ),
                'afresetlensaftersnap' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFResetLensAfterSnap',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFResetLensAfterSnap',
                ),
                'afstepsnearfar' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFStepsNearFar',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFStepsNearFar',
                ),
                'afstepsnearinfinity' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFStepsNearInfinity',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFStepsNearInfinity',
                ),
                'aftestmode' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTestMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTestMode',
                ),
                'aftracepositions00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions00',
                ),
                'aftracepositions10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions10',
                ),
                'aftracepositions11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions11',
                ),
                'aftracepositions12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions12',
                ),
                'aftracepositions13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions13',
                ),
                'aftracepositions14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions14',
                ),
                'aftracepositions15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions15',
                ),
                'aftracepositions16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions16',
                ),
                'aftracepositions17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions17',
                ),
                'aftracepositions18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions18',
                ),
                'aftracepositions19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions19',
                ),
                'aftracepositions01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions01',
                ),
                'aftracepositions20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions20',
                ),
                'aftracepositions21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions21',
                ),
                'aftracepositions22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions22',
                ),
                'aftracepositions23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions23',
                ),
                'aftracepositions24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions24',
                ),
                'aftracepositions25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions25',
                ),
                'aftracepositions26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions26',
                ),
                'aftracepositions27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions27',
                ),
                'aftracepositions28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions28',
                ),
                'aftracepositions29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions29',
                ),
                'aftracepositions02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions02',
                ),
                'aftracepositions30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions30',
                ),
                'aftracepositions31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions31',
                ),
                'aftracepositions32' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions32',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions32',
                ),
                'aftracepositions33' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions33',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions33',
                ),
                'aftracepositions34' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions34',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions34',
                ),
                'aftracepositions35' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions35',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions35',
                ),
                'aftracepositions36' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions36',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions36',
                ),
                'aftracepositions37' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions37',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions37',
                ),
                'aftracepositions38' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions38',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions38',
                ),
                'aftracepositions39' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions39',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions39',
                ),
                'aftracepositions03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions03',
                ),
                'aftracepositions40' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions40',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions40',
                ),
                'aftracepositions41' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions41',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions41',
                ),
                'aftracepositions42' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions42',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions42',
                ),
                'aftracepositions43' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions43',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions43',
                ),
                'aftracepositions44' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions44',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions44',
                ),
                'aftracepositions45' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions45',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions45',
                ),
                'aftracepositions46' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions46',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions46',
                ),
                'aftracepositions47' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions47',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions47',
                ),
                'aftracepositions48' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions48',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions48',
                ),
                'aftracepositions49' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions49',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions49',
                ),
                'aftracepositions04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions04',
                ),
                'aftracepositions05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions05',
                ),
                'aftracepositions06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions06',
                ),
                'aftracepositions07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions07',
                ),
                'aftracepositions08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions08',
                ),
                'aftracepositions09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTracePositions09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTracePositions09',
                ),
                'aftracestats00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats00',
                ),
                'aftracestats10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats10',
                ),
                'aftracestats11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats11',
                ),
                'aftracestats12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats12',
                ),
                'aftracestats13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats13',
                ),
                'aftracestats14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats14',
                ),
                'aftracestats15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats15',
                ),
                'aftracestats16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats16',
                ),
                'aftracestats17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats17',
                ),
                'aftracestats18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats18',
                ),
                'aftracestats19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats19',
                ),
                'aftracestats01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats01',
                ),
                'aftracestats20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats20',
                ),
                'aftracestats21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats21',
                ),
                'aftracestats22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats22',
                ),
                'aftracestats23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats23',
                ),
                'aftracestats24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats24',
                ),
                'aftracestats25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats25',
                ),
                'aftracestats26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats26',
                ),
                'aftracestats27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats27',
                ),
                'aftracestats28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats28',
                ),
                'aftracestats29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats29',
                ),
                'aftracestats02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats02',
                ),
                'aftracestats30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats30',
                ),
                'aftracestats31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats31',
                ),
                'aftracestats32' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats32',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats32',
                ),
                'aftracestats33' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats33',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats33',
                ),
                'aftracestats34' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats34',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats34',
                ),
                'aftracestats35' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats35',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats35',
                ),
                'aftracestats36' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats36',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats36',
                ),
                'aftracestats37' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats37',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats37',
                ),
                'aftracestats38' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats38',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats38',
                ),
                'aftracestats39' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats39',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats39',
                ),
                'aftracestats03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats03',
                ),
                'aftracestats40' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats40',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats40',
                ),
                'aftracestats41' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats41',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats41',
                ),
                'aftracestats42' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats42',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats42',
                ),
                'aftracestats43' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats43',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats43',
                ),
                'aftracestats44' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats44',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats44',
                ),
                'aftracestats45' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats45',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats45',
                ),
                'aftracestats46' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats46',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats46',
                ),
                'aftracestats47' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats47',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats47',
                ),
                'aftracestats48' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats48',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats48',
                ),
                'aftracestats49' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats49',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats49',
                ),
                'aftracestats04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats04',
                ),
                'aftracestats05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats05',
                ),
                'aftracestats06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats06',
                ),
                'aftracestats07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats07',
                ),
                'aftracestats08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats08',
                ),
                'aftracestats09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFTraceStats09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFTraceStats09',
                ),
                'afundershootprotect' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFUndershootProtect',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFUndershootProtect',
                ),
                'afvfehorzoffset' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFVfeHorzOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFVfeHorzOffset',
                ),
                'afvfehorzwidth' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFVfeHorzWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFVfeHorzWidth',
                ),
                'afvfemetricmax' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFVfeMetricMax',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFVfeMetricMax',
                ),
                'afvfevertheight' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFVfeVertHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFVfeVertHeight',
                ),
                'afvfevertoffset' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFVfeVertOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFVfeVertOffset',
                ),
                'afrenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFREnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFREnable',
                ),
                'afrfaster0expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster0ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster0ExpMod',
                ),
                'afrfaster0trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster0Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster0Trigger',
                ),
                'afrfaster1expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster1ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster1ExpMod',
                ),
                'afrfaster1trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster1Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster1Trigger',
                ),
                'afrfaster2expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster2ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster2ExpMod',
                ),
                'afrfaster2trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster2Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster2Trigger',
                ),
                'afrfaster3expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster3ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster3ExpMod',
                ),
                'afrfaster3trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster3Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster3Trigger',
                ),
                'afrfaster4expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster4ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster4ExpMod',
                ),
                'afrfaster4trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRFaster4Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRFaster4Trigger',
                ),
                'afrpossibleframecnt' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRPossibleFrameCnt',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRPossibleFrameCnt',
                ),
                'afrslower0expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower0ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower0ExpMod',
                ),
                'afrslower0trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower0Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower0Trigger',
                ),
                'afrslower1expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower1ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower1ExpMod',
                ),
                'afrslower1trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower1Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower1Trigger',
                ),
                'afrslower2expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower2ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower2ExpMod',
                ),
                'afrslower2trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower2Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower2Trigger',
                ),
                'afrslower3expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower3ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower3ExpMod',
                ),
                'afrslower3trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower3Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower3Trigger',
                ),
                'afrslower4expmod' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower4ExpMod',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower4ExpMod',
                ),
                'afrslower4trigger' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AFRSlower4Trigger',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AFRSlower4Trigger',
                ),
                'antibadingpixelclk' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AntiBadingPixelClk',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AntiBadingPixelClk',
                ),
                'antibadingpixelclkperline' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AntiBadingPixelClkPerLine',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AntiBadingPixelClkPerLine',
                ),
                'antibandingenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AntibandingEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AntibandingEnable',
                ),
                'asf3edgedetect' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeDetect',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeDetect',
                ),
                'asf3edgefiltera11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA11',
                ),
                'asf3edgefiltera12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA12',
                ),
                'asf3edgefiltera13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA13',
                ),
                'asf3edgefiltera21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA21',
                ),
                'asf3edgefiltera22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA22',
                ),
                'asf3edgefiltera23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA23',
                ),
                'asf3edgefiltera31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA31',
                ),
                'asf3edgefiltera32' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA32',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA32',
                ),
                'asf3edgefiltera33' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3EdgeFilterA33',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3EdgeFilterA33',
                ),
                'asf3enable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3Enable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3Enable',
                ),
                'asf3lowerthreshold' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3LowerThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3LowerThreshold',
                ),
                'asf3noisefiltera11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA11',
                ),
                'asf3noisefiltera12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA12',
                ),
                'asf3noisefiltera13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA13',
                ),
                'asf3noisefiltera21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA21',
                ),
                'asf3noisefiltera22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA22',
                ),
                'asf3noisefiltera23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA23',
                ),
                'asf3noisefiltera31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA31',
                ),
                'asf3noisefiltera32' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA32',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA32',
                ),
                'asf3noisefiltera33' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3NoiseFilterA33',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3NoiseFilterA33',
                ),
                'asf3upperthreshold' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF3UpperThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF3UpperThreshold',
                ),
                'asf5brtlothres' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5BrtLoThres',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtLoThres',
                ),
                'asf5brtshrpdegf1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5BrtShrpDegF1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtShrpDegF1',
                ),
                'asf5brtshrpdegf2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5BrtShrpDegF2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtShrpDegF2',
                ),
                'asf5brtsmthpercent' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5BrtSmthPercent',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtSmthPercent',
                ),
                'asf5brtupthres' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5BrtUpThres',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5BrtUpThres',
                ),
                'asf5enable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Enable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Enable',
                ),
                'asf5exposureindex1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5ExposureIndex1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5ExposureIndex1',
                ),
                'asf5exposureindex2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5ExposureIndex2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5ExposureIndex2',
                ),
                'asf5filter1a11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A11',
                ),
                'asf5filter1a12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A12',
                ),
                'asf5filter1a13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A13',
                ),
                'asf5filter1a14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A14',
                ),
                'asf5filter1a15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A15',
                ),
                'asf5filter1a21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A21',
                ),
                'asf5filter1a22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A22',
                ),
                'asf5filter1a23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A23',
                ),
                'asf5filter1a24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A24',
                ),
                'asf5filter1a25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A25',
                ),
                'asf5filter1a31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A31',
                ),
                'asf5filter1a32' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A32',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A32',
                ),
                'asf5filter1a33' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A33',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A33',
                ),
                'asf5filter1a34' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A34',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A34',
                ),
                'asf5filter1a35' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A35',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A35',
                ),
                'asf5filter1a41' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A41',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A41',
                ),
                'asf5filter1a42' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A42',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A42',
                ),
                'asf5filter1a43' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A43',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A43',
                ),
                'asf5filter1a44' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A44',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A44',
                ),
                'asf5filter1a45' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A45',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A45',
                ),
                'asf5filter1a51' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A51',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A51',
                ),
                'asf5filter1a52' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A52',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A52',
                ),
                'asf5filter1a53' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A53',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A53',
                ),
                'asf5filter1a54' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A54',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A54',
                ),
                'asf5filter1a55' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter1A55',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter1A55',
                ),
                'asf5filter2a11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A11',
                ),
                'asf5filter2a12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A12',
                ),
                'asf5filter2a13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A13',
                ),
                'asf5filter2a14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A14',
                ),
                'asf5filter2a15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A15',
                ),
                'asf5filter2a21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A21',
                ),
                'asf5filter2a22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A22',
                ),
                'asf5filter2a23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A23',
                ),
                'asf5filter2a24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A24',
                ),
                'asf5filter2a25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A25',
                ),
                'asf5filter2a31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A31',
                ),
                'asf5filter2a32' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A32',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A32',
                ),
                'asf5filter2a33' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A33',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A33',
                ),
                'asf5filter2a34' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A34',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A34',
                ),
                'asf5filter2a35' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A35',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A35',
                ),
                'asf5filter2a41' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A41',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A41',
                ),
                'asf5filter2a42' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A42',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A42',
                ),
                'asf5filter2a43' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A43',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A43',
                ),
                'asf5filter2a44' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A44',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A44',
                ),
                'asf5filter2a45' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A45',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A45',
                ),
                'asf5filter2a51' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A51',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A51',
                ),
                'asf5filter2a52' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A52',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A52',
                ),
                'asf5filter2a53' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A53',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A53',
                ),
                'asf5filter2a54' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A54',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A54',
                ),
                'asf5filter2a55' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5Filter2A55',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5Filter2A55',
                ),
                'asf5filtermode' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5FilterMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5FilterMode',
                ),
                'asf5lowlothres' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LowLoThres',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LowLoThres',
                ),
                'asf5lowshrpdegf1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LowShrpDegF1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LowShrpDegF1',
                ),
                'asf5lowshrpdegf2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LowShrpDegF2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LowShrpDegF2',
                ),
                'asf5lowsmthprcnt' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LowSmthPrcnt',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LowSmthPrcnt',
                ),
                'asf5lowupthres' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LowUpThres',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LowUpThres',
                ),
                'asf5lumafilter00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter00',
                ),
                'asf5lumafilter01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter01',
                ),
                'asf5lumafilter02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter02',
                ),
                'asf5lumafilter03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter03',
                ),
                'asf5lumafilter04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter04',
                ),
                'asf5lumafilter05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter05',
                ),
                'asf5lumafilter06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter06',
                ),
                'asf5lumafilter07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter07',
                ),
                'asf5lumafilter08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5LumaFilter08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5LumaFilter08',
                ),
                'asf5maxexposureindex' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5MaxExposureIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5MaxExposureIndex',
                ),
                'asf5nrmlothres' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5NrmLoThres',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmLoThres',
                ),
                'asf5nrmshrpdegf1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5NrmShrpDegF1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmShrpDegF1',
                ),
                'asf5nrmshrpdegf2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5NrmShrpDegF2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmShrpDegF2',
                ),
                'asf5nrmsmthprcnt' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5NrmSmthPrcnt',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmSmthPrcnt',
                ),
                'asf5nrmupthres' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5NrmUpThres',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmUpThres',
                ),
                'asf5nrmizefactor1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5NrmizeFactor1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmizeFactor1',
                ),
                'asf5nrmizefactor2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ASF5NrmizeFactor2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ASF5NrmizeFactor2',
                ),
                'awbaggressiveness' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBAggressiveness',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBAggressiveness',
                ),
                'awbagwgriddist2thresh' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBAgwGridDist2Thresh',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBAgwGridDist2Thresh',
                ),
                'awbalgorithm' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBAlgorithm',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBAlgorithm',
                ),
                'awbavebgratio' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBAveBgRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBAveBgRatio',
                ),
                'awbavergratio' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBAveRgRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBAveRgRatio',
                ),
                'awbbluegainadjref1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainAdjRef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef1',
                ),
                'awbbluegainadjref2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainAdjRef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef2',
                ),
                'awbbluegainadjref3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainAdjRef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef3',
                ),
                'awbbluegainadjref4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainAdjRef4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef4',
                ),
                'awbbluegainadjref5' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainAdjRef5',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef5',
                ),
                'awbbluegainadjref6' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainAdjRef6',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef6',
                ),
                'awbbluegainadjref7' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainAdjRef7',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef7',
                ),
                'awbbluegainadjref8' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainAdjRef8',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainAdjRef8',
                ),
                'awbbluegainref1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainRef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef1',
                ),
                'awbbluegainref2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainRef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef2',
                ),
                'awbbluegainref3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainRef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef3',
                ),
                'awbbluegainref4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainRef4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef4',
                ),
                'awbbluegainref5' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainRef5',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef5',
                ),
                'awbbluegainref6' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainRef6',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef6',
                ),
                'awbbluegainref7' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainRef7',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef7',
                ),
                'awbbluegainref8' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBBlueGainRef8',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBBlueGainRef8',
                ),
                'awbccbias' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBCcBias',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBCcBias',
                ),
                'awbcompactclusterr2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBCompactClusterR2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBCompactClusterR2',
                ),
                'awbenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBEnable',
                ),
                'awbgreenoffsetbg' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBGreenOffsetBg',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBGreenOffsetBg',
                ),
                'awbgreenoffsetrg' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBGreenOffsetRg',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBGreenOffsetRg',
                ),
                'awbindoorsampleinfluence' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBIndoorSampleInfluence',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBIndoorSampleInfluence',
                ),
                'awblovfec1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeC1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeC1',
                ),
                'awblovfec2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeC2',
                ),
                'awblovfec3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeC3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeC3',
                ),
                'awblovfec4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeC4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeC4',
                ),
                'awblovfem1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeM1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeM1',
                ),
                'awblovfem2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeM2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeM2',
                ),
                'awblovfem3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeM3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeM3',
                ),
                'awblovfem4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeM4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeM4',
                ),
                'awblovfemaxy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeMaxY',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeMaxY',
                ),
                'awblovfeminy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLoVfeMinY',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLoVfeMinY',
                ),
                'awblowligcolcorena' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBLowLigColCorEna',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBLowLigColCorEna',
                ),
                'awbmaxbgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBMaxBGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBMaxBGain',
                ),
                'awbmaxggain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBMaxGGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBMaxGGain',
                ),
                'awbmaxrgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBMaxRGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBMaxRGain',
                ),
                'awbminbgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBMinBGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBMinBGain',
                ),
                'awbminggain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBMinGGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBMinGGain',
                ),
                'awbminrgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBMinRGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBMinRGain',
                ),
                'awbnormvfec1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeC1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeC1',
                ),
                'awbnormvfec2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeC2',
                ),
                'awbnormvfec3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeC3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeC3',
                ),
                'awbnormvfec4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeC4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeC4',
                ),
                'awbnormvfem1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeM1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeM1',
                ),
                'awbnormvfem2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeM2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeM2',
                ),
                'awbnormvfem3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeM3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeM3',
                ),
                'awbnormvfem4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeM4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeM4',
                ),
                'awbnormvfemaxy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeMaxY',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeMaxY',
                ),
                'awbnormvfeminy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBNormVfeMinY',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBNormVfeMinY',
                ),
                'awboudorvfec1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeC1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeC1',
                ),
                'awboudorvfec2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeC2',
                ),
                'awboudorvfec3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeC3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeC3',
                ),
                'awboudorvfec4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeC4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeC4',
                ),
                'awboudorvfem1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeM1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeM1',
                ),
                'awboudorvfem2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeM2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeM2',
                ),
                'awboudorvfem3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeM3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeM3',
                ),
                'awboudorvfem4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeM4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeM4',
                ),
                'awboudorvfemaxy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeMaxY',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeMaxY',
                ),
                'awboudorvfeminy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOudorVfeMinY',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOudorVfeMinY',
                ),
                'awboutdoorsampleinfluence' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBOutdoorSampleInfluence',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBOutdoorSampleInfluence',
                ),
                'awbprevwbbgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBPrevWbBgain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBPrevWbBgain',
                ),
                'awbprevwbggain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBPrevWbGgain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBPrevWbGgain',
                ),
                'awbprevwbrgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBPrevWbRgain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBPrevWbRgain',
                ),
                'awbredgainadjref1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainAdjRef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef1',
                ),
                'awbredgainadjref2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainAdjRef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef2',
                ),
                'awbredgainadjref3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainAdjRef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef3',
                ),
                'awbredgainadjref4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainAdjRef4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef4',
                ),
                'awbredgainadjref5' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainAdjRef5',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef5',
                ),
                'awbredgainadjref6' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainAdjRef6',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef6',
                ),
                'awbredgainadjref7' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainAdjRef7',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef7',
                ),
                'awbredgainadjref8' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainAdjRef8',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainAdjRef8',
                ),
                'awbredgainref1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainRef1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef1',
                ),
                'awbredgainref2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainRef2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef2',
                ),
                'awbredgainref3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainRef3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef3',
                ),
                'awbredgainref4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainRef4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef4',
                ),
                'awbredgainref5' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainRef5',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef5',
                ),
                'awbredgainref6' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainRef6',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef6',
                ),
                'awbredgainref7' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainRef7',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef7',
                ),
                'awbredgainref8' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBRedGainRef8',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBRedGainRef8',
                ),
                'awbsampledecision' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBSampleDecision',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBSampleDecision',
                ),
                'awbsnapshotbgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBSnapshotBGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBSnapshotBGain',
                ),
                'awbsnapshotrgain' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'AWBSnapshotRGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\AWBSnapshotRGain',
                ),
                'blcklvlevencols' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'BlckLvlEvenCols',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\BlckLvlEvenCols',
                ),
                'blcklvloddcols' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'BlckLvlOddCols',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\BlckLvlOddCols',
                ),
                'cammclkhz' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'CamMclkHz',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\CamMclkHz',
                ),
                'chrosupchrothres1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ChroSupChroThres1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ChroSupChroThres1',
                ),
                'chrosupchrothres2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ChroSupChroThres2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ChroSupChroThres2',
                ),
                'chrosuplumathres1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ChroSupLumaThres1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ChroSupLumaThres1',
                ),
                'chrosuplumathres2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ChroSupLumaThres2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ChroSupLumaThres2',
                ),
                'chrosuplumathres3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ChroSupLumaThres3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ChroSupLumaThres3',
                ),
                'chrosuplumathres4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ChroSupLumaThres4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ChroSupLumaThres4',
                ),
                'chromsupress' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ChromSupress',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ChromSupress',
                ),
                'cliptoafrato' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'ClipToAfRato',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\ClipToAfRato',
                ),
                'currresol' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'CurrResol',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\CurrResol',
                ),
                'dayltconvchrma_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmA_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmAM',
                ),
                'dayltconvchrma_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmA_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmAP',
                ),
                'dayltconvchrmb_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmB_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmBM',
                ),
                'dayltconvchrmb_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmB_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmBP',
                ),
                'dayltconvchrmc_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmC_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmCM',
                ),
                'dayltconvchrmc_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmC_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmCP',
                ),
                'dayltconvchrmd_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmD_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmDM',
                ),
                'dayltconvchrmd_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmD_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmDP',
                ),
                'dayltconvchrmkcb' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmKCb',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmKCb',
                ),
                'dayltconvchrmkcr' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvChrmKCr',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvChrmKCr',
                ),
                'dayltconvlumak' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvLumaK',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvLumaK',
                ),
                'dayltconvlumav0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvLumaV0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvLumaV0',
                ),
                'dayltconvlumav1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvLumaV1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvLumaV1',
                ),
                'dayltconvlumav2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DayltConvLumaV2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DayltConvLumaV2',
                ),
                'defconvchrma_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmA_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmAM',
                ),
                'defconvchrma_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmA_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmAP',
                ),
                'defconvchrmb_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmB_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmBM',
                ),
                'defconvchrmb_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmB_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmBP',
                ),
                'defconvchrmc_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmC_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmCM',
                ),
                'defconvchrmc_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmC_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmCP',
                ),
                'defconvchrmd_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmD_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmDM',
                ),
                'defconvchrmd_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmD_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmDP',
                ),
                'defconvchrmkcb' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmKCb',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmKCb',
                ),
                'defconvchrmkcr' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvChrmKCr',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvChrmKCr',
                ),
                'defconvlumak' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvLumaK',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvLumaK',
                ),
                'defconvlumav0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvLumaV0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvLumaV0',
                ),
                'defconvlumav1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvLumaV1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvLumaV1',
                ),
                'defconvlumav2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefConvLumaV2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefConvLumaV2',
                ),
                'defcorc0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC0',
                ),
                'defcorc1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC1',
                ),
                'defcorc2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC2',
                ),
                'defcorc3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC3',
                ),
                'defcorc4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC4',
                ),
                'defcorc5' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC5',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC5',
                ),
                'defcorc6' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC6',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC6',
                ),
                'defcorc7' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC7',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC7',
                ),
                'defcorc8' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorC8',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorC8',
                ),
                'defcork0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorK0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorK0',
                ),
                'defcork1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorK1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorK1',
                ),
                'defcork2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefCorK2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefCorK2',
                ),
                'deflumagammamode' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefLumaGammaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefLumaGammaMode',
                ),
                'defrgbgammamode' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefRgbGammaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefRgbGammaMode',
                ),
                'defectpixcorenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefectPixCorEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefectPixCorEnable',
                ),
                'defectpixmaxthresh' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefectPixMaxThresh',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefectPixMaxThresh',
                ),
                'defectpixminthresh' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DefectPixMinThresh',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DefectPixMinThresh',
                ),
                'discardfrstfrm' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'DiscardFrstFrm',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\DiscardFrstFrm',
                ),
                'frmskippttrn' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'FrmSkipPttrn',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\FrmSkipPttrn',
                ),
                'gammaenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'GammaEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\GammaEnable',
                ),
                'incandconvchrma_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmA_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmAM',
                ),
                'incandconvchrma_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmA_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmAP',
                ),
                'incandconvchrmb_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmB_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmBM',
                ),
                'incandconvchrmb_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmB_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmBP',
                ),
                'incandconvchrmc_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmC_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmCM',
                ),
                'incandconvchrmc_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmC_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmCP',
                ),
                'incandconvchrmd_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmD_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmDM',
                ),
                'incandconvchrmd_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmD_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmDP',
                ),
                'incandconvchrmkcb' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmKCb',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmKCb',
                ),
                'incandconvchrmkcr' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvChrmKCr',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvChrmKCr',
                ),
                'incandconvlumak' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvLumaK',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvLumaK',
                ),
                'incandconvlumav0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvLumaV0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvLumaV0',
                ),
                'incandconvlumav1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvLumaV1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvLumaV1',
                ),
                'incandconvlumav2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'IncandConvLumaV2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\IncandConvLumaV2',
                ),
                'ladetect' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'LADetect',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\LADetect',
                ),
                'laenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'LAEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\LAEnable',
                ),
                'maxprviewfps' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'MaxPrviewFps',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\MaxPrviewFps',
                ),
                'maxvideofps' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'MaxVideoFps',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\MaxVideoFps',
                ),
                'nghtshtfps' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'NghtshtFps',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\NghtshtFps',
                ),
                'nightshotmode' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'NightshotMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\NightshotMode',
                ),
                'outlierdistance' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'OutlierDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\OutlierDistance',
                ),
                'pclkinvert' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'PclkInvert',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\PclkInvert',
                ),
                'prviewfps' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'PrviewFps',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\PrviewFps',
                ),
                'prviewresol' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'PrviewResol',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\PrviewResol',
                ),
                'r2abluectbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl00',
                ),
                'r2abluectbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl10',
                ),
                'r2abluectbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl11',
                ),
                'r2abluectbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl12',
                ),
                'r2abluectbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl13',
                ),
                'r2abluectbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl14',
                ),
                'r2abluectbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl15',
                ),
                'r2abluectbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl16',
                ),
                'r2abluectbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl17',
                ),
                'r2abluectbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl18',
                ),
                'r2abluectbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl19',
                ),
                'r2abluectbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl01',
                ),
                'r2abluectbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl20',
                ),
                'r2abluectbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl21',
                ),
                'r2abluectbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl22',
                ),
                'r2abluectbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl23',
                ),
                'r2abluectbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl24',
                ),
                'r2abluectbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl25',
                ),
                'r2abluectbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl26',
                ),
                'r2abluectbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl27',
                ),
                'r2abluectbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl28',
                ),
                'r2abluectbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl29',
                ),
                'r2abluectbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl02',
                ),
                'r2abluectbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl30',
                ),
                'r2abluectbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl31',
                ),
                'r2abluectbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl03',
                ),
                'r2abluectbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl04',
                ),
                'r2abluectbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl05',
                ),
                'r2abluectbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl06',
                ),
                'r2abluectbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl07',
                ),
                'r2abluectbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl08',
                ),
                'r2abluectbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueCtbl09',
                ),
                'r2abluestbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl00',
                ),
                'r2abluestbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl10',
                ),
                'r2abluestbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl11',
                ),
                'r2abluestbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl12',
                ),
                'r2abluestbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl13',
                ),
                'r2abluestbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl14',
                ),
                'r2abluestbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl15',
                ),
                'r2abluestbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl16',
                ),
                'r2abluestbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl17',
                ),
                'r2abluestbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl18',
                ),
                'r2abluestbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl19',
                ),
                'r2abluestbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl01',
                ),
                'r2abluestbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl20',
                ),
                'r2abluestbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl21',
                ),
                'r2abluestbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl22',
                ),
                'r2abluestbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl23',
                ),
                'r2abluestbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl24',
                ),
                'r2abluestbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl25',
                ),
                'r2abluestbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl26',
                ),
                'r2abluestbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl27',
                ),
                'r2abluestbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl28',
                ),
                'r2abluestbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl29',
                ),
                'r2abluestbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl02',
                ),
                'r2abluestbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl30',
                ),
                'r2abluestbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl31',
                ),
                'r2abluestbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl03',
                ),
                'r2abluestbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl04',
                ),
                'r2abluestbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl05',
                ),
                'r2abluestbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl06',
                ),
                'r2abluestbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl07',
                ),
                'r2abluestbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl08',
                ),
                'r2abluestbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ABlueStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ABlueStbl09',
                ),
                'r2acx' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ACx',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ACx',
                ),
                'r2acy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ACy',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ACy',
                ),
                'r2agreenctbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl00',
                ),
                'r2agreenctbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl10',
                ),
                'r2agreenctbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl11',
                ),
                'r2agreenctbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl12',
                ),
                'r2agreenctbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl13',
                ),
                'r2agreenctbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl14',
                ),
                'r2agreenctbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl15',
                ),
                'r2agreenctbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl16',
                ),
                'r2agreenctbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl17',
                ),
                'r2agreenctbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl18',
                ),
                'r2agreenctbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl19',
                ),
                'r2agreenctbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl01',
                ),
                'r2agreenctbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl20',
                ),
                'r2agreenctbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl21',
                ),
                'r2agreenctbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl22',
                ),
                'r2agreenctbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl23',
                ),
                'r2agreenctbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl24',
                ),
                'r2agreenctbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl25',
                ),
                'r2agreenctbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl26',
                ),
                'r2agreenctbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl27',
                ),
                'r2agreenctbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl28',
                ),
                'r2agreenctbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl29',
                ),
                'r2agreenctbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl02',
                ),
                'r2agreenctbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl30',
                ),
                'r2agreenctbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl31',
                ),
                'r2agreenctbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl03',
                ),
                'r2agreenctbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl04',
                ),
                'r2agreenctbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl05',
                ),
                'r2agreenctbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl06',
                ),
                'r2agreenctbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl07',
                ),
                'r2agreenctbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl08',
                ),
                'r2agreenctbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenCtbl09',
                ),
                'r2agreenstbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl00',
                ),
                'r2agreenstbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl10',
                ),
                'r2agreenstbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl11',
                ),
                'r2agreenstbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl12',
                ),
                'r2agreenstbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl13',
                ),
                'r2agreenstbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl14',
                ),
                'r2agreenstbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl15',
                ),
                'r2agreenstbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl16',
                ),
                'r2agreenstbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl17',
                ),
                'r2agreenstbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl18',
                ),
                'r2agreenstbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl19',
                ),
                'r2agreenstbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl01',
                ),
                'r2agreenstbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl20',
                ),
                'r2agreenstbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl21',
                ),
                'r2agreenstbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl22',
                ),
                'r2agreenstbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl23',
                ),
                'r2agreenstbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl24',
                ),
                'r2agreenstbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl25',
                ),
                'r2agreenstbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl26',
                ),
                'r2agreenstbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl27',
                ),
                'r2agreenstbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl28',
                ),
                'r2agreenstbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl29',
                ),
                'r2agreenstbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl02',
                ),
                'r2agreenstbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl30',
                ),
                'r2agreenstbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl31',
                ),
                'r2agreenstbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl03',
                ),
                'r2agreenstbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl04',
                ),
                'r2agreenstbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl05',
                ),
                'r2agreenstbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl06',
                ),
                'r2agreenstbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl07',
                ),
                'r2agreenstbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl08',
                ),
                'r2agreenstbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AGreenStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AGreenStbl09',
                ),
                'r2aheight' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AHeight',
                ),
                'r2aintervals' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AIntervals',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AIntervals',
                ),
                'r2aredctbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl00',
                ),
                'r2aredctbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl10',
                ),
                'r2aredctbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl11',
                ),
                'r2aredctbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl12',
                ),
                'r2aredctbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl13',
                ),
                'r2aredctbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl14',
                ),
                'r2aredctbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl15',
                ),
                'r2aredctbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl16',
                ),
                'r2aredctbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl17',
                ),
                'r2aredctbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl18',
                ),
                'r2aredctbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl19',
                ),
                'r2aredctbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl01',
                ),
                'r2aredctbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl20',
                ),
                'r2aredctbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl21',
                ),
                'r2aredctbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl22',
                ),
                'r2aredctbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl23',
                ),
                'r2aredctbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl24',
                ),
                'r2aredctbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl25',
                ),
                'r2aredctbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl26',
                ),
                'r2aredctbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl27',
                ),
                'r2aredctbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl28',
                ),
                'r2aredctbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl29',
                ),
                'r2aredctbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl02',
                ),
                'r2aredctbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl30',
                ),
                'r2aredctbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl31',
                ),
                'r2aredctbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl03',
                ),
                'r2aredctbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl04',
                ),
                'r2aredctbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl05',
                ),
                'r2aredctbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl06',
                ),
                'r2aredctbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl07',
                ),
                'r2aredctbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl08',
                ),
                'r2aredctbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedCtbl09',
                ),
                'r2aredstbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl00',
                ),
                'r2aredstbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl10',
                ),
                'r2aredstbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl11',
                ),
                'r2aredstbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl12',
                ),
                'r2aredstbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl13',
                ),
                'r2aredstbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl14',
                ),
                'r2aredstbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl15',
                ),
                'r2aredstbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl16',
                ),
                'r2aredstbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl17',
                ),
                'r2aredstbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl18',
                ),
                'r2aredstbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl19',
                ),
                'r2aredstbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl01',
                ),
                'r2aredstbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl20',
                ),
                'r2aredstbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl21',
                ),
                'r2aredstbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl22',
                ),
                'r2aredstbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl23',
                ),
                'r2aredstbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl24',
                ),
                'r2aredstbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl25',
                ),
                'r2aredstbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl26',
                ),
                'r2aredstbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl27',
                ),
                'r2aredstbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl28',
                ),
                'r2aredstbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl29',
                ),
                'r2aredstbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl02',
                ),
                'r2aredstbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl30',
                ),
                'r2aredstbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl31',
                ),
                'r2aredstbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl03',
                ),
                'r2aredstbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl04',
                ),
                'r2aredstbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl05',
                ),
                'r2aredstbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl06',
                ),
                'r2aredstbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl07',
                ),
                'r2aredstbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl08',
                ),
                'r2aredstbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ARedStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ARedStbl09',
                ),
                'r2atbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl00',
                ),
                'r2atbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl10',
                ),
                'r2atbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl11',
                ),
                'r2atbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl12',
                ),
                'r2atbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl13',
                ),
                'r2atbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl14',
                ),
                'r2atbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl15',
                ),
                'r2atbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl16',
                ),
                'r2atbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl17',
                ),
                'r2atbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl18',
                ),
                'r2atbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl19',
                ),
                'r2atbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl01',
                ),
                'r2atbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl20',
                ),
                'r2atbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl21',
                ),
                'r2atbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl22',
                ),
                'r2atbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl23',
                ),
                'r2atbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl24',
                ),
                'r2atbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl25',
                ),
                'r2atbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl26',
                ),
                'r2atbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl27',
                ),
                'r2atbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl28',
                ),
                'r2atbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl29',
                ),
                'r2atbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl02',
                ),
                'r2atbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl30',
                ),
                'r2atbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl31',
                ),
                'r2atbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl03',
                ),
                'r2atbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl04',
                ),
                'r2atbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl05',
                ),
                'r2atbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl06',
                ),
                'r2atbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl07',
                ),
                'r2atbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl08',
                ),
                'r2atbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2ATbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2ATbl09',
                ),
                'r2awidth' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2AWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2AWidth',
                ),
                'r2d65bluectbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl00',
                ),
                'r2d65bluectbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl10',
                ),
                'r2d65bluectbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl11',
                ),
                'r2d65bluectbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl12',
                ),
                'r2d65bluectbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl13',
                ),
                'r2d65bluectbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl14',
                ),
                'r2d65bluectbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl15',
                ),
                'r2d65bluectbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl16',
                ),
                'r2d65bluectbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl17',
                ),
                'r2d65bluectbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl18',
                ),
                'r2d65bluectbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl19',
                ),
                'r2d65bluectbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl01',
                ),
                'r2d65bluectbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl20',
                ),
                'r2d65bluectbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl21',
                ),
                'r2d65bluectbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl22',
                ),
                'r2d65bluectbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl23',
                ),
                'r2d65bluectbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl24',
                ),
                'r2d65bluectbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl25',
                ),
                'r2d65bluectbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl26',
                ),
                'r2d65bluectbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl27',
                ),
                'r2d65bluectbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl28',
                ),
                'r2d65bluectbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl29',
                ),
                'r2d65bluectbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl02',
                ),
                'r2d65bluectbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl30',
                ),
                'r2d65bluectbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl31',
                ),
                'r2d65bluectbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl03',
                ),
                'r2d65bluectbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl04',
                ),
                'r2d65bluectbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl05',
                ),
                'r2d65bluectbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl06',
                ),
                'r2d65bluectbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl07',
                ),
                'r2d65bluectbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl08',
                ),
                'r2d65bluectbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueCtbl09',
                ),
                'r2d65bluestbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl00',
                ),
                'r2d65bluestbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl10',
                ),
                'r2d65bluestbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl11',
                ),
                'r2d65bluestbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl12',
                ),
                'r2d65bluestbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl13',
                ),
                'r2d65bluestbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl14',
                ),
                'r2d65bluestbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl15',
                ),
                'r2d65bluestbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl16',
                ),
                'r2d65bluestbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl17',
                ),
                'r2d65bluestbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl18',
                ),
                'r2d65bluestbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl19',
                ),
                'r2d65bluestbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl01',
                ),
                'r2d65bluestbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl20',
                ),
                'r2d65bluestbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl21',
                ),
                'r2d65bluestbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl22',
                ),
                'r2d65bluestbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl23',
                ),
                'r2d65bluestbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl24',
                ),
                'r2d65bluestbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl25',
                ),
                'r2d65bluestbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl26',
                ),
                'r2d65bluestbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl27',
                ),
                'r2d65bluestbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl28',
                ),
                'r2d65bluestbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl29',
                ),
                'r2d65bluestbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl02',
                ),
                'r2d65bluestbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl30',
                ),
                'r2d65bluestbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl31',
                ),
                'r2d65bluestbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl03',
                ),
                'r2d65bluestbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl04',
                ),
                'r2d65bluestbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl05',
                ),
                'r2d65bluestbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl06',
                ),
                'r2d65bluestbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl07',
                ),
                'r2d65bluestbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl08',
                ),
                'r2d65bluestbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65BlueStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65BlueStbl09',
                ),
                'r2d65cx' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Cx',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Cx',
                ),
                'r2d65cy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Cy',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Cy',
                ),
                'r2d65greenctbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl00',
                ),
                'r2d65greenctbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl10',
                ),
                'r2d65greenctbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl11',
                ),
                'r2d65greenctbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl12',
                ),
                'r2d65greenctbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl13',
                ),
                'r2d65greenctbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl14',
                ),
                'r2d65greenctbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl15',
                ),
                'r2d65greenctbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl16',
                ),
                'r2d65greenctbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl17',
                ),
                'r2d65greenctbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl18',
                ),
                'r2d65greenctbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl19',
                ),
                'r2d65greenctbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl01',
                ),
                'r2d65greenctbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl20',
                ),
                'r2d65greenctbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl21',
                ),
                'r2d65greenctbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl22',
                ),
                'r2d65greenctbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl23',
                ),
                'r2d65greenctbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl24',
                ),
                'r2d65greenctbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl25',
                ),
                'r2d65greenctbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl26',
                ),
                'r2d65greenctbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl27',
                ),
                'r2d65greenctbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl28',
                ),
                'r2d65greenctbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl29',
                ),
                'r2d65greenctbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl02',
                ),
                'r2d65greenctbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl30',
                ),
                'r2d65greenctbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl31',
                ),
                'r2d65greenctbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl03',
                ),
                'r2d65greenctbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl04',
                ),
                'r2d65greenctbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl05',
                ),
                'r2d65greenctbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl06',
                ),
                'r2d65greenctbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl07',
                ),
                'r2d65greenctbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl08',
                ),
                'r2d65greenctbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenCtbl09',
                ),
                'r2d65greenstbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl00',
                ),
                'r2d65greenstbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl10',
                ),
                'r2d65greenstbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl11',
                ),
                'r2d65greenstbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl12',
                ),
                'r2d65greenstbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl13',
                ),
                'r2d65greenstbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl14',
                ),
                'r2d65greenstbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl15',
                ),
                'r2d65greenstbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl16',
                ),
                'r2d65greenstbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl17',
                ),
                'r2d65greenstbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl18',
                ),
                'r2d65greenstbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl19',
                ),
                'r2d65greenstbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl01',
                ),
                'r2d65greenstbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl20',
                ),
                'r2d65greenstbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl21',
                ),
                'r2d65greenstbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl22',
                ),
                'r2d65greenstbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl23',
                ),
                'r2d65greenstbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl24',
                ),
                'r2d65greenstbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl25',
                ),
                'r2d65greenstbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl26',
                ),
                'r2d65greenstbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl27',
                ),
                'r2d65greenstbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl28',
                ),
                'r2d65greenstbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl29',
                ),
                'r2d65greenstbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl02',
                ),
                'r2d65greenstbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl30',
                ),
                'r2d65greenstbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl31',
                ),
                'r2d65greenstbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl03',
                ),
                'r2d65greenstbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl04',
                ),
                'r2d65greenstbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl05',
                ),
                'r2d65greenstbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl06',
                ),
                'r2d65greenstbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl07',
                ),
                'r2d65greenstbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl08',
                ),
                'r2d65greenstbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65GreenStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65GreenStbl09',
                ),
                'r2d65height' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Height',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Height',
                ),
                'r2d65intervals' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Intervals',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Intervals',
                ),
                'r2d65redctbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl00',
                ),
                'r2d65redctbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl10',
                ),
                'r2d65redctbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl11',
                ),
                'r2d65redctbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl12',
                ),
                'r2d65redctbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl13',
                ),
                'r2d65redctbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl14',
                ),
                'r2d65redctbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl15',
                ),
                'r2d65redctbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl16',
                ),
                'r2d65redctbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl17',
                ),
                'r2d65redctbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl18',
                ),
                'r2d65redctbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl19',
                ),
                'r2d65redctbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl01',
                ),
                'r2d65redctbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl20',
                ),
                'r2d65redctbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl21',
                ),
                'r2d65redctbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl22',
                ),
                'r2d65redctbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl23',
                ),
                'r2d65redctbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl24',
                ),
                'r2d65redctbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl25',
                ),
                'r2d65redctbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl26',
                ),
                'r2d65redctbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl27',
                ),
                'r2d65redctbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl28',
                ),
                'r2d65redctbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl29',
                ),
                'r2d65redctbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl02',
                ),
                'r2d65redctbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl30',
                ),
                'r2d65redctbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl31',
                ),
                'r2d65redctbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl03',
                ),
                'r2d65redctbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl04',
                ),
                'r2d65redctbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl05',
                ),
                'r2d65redctbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl06',
                ),
                'r2d65redctbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl07',
                ),
                'r2d65redctbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl08',
                ),
                'r2d65redctbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedCtbl09',
                ),
                'r2d65redstbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl00',
                ),
                'r2d65redstbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl10',
                ),
                'r2d65redstbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl11',
                ),
                'r2d65redstbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl12',
                ),
                'r2d65redstbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl13',
                ),
                'r2d65redstbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl14',
                ),
                'r2d65redstbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl15',
                ),
                'r2d65redstbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl16',
                ),
                'r2d65redstbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl17',
                ),
                'r2d65redstbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl18',
                ),
                'r2d65redstbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl19',
                ),
                'r2d65redstbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl01',
                ),
                'r2d65redstbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl20',
                ),
                'r2d65redstbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl21',
                ),
                'r2d65redstbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl22',
                ),
                'r2d65redstbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl23',
                ),
                'r2d65redstbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl24',
                ),
                'r2d65redstbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl25',
                ),
                'r2d65redstbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl26',
                ),
                'r2d65redstbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl27',
                ),
                'r2d65redstbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl28',
                ),
                'r2d65redstbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl29',
                ),
                'r2d65redstbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl02',
                ),
                'r2d65redstbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl30',
                ),
                'r2d65redstbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl31',
                ),
                'r2d65redstbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl03',
                ),
                'r2d65redstbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl04',
                ),
                'r2d65redstbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl05',
                ),
                'r2d65redstbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl06',
                ),
                'r2d65redstbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl07',
                ),
                'r2d65redstbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl08',
                ),
                'r2d65redstbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65RedStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65RedStbl09',
                ),
                'r2d65tbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl00',
                ),
                'r2d65tbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl10',
                ),
                'r2d65tbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl11',
                ),
                'r2d65tbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl12',
                ),
                'r2d65tbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl13',
                ),
                'r2d65tbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl14',
                ),
                'r2d65tbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl15',
                ),
                'r2d65tbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl16',
                ),
                'r2d65tbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl17',
                ),
                'r2d65tbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl18',
                ),
                'r2d65tbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl19',
                ),
                'r2d65tbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl01',
                ),
                'r2d65tbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl20',
                ),
                'r2d65tbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl21',
                ),
                'r2d65tbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl22',
                ),
                'r2d65tbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl23',
                ),
                'r2d65tbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl24',
                ),
                'r2d65tbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl25',
                ),
                'r2d65tbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl26',
                ),
                'r2d65tbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl27',
                ),
                'r2d65tbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl28',
                ),
                'r2d65tbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl29',
                ),
                'r2d65tbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl02',
                ),
                'r2d65tbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl30',
                ),
                'r2d65tbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl31',
                ),
                'r2d65tbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl03',
                ),
                'r2d65tbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl04',
                ),
                'r2d65tbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl05',
                ),
                'r2d65tbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl06',
                ),
                'r2d65tbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl07',
                ),
                'r2d65tbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl08',
                ),
                'r2d65tbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Tbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Tbl09',
                ),
                'r2d65width' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2D65Width',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2D65Width',
                ),
                'r2tl84bluectbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl00',
                ),
                'r2tl84bluectbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl10',
                ),
                'r2tl84bluectbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl11',
                ),
                'r2tl84bluectbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl12',
                ),
                'r2tl84bluectbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl13',
                ),
                'r2tl84bluectbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl14',
                ),
                'r2tl84bluectbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl15',
                ),
                'r2tl84bluectbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl16',
                ),
                'r2tl84bluectbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl17',
                ),
                'r2tl84bluectbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl18',
                ),
                'r2tl84bluectbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl19',
                ),
                'r2tl84bluectbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl01',
                ),
                'r2tl84bluectbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl20',
                ),
                'r2tl84bluectbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl21',
                ),
                'r2tl84bluectbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl22',
                ),
                'r2tl84bluectbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl23',
                ),
                'r2tl84bluectbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl24',
                ),
                'r2tl84bluectbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl25',
                ),
                'r2tl84bluectbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl26',
                ),
                'r2tl84bluectbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl27',
                ),
                'r2tl84bluectbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl28',
                ),
                'r2tl84bluectbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl29',
                ),
                'r2tl84bluectbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl02',
                ),
                'r2tl84bluectbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl30',
                ),
                'r2tl84bluectbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl31',
                ),
                'r2tl84bluectbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl03',
                ),
                'r2tl84bluectbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl04',
                ),
                'r2tl84bluectbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl05',
                ),
                'r2tl84bluectbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl06',
                ),
                'r2tl84bluectbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl07',
                ),
                'r2tl84bluectbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl08',
                ),
                'r2tl84bluectbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueCtbl09',
                ),
                'r2tl84bluestbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl00',
                ),
                'r2tl84bluestbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl10',
                ),
                'r2tl84bluestbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl11',
                ),
                'r2tl84bluestbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl12',
                ),
                'r2tl84bluestbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl13',
                ),
                'r2tl84bluestbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl14',
                ),
                'r2tl84bluestbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl15',
                ),
                'r2tl84bluestbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl16',
                ),
                'r2tl84bluestbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl17',
                ),
                'r2tl84bluestbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl18',
                ),
                'r2tl84bluestbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl19',
                ),
                'r2tl84bluestbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl01',
                ),
                'r2tl84bluestbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl20',
                ),
                'r2tl84bluestbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl21',
                ),
                'r2tl84bluestbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl22',
                ),
                'r2tl84bluestbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl23',
                ),
                'r2tl84bluestbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl24',
                ),
                'r2tl84bluestbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl25',
                ),
                'r2tl84bluestbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl26',
                ),
                'r2tl84bluestbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl27',
                ),
                'r2tl84bluestbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl28',
                ),
                'r2tl84bluestbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl29',
                ),
                'r2tl84bluestbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl02',
                ),
                'r2tl84bluestbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl30',
                ),
                'r2tl84bluestbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl31',
                ),
                'r2tl84bluestbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl03',
                ),
                'r2tl84bluestbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl04',
                ),
                'r2tl84bluestbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl05',
                ),
                'r2tl84bluestbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl06',
                ),
                'r2tl84bluestbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl07',
                ),
                'r2tl84bluestbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl08',
                ),
                'r2tl84bluestbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84BlueStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84BlueStbl09',
                ),
                'r2tl84cx' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Cx',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Cx',
                ),
                'r2tl84cy' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Cy',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Cy',
                ),
                'r2tl84greenctbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl00',
                ),
                'r2tl84greenctbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl10',
                ),
                'r2tl84greenctbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl11',
                ),
                'r2tl84greenctbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl12',
                ),
                'r2tl84greenctbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl13',
                ),
                'r2tl84greenctbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl14',
                ),
                'r2tl84greenctbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl15',
                ),
                'r2tl84greenctbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl16',
                ),
                'r2tl84greenctbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl17',
                ),
                'r2tl84greenctbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl18',
                ),
                'r2tl84greenctbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl19',
                ),
                'r2tl84greenctbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl01',
                ),
                'r2tl84greenctbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl20',
                ),
                'r2tl84greenctbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl21',
                ),
                'r2tl84greenctbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl22',
                ),
                'r2tl84greenctbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl23',
                ),
                'r2tl84greenctbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl24',
                ),
                'r2tl84greenctbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl25',
                ),
                'r2tl84greenctbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl26',
                ),
                'r2tl84greenctbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl27',
                ),
                'r2tl84greenctbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl28',
                ),
                'r2tl84greenctbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl29',
                ),
                'r2tl84greenctbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl02',
                ),
                'r2tl84greenctbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl30',
                ),
                'r2tl84greenctbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl31',
                ),
                'r2tl84greenctbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl03',
                ),
                'r2tl84greenctbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl04',
                ),
                'r2tl84greenctbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl05',
                ),
                'r2tl84greenctbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl06',
                ),
                'r2tl84greenctbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl07',
                ),
                'r2tl84greenctbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl08',
                ),
                'r2tl84greenctbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenCtbl09',
                ),
                'r2tl84greenstbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl00',
                ),
                'r2tl84greenstbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl10',
                ),
                'r2tl84greenstbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl11',
                ),
                'r2tl84greenstbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl12',
                ),
                'r2tl84greenstbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl13',
                ),
                'r2tl84greenstbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl14',
                ),
                'r2tl84greenstbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl15',
                ),
                'r2tl84greenstbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl16',
                ),
                'r2tl84greenstbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl17',
                ),
                'r2tl84greenstbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl18',
                ),
                'r2tl84greenstbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl19',
                ),
                'r2tl84greenstbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl01',
                ),
                'r2tl84greenstbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl20',
                ),
                'r2tl84greenstbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl21',
                ),
                'r2tl84greenstbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl22',
                ),
                'r2tl84greenstbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl23',
                ),
                'r2tl84greenstbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl24',
                ),
                'r2tl84greenstbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl25',
                ),
                'r2tl84greenstbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl26',
                ),
                'r2tl84greenstbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl27',
                ),
                'r2tl84greenstbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl28',
                ),
                'r2tl84greenstbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl29',
                ),
                'r2tl84greenstbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl02',
                ),
                'r2tl84greenstbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl30',
                ),
                'r2tl84greenstbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl31',
                ),
                'r2tl84greenstbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl03',
                ),
                'r2tl84greenstbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl04',
                ),
                'r2tl84greenstbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl05',
                ),
                'r2tl84greenstbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl06',
                ),
                'r2tl84greenstbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl07',
                ),
                'r2tl84greenstbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl08',
                ),
                'r2tl84greenstbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84GreenStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84GreenStbl09',
                ),
                'r2tl84height' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Height',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Height',
                ),
                'r2tl84intervals' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Intervals',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Intervals',
                ),
                'r2tl84redctbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl00',
                ),
                'r2tl84redctbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl10',
                ),
                'r2tl84redctbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl11',
                ),
                'r2tl84redctbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl12',
                ),
                'r2tl84redctbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl13',
                ),
                'r2tl84redctbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl14',
                ),
                'r2tl84redctbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl15',
                ),
                'r2tl84redctbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl16',
                ),
                'r2tl84redctbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl17',
                ),
                'r2tl84redctbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl18',
                ),
                'r2tl84redctbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl19',
                ),
                'r2tl84redctbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl01',
                ),
                'r2tl84redctbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl20',
                ),
                'r2tl84redctbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl21',
                ),
                'r2tl84redctbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl22',
                ),
                'r2tl84redctbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl23',
                ),
                'r2tl84redctbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl24',
                ),
                'r2tl84redctbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl25',
                ),
                'r2tl84redctbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl26',
                ),
                'r2tl84redctbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl27',
                ),
                'r2tl84redctbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl28',
                ),
                'r2tl84redctbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl29',
                ),
                'r2tl84redctbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl02',
                ),
                'r2tl84redctbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl30',
                ),
                'r2tl84redctbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl31',
                ),
                'r2tl84redctbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl03',
                ),
                'r2tl84redctbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl04',
                ),
                'r2tl84redctbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl05',
                ),
                'r2tl84redctbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl06',
                ),
                'r2tl84redctbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl07',
                ),
                'r2tl84redctbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl08',
                ),
                'r2tl84redctbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedCtbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedCtbl09',
                ),
                'r2tl84redstbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl00',
                ),
                'r2tl84redstbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl10',
                ),
                'r2tl84redstbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl11',
                ),
                'r2tl84redstbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl12',
                ),
                'r2tl84redstbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl13',
                ),
                'r2tl84redstbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl14',
                ),
                'r2tl84redstbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl15',
                ),
                'r2tl84redstbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl16',
                ),
                'r2tl84redstbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl17',
                ),
                'r2tl84redstbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl18',
                ),
                'r2tl84redstbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl19',
                ),
                'r2tl84redstbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl01',
                ),
                'r2tl84redstbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl20',
                ),
                'r2tl84redstbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl21',
                ),
                'r2tl84redstbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl22',
                ),
                'r2tl84redstbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl23',
                ),
                'r2tl84redstbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl24',
                ),
                'r2tl84redstbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl25',
                ),
                'r2tl84redstbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl26',
                ),
                'r2tl84redstbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl27',
                ),
                'r2tl84redstbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl28',
                ),
                'r2tl84redstbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl29',
                ),
                'r2tl84redstbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl02',
                ),
                'r2tl84redstbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl30',
                ),
                'r2tl84redstbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl31',
                ),
                'r2tl84redstbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl03',
                ),
                'r2tl84redstbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl04',
                ),
                'r2tl84redstbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl05',
                ),
                'r2tl84redstbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl06',
                ),
                'r2tl84redstbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl07',
                ),
                'r2tl84redstbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl08',
                ),
                'r2tl84redstbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84RedStbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84RedStbl09',
                ),
                'r2tl84tbl00' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl00',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl00',
                ),
                'r2tl84tbl10' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl10',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl10',
                ),
                'r2tl84tbl11' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl11',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl11',
                ),
                'r2tl84tbl12' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl12',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl12',
                ),
                'r2tl84tbl13' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl13',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl13',
                ),
                'r2tl84tbl14' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl14',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl14',
                ),
                'r2tl84tbl15' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl15',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl15',
                ),
                'r2tl84tbl16' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl16',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl16',
                ),
                'r2tl84tbl17' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl17',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl17',
                ),
                'r2tl84tbl18' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl18',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl18',
                ),
                'r2tl84tbl19' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl19',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl19',
                ),
                'r2tl84tbl01' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl01',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl01',
                ),
                'r2tl84tbl20' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl20',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl20',
                ),
                'r2tl84tbl21' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl21',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl21',
                ),
                'r2tl84tbl22' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl22',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl22',
                ),
                'r2tl84tbl23' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl23',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl23',
                ),
                'r2tl84tbl24' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl24',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl24',
                ),
                'r2tl84tbl25' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl25',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl25',
                ),
                'r2tl84tbl26' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl26',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl26',
                ),
                'r2tl84tbl27' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl27',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl27',
                ),
                'r2tl84tbl28' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl28',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl28',
                ),
                'r2tl84tbl29' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl29',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl29',
                ),
                'r2tl84tbl02' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl02',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl02',
                ),
                'r2tl84tbl30' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl30',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl30',
                ),
                'r2tl84tbl31' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl31',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl31',
                ),
                'r2tl84tbl03' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl03',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl03',
                ),
                'r2tl84tbl04' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl04',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl04',
                ),
                'r2tl84tbl05' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl05',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl05',
                ),
                'r2tl84tbl06' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl06',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl06',
                ),
                'r2tl84tbl07' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl07',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl07',
                ),
                'r2tl84tbl08' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl08',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl08',
                ),
                'r2tl84tbl09' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Tbl09',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Tbl09',
                ),
                'r2tl84width' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'R2TL84Width',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\R2TL84Width',
                ),
                'rolloffenable' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'RolloffEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\RolloffEnable',
                ),
                'sensorfmt' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'SensorFmt',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\SensorFmt',
                ),
                'sensortype' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'SensorType',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\SensorType',
                ),
                'sensrfulhght' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'SensrFulHght',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\SensrFulHght',
                ),
                'sensrfulwdth' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'SensrFulWdth',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\SensrFulWdth',
                ),
                'sensrqtrhght' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'SensrQtrHght',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\SensrQtrHght',
                ),
                'sensrqtrwdth' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'SensrQtrWdth',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\SensrQtrWdth',
                ),
                'snapshotresol' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'SnapshotResol',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\SnapshotResol',
                ),
                'tl84convchrma_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmA_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmAM',
                ),
                'tl84convchrma_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmA_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmAP',
                ),
                'tl84convchrmb_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmB_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmBM',
                ),
                'tl84convchrmb_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmB_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmBP',
                ),
                'tl84convchrmc_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmC_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmCM',
                ),
                'tl84convchrmc_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmC_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmCP',
                ),
                'tl84convchrmd_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmD_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmDM',
                ),
                'tl84convchrmd_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmD_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmDP',
                ),
                'tl84convchrmkcb' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmKCb',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmKCb',
                ),
                'tl84convchrmkcr' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvChrmKCr',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvChrmKCr',
                ),
                'tl84convlumak' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvLumaK',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvLumaK',
                ),
                'tl84convlumav0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvLumaV0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvLumaV0',
                ),
                'tl84convlumav1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvLumaV1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvLumaV1',
                ),
                'tl84convlumav2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'TL84ConvLumaV2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\TL84ConvLumaV2',
                ),
                'videofps' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'VideoFps',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\VideoFps',
                ),
                'yhiyloconvchrma_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmA_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmAM',
                ),
                'yhiyloconvchrma_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmA_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmAP',
                ),
                'yhiyloconvchrmb_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmB_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmBM',
                ),
                'yhiyloconvchrmb_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmB_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmBP',
                ),
                'yhiyloconvchrmc_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmC_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmCM',
                ),
                'yhiyloconvchrmc_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmC_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmCP',
                ),
                'yhiyloconvchrmd_m' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmD_M',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmDM',
                ),
                'yhiyloconvchrmd_p' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmD_P',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmDP',
                ),
                'yhiyloconvchrmkcb' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmKCb',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmKCb',
                ),
                'yhiyloconvchrmkcr' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvChrmKCr',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvChrmKCr',
                ),
                'yhiyloconvlumak' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvLumaK',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvLumaK',
                ),
                'yhiyloconvlumav0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvLumaV0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvLumaV0',
                ),
                'yhiyloconvlumav1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvLumaV1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvLumaV1',
                ),
                'yhiyloconvlumav2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloConvLumaV2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloConvLumaV2',
                ),
                'yhiylocorc0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC0',
                ),
                'yhiylocorc1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC1',
                ),
                'yhiylocorc2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC2',
                ),
                'yhiylocorc3' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC3',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC3',
                ),
                'yhiylocorc4' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC4',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC4',
                ),
                'yhiylocorc5' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC5',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC5',
                ),
                'yhiylocorc6' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC6',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC6',
                ),
                'yhiylocorc7' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC7',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC7',
                ),
                'yhiylocorc8' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorC8',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorC8',
                ),
                'yhiylocork0' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorK0',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorK0',
                ),
                'yhiylocork1' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorK1',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorK1',
                ),
                'yhiylocork2' => array(
                    'namespace' => 'Qualcomm',
                    'tagname' => 'YhiYloCorK2',
                    'classname' => 'PHPExiftool\Driver\Tag\Qualcomm\YhiYloCorK2',
                ),

            ),
            'quicktime' => array(
                'balance' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Balance',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Balance',
                ),
                'audioprofileversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioProfileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioProfileVersion',
                ),
                'audiotrackid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioTrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioTrackID',
                ),
                'audiocodec' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioCodec',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioCodec',
                ),
                'audiocodecinfo' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioCodecInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioCodecInfo',
                ),
                'audioattributes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioAttributes',
                ),
                'audioavgbitrate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioAvgBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioAvgBitrate',
                ),
                'audiomaxbitrate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioMaxBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioMaxBitrate',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioSampleRate',
                ),
                'audiochannels' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioChannels',
                ),
                'audioformat' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioFormat',
                ),
                'audiovendorid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioVendorID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioVendorID',
                ),
                'audiobitspersample' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioBitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioBitsPerSample',
                ),
                'compression' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Compression',
                ),
                'url' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\URL',
                ),
                'urn' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'URN',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\URN',
                ),
                'fileprofileversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'FileProfileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\FileProfileVersion',
                ),
                'filefunctionflags' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'FileFunctionFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\FileFunctionFlags',
                ),
                'majorbrand' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MajorBrand',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MajorBrand',
                ),
                'minorversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MinorVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MinorVersion',
                ),
                'compatiblebrands' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CompatibleBrands',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CompatibleBrands',
                ),
                'text' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Text',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Text',
                ),
                'genmediaversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'GenMediaVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\GenMediaVersion',
                ),
                'genflags' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'GenFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\GenFlags',
                ),
                'gengraphicsmode' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'GenGraphicsMode',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\GenGraphicsMode',
                ),
                'genopcolor' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'GenOpColor',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\GenOpColor',
                ),
                'genbalance' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'GenBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\GenBalance',
                ),
                'handlerclass' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'HandlerClass',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\HandlerClass',
                ),
                'handlertype' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'HandlerType',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\HandlerType',
                ),
                'handlervendorid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'HandlerVendorID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\HandlerVendorID',
                ),
                'handlerdescription' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'HandlerDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\HandlerDescription',
                ),
                'maxpdusize' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MaxPDUSize',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MaxPDUSize',
                ),
                'avgpdusize' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AvgPDUSize',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AvgPDUSize',
                ),
                'maxbitrate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MaxBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MaxBitrate',
                ),
                'avgbitrate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AvgBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AvgBitrate',
                ),
                'realtimestreamingprotocol' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'RealtimeStreamingProtocol',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\RealtimeStreamingProtocol',
                ),
                'streamingdataprotocol' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'StreamingDataProtocol',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\StreamingDataProtocol',
                ),
                'hintformat' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'HintFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\HintFormat',
                ),
                'immediatedatabytes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ImmediateDataBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ImmediateDataBytes',
                ),
                'largestpacketduration' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LargestPacketDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LargestPacketDuration',
                ),
                'mediatrackbytes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MediaTrackBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MediaTrackBytes',
                ),
                'repeateddatabytes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'RepeatedDataBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\RepeatedDataBytes',
                ),
                'maxdatarate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MaxDataRate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MaxDataRate',
                ),
                'numpackets' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'NumPackets',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\NumPackets',
                ),
                'payloadtype' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PayloadType',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PayloadType',
                ),
                'largestpacketsize' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LargestPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LargestPacketSize',
                ),
                'maxtransmissiontime' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MaxTransmissionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MaxTransmissionTime',
                ),
                'mintransmissiontime' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MinTransmissionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MinTransmissionTime',
                ),
                'totalbytes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TotalBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TotalBytes',
                ),
                'totalbytesnortpheaders' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TotalBytesNoRTPHeaders',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TotalBytesNoRTPHeaders',
                ),
                'compressorid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CompressorID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CompressorID',
                ),
                'vendorid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VendorID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VendorID',
                ),
                'sourceimagewidth' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SourceImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SourceImageWidth',
                ),
                'sourceimageheight' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SourceImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SourceImageHeight',
                ),
                'xresolution' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\XResolution',
                ),
                'yresolution' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\YResolution',
                ),
                'compressorname' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CompressorName',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CompressorName',
                ),
                'bitdepth' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'BitDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\BitDepth',
                ),
                'imagedata' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ImageData',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ImageData',
                ),
                'albumartist' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AlbumArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AlbumArtist',
                ),
                'applestoreaccounttype' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AppleStoreAccountType',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AppleStoreAccountType',
                ),
                'album' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Album',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Album',
                ),
                'applestoreaccount' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AppleStoreAccount',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AppleStoreAccount',
                ),
                'albumtitleid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AlbumTitleID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AlbumTitleID',
                ),
                'author' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Author',
                ),
                'category' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Category',
                ),
                'applestorecatalogid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AppleStoreCatalogID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AppleStoreCatalogID',
                ),
                'coverart' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CoverArt',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CoverArt',
                ),
                'compilation' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Compilation',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Compilation',
                ),
                'copyright' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Copyright',
                ),
                'description' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Description',
                ),
                'disknumber' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'DiskNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\DiskNumber',
                ),
                'episodeglobaluniqueid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'EpisodeGlobalUniqueID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\EpisodeGlobalUniqueID',
                ),
                'genreid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'GenreID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\GenreID',
                ),
                'genre' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Genre',
                ),
                'grouping' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Grouping',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Grouping',
                ),
                'hdvideo' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'HDVideo',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\HDVideo',
                ),
                'itunesu' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'iTunesU',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ITunesU',
                ),
                'keyword' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Keyword',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Keyword',
                ),
                'longdescription' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LongDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LongDescription',
                ),
                'podcast' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Podcast',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Podcast',
                ),
                'performer' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Performer',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Performer',
                ),
                'playgap' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PlayGap',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PlayGap',
                ),
                'playlistid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PlayListID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PlayListID',
                ),
                'purchasedate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PurchaseDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PurchaseDate',
                ),
                'podcasturl' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PodcastURL',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PodcastURL',
                ),
                'rating' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Rating',
                ),
                'applestorecountry' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AppleStoreCountry',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AppleStoreCountry',
                ),
                'sortalbumartist' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SortAlbumArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SortAlbumArtist',
                ),
                'sortalbum' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SortAlbum',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SortAlbum',
                ),
                'sortartist' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SortArtist',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SortArtist',
                ),
                'sortcomposer' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SortComposer',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SortComposer',
                ),
                'sortname' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SortName',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SortName',
                ),
                'sortshow' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SortShow',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SortShow',
                ),
                'mediatype' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MediaType',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MediaType',
                ),
                'title' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Title',
                ),
                'beatsperminute' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'BeatsPerMinute',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\BeatsPerMinute',
                ),
                'tracknumber' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TrackNumber',
                ),
                'tvepisodeid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TVEpisodeID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TVEpisodeID',
                ),
                'tvepisode' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TVEpisode',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TVEpisode',
                ),
                'tvnetworkname' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TVNetworkName',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TVNetworkName',
                ),
                'tvshow' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TVShow',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TVShow',
                ),
                'tvseason' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TVSeason',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TVSeason',
                ),
                'year' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Year',
                ),
                'artist' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Artist',
                ),
                'comment' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Comment',
                ),
                'composer' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Composer',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Composer',
                ),
                'encodedby' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'EncodedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\EncodedBy',
                ),
                'lyrics' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Lyrics',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Lyrics',
                ),
                'encoder' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Encoder',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Encoder',
                ),
                'track' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Track',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Track',
                ),
                'encodedwith' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'EncodedWith',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\EncodedWith',
                ),
                'artwork' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Artwork',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Artwork',
                ),
                'framereadouttime' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'FrameReadoutTime',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\FrameReadoutTime',
                ),
                'cameraidentifier' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CameraIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CameraIdentifier',
                ),
                'creationdate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CreationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CreationDate',
                ),
                'cameradirection' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CameraDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CameraDirection',
                ),
                'cameramotion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CameraMotion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CameraMotion',
                ),
                'director' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Director',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Director',
                ),
                'information' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Information',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Information',
                ),
                'keywords' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Keywords',
                ),
                'gpscoordinates' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'GPSCoordinates',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\GPSCoordinates',
                ),
                'locationbody' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LocationBody',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LocationBody',
                ),
                'locationdate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LocationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LocationDate',
                ),
                'locationname' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LocationName',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LocationName',
                ),
                'locationnote' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LocationNote',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LocationNote',
                ),
                'locationrole' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LocationRole',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LocationRole',
                ),
                'make' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Make',
                ),
                'model' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Model',
                ),
                'bass' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Bass',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Bass',
                ),
                'audiogain' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'AudioGain',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\AudioGain',
                ),
                'mute' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Mute',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Mute',
                ),
                'pitchshift' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PitchShift',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PitchShift',
                ),
                'trebel' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Trebel',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Trebel',
                ),
                'brightness' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Brightness',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Brightness',
                ),
                'color' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Color',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Color',
                ),
                'contrast' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Contrast',
                ),
                'tint' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Tint',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Tint',
                ),
                'playerversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PlayerVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PlayerVersion',
                ),
                'publisher' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Publisher',
                ),
                'userrating' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'UserRating',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\UserRating',
                ),
                'software' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Software',
                ),
                'version' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Version',
                ),
                'previewpict' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreviewPICT',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreviewPICT',
                ),
                'free' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Free',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Free',
                ),
                'junk' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Junk',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Junk',
                ),
                'moviedata' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MovieData',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MovieData',
                ),
                'moviedatasize' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MovieDataSize',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MovieDataSize',
                ),
                'skip' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Skip',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Skip',
                ),
                'uuid-unknown' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'UUID-Unknown',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\UUIDUnknown',
                ),
                'wide' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Wide',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Wide',
                ),
                'mediaheaderversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MediaHeaderVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MediaHeaderVersion',
                ),
                'mediacreatedate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MediaCreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MediaCreateDate',
                ),
                'mediamodifydate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MediaModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MediaModifyDate',
                ),
                'mediatimescale' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MediaTimeScale',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MediaTimeScale',
                ),
                'mediaduration' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MediaDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MediaDuration',
                ),
                'medialanguagecode' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MediaLanguageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MediaLanguageCode',
                ),
                'nullmediaheader' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'NullMediaHeader',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\NullMediaHeader',
                ),
                'binaryxml' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'BinaryXML',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\BinaryXML',
                ),
                'datainformation' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'DataInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\DataInformation',
                ),
                'iteminformation' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ItemInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ItemInformation',
                ),
                'itemlocation' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ItemLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ItemLocation',
                ),
                'ipmpcontrol' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'IPMPControl',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\IPMPControl',
                ),
                'itemprotection' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ItemProtection',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ItemProtection',
                ),
                'primaryitemreference' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PrimaryItemReference',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PrimaryItemReference',
                ),
                'productiondate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ProductionDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ProductionDate',
                ),
                'product' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Product',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Product',
                ),
                'trackproperty' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TrackProperty',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TrackProperty',
                ),
                'timezone' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TimeZone',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TimeZone',
                ),
                'modifydate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ModifyDate',
                ),
                'initialobjectdescriptor' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'InitialObjectDescriptor',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\InitialObjectDescriptor',
                ),
                'movieheaderversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MovieHeaderVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MovieHeaderVersion',
                ),
                'createdate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CreateDate',
                ),
                'timescale' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TimeScale',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TimeScale',
                ),
                'duration' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Duration',
                ),
                'preferredrate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreferredRate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreferredRate',
                ),
                'preferredvolume' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreferredVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreferredVolume',
                ),
                'matrixstructure' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MatrixStructure',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MatrixStructure',
                ),
                'previewtime' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreviewTime',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreviewTime',
                ),
                'previewduration' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreviewDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreviewDuration',
                ),
                'postertime' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PosterTime',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PosterTime',
                ),
                'selectiontime' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SelectionTime',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SelectionTime',
                ),
                'selectionduration' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SelectionDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SelectionDuration',
                ),
                'currenttime' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CurrentTime',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CurrentTime',
                ),
                'nexttrackid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'NextTrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\NextTrackID',
                ),
                'otherformat' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'OtherFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\OtherFormat',
                ),
                'previewdate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreviewDate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreviewDate',
                ),
                'previewversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreviewVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreviewVersion',
                ),
                'previewatomtype' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreviewAtomType',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreviewAtomType',
                ),
                'previewatomindex' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PreviewAtomIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PreviewAtomIndex',
                ),
                'chunkoffset64' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ChunkOffset64',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ChunkOffset64',
                ),
                'compositiontodecodetimelinemapping' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CompositionToDecodeTimelineMapping',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CompositionToDecodeTimelineMapping',
                ),
                'compositiontimetosample' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CompositionTimeToSample',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CompositionTimeToSample',
                ),
                'samplepaddingbits' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SamplePaddingBits',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SamplePaddingBits',
                ),
                'sampletogroup' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SampleToGroup',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SampleToGroup',
                ),
                'idependentanddisposablesamples' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'IdependentAndDisposableSamples',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\IdependentAndDisposableSamples',
                ),
                'samplegroupdescription' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SampleGroupDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SampleGroupDescription',
                ),
                'chunkoffset' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ChunkOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ChunkOffset',
                ),
                'sampledegradationpriority' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SampleDegradationPriority',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SampleDegradationPriority',
                ),
                'sampletochunk' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SampleToChunk',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SampleToChunk',
                ),
                'shadowsyncsampletable' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ShadowSyncSampleTable',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ShadowSyncSampleTable',
                ),
                'syncsampletable' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SyncSampleTable',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SyncSampleTable',
                ),
                'samplesizes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SampleSizes',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SampleSizes',
                ),
                'videoframerate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoFrameRate',
                ),
                'timetosampletable' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TimeToSampleTable',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TimeToSampleTable',
                ),
                'compactsamplesizes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CompactSampleSizes',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CompactSampleSizes',
                ),
                'sub-sampleinformation' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Sub-sampleInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SubSampleInformation',
                ),
                'textfont' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TextFont',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TextFont',
                ),
                'textface' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TextFace',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TextFace',
                ),
                'textsize' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TextSize',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TextSize',
                ),
                'textcolor' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TextColor',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TextColor',
                ),
                'backgroundcolor' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'BackgroundColor',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\BackgroundColor',
                ),
                'fontname' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'FontName',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\FontName',
                ),
                'cleanaperturedimensions' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CleanApertureDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CleanApertureDimensions',
                ),
                'encodedpixelsdimensions' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'EncodedPixelsDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\EncodedPixelsDimensions',
                ),
                'productionaperturedimensions' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ProductionApertureDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ProductionApertureDimensions',
                ),
                'chapterlist' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ChapterList',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ChapterList',
                ),
                'timecode' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'TimeCode',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\TimeCode',
                ),
                'playallframes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PlayAllFrames',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PlayAllFrames',
                ),
                'compressorversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'CompressorVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\CompressorVersion',
                ),
                'firmwareversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\FirmwareVersion',
                ),
                'loopstyle' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'LoopStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\LoopStyle',
                ),
                'playmode' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PlayMode',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PlayMode',
                ),
                'playselection' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PlaySelection',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PlaySelection',
                ),
                'unknowntags' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'UnknownTags',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\UnknownTags',
                ),
                'windowlocation' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'WindowLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\WindowLocation',
                ),
                'hintversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'HintVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\HintVersion',
                ),
                'name' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Name',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Name',
                ),
                'vendor' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Vendor',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Vendor',
                ),
                'arranger' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Arranger',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Arranger',
                ),
                'arrangerkeywords' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ArrangerKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ArrangerKeywords',
                ),
                'composerkeywords' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ComposerKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ComposerKeywords',
                ),
                'edit1' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit1',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit1',
                ),
                'edit2' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit2',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit2',
                ),
                'edit3' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit3',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit3',
                ),
                'edit4' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit4',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit4',
                ),
                'edit5' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit5',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit5',
                ),
                'edit6' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit6',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit6',
                ),
                'edit7' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit7',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit7',
                ),
                'edit8' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit8',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit8',
                ),
                'edit9' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Edit9',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Edit9',
                ),
                'format' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Format',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Format',
                ),
                'isrccode' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ISRCCode',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ISRCCode',
                ),
                'recordlabelname' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'RecordLabelName',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\RecordLabelName',
                ),
                'recordlabelurl' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'RecordLabelURL',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\RecordLabelURL',
                ),
                'makerurl' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'MakerURL',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\MakerURL',
                ),
                'producerkeywords' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'ProducerKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\ProducerKeywords',
                ),
                'recordingcopyright' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'RecordingCopyright',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\RecordingCopyright',
                ),
                'producer' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Producer',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Producer',
                ),
                'performers' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Performers',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Performers',
                ),
                'performerkeywords' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PerformerKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PerformerKeywords',
                ),
                'performerurl' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PerformerURL',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PerformerURL',
                ),
                'requirements' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Requirements',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Requirements',
                ),
                'subtitlekeywords' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SubtitleKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SubtitleKeywords',
                ),
                'subtitle' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Subtitle',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Subtitle',
                ),
                'sourcecredits' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SourceCredits',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SourceCredits',
                ),
                'songwriter' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SongWriter',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SongWriter',
                ),
                'songwriterkeywords' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SongWriterKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SongWriterKeywords',
                ),
                'softwareversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SoftwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SoftwareVersion',
                ),
                'displaysize' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'DisplaySize',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\DisplaySize',
                ),
                'slideshow' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'SlideShow',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\SlideShow',
                ),
                'graphicsmode' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'GraphicsMode',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\GraphicsMode',
                ),
                'opcolor' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'OpColor',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\OpColor',
                ),
                'videoprofileversion' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoProfileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoProfileVersion',
                ),
                'videotrackid' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoTrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoTrackID',
                ),
                'videocodec' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoCodec',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoCodec',
                ),
                'videocodecinfo' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoCodecInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoCodecInfo',
                ),
                'videoattributes' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoAttributes',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoAttributes',
                ),
                'videoavgbitrate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoAvgBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoAvgBitrate',
                ),
                'videomaxbitrate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoMaxBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoMaxBitrate',
                ),
                'videoavgframerate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoAvgFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoAvgFrameRate',
                ),
                'videomaxframerate' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoMaxFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoMaxFrameRate',
                ),
                'videosize' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'VideoSize',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\VideoSize',
                ),
                'pixelaspectratio' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'PixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\PixelAspectRatio',
                ),
                'data' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Data',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Data',
                ),
                'mean' => array(
                    'namespace' => 'QuickTime',
                    'tagname' => 'Mean',
                    'classname' => 'PHPExiftool\Driver\Tag\QuickTime\Mean',
                ),

            ),
            'makernotes' => array(
                'previewimagewidth' => array(
                    'namespace' => 'MakerNotes',
                    'tagname' => 'PreviewImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\MakerNotes\PreviewImageWidth',
                ),
                'previewimageheight' => array(
                    'namespace' => 'MakerNotes',
                    'tagname' => 'PreviewImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\MakerNotes\PreviewImageHeight',
                ),
                'previewimagelength' => array(
                    'namespace' => 'MakerNotes',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\MakerNotes\PreviewImageLength',
                ),
                'serialnumber' => array(
                    'namespace' => 'MakerNotes',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\MakerNotes\SerialNumber',
                ),
                'previewimage' => array(
                    'namespace' => 'MakerNotes',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\MakerNotes\PreviewImage',
                ),

            ),
            'track#' => array(
                'trackheaderversion' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'TrackHeaderVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\TrackHeaderVersion',
                ),
                'trackcreatedate' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'TrackCreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\TrackCreateDate',
                ),
                'trackmodifydate' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'TrackModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\TrackModifyDate',
                ),
                'trackid' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'TrackID',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\TrackID',
                ),
                'trackduration' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'TrackDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\TrackDuration',
                ),
                'tracklayer' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'TrackLayer',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\TrackLayer',
                ),
                'trackvolume' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'TrackVolume',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\TrackVolume',
                ),
                'matrixstructure' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'MatrixStructure',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\MatrixStructure',
                ),
                'imagewidth' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'Track#',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Track\ImageHeight',
                ),

            ),
            'riff' => array(
                'framerate' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\FrameRate',
                ),
                'maxdatarate' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'MaxDataRate',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\MaxDataRate',
                ),
                'framecount' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'FrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\FrameCount',
                ),
                'streamcount' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'StreamCount',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\StreamCount',
                ),
                'imagewidth' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\ImageHeight',
                ),
                'encoding' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Encoding',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Encoding',
                ),
                'numchannels' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'NumChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\NumChannels',
                ),
                'samplerate' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\SampleRate',
                ),
                'avgbytespersec' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'AvgBytesPerSec',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\AvgBytesPerSec',
                ),
                'bitspersample' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\BitsPerSample',
                ),
                'description' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Description',
                ),
                'originator' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Originator',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Originator',
                ),
                'originatorreference' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'OriginatorReference',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\OriginatorReference',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\DateTimeOriginal',
                ),
                'timereference' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'TimeReference',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\TimeReference',
                ),
                'bwfversion' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'BWFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\BWFVersion',
                ),
                'codinghistory' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'CodingHistory',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\CodingHistory',
                ),
                'make' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Make',
                ),
                'model' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Model',
                ),
                'makernotes' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'MakerNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\MakerNotes',
                ),
                'relatedimagefile' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'RelatedImageFile',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\RelatedImageFile',
                ),
                'timecreated' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'TimeCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\TimeCreated',
                ),
                'usercomment' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'UserComment',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\UserComment',
                ),
                'exifversion' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'ExifVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\ExifVersion',
                ),
                'totalframecount' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'TotalFrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\TotalFrameCount',
                ),
                'timecode' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Timecode',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Timecode',
                ),
                'rated' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Rated',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Rated',
                ),
                'comment' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Comment',
                ),
                'encodedby' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'EncodedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\EncodedBy',
                ),
                'comments' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Comments',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Comments',
                ),
                'directory' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Directory',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Directory',
                ),
                'soundschemetitle' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'SoundSchemeTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\SoundSchemeTitle',
                ),
                'genre' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Genre',
                ),
                'archivallocation' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'ArchivalLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\ArchivalLocation',
                ),
                'artist' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Artist',
                ),
                'firstlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'FirstLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\FirstLanguage',
                ),
                'secondlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'SecondLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\SecondLanguage',
                ),
                'thirdlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'ThirdLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\ThirdLanguage',
                ),
                'fourthlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'FourthLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\FourthLanguage',
                ),
                'fifthlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'FifthLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\FifthLanguage',
                ),
                'sixthlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'SixthLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\SixthLanguage',
                ),
                'seventhlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'SeventhLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\SeventhLanguage',
                ),
                'eighthlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'EighthLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\EighthLanguage',
                ),
                'ninthlanguage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'NinthLanguage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\NinthLanguage',
                ),
                'baseurl' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'BaseURL',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\BaseURL',
                ),
                'defaultaudiostream' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'DefaultAudioStream',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\DefaultAudioStream',
                ),
                'costumedesigner' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'CostumeDesigner',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\CostumeDesigner',
                ),
                'commissioned' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Commissioned',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Commissioned',
                ),
                'cinematographer' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Cinematographer',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Cinematographer',
                ),
                'country' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Country',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Country',
                ),
                'copyright' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Copyright',
                ),
                'datecreated' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'DateCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\DateCreated',
                ),
                'cropped' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Cropped',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Cropped',
                ),
                'dimensions' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Dimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Dimensions',
                ),
                'dotsperinch' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'DotsPerInch',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\DotsPerInch',
                ),
                'distributedby' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'DistributedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\DistributedBy',
                ),
                'editedby' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'EditedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\EditedBy',
                ),
                'engineer' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Engineer',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Engineer',
                ),
                'keywords' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Keywords',
                ),
                'lightness' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Lightness',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Lightness',
                ),
                'logourl' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'LogoURL',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\LogoURL',
                ),
                'logoiconurl' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'LogoIconURL',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\LogoIconURL',
                ),
                'language' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Language',
                ),
                'moreinfobannerimage' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'MoreInfoBannerImage',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\MoreInfoBannerImage',
                ),
                'moreinfobannerurl' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'MoreInfoBannerURL',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\MoreInfoBannerURL',
                ),
                'medium' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Medium',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Medium',
                ),
                'moreinfotext' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'MoreInfoText',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\MoreInfoText',
                ),
                'moreinfourl' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'MoreInfoURL',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\MoreInfoURL',
                ),
                'musicby' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'MusicBy',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\MusicBy',
                ),
                'title' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Title',
                ),
                'productiondesigner' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'ProductionDesigner',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\ProductionDesigner',
                ),
                'numcolors' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'NumColors',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\NumColors',
                ),
                'product' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Product',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Product',
                ),
                'producedby' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'ProducedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\ProducedBy',
                ),
                'rippedby' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'RippedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\RippedBy',
                ),
                'rating' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Rating',
                ),
                'subject' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Subject',
                ),
                'software' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Software',
                ),
                'secondarygenre' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'SecondaryGenre',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\SecondaryGenre',
                ),
                'sharpness' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Sharpness',
                ),
                'source' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Source',
                ),
                'sourceform' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'SourceForm',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\SourceForm',
                ),
                'productionstudio' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'ProductionStudio',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\ProductionStudio',
                ),
                'starring' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Starring',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Starring',
                ),
                'technician' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Technician',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Technician',
                ),
                'watermarkurl' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'WatermarkURL',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\WatermarkURL',
                ),
                'writtenby' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'WrittenBy',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\WrittenBy',
                ),
                'location' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Location',
                ),
                'part' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Part',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Part',
                ),
                'numberofparts' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'NumberOfParts',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\NumberOfParts',
                ),
                'rate' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Rate',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Rate',
                ),
                'statistics' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Statistics',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Statistics',
                ),
                'tapename' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'TapeName',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\TapeName',
                ),
                'endtimecode' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'EndTimecode',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\EndTimecode',
                ),
                'starttimecode' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'StartTimecode',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\StartTimecode',
                ),
                'length' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Length',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Length',
                ),
                'organization' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Organization',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Organization',
                ),
                'tracknumber' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'TrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\TrackNumber',
                ),
                'url' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\URL',
                ),
                'version' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Version',
                ),
                'vegasversionmajor' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'VegasVersionMajor',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\VegasVersionMajor',
                ),
                'vegasversionminor' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'VegasVersionMinor',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\VegasVersionMinor',
                ),
                'year' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Year',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Year',
                ),
                'textjunk' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'TextJunk',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\TextJunk',
                ),
                'oldxmp' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'OldXMP',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\OldXMP',
                ),
                'streamname' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'StreamName',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\StreamName',
                ),
                'vendorname' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'VendorName',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\VendorName',
                ),
                'unknowndata' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'UnknownData',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\UnknownData',
                ),
                'streamtype' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'StreamType',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\StreamType',
                ),
                'audiocodec' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'AudioCodec',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\AudioCodec',
                ),
                'videocodec' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'VideoCodec',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\VideoCodec',
                ),
                'codec' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Codec',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Codec',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\AudioSampleRate',
                ),
                'videoframerate' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'VideoFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\VideoFrameRate',
                ),
                'streamsamplerate' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'StreamSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\StreamSampleRate',
                ),
                'audiosamplecount' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'AudioSampleCount',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\AudioSampleCount',
                ),
                'videoframecount' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'VideoFrameCount',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\VideoFrameCount',
                ),
                'streamsamplecount' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'StreamSampleCount',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\StreamSampleCount',
                ),
                'quality' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\Quality',
                ),
                'samplesize' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'SampleSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\SampleSize',
                ),
                'vp8version' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'VP8Version',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\VP8Version',
                ),
                'horizontalscale' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'HorizontalScale',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\HorizontalScale',
                ),
                'verticalscale' => array(
                    'namespace' => 'RIFF',
                    'tagname' => 'VerticalScale',
                    'classname' => 'PHPExiftool\Driver\Tag\RIFF\VerticalScale',
                ),

            ),
            'rsrc' => array(
                'applicationmissingmsg' => array(
                    'namespace' => 'RSRC',
                    'tagname' => 'ApplicationMissingMsg',
                    'classname' => 'PHPExiftool\Driver\Tag\RSRC\ApplicationMissingMsg',
                ),
                'creatorapplication' => array(
                    'namespace' => 'RSRC',
                    'tagname' => 'CreatorApplication',
                    'classname' => 'PHPExiftool\Driver\Tag\RSRC\CreatorApplication',
                ),
                'keywords' => array(
                    'namespace' => 'RSRC',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\RSRC\Keywords',
                ),
                'description' => array(
                    'namespace' => 'RSRC',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\RSRC\Description',
                ),
                'openwithapplication' => array(
                    'namespace' => 'RSRC',
                    'tagname' => 'OpenWithApplication',
                    'classname' => 'PHPExiftool\Driver\Tag\RSRC\OpenWithApplication',
                ),
                'applicationversion' => array(
                    'namespace' => 'RSRC',
                    'tagname' => 'ApplicationVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\RSRC\ApplicationVersion',
                ),

            ),
            'rtf' => array(
                'author' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Author',
                ),
                'backuptime' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'BackupTime',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\BackupTime',
                ),
                'category' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Category',
                ),
                'comment' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Comment',
                ),
                'company' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Company',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Company',
                ),
                'copyright' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Copyright',
                ),
                'createdate' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\CreateDate',
                ),
                'comments' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Comments',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Comments',
                ),
                'totaledittime' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'TotalEditTime',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\TotalEditTime',
                ),
                'hyperlinkbase' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'HyperlinkBase',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\HyperlinkBase',
                ),
                'internalidnumber' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'InternalIDNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\InternalIDNumber',
                ),
                'keywords' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Keywords',
                ),
                'manager' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Manager',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Manager',
                ),
                'characters' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Characters',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Characters',
                ),
                'characterswithspaces' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'CharactersWithSpaces',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\CharactersWithSpaces',
                ),
                'pages' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Pages',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Pages',
                ),
                'words' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Words',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Words',
                ),
                'lastmodifiedby' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'LastModifiedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\LastModifiedBy',
                ),
                'lastprinted' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'LastPrinted',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\LastPrinted',
                ),
                'modifydate' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\ModifyDate',
                ),
                'subject' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Subject',
                ),
                'title' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\Title',
                ),
                'internalversionnumber' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'InternalVersionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\InternalVersionNumber',
                ),
                'revisionnumber' => array(
                    'namespace' => 'RTF',
                    'tagname' => 'RevisionNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\RTF\RevisionNumber',
                ),

            ),
            'radiance' => array(
                'command' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'Command',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\Command',
                ),
                'orientation' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\Orientation',
                ),
                'colorcorrection' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'ColorCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\ColorCorrection',
                ),
                'exposure' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'Exposure',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\Exposure',
                ),
                'format' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'Format',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\Format',
                ),
                'gamma' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'Gamma',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\Gamma',
                ),
                'pixelaspectratio' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'PixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\PixelAspectRatio',
                ),
                'colorprimaries' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'ColorPrimaries',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\ColorPrimaries',
                ),
                'software' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\Software',
                ),
                'view' => array(
                    'namespace' => 'Radiance',
                    'tagname' => 'View',
                    'classname' => 'PHPExiftool\Driver\Tag\Radiance\View',
                ),

            ),
            'rawzor' => array(
                'compressionfactor' => array(
                    'namespace' => 'Rawzor',
                    'tagname' => 'CompressionFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\Rawzor\CompressionFactor',
                ),
                'originalfilesize' => array(
                    'namespace' => 'Rawzor',
                    'tagname' => 'OriginalFileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Rawzor\OriginalFileSize',
                ),
                'originalfiletype' => array(
                    'namespace' => 'Rawzor',
                    'tagname' => 'OriginalFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\Rawzor\OriginalFileType',
                ),
                'rawzorcreatorversion' => array(
                    'namespace' => 'Rawzor',
                    'tagname' => 'RawzorCreatorVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Rawzor\RawzorCreatorVersion',
                ),
                'rawzorrequiredversion' => array(
                    'namespace' => 'Rawzor',
                    'tagname' => 'RawzorRequiredVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Rawzor\RawzorRequiredVersion',
                ),

            ),
            'real-ra3' => array(
                'channels' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'Channels',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\Channels',
                ),
                'unknown' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'Unknown',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\Unknown',
                ),
                'bytesperminute' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'BytesPerMinute',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\BytesPerMinute',
                ),
                'audiobytes' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'AudioBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\AudioBytes',
                ),
                'titlelen' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'TitleLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\TitleLen',
                ),
                'title' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\Title',
                ),
                'artistlen' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'ArtistLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\ArtistLen',
                ),
                'artist' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\Artist',
                ),
                'copyrightlen' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'CopyrightLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\CopyrightLen',
                ),
                'copyright' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\Copyright',
                ),
                'commentlen' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'CommentLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\CommentLen',
                ),
                'comment' => array(
                    'namespace' => 'Real-RA3',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA3\Comment',
                ),

            ),
            'real-ra4' => array(
                'fourcc1' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'FourCC1',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\FourCC1',
                ),
                'audiofilesize' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'AudioFileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\AudioFileSize',
                ),
                'version2' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'Version2',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\Version2',
                ),
                'headersize' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'HeaderSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\HeaderSize',
                ),
                'codecflavorid' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'CodecFlavorID',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\CodecFlavorID',
                ),
                'codedframesize' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'CodedFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\CodedFrameSize',
                ),
                'audiobytes' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'AudioBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\AudioBytes',
                ),
                'bytesperminute' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'BytesPerMinute',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\BytesPerMinute',
                ),
                'unknown' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'Unknown',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\Unknown',
                ),
                'subpacketh' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'SubPacketH',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\SubPacketH',
                ),
                'audioframesize' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'AudioFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\AudioFrameSize',
                ),
                'subpacketsize' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'SubPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\SubPacketSize',
                ),
                'samplerate' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\SampleRate',
                ),
                'bitspersample' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\BitsPerSample',
                ),
                'channels' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'Channels',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\Channels',
                ),
                'fourcc2len' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'FourCC2Len',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\FourCC2Len',
                ),
                'fourcc2' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'FourCC2',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\FourCC2',
                ),
                'fourcc3len' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'FourCC3Len',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\FourCC3Len',
                ),
                'fourcc3' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'FourCC3',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\FourCC3',
                ),
                'titlelen' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'TitleLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\TitleLen',
                ),
                'title' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\Title',
                ),
                'artistlen' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'ArtistLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\ArtistLen',
                ),
                'artist' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\Artist',
                ),
                'copyrightlen' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'CopyrightLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\CopyrightLen',
                ),
                'copyright' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\Copyright',
                ),
                'commentlen' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'CommentLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\CommentLen',
                ),
                'comment' => array(
                    'namespace' => 'Real-RA4',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA4\Comment',
                ),

            ),
            'real-ra5' => array(
                'fourcc1' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'FourCC1',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\FourCC1',
                ),
                'audiofilesize' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'AudioFileSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\AudioFileSize',
                ),
                'version2' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'Version2',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\Version2',
                ),
                'headersize' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'HeaderSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\HeaderSize',
                ),
                'codecflavorid' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'CodecFlavorID',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\CodecFlavorID',
                ),
                'codedframesize' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'CodedFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\CodedFrameSize',
                ),
                'audiobytes' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'AudioBytes',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\AudioBytes',
                ),
                'bytesperminute' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'BytesPerMinute',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\BytesPerMinute',
                ),
                'unknown' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'Unknown',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\Unknown',
                ),
                'subpacketh' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'SubPacketH',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\SubPacketH',
                ),
                'framesize' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'FrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\FrameSize',
                ),
                'subpacketsize' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'SubPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\SubPacketSize',
                ),
                'samplerate' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\SampleRate',
                ),
                'samplerate2' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'SampleRate2',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\SampleRate2',
                ),
                'bitspersample' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\BitsPerSample',
                ),
                'channels' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'Channels',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\Channels',
                ),
                'genr' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'Genr',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\Genr',
                ),
                'fourcc3' => array(
                    'namespace' => 'Real-RA5',
                    'tagname' => 'FourCC3',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRA5\FourCC3',
                ),

            ),
            'real-cont' => array(
                'titlelen' => array(
                    'namespace' => 'Real-CONT',
                    'tagname' => 'TitleLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealCONT\TitleLen',
                ),
                'title' => array(
                    'namespace' => 'Real-CONT',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\RealCONT\Title',
                ),
                'authorlen' => array(
                    'namespace' => 'Real-CONT',
                    'tagname' => 'AuthorLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealCONT\AuthorLen',
                ),
                'author' => array(
                    'namespace' => 'Real-CONT',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\RealCONT\Author',
                ),
                'copyrightlen' => array(
                    'namespace' => 'Real-CONT',
                    'tagname' => 'CopyrightLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealCONT\CopyrightLen',
                ),
                'copyright' => array(
                    'namespace' => 'Real-CONT',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\RealCONT\Copyright',
                ),
                'commentlen' => array(
                    'namespace' => 'Real-CONT',
                    'tagname' => 'CommentLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealCONT\CommentLen',
                ),
                'comment' => array(
                    'namespace' => 'Real-CONT',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\RealCONT\Comment',
                ),

            ),
            'real-mdpr' => array(
                'audiences' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'Audiences',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\Audiences',
                ),
                'audioformat' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'AudioFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\AudioFormat',
                ),
                'contentrating' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'ContentRating',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\ContentRating',
                ),
                'createdate' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\CreateDate',
                ),
                'description' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\Description',
                ),
                'fileid' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'FileID',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\FileID',
                ),
                'software' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\Software',
                ),
                'indexable' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'Indexable',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\Indexable',
                ),
                'keywords' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\Keywords',
                ),
                'modifydate' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\ModifyDate',
                ),
                'targetaudiences' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'TargetAudiences',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\TargetAudiences',
                ),
                'videoquality' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'VideoQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\VideoQuality',
                ),
                'audiomode' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'AudioMode',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\AudioMode',
                ),
                'videomode' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'VideoMode',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\VideoMode',
                ),
                'streamnumber' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamNumber',
                ),
                'streammaxbitrate' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamMaxBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamMaxBitrate',
                ),
                'streamavgbitrate' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamAvgBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamAvgBitrate',
                ),
                'streammaxpacketsize' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamMaxPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamMaxPacketSize',
                ),
                'streamavgpacketsize' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamAvgPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamAvgPacketSize',
                ),
                'streamstarttime' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamStartTime',
                ),
                'streampreroll' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamPreroll',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamPreroll',
                ),
                'streamduration' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamDuration',
                ),
                'streamnamelen' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamNameLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamNameLen',
                ),
                'streamname' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamName',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamName',
                ),
                'streammimelen' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamMimeLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamMimeLen',
                ),
                'streammimetype' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'StreamMimeType',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\StreamMimeType',
                ),
                'fileinfolen' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'FileInfoLen',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\FileInfoLen',
                ),
                'fileinfolen2' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'FileInfoLen2',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\FileInfoLen2',
                ),
                'fileinfoversion' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'FileInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\FileInfoVersion',
                ),
                'physicalstreams' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'PhysicalStreams',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\PhysicalStreams',
                ),
                'physicalstreamnumbers' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'PhysicalStreamNumbers',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\PhysicalStreamNumbers',
                ),
                'dataoffsets' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'DataOffsets',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\DataOffsets',
                ),
                'numrules' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'NumRules',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\NumRules',
                ),
                'physicalstreamnumbermap' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'PhysicalStreamNumberMap',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\PhysicalStreamNumberMap',
                ),
                'numproperties' => array(
                    'namespace' => 'Real-MDPR',
                    'tagname' => 'NumProperties',
                    'classname' => 'PHPExiftool\Driver\Tag\RealMDPR\NumProperties',
                ),

            ),
            'real-rjmd' => array(
                'albumname' => array(
                    'namespace' => 'Real-RJMD',
                    'tagname' => 'AlbumName',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRJMD\AlbumName',
                ),
                'trackcategory' => array(
                    'namespace' => 'Real-RJMD',
                    'tagname' => 'TrackCategory',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRJMD\TrackCategory',
                ),
                'trackcomments' => array(
                    'namespace' => 'Real-RJMD',
                    'tagname' => 'TrackComments',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRJMD\TrackComments',
                ),
                'tracklyrics' => array(
                    'namespace' => 'Real-RJMD',
                    'tagname' => 'TrackLyrics',
                    'classname' => 'PHPExiftool\Driver\Tag\RealRJMD\TrackLyrics',
                ),

            ),
            'real' => array(
                'text' => array(
                    'namespace' => 'Real',
                    'tagname' => 'Text',
                    'classname' => 'PHPExiftool\Driver\Tag\Real\Text',
                ),
                'url' => array(
                    'namespace' => 'Real',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\Real\URL',
                ),

            ),
            'real-prop' => array(
                'maxbitrate' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'MaxBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\MaxBitrate',
                ),
                'avgbitrate' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'AvgBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\AvgBitrate',
                ),
                'maxpacketsize' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'MaxPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\MaxPacketSize',
                ),
                'avgpacketsize' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'AvgPacketSize',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\AvgPacketSize',
                ),
                'numpackets' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'NumPackets',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\NumPackets',
                ),
                'duration' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\Duration',
                ),
                'preroll' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'Preroll',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\Preroll',
                ),
                'indexoffset' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'IndexOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\IndexOffset',
                ),
                'dataoffset' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'DataOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\DataOffset',
                ),
                'numstreams' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'NumStreams',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\NumStreams',
                ),
                'flags' => array(
                    'namespace' => 'Real-PROP',
                    'tagname' => 'Flags',
                    'classname' => 'PHPExiftool\Driver\Tag\RealPROP\Flags',
                ),

            ),
            'reconyx' => array(
                'makernoteversion' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\MakerNoteVersion',
                ),
                'firmwareversion' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\FirmwareVersion',
                ),
                'firmwaredate' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'FirmwareDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\FirmwareDate',
                ),
                'triggermode' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'TriggerMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\TriggerMode',
                ),
                'sequence' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'Sequence',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\Sequence',
                ),
                'eventnumber' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'EventNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\EventNumber',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\DateTimeOriginal',
                ),
                'moonphase' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'MoonPhase',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\MoonPhase',
                ),
                'ambienttemperaturefahrenheit' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'AmbientTemperatureFahrenheit',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\AmbientTemperatureFahrenheit',
                ),
                'ambienttemperature' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'AmbientTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\AmbientTemperature',
                ),
                'serialnumber' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\SerialNumber',
                ),
                'contrast' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\Contrast',
                ),
                'brightness' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'Brightness',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\Brightness',
                ),
                'sharpness' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\Sharpness',
                ),
                'saturation' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\Saturation',
                ),
                'infraredilluminator' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'InfraredIlluminator',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\InfraredIlluminator',
                ),
                'motionsensitivity' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'MotionSensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\MotionSensitivity',
                ),
                'batteryvoltage' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'BatteryVoltage',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\BatteryVoltage',
                ),
                'userlabel' => array(
                    'namespace' => 'Reconyx',
                    'tagname' => 'UserLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\Reconyx\UserLabel',
                ),

            ),
            'ricoh' => array(
                'ricohrdc2' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'RicohRDC2',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\RicohRDC2',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\ThumbnailImage',
                ),
                'comment' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Comment',
                ),
                'facesdetected' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\FacesDetected',
                ),
                'facedetectframesize' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'FaceDetectFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\FaceDetectFrameSize',
                ),
                'face1position' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Face1Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Face1Position',
                ),
                'face2position' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Face2Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Face2Position',
                ),
                'face3position' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Face3Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Face3Position',
                ),
                'face4position' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Face4Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Face4Position',
                ),
                'face5position' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Face5Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Face5Position',
                ),
                'face6position' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Face6Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Face6Position',
                ),
                'face7position' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Face7Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Face7Position',
                ),
                'face8position' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Face8Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Face8Position',
                ),
                'firmwarerevision' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'FirmwareRevision',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\FirmwareRevision',
                ),
                'firmwarerevision2' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'FirmwareRevision2',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\FirmwareRevision2',
                ),
                'ricohimagewidth' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'RicohImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\RicohImageWidth',
                ),
                'ricohimageheight' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'RicohImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\RicohImageHeight',
                ),
                'ricohdate' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'RicohDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\RicohDate',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\PreviewImageStart',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\PreviewImageLength',
                ),
                'flashmode' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\FlashMode',
                ),
                'macro' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Macro',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Macro',
                ),
                'sharpness' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Sharpness',
                ),
                'whitebalance' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\WhiteBalance',
                ),
                'isosetting' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'ISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\ISOSetting',
                ),
                'saturation' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\Saturation',
                ),
                'makernotetype' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'MakerNoteType',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\MakerNoteType',
                ),
                'firmwareversion' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\FirmwareVersion',
                ),
                'serialnumber' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\SerialNumber',
                ),
                'internalserialnumber' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'InternalSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\InternalSerialNumber',
                ),
                'bodyfirmware' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'BodyFirmware',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\BodyFirmware',
                ),
                'bodyserialnumber' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'BodySerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\BodySerialNumber',
                ),
                'lensfirmware' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'LensFirmware',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\LensFirmware',
                ),
                'lensserialnumber' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'LensSerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\LensSerialNumber',
                ),
                'manufacturedate1' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'ManufactureDate1',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\ManufactureDate1',
                ),
                'manufacturedate2' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'ManufactureDate2',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\ManufactureDate2',
                ),
                'noisereduction' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'NoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\NoiseReduction',
                ),
                'bluegain' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'BlueGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\BlueGain',
                ),
                'greengain' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'GreenGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\GreenGain',
                ),
                'redgain' => array(
                    'namespace' => 'Ricoh',
                    'tagname' => 'RedGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Ricoh\RedGain',
                ),

            ),
            'rmeta' => array(
                'azimuth' => array(
                    'namespace' => 'RMETA',
                    'tagname' => 'Azimuth',
                    'classname' => 'PHPExiftool\Driver\Tag\RMETA\Azimuth',
                ),
                'condition' => array(
                    'namespace' => 'RMETA',
                    'tagname' => 'Condition',
                    'classname' => 'PHPExiftool\Driver\Tag\RMETA\Condition',
                ),
                'lit' => array(
                    'namespace' => 'RMETA',
                    'tagname' => 'Lit',
                    'classname' => 'PHPExiftool\Driver\Tag\RMETA\Lit',
                ),
                'location' => array(
                    'namespace' => 'RMETA',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\RMETA\Location',
                ),
                'signtype' => array(
                    'namespace' => 'RMETA',
                    'tagname' => 'SignType',
                    'classname' => 'PHPExiftool\Driver\Tag\RMETA\SignType',
                ),

            ),
            'samsung' => array(
                'effect' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Effect',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\Effect',
                ),
                'quality' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\Quality',
                ),
                'make' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\Make',
                ),
                'model' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\Model',
                ),
                'exposuretime' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ExposureTime',
                ),
                'fnumber' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\FNumber',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ExposureCompensation',
                ),
                'iso' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ISO',
                ),
                'software' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\Software',
                ),
                'picturewizardmode' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'PictureWizardMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\PictureWizardMode',
                ),
                'picturewizardcolor' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'PictureWizardColor',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\PictureWizardColor',
                ),
                'picturewizardsaturation' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'PictureWizardSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\PictureWizardSaturation',
                ),
                'picturewizardsharpness' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'PictureWizardSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\PictureWizardSharpness',
                ),
                'picturewizardcontrast' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'PictureWizardContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\PictureWizardContrast',
                ),
                'thumbnailwidth' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ThumbnailWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ThumbnailWidth',
                ),
                'thumbnailheight' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ThumbnailHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ThumbnailHeight',
                ),
                'thumbnaillength' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ThumbnailLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ThumbnailLength',
                ),
                'thumbnailoffset' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ThumbnailOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ThumbnailOffset',
                ),
                'makernoteversion' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\MakerNoteVersion',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\PreviewImageStart',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\PreviewImageLength',
                ),
                'picturewizard' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'PictureWizard',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\PictureWizard',
                ),
                'locallocationname' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'LocalLocationName',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\LocalLocationName',
                ),
                'locationname' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'LocationName',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\LocationName',
                ),
                'cameratemperature' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'CameraTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\CameraTemperature',
                ),
                'firmwarename' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'FirmwareName',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\FirmwareName',
                ),
                'lenstype' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\LensType',
                ),
                'lensfirmware' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'LensFirmware',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\LensFirmware',
                ),
                'sensorareas' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'SensorAreas',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SensorAreas',
                ),
                'colorspace' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ColorSpace',
                ),
                'smartrange' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'SmartRange',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SmartRange',
                ),
                'focallengthin35mmformat' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'FocalLengthIn35mmFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\FocalLengthIn35mmFormat',
                ),
                'encryptionkey' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'EncryptionKey',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\EncryptionKey',
                ),
                'wb_rggblevelsuncorrected' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'WB_RGGBLevelsUncorrected',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsUncorrected',
                ),
                'wb_rggblevelsauto' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'WB_RGGBLevelsAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsAuto',
                ),
                'wb_rggblevelsilluminator1' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'WB_RGGBLevelsIlluminator1',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsIlluminator1',
                ),
                'wb_rggblevelsilluminator2' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'WB_RGGBLevelsIlluminator2',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsIlluminator2',
                ),
                'wb_rggblevelsblack' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'WB_RGGBLevelsBlack',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\WBRGGBLevelsBlack',
                ),
                'colormatrix' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ColorMatrix',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ColorMatrix',
                ),
                'colormatrixsrgb' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ColorMatrixSRGB',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ColorMatrixSRGB',
                ),
                'colormatrixadobergb' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ColorMatrixAdobeRGB',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ColorMatrixAdobeRGB',
                ),
                'samsung_type2_0xa033' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa033',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa033',
                ),
                'samsung_type2_0xa034' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa034',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa034',
                ),
                'samsung_type2_0xa035' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa035',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa035',
                ),
                'samsung_type2_0xa036' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa036',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa036',
                ),
                'tonecurve1' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ToneCurve1',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ToneCurve1',
                ),
                'tonecurve2' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ToneCurve2',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ToneCurve2',
                ),
                'tonecurve3' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ToneCurve3',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ToneCurve3',
                ),
                'tonecurve4' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'ToneCurve4',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\ToneCurve4',
                ),
                'samsung_type2_0xa048' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa048',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa048',
                ),
                'samsung_type2_0xa050' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa050',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa050',
                ),
                'samsung_type2_0xa051' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa051',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa051',
                ),
                'samsung_type2_0xa052' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa052',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa052',
                ),
                'samsung_type2_0xa053' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa053',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa053',
                ),
                'samsung_type2_0xa054' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa054',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa054',
                ),
                'samsung_type2_0xa055' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa055',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa055',
                ),
                'samsung_type2_0xa056' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa056',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa056',
                ),
                'samsung_type2_0xa057' => array(
                    'namespace' => 'Samsung',
                    'tagname' => 'Samsung_Type2_0xa057',
                    'classname' => 'PHPExiftool\Driver\Tag\Samsung\SamsungType20xa057',
                ),

            ),
            'sanyo' => array(
                'facesdetected' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\FacesDetected',
                ),
                'faceposition' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'FacePosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\FacePosition',
                ),
                'make' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\Make',
                ),
                'model' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\Model',
                ),
                'exposuretime' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ExposureTime',
                ),
                'fnumber' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\FNumber',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ExposureCompensation',
                ),
                'whitebalance' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\WhiteBalance',
                ),
                'focallength' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\FocalLength',
                ),
                'iso' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ISO',
                ),
                'software' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\Software',
                ),
                'makernoteoffset' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'MakerNoteOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\MakerNoteOffset',
                ),
                'sanyothumbnail' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'SanyoThumbnail',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\SanyoThumbnail',
                ),
                'specialmode' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'SpecialMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\SpecialMode',
                ),
                'sanyoquality' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'SanyoQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\SanyoQuality',
                ),
                'macro' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'Macro',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\Macro',
                ),
                'digitalzoom' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'DigitalZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\DigitalZoom',
                ),
                'softwareversion' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'SoftwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\SoftwareVersion',
                ),
                'pictinfo' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'PictInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\PictInfo',
                ),
                'cameraid' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'CameraID',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\CameraID',
                ),
                'sequentialshot' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'SequentialShot',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\SequentialShot',
                ),
                'widerange' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'WideRange',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\WideRange',
                ),
                'coloradjustmentmode' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ColorAdjustmentMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ColorAdjustmentMode',
                ),
                'quickshot' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'QuickShot',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\QuickShot',
                ),
                'selftimer' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'SelfTimer',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\SelfTimer',
                ),
                'voicememo' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'VoiceMemo',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\VoiceMemo',
                ),
                'recordshutterrelease' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'RecordShutterRelease',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\RecordShutterRelease',
                ),
                'flickerreduce' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'FlickerReduce',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\FlickerReduce',
                ),
                'opticalzoomon' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'OpticalZoomOn',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\OpticalZoomOn',
                ),
                'digitalzoomon' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'DigitalZoomOn',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\DigitalZoomOn',
                ),
                'lightsourcespecial' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'LightSourceSpecial',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\LightSourceSpecial',
                ),
                'resaved' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'Resaved',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\Resaved',
                ),
                'sceneselect' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'SceneSelect',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\SceneSelect',
                ),
                'manualfocusdistance' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ManualFocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ManualFocusDistance',
                ),
                'sequenceshotinterval' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'SequenceShotInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\SequenceShotInterval',
                ),
                'flashmode' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\FlashMode',
                ),
                'datadump' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'DataDump',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\DataDump',
                ),
                'thumbnailwidth' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ThumbnailWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ThumbnailWidth',
                ),
                'thumbnailheight' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ThumbnailHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ThumbnailHeight',
                ),
                'thumbnaillength' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ThumbnailLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ThumbnailLength',
                ),
                'thumbnailoffset' => array(
                    'namespace' => 'Sanyo',
                    'tagname' => 'ThumbnailOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Sanyo\ThumbnailOffset',
                ),

            ),
            'sigma' => array(
                'serialnumber' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\SerialNumber',
                ),
                'drivemode' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\DriveMode',
                ),
                'resolutionmode' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ResolutionMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ResolutionMode',
                ),
                'afmode' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'AFMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\AFMode',
                ),
                'focussetting' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'FocusSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\FocusSetting',
                ),
                'whitebalance' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\WhiteBalance',
                ),
                'exposuremode' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ExposureMode',
                ),
                'meteringmode' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\MeteringMode',
                ),
                'lensfocalrange' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'LensFocalRange',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\LensFocalRange',
                ),
                'colorspace' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ColorSpace',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ExposureCompensation',
                ),
                'exposureadjust' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ExposureAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ExposureAdjust',
                ),
                'contrast' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Contrast',
                ),
                'shadow' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Shadow',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Shadow',
                ),
                'highlight' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Highlight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Highlight',
                ),
                'saturation' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Saturation',
                ),
                'sharpness' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Sharpness',
                ),
                'x3filllight' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'X3FillLight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\X3FillLight',
                ),
                'coloradjustment' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ColorAdjustment',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ColorAdjustment',
                ),
                'adjustmentmode' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'AdjustmentMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\AdjustmentMode',
                ),
                'quality' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Quality',
                ),
                'firmware' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Firmware',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Firmware',
                ),
                'software' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Software',
                ),
                'autobracket' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'AutoBracket',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\AutoBracket',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\PreviewImageStart',
                ),
                'chrominancenoisereduction' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ChrominanceNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ChrominanceNoiseReduction',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\PreviewImageLength',
                ),
                'luminancenoisereduction' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'LuminanceNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\LuminanceNoiseReduction',
                ),
                'previewimagesize' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'PreviewImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\PreviewImageSize',
                ),
                'makernoteversion' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\MakerNoteVersion',
                ),
                'afpoint' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'AFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\AFPoint',
                ),
                'fileformat' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'FileFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\FileFormat',
                ),
                'calibration' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'Calibration',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\Calibration',
                ),
                'colormode' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ColorMode',
                ),
                'lensaperturerange' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'LensApertureRange',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\LensApertureRange',
                ),
                'fnumber' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\FNumber',
                ),
                'exposuretime' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ExposureTime',
                ),
                'exposuretime2' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'ExposureTime2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\ExposureTime2',
                ),
                'burstshot' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'BurstShot',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\BurstShot',
                ),
                'sensortemperature' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'SensorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\SensorTemperature',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\FlashExposureComp',
                ),
                'picturemode' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'PictureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\PictureMode',
                ),
                'digitalfilter' => array(
                    'namespace' => 'Sigma',
                    'tagname' => 'DigitalFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Sigma\DigitalFilter',
                ),

            ),
            'sigmaraw' => array(
                'fileversion' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FileVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FileVersion',
                ),
                'imageuniqueid' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ImageUniqueID',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ImageUniqueID',
                ),
                'markbits' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'MarkBits',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\MarkBits',
                ),
                'imagewidth' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ImageHeight',
                ),
                'rotation' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Rotation',
                ),
                'whitebalance' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\WhiteBalance',
                ),
                'scenecapturetype' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'SceneCaptureType',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\SceneCaptureType',
                ),
                'unused' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Unused',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Unused',
                ),
                'exposureadjust' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ExposureAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ExposureAdjust',
                ),
                'contrast' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Contrast',
                ),
                'shadow' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Shadow',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Shadow',
                ),
                'highlight' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Highlight',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Highlight',
                ),
                'saturation' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Saturation',
                ),
                'sharpness' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Sharpness',
                ),
                'redadjust' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'RedAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\RedAdjust',
                ),
                'greenadjust' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'GreenAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\GreenAdjust',
                ),
                'blueadjust' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'BlueAdjust',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\BlueAdjust',
                ),
                'x3filllight' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'X3FillLight',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\X3FillLight',
                ),
                'previewimage' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\PreviewImage',
                ),
                'jpgfromraw' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'JpgFromRaw',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\JpgFromRaw',
                ),
                'meteringmode' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\MeteringMode',
                ),
                'afarea' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'AFArea',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\AFArea',
                ),
                'afinfocus' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'AFInFocus',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\AFInFocus',
                ),
                'focusmode' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FocusMode',
                ),
                'fnumber' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FNumber',
                ),
                'aperturedisplayed' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ApertureDisplayed',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ApertureDisplayed',
                ),
                'bracketshot' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'BracketShot',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\BracketShot',
                ),
                'burstshot' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'BurstShot',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\BurstShot',
                ),
                'make' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Make',
                ),
                'model' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Model',
                ),
                'cameraname' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'CameraName',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\CameraName',
                ),
                'serialnumber' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\SerialNumber',
                ),
                'colorspace' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ColorSpace',
                ),
                'drivemode' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\DriveMode',
                ),
                'evalstate' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'EvalState',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\EvalState',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ExposureCompensation',
                ),
                'netexposurecompensation' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'NetExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\NetExposureCompensation',
                ),
                'integrationtime' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'IntegrationTime',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\IntegrationTime',
                ),
                'firmwareversion' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FirmwareVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FirmwareVersion',
                ),
                'flashmode' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FlashMode',
                ),
                'flashexpcomp' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FlashExpComp',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FlashExpComp',
                ),
                'flashpower' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FlashPower',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FlashPower',
                ),
                'flashttlmode' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FlashTTLMode',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FlashTTLMode',
                ),
                'flashtype' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FlashType',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FlashType',
                ),
                'focallength' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FocalLength',
                ),
                'focallengthin35mmformat' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'FocalLengthIn35mmFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\FocalLengthIn35mmFormat',
                ),
                'focus' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Focus',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Focus',
                ),
                'imageboardid' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ImageBoardID',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ImageBoardID',
                ),
                'imagerboardid' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ImagerBoardID',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ImagerBoardID',
                ),
                'sensortemperature' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'SensorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\SensorTemperature',
                ),
                'iso' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ISO',
                ),
                'lensaperturerange' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'LensApertureRange',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\LensApertureRange',
                ),
                'lensfocalrange' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'LensFocalRange',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\LensFocalRange',
                ),
                'lenstype' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\LensType',
                ),
                'exposureprogram' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ExposureProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ExposureProgram',
                ),
                'quality' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\Quality',
                ),
                'sensorid' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'SensorID',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\SensorID',
                ),
                'exposuretime' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ExposureTime',
                ),
                'shutterspeeddisplayed' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'ShutterSpeedDisplayed',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\ShutterSpeedDisplayed',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\DateTimeOriginal',
                ),
                'versionbf' => array(
                    'namespace' => 'SigmaRaw',
                    'tagname' => 'VersionBF',
                    'classname' => 'PHPExiftool\Driver\Tag\SigmaRaw\VersionBF',
                ),

            ),
            'sony' => array(
                'lensspec' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'LensSpec',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\LensSpec',
                ),
                'focallength' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FocalLength',
                ),
                'focallengthtelezoom' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FocalLengthTeleZoom',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FocalLengthTeleZoom',
                ),
                'focusstatus' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FocusStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FocusStatus',
                ),
                'afpointselected' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFPointSelected',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFPointSelected',
                ),
                'focusmode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FocusMode',
                ),
                'afpoint' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFPoint',
                ),
                'afmicroadjvalue' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFMicroAdjValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFMicroAdjValue',
                ),
                'afmicroadjmode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFMicroAdjMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFMicroAdjMode',
                ),
                'afmicroadjregisteredlenses' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFMicroAdjRegisteredLenses',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFMicroAdjRegisteredLenses',
                ),
                'exposuretime' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExposureTime',
                ),
                'fnumber' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FNumber',
                ),
                'drivemode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DriveMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DriveMode',
                ),
                'whitebalancefinetune' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'WhiteBalanceFineTune',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\WhiteBalanceFineTune',
                ),
                'colortemperaturesetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ColorTemperatureSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ColorTemperatureSetting',
                ),
                'colorcompensationfilterset' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ColorCompensationFilterSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ColorCompensationFilterSet',
                ),
                'focusmodesetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FocusModeSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FocusModeSetting',
                ),
                'afareamode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFAreaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFAreaMode',
                ),
                'meteringmode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\MeteringMode',
                ),
                'isosetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ISOSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ISOSetting',
                ),
                'dynamicrangeoptimizermode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DynamicRangeOptimizerMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizerMode',
                ),
                'dynamicrangeoptimizerlevel' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DynamicRangeOptimizerLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizerLevel',
                ),
                'creativestyle' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'CreativeStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\CreativeStyle',
                ),
                'colorspace' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ColorSpace',
                ),
                'sharpness' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sharpness',
                ),
                'contrast' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Contrast',
                ),
                'saturation' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Saturation',
                ),
                'zonematchingvalue' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ZoneMatchingValue',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ZoneMatchingValue',
                ),
                'brightness' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Brightness',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Brightness',
                ),
                'flashmode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FlashMode',
                ),
                'prioritysetupshutterrelease' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PrioritySetupShutterRelease',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PrioritySetupShutterRelease',
                ),
                'afilluminator' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFIlluminator',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFIlluminator',
                ),
                'afwithshutter' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFWithShutter',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFWithShutter',
                ),
                'longexposurenoisereduction' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'LongExposureNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\LongExposureNoiseReduction',
                ),
                'highisonoisereduction' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'HighISONoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\HighISONoiseReduction',
                ),
                'imagestyle' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ImageStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ImageStyle',
                ),
                'focusmodeswitch' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FocusModeSwitch',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FocusModeSwitch',
                ),
                'shutterspeedsetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ShutterSpeedSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ShutterSpeedSetting',
                ),
                'aperturesetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ApertureSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ApertureSetting',
                ),
                'exposureprogram' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExposureProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExposureProgram',
                ),
                'imagestabilizationsetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ImageStabilizationSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ImageStabilizationSetting',
                ),
                'rotation' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Rotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Rotation',
                ),
                'batterylevel' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BatteryLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BatteryLevel',
                ),
                'sonyimagesize' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SonyImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SonyImageSize',
                ),
                'aspectratio' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AspectRatio',
                ),
                'quality' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Quality',
                ),
                'exposurelevelincrements' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExposureLevelIncrements',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExposureLevelIncrements',
                ),
                'imagenumber' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ImageNumber',
                ),
                'exposurecompensationset' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExposureCompensationSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExposureCompensationSet',
                ),
                'drivemodesetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DriveModeSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DriveModeSetting',
                ),
                'dynamicrangeoptimizersetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DynamicRangeOptimizerSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizerSetting',
                ),
                'creativestylesetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'CreativeStyleSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\CreativeStyleSetting',
                ),
                'contrastsetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ContrastSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ContrastSetting',
                ),
                'saturationsetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SaturationSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SaturationSetting',
                ),
                'sharpnesssetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SharpnessSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SharpnessSetting',
                ),
                'whitebalancesetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'WhiteBalanceSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\WhiteBalanceSetting',
                ),
                'customwb_rgblevels' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'CustomWB_RGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\CustomWBRGBLevels',
                ),
                'flashcontrol' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FlashControl',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FlashControl',
                ),
                'flashexposurecompset' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FlashExposureCompSet',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FlashExposureCompSet',
                ),
                'smileshuttermode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SmileShutterMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SmileShutterMode',
                ),
                'redeyereduction' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'RedEyeReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\RedEyeReduction',
                ),
                'hdrsetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'HDRSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\HDRSetting',
                ),
                'hdrlevel' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'HDRLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\HDRLevel',
                ),
                'viewingmode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ViewingMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ViewingMode',
                ),
                'facedetection' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FaceDetection',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FaceDetection',
                ),
                'smileshutter' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SmileShutter',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SmileShutter',
                ),
                'sweeppanoramasize' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SweepPanoramaSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SweepPanoramaSize',
                ),
                'sweeppanoramadirection' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SweepPanoramaDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SweepPanoramaDirection',
                ),
                'multiframenoisereduction' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'MultiFrameNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\MultiFrameNoiseReduction',
                ),
                'liveviewafsetting' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'LiveViewAFSetting',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\LiveViewAFSetting',
                ),
                'panoramasize3d' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaSize3D',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaSize3D',
                ),
                'afbuttonpressed' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFButtonPressed',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFButtonPressed',
                ),
                'liveviewmetering' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'LiveViewMetering',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\LiveViewMetering',
                ),
                'viewingmode2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ViewingMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ViewingMode2',
                ),
                'aelock' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AELock',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AELock',
                ),
                'flashaction' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FlashAction',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FlashAction',
                ),
                'liveviewfocusmode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'LiveViewFocusMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\LiveViewFocusMode',
                ),
                'sequencenumber' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SequenceNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SequenceNumber',
                ),
                'previewimagestart' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PreviewImageStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PreviewImageStart',
                ),
                'previewimagelength' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PreviewImageLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PreviewImageLength',
                ),
                'makernoteversion' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'MakerNoteVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\MakerNoteVersion',
                ),
                'batterytemperature' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BatteryTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BatteryTemperature',
                ),
                'batteryunknown' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BatteryUnknown',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BatteryUnknown',
                ),
                'batteryvoltage' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BatteryVoltage',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BatteryVoltage',
                ),
                'imagestabilization2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ImageStabilization2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ImageStabilization2',
                ),
                'extrainfoversion' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExtraInfoVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExtraInfoVersion',
                ),
                'imagestabilization' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ImageStabilization',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ImageStabilization',
                ),
                'batteryvoltage1' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BatteryVoltage1',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BatteryVoltage1',
                ),
                'batteryvoltage2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BatteryVoltage2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BatteryVoltage2',
                ),
                'batterystate' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BatteryState',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BatteryState',
                ),
                'modedialposition' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ModeDialPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ModeDialPosition',
                ),
                'memorycardconfiguration' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'MemoryCardConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\MemoryCardConfiguration',
                ),
                'cameraorientation' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'CameraOrientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\CameraOrientation',
                ),
                'facesdetected' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FacesDetected',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FacesDetected',
                ),
                'face1position' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Face1Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Face1Position',
                ),
                'face2position' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Face2Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Face2Position',
                ),
                'face3position' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Face3Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Face3Position',
                ),
                'face4position' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Face4Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Face4Position',
                ),
                'face5position' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Face5Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Face5Position',
                ),
                'face6position' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Face6Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Face6Position',
                ),
                'face7position' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Face7Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Face7Position',
                ),
                'face8position' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Face8Position',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Face8Position',
                ),
                'drivemode2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DriveMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DriveMode2',
                ),
                'bracketshotnumber' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BracketShotNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BracketShotNumber',
                ),
                'whitebalancebracketing' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'WhiteBalanceBracketing',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\WhiteBalanceBracketing',
                ),
                'bracketshotnumber2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'BracketShotNumber2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\BracketShotNumber2',
                ),
                'dynamicrangeoptimizerbracket' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DynamicRangeOptimizerBracket',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizerBracket',
                ),
                'exposurebracketshotnumber' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExposureBracketShotNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExposureBracketShotNumber',
                ),
                'focusposition' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FocusPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FocusPosition',
                ),
                'flashexposurecomp' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FlashExposureComp',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FlashExposureComp',
                ),
                'teleconverter' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Teleconverter',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Teleconverter',
                ),
                'whitebalance' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\WhiteBalance',
                ),
                'multiburstmode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'MultiBurstMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\MultiBurstMode',
                ),
                'multiburstimagewidth' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'MultiBurstImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\MultiBurstImageWidth',
                ),
                'multiburstimageheight' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'MultiBurstImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\MultiBurstImageHeight',
                ),
                'previewimage' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PreviewImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PreviewImage',
                ),
                'rating' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Rating',
                ),
                'hdr' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'HDR',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\HDR',
                ),
                'pictureeffect' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PictureEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PictureEffect',
                ),
                'softskineffect' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SoftSkinEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SoftSkinEffect',
                ),
                'sony_0x2010' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x2010',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x2010',
                ),
                'vignettingcorrection' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'VignettingCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\VignettingCorrection',
                ),
                'lateralchromaticaberration' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'LateralChromaticAberration',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\LateralChromaticAberration',
                ),
                'distortioncorrection' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DistortionCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DistortionCorrection',
                ),
                'wbshiftab_gm' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'WBShiftAB_GM',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\WBShiftABGM',
                ),
                'autoportraitframed' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AutoPortraitFramed',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AutoPortraitFramed',
                ),
                'sony_0x9400' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9400',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9400',
                ),
                'sony_0x9401' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9401',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9401',
                ),
                'sony_0x9402' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9402',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9402',
                ),
                'sony_0x9403' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9403',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9403',
                ),
                'sony_0x9404' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9404',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9404',
                ),
                'sony_0x9405' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9405',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9405',
                ),
                'sony_0x9406' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9406',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9406',
                ),
                'sony_0x9407' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9407',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9407',
                ),
                'sony_0x9408' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9408',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9408',
                ),
                'sony_0x9409' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9409',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9409',
                ),
                'sony_0x940a' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x940a',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x940a',
                ),
                'sony_0x940b' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x940b',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x940b',
                ),
                'sony_0x940c' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x940c',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x940c',
                ),
                'sony_0x940d' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x940d',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x940d',
                ),
                'sony_0x9411' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Sony_0x9411',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Sony0x9411',
                ),
                'fileformat' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FileFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FileFormat',
                ),
                'sonymodelid' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SonyModelID',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SonyModelID',
                ),
                'colorreproduction' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ColorReproduction',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ColorReproduction',
                ),
                'colortemperature' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ColorTemperature',
                ),
                'colorcompensationfilter' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ColorCompensationFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ColorCompensationFilter',
                ),
                'scenemode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SceneMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SceneMode',
                ),
                'zonematching' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ZoneMatching',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ZoneMatching',
                ),
                'dynamicrangeoptimizer' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DynamicRangeOptimizer',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DynamicRangeOptimizer',
                ),
                'lenstype' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'LensType',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\LensType',
                ),
                'colormode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ColorMode',
                ),
                'fullimagesize' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FullImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FullImageSize',
                ),
                'previewimagesize' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PreviewImageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PreviewImageSize',
                ),
                'macro' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Macro',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Macro',
                ),
                'exposuremode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExposureMode',
                ),
                'afmode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFMode',
                ),
                'flashlevel' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FlashLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FlashLevel',
                ),
                'releasemode' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ReleaseMode',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ReleaseMode',
                ),
                'anti-blur' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Anti-Blur',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AntiBlur',
                ),
                'highisonoisereduction2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'HighISONoiseReduction2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\HighISONoiseReduction2',
                ),
                'intelligentauto' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'IntelligentAuto',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\IntelligentAuto',
                ),
                'tiffmeteringimage' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'TiffMeteringImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\TiffMeteringImage',
                ),
                'customwb_rblevels' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'CustomWB_RBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\CustomWBRBLevels',
                ),
                'liveviewafmethod' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'LiveViewAFMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\LiveViewAFMethod',
                ),
                'exposurecompensation2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExposureCompensation2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExposureCompensation2',
                ),
                'flashexposurecompset2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FlashExposureCompSet2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FlashExposureCompSet2',
                ),
                'orientation2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Orientation2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Orientation2',
                ),
                'flashaction2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FlashAction2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FlashAction2',
                ),
                'focusmode2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FocusMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FocusMode2',
                ),
                'jpgfromrawstart' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'JpgFromRawStart',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\JpgFromRawStart',
                ),
                'jpgfromrawlength' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'JpgFromRawLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\JpgFromRawLength',
                ),
                'sonyimagewidth' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SonyImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SonyImageWidth',
                ),
                'sonyimageheight' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SonyImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SonyImageHeight',
                ),
                'orientation' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Orientation',
                ),
                'imagequality' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ImageQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ImageQuality',
                ),
                'comment' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Comment',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\DateTimeOriginal',
                ),
                'modifydate' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ModifyDate',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ExposureCompensation',
                ),
                'flash' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Flash',
                ),
                'panoramafullwidth' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaFullWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaFullWidth',
                ),
                'panoramafullheight' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaFullHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaFullHeight',
                ),
                'panoramadirection' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaDirection',
                ),
                'panoramacropleft' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaCropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaCropLeft',
                ),
                'panoramacroptop' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaCropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaCropTop',
                ),
                'panoramacropright' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaCropRight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaCropRight',
                ),
                'panoramacropbottom' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaCropBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaCropBottom',
                ),
                'panoramaframewidth' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaFrameWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaFrameWidth',
                ),
                'panoramaframeheight' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaFrameHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaFrameHeight',
                ),
                'panoramasourcewidth' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaSourceWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaSourceWidth',
                ),
                'panoramasourceheight' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'PanoramaSourceHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\PanoramaSourceHeight',
                ),
                'faceinfooffset' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FaceInfoOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FaceInfoOffset',
                ),
                'sonydatetime' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SonyDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SonyDateTime',
                ),
                'faceinfolength' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'FaceInfoLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\FaceInfoLength',
                ),
                'sequenceimagenumber' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SequenceImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SequenceImageNumber',
                ),
                'sequencefilenumber' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SequenceFileNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SequenceFileNumber',
                ),
                'releasemode2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ReleaseMode2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ReleaseMode2',
                ),
                'shotnumbersincepowerup' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'ShotNumberSincePowerUp',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\ShotNumberSincePowerUp',
                ),
                'sequencelength' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'SequenceLength',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\SequenceLength',
                ),
                'quality2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'Quality2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\Quality2',
                ),
                'temptest1' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'TempTest1',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\TempTest1',
                ),
                'ambienttemperature' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AmbientTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AmbientTemperature',
                ),
                'temptest2' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'TempTest2',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\TempTest2',
                ),
                'cameratemperature' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'CameraTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\CameraTemperature',
                ),
                'afmicroadj' => array(
                    'namespace' => 'Sony',
                    'tagname' => 'AFMicroAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\Sony\AFMicroAdj',
                ),

            ),
            'sr2dataifd' => array(
                'colormode' => array(
                    'namespace' => 'SR2DataIFD',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2DataIFD\ColorMode',
                ),

            ),
            'sr2' => array(
                'sr2subifdoffset' => array(
                    'namespace' => 'SR2',
                    'tagname' => 'SR2SubIFDOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2\SR2SubIFDOffset',
                ),
                'sr2subifdlength' => array(
                    'namespace' => 'SR2',
                    'tagname' => 'SR2SubIFDLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2\SR2SubIFDLength',
                ),
                'sr2subifdkey' => array(
                    'namespace' => 'SR2',
                    'tagname' => 'SR2SubIFDKey',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2\SR2SubIFDKey',
                ),

            ),
            'sr2subifd' => array(
                'wb_grbglevels' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'WB_GRBGLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\WBGRBGLevels',
                ),
                'wb_rggblevels' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'WB_RGGBLevels',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\WBRGGBLevels',
                ),
                'maxapertureatmaxfocal' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'MaxApertureAtMaxFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\MaxApertureAtMaxFocal',
                ),
                'maxapertureatminfocal' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'MaxApertureAtMinFocal',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\MaxApertureAtMinFocal',
                ),
                'wb_rgblevelsdaylight' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'WB_RGBLevelsDaylight',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsDaylight',
                ),
                'wb_rgblevelscloudy' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'WB_RGBLevelsCloudy',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsCloudy',
                ),
                'wb_rgblevelstungsten' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'WB_RGBLevelsTungsten',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsTungsten',
                ),
                'wb_rgblevelsshade' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'WB_RGBLevelsShade',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsShade',
                ),
                'wb_rgblevelsfluorescent' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'WB_RGBLevelsFluorescent',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsFluorescent',
                ),
                'wb_rgblevelsflash' => array(
                    'namespace' => 'SR2SubIFD',
                    'tagname' => 'WB_RGBLevelsFlash',
                    'classname' => 'PHPExiftool\Driver\Tag\SR2SubIFD\WBRGBLevelsFlash',
                ),

            ),
            'srf#' => array(
                'srf2key' => array(
                    'namespace' => 'SRF#',
                    'tagname' => 'SRF2Key',
                    'classname' => 'PHPExiftool\Driver\Tag\SRF\SRF2Key',
                ),
                'datakey' => array(
                    'namespace' => 'SRF#',
                    'tagname' => 'DataKey',
                    'classname' => 'PHPExiftool\Driver\Tag\SRF\DataKey',
                ),
                'srf6offset' => array(
                    'namespace' => 'SRF#',
                    'tagname' => 'SRF6Offset',
                    'classname' => 'PHPExiftool\Driver\Tag\SRF\SRF6Offset',
                ),
                'srfdataoffset' => array(
                    'namespace' => 'SRF#',
                    'tagname' => 'SRFDataOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\SRF\SRFDataOffset',
                ),
                'rawdataoffset' => array(
                    'namespace' => 'SRF#',
                    'tagname' => 'RawDataOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\SRF\RawDataOffset',
                ),
                'rawdatalength' => array(
                    'namespace' => 'SRF#',
                    'tagname' => 'RawDataLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SRF\RawDataLength',
                ),

            ),
            'sonyidc' => array(
                'idcpreviewstart' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'IDCPreviewStart',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\IDCPreviewStart',
                ),
                'idcpreviewlength' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'IDCPreviewLength',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\IDCPreviewLength',
                ),
                'idccreativestyle' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'IDCCreativeStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\IDCCreativeStyle',
                ),
                'creativestylewaschanged' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'CreativeStyleWasChanged',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\CreativeStyleWasChanged',
                ),
                'presetwhitebalance' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'PresetWhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\PresetWhiteBalance',
                ),
                'colortemperatureadj' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ColorTemperatureAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ColorTemperatureAdj',
                ),
                'presetwhitebalanceadj' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'PresetWhiteBalanceAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\PresetWhiteBalanceAdj',
                ),
                'colorcorrection' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ColorCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ColorCorrection',
                ),
                'saturationadj' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'SaturationAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\SaturationAdj',
                ),
                'contrastadj' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ContrastAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ContrastAdj',
                ),
                'brightnessadj' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'BrightnessAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\BrightnessAdj',
                ),
                'hueadj' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'HueAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\HueAdj',
                ),
                'sharpnessadj' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'SharpnessAdj',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\SharpnessAdj',
                ),
                'sharpnessovershoot' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'SharpnessOvershoot',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\SharpnessOvershoot',
                ),
                'sharpnessundershoot' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'SharpnessUndershoot',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\SharpnessUndershoot',
                ),
                'sharpnessthreshold' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'SharpnessThreshold',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\SharpnessThreshold',
                ),
                'noisereductionmode' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'NoiseReductionMode',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\NoiseReductionMode',
                ),
                'graypoint' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'GrayPoint',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\GrayPoint',
                ),
                'd-rangeoptimizermode' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'D-RangeOptimizerMode',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\DRangeOptimizerMode',
                ),
                'd-rangeoptimizervalue' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'D-RangeOptimizerValue',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\DRangeOptimizerValue',
                ),
                'd-rangeoptimizerhighlight' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'D-RangeOptimizerHighlight',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\DRangeOptimizerHighlight',
                ),
                'highlightcolordistortreduct' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'HighlightColorDistortReduct',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\HighlightColorDistortReduct',
                ),
                'noisereductionvalue' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'NoiseReductionValue',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\NoiseReductionValue',
                ),
                'edgenoisereduction' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'EdgeNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\EdgeNoiseReduction',
                ),
                'colornoisereduction' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ColorNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ColorNoiseReduction',
                ),
                'd-rangeoptimizershadow' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'D-RangeOptimizerShadow',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\DRangeOptimizerShadow',
                ),
                'peripheralillumcentralradius' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'PeripheralIllumCentralRadius',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\PeripheralIllumCentralRadius',
                ),
                'peripheralillumcentralvalue' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'PeripheralIllumCentralValue',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\PeripheralIllumCentralValue',
                ),
                'peripheralillumperiphvalue' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'PeripheralIllumPeriphValue',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\PeripheralIllumPeriphValue',
                ),
                'tonecurvebrightnessx' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ToneCurveBrightnessX',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ToneCurveBrightnessX',
                ),
                'tonecurveredx' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ToneCurveRedX',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ToneCurveRedX',
                ),
                'tonecurvegreenx' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ToneCurveGreenX',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ToneCurveGreenX',
                ),
                'tonecurvebluex' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ToneCurveBlueX',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ToneCurveBlueX',
                ),
                'tonecurvebrightnessy' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ToneCurveBrightnessY',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ToneCurveBrightnessY',
                ),
                'tonecurveredy' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ToneCurveRedY',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ToneCurveRedY',
                ),
                'tonecurvegreeny' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ToneCurveGreenY',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ToneCurveGreenY',
                ),
                'tonecurvebluey' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'ToneCurveBlueY',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\ToneCurveBlueY',
                ),
                'currentversion' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'CurrentVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\CurrentVersion',
                ),
                'versioncreatedate' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'VersionCreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\VersionCreateDate',
                ),
                'versionmodifydate' => array(
                    'namespace' => 'SonyIDC',
                    'tagname' => 'VersionModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\SonyIDC\VersionModifyDate',
                ),

            ),
            'stim' => array(
                'cropxcommonoffset' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropXCommonOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropXCommonOffset',
                ),
                'cropxviewpointnumber' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropXViewpointNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropXViewpointNumber',
                ),
                'cropxoffset' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropXOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropXOffset',
                ),
                'cropxviewpointnumber2' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropXViewpointNumber2',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropXViewpointNumber2',
                ),
                'cropxoffset2' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropXOffset2',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropXOffset2',
                ),
                'cropycommonoffset' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropYCommonOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropYCommonOffset',
                ),
                'cropyviewpointnumber' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropYViewpointNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropYViewpointNumber',
                ),
                'cropyoffset' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropYOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropYOffset',
                ),
                'cropyviewpointnumber2' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropYViewpointNumber2',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropYViewpointNumber2',
                ),
                'cropyoffset2' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropYOffset2',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropYOffset2',
                ),
                'stimversion' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'StimVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\StimVersion',
                ),
                'applicationdata' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'ApplicationData',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\ApplicationData',
                ),
                'imagearrangement' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'ImageArrangement',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\ImageArrangement',
                ),
                'imagerotation' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'ImageRotation',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\ImageRotation',
                ),
                'scalingfactor' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'ScalingFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\ScalingFactor',
                ),
                'cropxsize' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropXSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropXSize',
                ),
                'cropysize' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CropYSize',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CropYSize',
                ),
                'viewtype' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'ViewType',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\ViewType',
                ),
                'representativeimage' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'RepresentativeImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\RepresentativeImage',
                ),
                'convergencebaseimage' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'ConvergenceBaseImage',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\ConvergenceBaseImage',
                ),
                'assumeddisplaysize' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'AssumedDisplaySize',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\AssumedDisplaySize',
                ),
                'assumeddistanceview' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'AssumedDistanceView',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\AssumedDistanceView',
                ),
                'representativedisparitynear' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'RepresentativeDisparityNear',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\RepresentativeDisparityNear',
                ),
                'representativedisparityfar' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'RepresentativeDisparityFar',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\RepresentativeDisparityFar',
                ),
                'initialdisplayeffect' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'InitialDisplayEffect',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\InitialDisplayEffect',
                ),
                'convergencedistance' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'ConvergenceDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\ConvergenceDistance',
                ),
                'cameraarrangementinterval' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'CameraArrangementInterval',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\CameraArrangementInterval',
                ),
                'shootingcount' => array(
                    'namespace' => 'Stim',
                    'tagname' => 'ShootingCount',
                    'classname' => 'PHPExiftool\Driver\Tag\Stim\ShootingCount',
                ),

            ),
            'theora' => array(
                'theoraversion' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'TheoraVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\TheoraVersion',
                ),
                'imagewidth' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\ImageWidth',
                ),
                'imageheight' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\ImageHeight',
                ),
                'xoffset' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'XOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\XOffset',
                ),
                'yoffset' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'YOffset',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\YOffset',
                ),
                'framerate' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'FrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\FrameRate',
                ),
                'pixelaspectratio' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'PixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\PixelAspectRatio',
                ),
                'colorspace' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\ColorSpace',
                ),
                'nominalvideobitrate' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'NominalVideoBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\NominalVideoBitrate',
                ),
                'quality' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'Quality',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\Quality',
                ),
                'pixelformat' => array(
                    'namespace' => 'Theora',
                    'tagname' => 'PixelFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\Theora\PixelFormat',
                ),

            ),
            'vorbis' => array(
                'actor' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Actor',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Actor',
                ),
                'album' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Album',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Album',
                ),
                'artist' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Artist',
                ),
                'comment' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Comment',
                ),
                'composer' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Composer',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Composer',
                ),
                'contact' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Contact',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Contact',
                ),
                'copyright' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Copyright',
                ),
                'coverart' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'CoverArt',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\CoverArt',
                ),
                'coverartmimetype' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'CoverArtMIMEType',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\CoverArtMIMEType',
                ),
                'date' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Date',
                ),
                'description' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Description',
                ),
                'director' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Director',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Director',
                ),
                'encodedby' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'EncodedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\EncodedBy',
                ),
                'encodedusing' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'EncodedUsing',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\EncodedUsing',
                ),
                'genre' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Genre',
                ),
                'isrcnumber' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'ISRCNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\ISRCNumber',
                ),
                'license' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'License',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\License',
                ),
                'location' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Location',
                ),
                'organization' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Organization',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Organization',
                ),
                'performer' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Performer',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Performer',
                ),
                'producer' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Producer',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Producer',
                ),
                'replaygainalbumgain' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'ReplayGainAlbumGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\ReplayGainAlbumGain',
                ),
                'replaygainalbumpeak' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'ReplayGainAlbumPeak',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\ReplayGainAlbumPeak',
                ),
                'replaygaintrackgain' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'ReplayGainTrackGain',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\ReplayGainTrackGain',
                ),
                'replaygaintrackpeak' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'ReplayGainTrackPeak',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\ReplayGainTrackPeak',
                ),
                'title' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Title',
                ),
                'tracknumber' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'TrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\TrackNumber',
                ),
                'version' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Version',
                ),
                'vendor' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'Vendor',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\Vendor',
                ),
                'vorbisversion' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'VorbisVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\VorbisVersion',
                ),
                'audiochannels' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'AudioChannels',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\AudioChannels',
                ),
                'samplerate' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'SampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\SampleRate',
                ),
                'maximumbitrate' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'MaximumBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\MaximumBitrate',
                ),
                'nominalbitrate' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'NominalBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\NominalBitrate',
                ),
                'minimumbitrate' => array(
                    'namespace' => 'Vorbis',
                    'tagname' => 'MinimumBitrate',
                    'classname' => 'PHPExiftool\Driver\Tag\Vorbis\MinimumBitrate',
                ),

            ),
            'xmp-album' => array(
                'notes' => array(
                    'namespace' => 'XMP-album',
                    'tagname' => 'Notes',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAlbum\Notes',
                ),

            ),
            'xmp-dicom' => array(
                'equipmentinstitution' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'EquipmentInstitution',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\EquipmentInstitution',
                ),
                'equipmentmanufacturer' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'EquipmentManufacturer',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\EquipmentManufacturer',
                ),
                'patientbirthdate' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'PatientBirthDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\PatientBirthDate',
                ),
                'patientid' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'PatientID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\PatientID',
                ),
                'patientname' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'PatientName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\PatientName',
                ),
                'patientsex' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'PatientSex',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\PatientSex',
                ),
                'seriesdatetime' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'SeriesDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\SeriesDateTime',
                ),
                'seriesdescription' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'SeriesDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\SeriesDescription',
                ),
                'seriesmodality' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'SeriesModality',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\SeriesModality',
                ),
                'seriesnumber' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'SeriesNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\SeriesNumber',
                ),
                'studydatetime' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'StudyDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\StudyDateTime',
                ),
                'studydescription' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'StudyDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\StudyDescription',
                ),
                'studyid' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'StudyID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\StudyID',
                ),
                'studyphysician' => array(
                    'namespace' => 'XMP-DICOM',
                    'tagname' => 'StudyPhysician',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDICOM\StudyPhysician',
                ),

            ),
            'xmp-expressionmedia' => array(
                'catalogsets' => array(
                    'namespace' => 'XMP-expressionmedia',
                    'tagname' => 'CatalogSets',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExpressionmedia\CatalogSets',
                ),

            ),
            'xmp-gpano' => array(
                'capturesoftware' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'CaptureSoftware',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\CaptureSoftware',
                ),
                'croppedareaimageheightpixels' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'CroppedAreaImageHeightPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\CroppedAreaImageHeightPixels',
                ),
                'croppedareaimagewidthpixels' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'CroppedAreaImageWidthPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\CroppedAreaImageWidthPixels',
                ),
                'croppedarealeftpixels' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'CroppedAreaLeftPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\CroppedAreaLeftPixels',
                ),
                'croppedareatoppixels' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'CroppedAreaTopPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\CroppedAreaTopPixels',
                ),
                'exposurelockused' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'ExposureLockUsed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\ExposureLockUsed',
                ),
                'firstphotodate' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'FirstPhotoDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\FirstPhotoDate',
                ),
                'fullpanoheightpixels' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'FullPanoHeightPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\FullPanoHeightPixels',
                ),
                'fullpanowidthpixels' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'FullPanoWidthPixels',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\FullPanoWidthPixels',
                ),
                'initialhorizontalfovdegrees' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'InitialHorizontalFOVDegrees',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\InitialHorizontalFOVDegrees',
                ),
                'initialviewheadingdegrees' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'InitialViewHeadingDegrees',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\InitialViewHeadingDegrees',
                ),
                'initialviewpitchdegrees' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'InitialViewPitchDegrees',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\InitialViewPitchDegrees',
                ),
                'initialviewrolldegrees' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'InitialViewRollDegrees',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\InitialViewRollDegrees',
                ),
                'largestvalidinteriorrectheight' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'LargestValidInteriorRectHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\LargestValidInteriorRectHeight',
                ),
                'largestvalidinteriorrectleft' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'LargestValidInteriorRectLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\LargestValidInteriorRectLeft',
                ),
                'largestvalidinteriorrecttop' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'LargestValidInteriorRectTop',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\LargestValidInteriorRectTop',
                ),
                'largestvalidinteriorrectwidth' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'LargestValidInteriorRectWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\LargestValidInteriorRectWidth',
                ),
                'lastphotodate' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'LastPhotoDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\LastPhotoDate',
                ),
                'poseheadingdegrees' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'PoseHeadingDegrees',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\PoseHeadingDegrees',
                ),
                'posepitchdegrees' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'PosePitchDegrees',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\PosePitchDegrees',
                ),
                'poserolldegrees' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'PoseRollDegrees',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\PoseRollDegrees',
                ),
                'projectiontype' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'ProjectionType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\ProjectionType',
                ),
                'sourcephotoscount' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'SourcePhotosCount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\SourcePhotosCount',
                ),
                'stitchingsoftware' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'StitchingSoftware',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\StitchingSoftware',
                ),
                'usepanoramaviewer' => array(
                    'namespace' => 'XMP-GPano',
                    'tagname' => 'UsePanoramaViewer',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPGPano\UsePanoramaViewer',
                ),

            ),
            'xmp-lr' => array(
                'hierarchicalsubject' => array(
                    'namespace' => 'XMP-lr',
                    'tagname' => 'HierarchicalSubject',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPLr\HierarchicalSubject',
                ),
                'privatertkinfo' => array(
                    'namespace' => 'XMP-lr',
                    'tagname' => 'PrivateRTKInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPLr\PrivateRTKInfo',
                ),

            ),
            'xmp-mediapro' => array(
                'catalogsets' => array(
                    'namespace' => 'XMP-mediapro',
                    'tagname' => 'CatalogSets',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMediapro\CatalogSets',
                ),
                'event' => array(
                    'namespace' => 'XMP-mediapro',
                    'tagname' => 'Event',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMediapro\Event',
                ),
                'location' => array(
                    'namespace' => 'XMP-mediapro',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMediapro\Location',
                ),
                'people' => array(
                    'namespace' => 'XMP-mediapro',
                    'tagname' => 'People',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMediapro\People',
                ),
                'status' => array(
                    'namespace' => 'XMP-mediapro',
                    'tagname' => 'Status',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMediapro\Status',
                ),
                'userfields' => array(
                    'namespace' => 'XMP-mediapro',
                    'tagname' => 'UserFields',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMediapro\UserFields',
                ),

            ),
            'xmp-pixellive' => array(
                'author' => array(
                    'namespace' => 'XMP-PixelLive',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPixelLive\Author',
                ),
                'comments' => array(
                    'namespace' => 'XMP-PixelLive',
                    'tagname' => 'Comments',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPixelLive\Comments',
                ),
                'copyright' => array(
                    'namespace' => 'XMP-PixelLive',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPixelLive\Copyright',
                ),
                'date' => array(
                    'namespace' => 'XMP-PixelLive',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPixelLive\Date',
                ),
                'genre' => array(
                    'namespace' => 'XMP-PixelLive',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPixelLive\Genre',
                ),
                'title' => array(
                    'namespace' => 'XMP-PixelLive',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPixelLive\Title',
                ),

            ),
            'svg' => array(
                'imageheight' => array(
                    'namespace' => 'SVG',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\SVG\ImageHeight',
                ),
                'id' => array(
                    'namespace' => 'SVG',
                    'tagname' => 'ID',
                    'classname' => 'PHPExiftool\Driver\Tag\SVG\ID',
                ),
                'metadataid' => array(
                    'namespace' => 'SVG',
                    'tagname' => 'MetadataID',
                    'classname' => 'PHPExiftool\Driver\Tag\SVG\MetadataID',
                ),
                'svgversion' => array(
                    'namespace' => 'SVG',
                    'tagname' => 'SVGVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\SVG\SVGVersion',
                ),
                'imagewidth' => array(
                    'namespace' => 'SVG',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\SVG\ImageWidth',
                ),

            ),
            'xmp-aas' => array(
                'affinea' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'AffineA',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\AffineA',
                ),
                'affineb' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'AffineB',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\AffineB',
                ),
                'affinec' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'AffineC',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\AffineC',
                ),
                'affined' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'AffineD',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\AffineD',
                ),
                'affinex' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'AffineX',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\AffineX',
                ),
                'affiney' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'AffineY',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\AffineY',
                ),
                'croph' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'CropH',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\CropH',
                ),
                'cropw' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'CropW',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\CropW',
                ),
                'cropx' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'CropX',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\CropX',
                ),
                'cropy' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'CropY',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\CropY',
                ),
                'curve0x' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve0x',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve0x',
                ),
                'curve0y' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve0y',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve0y',
                ),
                'curve1x' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve1x',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve1x',
                ),
                'curve1y' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve1y',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve1y',
                ),
                'curve2x' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve2x',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve2x',
                ),
                'curve2y' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve2y',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve2y',
                ),
                'curve3x' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve3x',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve3x',
                ),
                'curve3y' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve3y',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve3y',
                ),
                'curve4x' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve4x',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve4x',
                ),
                'curve4y' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Curve4y',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Curve4y',
                ),
                'highlights' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Highlights',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Highlights',
                ),
                'shadows' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Shadows',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Shadows',
                ),
                'vibrance' => array(
                    'namespace' => 'XMP-aas',
                    'tagname' => 'Vibrance',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAas\Vibrance',
                ),

            ),
            'xmp-acdsee' => array(
                'author' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Author',
                ),
                'caption' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Caption',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Caption',
                ),
                'categories' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Categories',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Categories',
                ),
                'datetime' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Datetime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Datetime',
                ),
                'dpp' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'DPP',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\DPP',
                ),
                'keywords' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Keywords',
                ),
                'notes' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Notes',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Notes',
                ),
                'rating' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Rating',
                ),
                'rawrppused' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Rawrppused',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Rawrppused',
                ),
                'rpp' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'RPP',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\RPP',
                ),
                'tagged' => array(
                    'namespace' => 'XMP-acdsee',
                    'tagname' => 'Tagged',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAcdsee\Tagged',
                ),

            ),
            'xmp-apple-fi' => array(
                'angleinforoll' => array(
                    'namespace' => 'XMP-apple-fi',
                    'tagname' => 'AngleInfoRoll',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAppleFi\AngleInfoRoll',
                ),
                'confidencelevel' => array(
                    'namespace' => 'XMP-apple-fi',
                    'tagname' => 'ConfidenceLevel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAppleFi\ConfidenceLevel',
                ),
                'faceid' => array(
                    'namespace' => 'XMP-apple-fi',
                    'tagname' => 'FaceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAppleFi\FaceID',
                ),
                'timestamp' => array(
                    'namespace' => 'XMP-apple-fi',
                    'tagname' => 'TimeStamp',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAppleFi\TimeStamp',
                ),

            ),
            'xmp-aux' => array(
                'approximatefocusdistance' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'ApproximateFocusDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\ApproximateFocusDistance',
                ),
                'firmware' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'Firmware',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\Firmware',
                ),
                'flashcompensation' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'FlashCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\FlashCompensation',
                ),
                'imagenumber' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'ImageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\ImageNumber',
                ),
                'lens' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'Lens',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\Lens',
                ),
                'lensid' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'LensID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\LensID',
                ),
                'lensinfo' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'LensInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\LensInfo',
                ),
                'ownername' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'OwnerName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\OwnerName',
                ),
                'serialnumber' => array(
                    'namespace' => 'XMP-aux',
                    'tagname' => 'SerialNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPAux\SerialNumber',
                ),

            ),
            'xmp-cc' => array(
                'attributionname' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'AttributionName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\AttributionName',
                ),
                'attributionurl' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'AttributionURL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\AttributionURL',
                ),
                'deprecatedon' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'DeprecatedOn',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\DeprecatedOn',
                ),
                'jurisdiction' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'Jurisdiction',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\Jurisdiction',
                ),
                'legalcode' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'LegalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\LegalCode',
                ),
                'license' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'License',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\License',
                ),
                'morepermissions' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'MorePermissions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\MorePermissions',
                ),
                'permits' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'Permits',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\Permits',
                ),
                'prohibits' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'Prohibits',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\Prohibits',
                ),
                'requires' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'Requires',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\Requires',
                ),
                'useguidelines' => array(
                    'namespace' => 'XMP-cc',
                    'tagname' => 'UseGuidelines',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCc\UseGuidelines',
                ),

            ),
            'xmp-cell' => array(
                'celltowerid' => array(
                    'namespace' => 'XMP-cell',
                    'tagname' => 'CellTowerID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCell\CellTowerID',
                ),
                'cellglobalid' => array(
                    'namespace' => 'XMP-cell',
                    'tagname' => 'CellGlobalID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCell\CellGlobalID',
                ),
                'locationareacode' => array(
                    'namespace' => 'XMP-cell',
                    'tagname' => 'LocationAreaCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCell\LocationAreaCode',
                ),
                'mobilecountrycode' => array(
                    'namespace' => 'XMP-cell',
                    'tagname' => 'MobileCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCell\MobileCountryCode',
                ),
                'mobilenetworkcode' => array(
                    'namespace' => 'XMP-cell',
                    'tagname' => 'MobileNetworkCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCell\MobileNetworkCode',
                ),
                'cellr' => array(
                    'namespace' => 'XMP-cell',
                    'tagname' => 'CellR',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCell\CellR',
                ),

            ),
            'xmp-crs' => array(
                'alreadyapplied' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'AlreadyApplied',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\AlreadyApplied',
                ),
                'autobrightness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'AutoBrightness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\AutoBrightness',
                ),
                'autocontrast' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'AutoContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\AutoContrast',
                ),
                'autoexposure' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'AutoExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\AutoExposure',
                ),
                'autolateralca' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'AutoLateralCA',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\AutoLateralCA',
                ),
                'autoshadows' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'AutoShadows',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\AutoShadows',
                ),
                'blacks2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Blacks2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Blacks2012',
                ),
                'bluehue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'BlueHue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\BlueHue',
                ),
                'bluesaturation' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'BlueSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\BlueSaturation',
                ),
                'brightness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Brightness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Brightness',
                ),
                'cameraprofile' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CameraProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CameraProfile',
                ),
                'cameraprofiledigest' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CameraProfileDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CameraProfileDigest',
                ),
                'chromaticaberrationb' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ChromaticAberrationB',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ChromaticAberrationB',
                ),
                'chromaticaberrationr' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ChromaticAberrationR',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ChromaticAberrationR',
                ),
                'clarity' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Clarity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Clarity',
                ),
                'clarity2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Clarity2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Clarity2012',
                ),
                'colornoisereduction' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ColorNoiseReduction',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ColorNoiseReduction',
                ),
                'colornoisereductiondetail' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ColorNoiseReductionDetail',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ColorNoiseReductionDetail',
                ),
                'contrast' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Contrast',
                ),
                'contrast2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Contrast2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Contrast2012',
                ),
                'converter' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Converter',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Converter',
                ),
                'converttograyscale' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ConvertToGrayscale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ConvertToGrayscale',
                ),
                'cropangle' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropAngle',
                ),
                'cropbottom' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropBottom',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropBottom',
                ),
                'cropconstraintowarp' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropConstrainToWarp',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropConstrainToWarp',
                ),
                'cropheight' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropHeight',
                ),
                'cropleft' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropLeft',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropLeft',
                ),
                'cropright' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropRight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropRight',
                ),
                'croptop' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropTop',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropTop',
                ),
                'cropunit' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropUnit',
                ),
                'cropunits' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropUnits',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropUnits',
                ),
                'cropwidth' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'CropWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\CropWidth',
                ),
                'defringe' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Defringe',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Defringe',
                ),
                'defringegreenamount' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'DefringeGreenAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\DefringeGreenAmount',
                ),
                'defringegreenhuehi' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'DefringeGreenHueHi',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\DefringeGreenHueHi',
                ),
                'defringegreenhuelo' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'DefringeGreenHueLo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\DefringeGreenHueLo',
                ),
                'defringepurpleamount' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'DefringePurpleAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\DefringePurpleAmount',
                ),
                'defringepurplehuehi' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'DefringePurpleHueHi',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\DefringePurpleHueHi',
                ),
                'defringepurplehuelo' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'DefringePurpleHueLo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\DefringePurpleHueLo',
                ),
                'exposure' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Exposure',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Exposure',
                ),
                'exposure2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Exposure2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Exposure2012',
                ),
                'filllight' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'FillLight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\FillLight',
                ),
                'gradientbasedcorrections' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrections',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrections',
                ),
                'gradientbasedcorractive' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrActive',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrActive',
                ),
                'gradientbasedcorramount' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrAmount',
                ),
                'gradientbasedcorrmasks' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMasks',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMasks',
                ),
                'gradientbasedcorrmaskcenterweight' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskCenterWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskCenterWeight',
                ),
                'gradientbasedcorrmaskdabs' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskDabs',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskDabs',
                ),
                'gradientbasedcorrmaskflow' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskFlow',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskFlow',
                ),
                'gradientbasedcorrmaskfullx' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskFullX',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskFullX',
                ),
                'gradientbasedcorrmaskfully' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskFullY',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskFullY',
                ),
                'gradientbasedcorrmaskvalue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskValue',
                ),
                'gradientbasedcorrmaskradius' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskRadius',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskRadius',
                ),
                'gradientbasedcorrmaskwhat' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskWhat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskWhat',
                ),
                'gradientbasedcorrmaskzerox' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskZeroX',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskZeroX',
                ),
                'gradientbasedcorrmaskzeroy' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMaskZeroY',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMaskZeroY',
                ),
                'gradientbasedcorrbrightness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrBrightness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrBrightness',
                ),
                'gradientbasedcorrclarity' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrClarity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrClarity',
                ),
                'gradientbasedcorrclarity2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrClarity2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrClarity2012',
                ),
                'gradientbasedcorrcontrast' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrContrast',
                ),
                'gradientbasedcorrcontrast2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrContrast2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrContrast2012',
                ),
                'gradientbasedcorrdefringe' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrDefringe',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrDefringe',
                ),
                'gradientbasedcorrexposure' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrExposure',
                ),
                'gradientbasedcorrexposure2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrExposure2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrExposure2012',
                ),
                'gradientbasedcorrhighlights2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrHighlights2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrHighlights2012',
                ),
                'gradientbasedcorrluminancenoise' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrLuminanceNoise',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrLuminanceNoise',
                ),
                'gradientbasedcorrmoire' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrMoire',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrMoire',
                ),
                'gradientbasedcorrsaturation' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrSaturation',
                ),
                'gradientbasedcorrshadows2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrShadows2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrShadows2012',
                ),
                'gradientbasedcorrsharpness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrSharpness',
                ),
                'gradientbasedcorrtemperature' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrTemperature',
                ),
                'gradientbasedcorrtint' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrTint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrTint',
                ),
                'gradientbasedcorrhue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrHue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrHue',
                ),
                'gradientbasedcorrwhat' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GradientBasedCorrWhat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GradientBasedCorrWhat',
                ),
                'grainamount' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrainAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrainAmount',
                ),
                'grainfrequency' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrainFrequency',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrainFrequency',
                ),
                'grainsize' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrainSize',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrainSize',
                ),
                'graymixeraqua' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrayMixerAqua',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrayMixerAqua',
                ),
                'graymixerblue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrayMixerBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrayMixerBlue',
                ),
                'graymixergreen' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrayMixerGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrayMixerGreen',
                ),
                'graymixermagenta' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrayMixerMagenta',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrayMixerMagenta',
                ),
                'graymixerorange' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrayMixerOrange',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrayMixerOrange',
                ),
                'graymixerpurple' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrayMixerPurple',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrayMixerPurple',
                ),
                'graymixerred' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrayMixerRed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrayMixerRed',
                ),
                'graymixeryellow' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GrayMixerYellow',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GrayMixerYellow',
                ),
                'greenhue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GreenHue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GreenHue',
                ),
                'greensaturation' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'GreenSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\GreenSaturation',
                ),
                'hascrop' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HasCrop',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HasCrop',
                ),
                'hassettings' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HasSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HasSettings',
                ),
                'highlightrecovery' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HighlightRecovery',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HighlightRecovery',
                ),
                'highlights2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Highlights2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Highlights2012',
                ),
                'hueadjustmentaqua' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HueAdjustmentAqua',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentAqua',
                ),
                'hueadjustmentblue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HueAdjustmentBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentBlue',
                ),
                'hueadjustmentgreen' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HueAdjustmentGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentGreen',
                ),
                'hueadjustmentmagenta' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HueAdjustmentMagenta',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentMagenta',
                ),
                'hueadjustmentorange' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HueAdjustmentOrange',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentOrange',
                ),
                'hueadjustmentpurple' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HueAdjustmentPurple',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentPurple',
                ),
                'hueadjustmentred' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HueAdjustmentRed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentRed',
                ),
                'hueadjustmentyellow' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'HueAdjustmentYellow',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\HueAdjustmentYellow',
                ),
                'incrementaltemperature' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'IncrementalTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\IncrementalTemperature',
                ),
                'incrementaltint' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'IncrementalTint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\IncrementalTint',
                ),
                'lensmanualdistortionamount' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensManualDistortionAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensManualDistortionAmount',
                ),
                'lensprofilechromaticaberrationscale' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensProfileChromaticAberrationScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensProfileChromaticAberrationScale',
                ),
                'lensprofiledigest' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensProfileDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensProfileDigest',
                ),
                'lensprofiledistortionscale' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensProfileDistortionScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensProfileDistortionScale',
                ),
                'lensprofileenable' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensProfileEnable',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensProfileEnable',
                ),
                'lensprofilefilename' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensProfileFilename',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensProfileFilename',
                ),
                'lensprofilename' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensProfileName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensProfileName',
                ),
                'lensprofilesetup' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensProfileSetup',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensProfileSetup',
                ),
                'lensprofilevignettingscale' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LensProfileVignettingScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LensProfileVignettingScale',
                ),
                'luminanceadjustmentaqua' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceAdjustmentAqua',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentAqua',
                ),
                'luminanceadjustmentblue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceAdjustmentBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentBlue',
                ),
                'luminanceadjustmentgreen' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceAdjustmentGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentGreen',
                ),
                'luminanceadjustmentmagenta' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceAdjustmentMagenta',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentMagenta',
                ),
                'luminanceadjustmentorange' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceAdjustmentOrange',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentOrange',
                ),
                'luminanceadjustmentpurple' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceAdjustmentPurple',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentPurple',
                ),
                'luminanceadjustmentred' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceAdjustmentRed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentRed',
                ),
                'luminanceadjustmentyellow' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceAdjustmentYellow',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceAdjustmentYellow',
                ),
                'luminancenoisereductioncontrast' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceNoiseReductionContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceNoiseReductionContrast',
                ),
                'luminancenoisereductiondetail' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceNoiseReductionDetail',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceNoiseReductionDetail',
                ),
                'luminancesmoothing' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'LuminanceSmoothing',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\LuminanceSmoothing',
                ),
                'moirefilter' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'MoireFilter',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\MoireFilter',
                ),
                'paintbasedcorrections' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintBasedCorrections',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintBasedCorrections',
                ),
                'paintcorrectionactive' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionActive',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionActive',
                ),
                'paintcorrectionamount' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionAmount',
                ),
                'paintbasedcorrectionmasks' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintBasedCorrectionMasks',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintBasedCorrectionMasks',
                ),
                'paintcorrectionmaskcenterweight' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskCenterWeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskCenterWeight',
                ),
                'paintcorrectionmaskdabs' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskDabs',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskDabs',
                ),
                'paintcorrectionmaskflow' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskFlow',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskFlow',
                ),
                'paintcorrectionmaskfullx' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskFullX',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskFullX',
                ),
                'paintcorrectionmaskfully' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskFullY',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskFullY',
                ),
                'paintcorrectionmaskvalue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskValue',
                ),
                'paintcorrectionmaskradius' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskRadius',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskRadius',
                ),
                'paintcorrectionmaskwhat' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskWhat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskWhat',
                ),
                'paintcorrectionmaskzerox' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskZeroX',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskZeroX',
                ),
                'paintcorrectionmaskzeroy' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMaskZeroY',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMaskZeroY',
                ),
                'paintcorrectionbrightness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionBrightness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionBrightness',
                ),
                'paintcorrectionclarity' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionClarity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionClarity',
                ),
                'paintcorrectionclarity2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionClarity2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionClarity2012',
                ),
                'paintcorrectioncontrast' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionContrast',
                ),
                'paintcorrectioncontrast2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionContrast2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionContrast2012',
                ),
                'paintcorrectiondefringe' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionDefringe',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionDefringe',
                ),
                'paintcorrectionexposure' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionExposure',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionExposure',
                ),
                'paintcorrectionexposure2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionExposure2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionExposure2012',
                ),
                'paintcorrectionhighlights2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionHighlights2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionHighlights2012',
                ),
                'paintcorrectionluminancenoise' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionLuminanceNoise',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionLuminanceNoise',
                ),
                'paintcorrectionmoire' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionMoire',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionMoire',
                ),
                'paintcorrectionsaturation' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionSaturation',
                ),
                'paintcorrectionshadows2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionShadows2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionShadows2012',
                ),
                'paintcorrectionsharpness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionSharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionSharpness',
                ),
                'paintcorrectiontemperature' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionTemperature',
                ),
                'paintcorrectiontint' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionTint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionTint',
                ),
                'paintcorrectionhue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionHue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionHue',
                ),
                'paintcorrectionwhat' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PaintCorrectionWhat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PaintCorrectionWhat',
                ),
                'parametricdarks' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ParametricDarks',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ParametricDarks',
                ),
                'parametrichighlights' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ParametricHighlights',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ParametricHighlights',
                ),
                'parametrichighlightsplit' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ParametricHighlightSplit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ParametricHighlightSplit',
                ),
                'parametriclights' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ParametricLights',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ParametricLights',
                ),
                'parametricmidtonesplit' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ParametricMidtoneSplit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ParametricMidtoneSplit',
                ),
                'parametricshadows' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ParametricShadows',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ParametricShadows',
                ),
                'parametricshadowsplit' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ParametricShadowSplit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ParametricShadowSplit',
                ),
                'perspectivehorizontal' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PerspectiveHorizontal',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PerspectiveHorizontal',
                ),
                'perspectiverotate' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PerspectiveRotate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PerspectiveRotate',
                ),
                'perspectivescale' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PerspectiveScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PerspectiveScale',
                ),
                'perspectivevertical' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PerspectiveVertical',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PerspectiveVertical',
                ),
                'postcropvignetteamount' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PostCropVignetteAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteAmount',
                ),
                'postcropvignettefeather' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PostCropVignetteFeather',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteFeather',
                ),
                'postcropvignettehighlightcontrast' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PostCropVignetteHighlightContrast',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteHighlightContrast',
                ),
                'postcropvignettemidpoint' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PostCropVignetteMidpoint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteMidpoint',
                ),
                'postcropvignetteroundness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PostCropVignetteRoundness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteRoundness',
                ),
                'postcropvignettestyle' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'PostCropVignetteStyle',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\PostCropVignetteStyle',
                ),
                'processversion' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ProcessVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ProcessVersion',
                ),
                'rawfilename' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'RawFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\RawFileName',
                ),
                'redeyeinfo' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'RedEyeInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\RedEyeInfo',
                ),
                'redhue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'RedHue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\RedHue',
                ),
                'redsaturation' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'RedSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\RedSaturation',
                ),
                'retouchinfo' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'RetouchInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\RetouchInfo',
                ),
                'saturation' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Saturation',
                ),
                'saturationadjustmentaqua' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SaturationAdjustmentAqua',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentAqua',
                ),
                'saturationadjustmentblue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SaturationAdjustmentBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentBlue',
                ),
                'saturationadjustmentgreen' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SaturationAdjustmentGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentGreen',
                ),
                'saturationadjustmentmagenta' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SaturationAdjustmentMagenta',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentMagenta',
                ),
                'saturationadjustmentorange' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SaturationAdjustmentOrange',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentOrange',
                ),
                'saturationadjustmentpurple' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SaturationAdjustmentPurple',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentPurple',
                ),
                'saturationadjustmentred' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SaturationAdjustmentRed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentRed',
                ),
                'saturationadjustmentyellow' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SaturationAdjustmentYellow',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SaturationAdjustmentYellow',
                ),
                'shadows' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Shadows',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Shadows',
                ),
                'shadows2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Shadows2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Shadows2012',
                ),
                'shadowtint' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ShadowTint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ShadowTint',
                ),
                'sharpendetail' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SharpenDetail',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SharpenDetail',
                ),
                'sharpenedgemasking' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SharpenEdgeMasking',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SharpenEdgeMasking',
                ),
                'sharpenradius' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SharpenRadius',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SharpenRadius',
                ),
                'sharpness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Sharpness',
                ),
                'smoothness' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Smoothness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Smoothness',
                ),
                'splittoningbalance' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SplitToningBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SplitToningBalance',
                ),
                'splittoninghighlighthue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SplitToningHighlightHue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SplitToningHighlightHue',
                ),
                'splittoninghighlightsaturation' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SplitToningHighlightSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SplitToningHighlightSaturation',
                ),
                'splittoningshadowhue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SplitToningShadowHue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SplitToningShadowHue',
                ),
                'splittoningshadowsaturation' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'SplitToningShadowSaturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\SplitToningShadowSaturation',
                ),
                'colortemperature' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ColorTemperature',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ColorTemperature',
                ),
                'tint' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Tint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Tint',
                ),
                'tonecurve' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurve',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurve',
                ),
                'tonecurveblue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurveBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurveBlue',
                ),
                'tonecurvegreen' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurveGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurveGreen',
                ),
                'tonecurvename' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurveName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurveName',
                ),
                'tonecurvename2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurveName2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurveName2012',
                ),
                'tonecurvepv2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurvePV2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurvePV2012',
                ),
                'tonecurvepv2012blue' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurvePV2012Blue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurvePV2012Blue',
                ),
                'tonecurvepv2012green' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurvePV2012Green',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurvePV2012Green',
                ),
                'tonecurvepv2012red' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurvePV2012Red',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurvePV2012Red',
                ),
                'tonecurvered' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'ToneCurveRed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\ToneCurveRed',
                ),
                'version' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Version',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Version',
                ),
                'vibrance' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Vibrance',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Vibrance',
                ),
                'vignetteamount' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'VignetteAmount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\VignetteAmount',
                ),
                'vignettemidpoint' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'VignetteMidpoint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\VignetteMidpoint',
                ),
                'whitebalance' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\WhiteBalance',
                ),
                'whites2012' => array(
                    'namespace' => 'XMP-crs',
                    'tagname' => 'Whites2012',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPCrs\Whites2012',
                ),

            ),
            'xmp-dc' => array(
                'contributor' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Contributor',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Contributor',
                ),
                'coverage' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Coverage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Coverage',
                ),
                'creator' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Creator',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Creator',
                ),
                'date' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Date',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Date',
                ),
                'description' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Description',
                ),
                'format' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Format',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Format',
                ),
                'identifier' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Identifier',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Identifier',
                ),
                'language' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Language',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Language',
                ),
                'publisher' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Publisher',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Publisher',
                ),
                'relation' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Relation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Relation',
                ),
                'rights' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Rights',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Rights',
                ),
                'source' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Source',
                ),
                'subject' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Subject',
                ),
                'title' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Title',
                ),
                'type' => array(
                    'namespace' => 'XMP-dc',
                    'tagname' => 'Type',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDc\Type',
                ),

            ),
            'xmp-dex' => array(
                'crc32' => array(
                    'namespace' => 'XMP-dex',
                    'tagname' => 'CRC32',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDex\CRC32',
                ),
                'ffid' => array(
                    'namespace' => 'XMP-dex',
                    'tagname' => 'FFID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDex\FFID',
                ),
                'licensetype' => array(
                    'namespace' => 'XMP-dex',
                    'tagname' => 'LicenseType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDex\LicenseType',
                ),
                'os' => array(
                    'namespace' => 'XMP-dex',
                    'tagname' => 'OS',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDex\OS',
                ),
                'rating' => array(
                    'namespace' => 'XMP-dex',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDex\Rating',
                ),
                'revision' => array(
                    'namespace' => 'XMP-dex',
                    'tagname' => 'Revision',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDex\Revision',
                ),
                'shortdescription' => array(
                    'namespace' => 'XMP-dex',
                    'tagname' => 'ShortDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDex\ShortDescription',
                ),
                'source' => array(
                    'namespace' => 'XMP-dex',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDex\Source',
                ),

            ),
            'xmp-digikam' => array(
                'captionsauthornames' => array(
                    'namespace' => 'XMP-digiKam',
                    'tagname' => 'CaptionsAuthorNames',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDigiKam\CaptionsAuthorNames',
                ),
                'captionsdatetimestamps' => array(
                    'namespace' => 'XMP-digiKam',
                    'tagname' => 'CaptionsDateTimeStamps',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDigiKam\CaptionsDateTimeStamps',
                ),
                'colorlabel' => array(
                    'namespace' => 'XMP-digiKam',
                    'tagname' => 'ColorLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDigiKam\ColorLabel',
                ),
                'picklabel' => array(
                    'namespace' => 'XMP-digiKam',
                    'tagname' => 'PickLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDigiKam\PickLabel',
                ),
                'tagslist' => array(
                    'namespace' => 'XMP-digiKam',
                    'tagname' => 'TagsList',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPDigiKam\TagsList',
                ),

            ),
            'xmp-exif' => array(
                'aperturevalue' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ApertureValue',
                ),
                'brightnessvalue' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'BrightnessValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\BrightnessValue',
                ),
                'cfapattern' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'CFAPattern',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\CFAPattern',
                ),
                'cfapatterncolumns' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'CFAPatternColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\CFAPatternColumns',
                ),
                'cfapatternrows' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'CFAPatternRows',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\CFAPatternRows',
                ),
                'cfapatternvalues' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'CFAPatternValues',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\CFAPatternValues',
                ),
                'colorspace' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ColorSpace',
                ),
                'componentsconfiguration' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ComponentsConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ComponentsConfiguration',
                ),
                'compressedbitsperpixel' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'CompressedBitsPerPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\CompressedBitsPerPixel',
                ),
                'contrast' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'Contrast',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\Contrast',
                ),
                'customrendered' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'CustomRendered',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\CustomRendered',
                ),
                'datetimedigitized' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'DateTimeDigitized',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\DateTimeDigitized',
                ),
                'datetimeoriginal' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'DateTimeOriginal',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\DateTimeOriginal',
                ),
                'devicesettingdescription' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'DeviceSettingDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\DeviceSettingDescription',
                ),
                'devicesettingdescriptioncolumns' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'DeviceSettingDescriptionColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\DeviceSettingDescriptionColumns',
                ),
                'devicesettingdescriptionrows' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'DeviceSettingDescriptionRows',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\DeviceSettingDescriptionRows',
                ),
                'devicesettingdescriptionsettings' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'DeviceSettingDescriptionSettings',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\DeviceSettingDescriptionSettings',
                ),
                'digitalzoomratio' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'DigitalZoomRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\DigitalZoomRatio',
                ),
                'exifversion' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ExifVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ExifVersion',
                ),
                'exposurecompensation' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ExposureCompensation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ExposureCompensation',
                ),
                'exposureindex' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ExposureIndex',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ExposureIndex',
                ),
                'exposuremode' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ExposureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ExposureMode',
                ),
                'exposureprogram' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ExposureProgram',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ExposureProgram',
                ),
                'exposuretime' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ExposureTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ExposureTime',
                ),
                'filesource' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FileSource',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FileSource',
                ),
                'flash' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'Flash',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\Flash',
                ),
                'flashenergy' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FlashEnergy',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FlashEnergy',
                ),
                'flashfired' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FlashFired',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FlashFired',
                ),
                'flashfunction' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FlashFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FlashFunction',
                ),
                'flashmode' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FlashMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FlashMode',
                ),
                'flashpixversion' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FlashpixVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FlashpixVersion',
                ),
                'flashredeyemode' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FlashRedEyeMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FlashRedEyeMode',
                ),
                'flashreturn' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FlashReturn',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FlashReturn',
                ),
                'fnumber' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FNumber',
                ),
                'focallength' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FocalLength',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FocalLength',
                ),
                'focallengthin35mmformat' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FocalLengthIn35mmFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FocalLengthIn35mmFormat',
                ),
                'focalplaneresolutionunit' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FocalPlaneResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FocalPlaneResolutionUnit',
                ),
                'focalplanexresolution' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FocalPlaneXResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FocalPlaneXResolution',
                ),
                'focalplaneyresolution' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'FocalPlaneYResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\FocalPlaneYResolution',
                ),
                'gaincontrol' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GainControl',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GainControl',
                ),
                'gpsaltitude' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSAltitude',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSAltitude',
                ),
                'gpsaltituderef' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSAltitudeRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSAltitudeRef',
                ),
                'gpsareainformation' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSAreaInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSAreaInformation',
                ),
                'gpsdestbearing' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDestBearing',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDestBearing',
                ),
                'gpsdestbearingref' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDestBearingRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDestBearingRef',
                ),
                'gpsdestdistance' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDestDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDestDistance',
                ),
                'gpsdestdistanceref' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDestDistanceRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDestDistanceRef',
                ),
                'gpsdestlatitude' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDestLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDestLatitude',
                ),
                'gpsdestlongitude' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDestLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDestLongitude',
                ),
                'gpsdifferential' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDifferential',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDifferential',
                ),
                'gpsdop' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDOP',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDOP',
                ),
                'gpsimgdirection' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSImgDirection',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSImgDirection',
                ),
                'gpsimgdirectionref' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSImgDirectionRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSImgDirectionRef',
                ),
                'gpslatitude' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSLatitude',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSLatitude',
                ),
                'gpslongitude' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSLongitude',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSLongitude',
                ),
                'gpsmapdatum' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSMapDatum',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSMapDatum',
                ),
                'gpsmeasuremode' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSMeasureMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSMeasureMode',
                ),
                'gpsprocessingmethod' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSProcessingMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSProcessingMethod',
                ),
                'gpssatellites' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSSatellites',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSSatellites',
                ),
                'gpsspeed' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSSpeed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSSpeed',
                ),
                'gpsspeedref' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSSpeedRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSSpeedRef',
                ),
                'gpsstatus' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSStatus',
                ),
                'gpsdatetime' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSDateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSDateTime',
                ),
                'gpstrack' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSTrack',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSTrack',
                ),
                'gpstrackref' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSTrackRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSTrackRef',
                ),
                'gpsversionid' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'GPSVersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\GPSVersionID',
                ),
                'imageuniqueid' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ImageUniqueID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ImageUniqueID',
                ),
                'iso' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ISO',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ISO',
                ),
                'lightsource' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'LightSource',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\LightSource',
                ),
                'makernote' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'MakerNote',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\MakerNote',
                ),
                'maxaperturevalue' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'MaxApertureValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\MaxApertureValue',
                ),
                'meteringmode' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'MeteringMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\MeteringMode',
                ),
                'nativedigest' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'NativeDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\NativeDigest',
                ),
                'opto-electricconvfactor' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'Opto-ElectricConvFactor',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\OptoElectricConvFactor',
                ),
                'oecfcolumns' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'OECFColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\OECFColumns',
                ),
                'oecfnames' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'OECFNames',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\OECFNames',
                ),
                'oecfrows' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'OECFRows',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\OECFRows',
                ),
                'oecfvalues' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'OECFValues',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\OECFValues',
                ),
                'exifimagewidth' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ExifImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ExifImageWidth',
                ),
                'exifimageheight' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ExifImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ExifImageHeight',
                ),
                'relatedsoundfile' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'RelatedSoundFile',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\RelatedSoundFile',
                ),
                'saturation' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'Saturation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\Saturation',
                ),
                'scenecapturetype' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SceneCaptureType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SceneCaptureType',
                ),
                'scenetype' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SceneType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SceneType',
                ),
                'sensingmethod' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SensingMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SensingMethod',
                ),
                'sharpness' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'Sharpness',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\Sharpness',
                ),
                'shutterspeedvalue' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'ShutterSpeedValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\ShutterSpeedValue',
                ),
                'spatialfrequencyresponse' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SpatialFrequencyResponse',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponse',
                ),
                'spatialfrequencyresponsecolumns' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SpatialFrequencyResponseColumns',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponseColumns',
                ),
                'spatialfrequencyresponsenames' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SpatialFrequencyResponseNames',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponseNames',
                ),
                'spatialfrequencyresponserows' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SpatialFrequencyResponseRows',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponseRows',
                ),
                'spatialfrequencyresponsevalues' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SpatialFrequencyResponseValues',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SpatialFrequencyResponseValues',
                ),
                'spectralsensitivity' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SpectralSensitivity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SpectralSensitivity',
                ),
                'subjectarea' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SubjectArea',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SubjectArea',
                ),
                'subjectdistance' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SubjectDistance',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SubjectDistance',
                ),
                'subjectdistancerange' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SubjectDistanceRange',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SubjectDistanceRange',
                ),
                'subjectlocation' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'SubjectLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\SubjectLocation',
                ),
                'usercomment' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'UserComment',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\UserComment',
                ),
                'whitebalance' => array(
                    'namespace' => 'XMP-exif',
                    'tagname' => 'WhiteBalance',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExif\WhiteBalance',
                ),

            ),
            'xmp-extensis' => array(
                'approved' => array(
                    'namespace' => 'XMP-extensis',
                    'tagname' => 'Approved',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExtensis\Approved',
                ),
                'approvedby' => array(
                    'namespace' => 'XMP-extensis',
                    'tagname' => 'ApprovedBy',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExtensis\ApprovedBy',
                ),
                'clientname' => array(
                    'namespace' => 'XMP-extensis',
                    'tagname' => 'ClientName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExtensis\ClientName',
                ),
                'jobname' => array(
                    'namespace' => 'XMP-extensis',
                    'tagname' => 'JobName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExtensis\JobName',
                ),
                'jobstatus' => array(
                    'namespace' => 'XMP-extensis',
                    'tagname' => 'JobStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExtensis\JobStatus',
                ),
                'routedto' => array(
                    'namespace' => 'XMP-extensis',
                    'tagname' => 'RoutedTo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExtensis\RoutedTo',
                ),
                'routingnotes' => array(
                    'namespace' => 'XMP-extensis',
                    'tagname' => 'RoutingNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExtensis\RoutingNotes',
                ),
                'worktodo' => array(
                    'namespace' => 'XMP-extensis',
                    'tagname' => 'WorkToDo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPExtensis\WorkToDo',
                ),

            ),
            'xmp-fpv' => array(
                'richtextcomment' => array(
                    'namespace' => 'XMP-fpv',
                    'tagname' => 'RichTextComment',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPFpv\RichTextComment',
                ),

            ),
            'xmp-ics' => array(
                'imageref' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'ImageRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\ImageRef',
                ),
                'subversions' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'SubVersions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\SubVersions',
                ),
                'subversionfilename' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'SubVersionFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\SubVersionFileName',
                ),
                'subversionreference' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'SubVersionReference',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\SubVersionReference',
                ),
                'tagstructure' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'TagStructure',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\TagStructure',
                ),
                'labelname1' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'LabelName1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\LabelName1',
                ),
                'parentreference1' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'ParentReference1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\ParentReference1',
                ),
                'reference1' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'Reference1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\Reference1',
                ),
                'sublables1' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'SubLables1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\SubLables1',
                ),
                'labelname2' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'LabelName2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\LabelName2',
                ),
                'parentreference2' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'ParentReference2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\ParentReference2',
                ),
                'reference2' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'Reference2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\Reference2',
                ),
                'sublables2' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'SubLables2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\SubLables2',
                ),
                'labelname3' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'LabelName3',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\LabelName3',
                ),
                'parentreference3' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'ParentReference3',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\ParentReference3',
                ),
                'reference3' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'Reference3',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\Reference3',
                ),
                'sublables3' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'SubLables3',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\SubLables3',
                ),
                'labelname4' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'LabelName4',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\LabelName4',
                ),
                'parentreference4' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'ParentReference4',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\ParentReference4',
                ),
                'reference4' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'Reference4',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\Reference4',
                ),
                'sublabels4' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'SubLabels4',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\SubLabels4',
                ),
                'labelname5' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'LabelName5',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\LabelName5',
                ),
                'parentreference5' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'ParentReference5',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\ParentReference5',
                ),
                'reference5' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'Reference5',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\Reference5',
                ),
                'sublabels5' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'SubLabels5',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\SubLabels5',
                ),
                'labelname6' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'LabelName6',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\LabelName6',
                ),
                'parentreference6' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'ParentReference6',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\ParentReference6',
                ),
                'reference6' => array(
                    'namespace' => 'XMP-ics',
                    'tagname' => 'Reference6',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIcs\Reference6',
                ),

            ),
            'xmp-iptccore' => array(
                'countrycode' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CountryCode',
                ),
                'creatorcontactinfo' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorContactInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorContactInfo',
                ),
                'creatorcity' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorCity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorCity',
                ),
                'creatorcountry' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorCountry',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorCountry',
                ),
                'creatoraddress' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorAddress',
                ),
                'creatorpostalcode' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorPostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorPostalCode',
                ),
                'creatorregion' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorRegion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorRegion',
                ),
                'creatorworkemail' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorWorkEmail',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorWorkEmail',
                ),
                'creatorworktelephone' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorWorkTelephone',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorWorkTelephone',
                ),
                'creatorworkurl' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'CreatorWorkURL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\CreatorWorkURL',
                ),
                'intellectualgenre' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'IntellectualGenre',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\IntellectualGenre',
                ),
                'location' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\Location',
                ),
                'scene' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'Scene',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\Scene',
                ),
                'subjectcode' => array(
                    'namespace' => 'XMP-iptcCore',
                    'tagname' => 'SubjectCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcCore\SubjectCode',
                ),

            ),
            'xmp-iptcext' => array(
                'additionalmodelinformation' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'AdditionalModelInformation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\AdditionalModelInformation',
                ),
                'artworkorobject' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ArtworkOrObject',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkOrObject',
                ),
                'artworkcopyrightnotice' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ArtworkCopyrightNotice',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkCopyrightNotice',
                ),
                'artworkcreator' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ArtworkCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkCreator',
                ),
                'artworkdatecreated' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ArtworkDateCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkDateCreated',
                ),
                'artworksource' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ArtworkSource',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkSource',
                ),
                'artworksourceinventoryno' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ArtworkSourceInventoryNo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkSourceInventoryNo',
                ),
                'artworktitle' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ArtworkTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ArtworkTitle',
                ),
                'controlledvocabularyterm' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ControlledVocabularyTerm',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ControlledVocabularyTerm',
                ),
                'digitalimageguid' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'DigitalImageGUID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\DigitalImageGUID',
                ),
                'digitalsourcefiletype' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'DigitalSourceFileType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\DigitalSourceFileType',
                ),
                'digitalsourcetype' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'DigitalSourceType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\DigitalSourceType',
                ),
                'event' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'Event',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\Event',
                ),
                'iptclastedited' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'IPTCLastEdited',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\IPTCLastEdited',
                ),
                'locationcreated' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreated',
                ),
                'locationcreatedcity' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationCreatedCity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedCity',
                ),
                'locationcreatedcountrycode' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationCreatedCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedCountryCode',
                ),
                'locationcreatedcountryname' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationCreatedCountryName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedCountryName',
                ),
                'locationcreatedprovincestate' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationCreatedProvinceState',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedProvinceState',
                ),
                'locationcreatedsublocation' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationCreatedSublocation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedSublocation',
                ),
                'locationcreatedworldregion' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationCreatedWorldRegion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationCreatedWorldRegion',
                ),
                'locationshown' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationShown',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationShown',
                ),
                'locationshowncity' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationShownCity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownCity',
                ),
                'locationshowncountrycode' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationShownCountryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownCountryCode',
                ),
                'locationshowncountryname' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationShownCountryName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownCountryName',
                ),
                'locationshownprovincestate' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationShownProvinceState',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownProvinceState',
                ),
                'locationshownsublocation' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationShownSublocation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownSublocation',
                ),
                'locationshownworldregion' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'LocationShownWorldRegion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\LocationShownWorldRegion',
                ),
                'maxavailheight' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'MaxAvailHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\MaxAvailHeight',
                ),
                'maxavailwidth' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'MaxAvailWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\MaxAvailWidth',
                ),
                'modelage' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'ModelAge',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\ModelAge',
                ),
                'organisationinimagecode' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'OrganisationInImageCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\OrganisationInImageCode',
                ),
                'organisationinimagename' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'OrganisationInImageName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\OrganisationInImageName',
                ),
                'personinimage' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'PersonInImage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\PersonInImage',
                ),
                'registryid' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'RegistryID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\RegistryID',
                ),
                'registryitemid' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'RegistryItemID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\RegistryItemID',
                ),
                'registryorganisationid' => array(
                    'namespace' => 'XMP-iptcExt',
                    'tagname' => 'RegistryOrganisationID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPIptcExt\RegistryOrganisationID',
                ),

            ),
            'xmp-mwg-coll' => array(
                'collections' => array(
                    'namespace' => 'XMP-mwg-coll',
                    'tagname' => 'Collections',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgColl\Collections',
                ),
                'collectionname' => array(
                    'namespace' => 'XMP-mwg-coll',
                    'tagname' => 'CollectionName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgColl\CollectionName',
                ),
                'collectionuri' => array(
                    'namespace' => 'XMP-mwg-coll',
                    'tagname' => 'CollectionURI',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgColl\CollectionURI',
                ),

            ),
            'xmp-mwg-kw' => array(
                'keywordinfo' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'KeywordInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\KeywordInfo',
                ),
                'hierarchicalkeywords' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords',
                ),
                'hierarchicalkeywords1applied' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords1Applied',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords1Applied',
                ),
                'hierarchicalkeywords1children' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords1Children',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords1Children',
                ),
                'hierarchicalkeywords2applied' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords2Applied',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords2Applied',
                ),
                'hierarchicalkeywords2children' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords2Children',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords2Children',
                ),
                'hierarchicalkeywords3applied' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords3Applied',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords3Applied',
                ),
                'hierarchicalkeywords3children' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords3Children',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords3Children',
                ),
                'hierarchicalkeywords4applied' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords4Applied',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords4Applied',
                ),
                'hierarchicalkeywords4children' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords4Children',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords4Children',
                ),
                'hierarchicalkeywords5applied' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords5Applied',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords5Applied',
                ),
                'hierarchicalkeywords5children' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords5Children',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords5Children',
                ),
                'hierarchicalkeywords6applied' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords6Applied',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords6Applied',
                ),
                'hierarchicalkeywords6' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords6',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords6',
                ),
                'hierarchicalkeywords5' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords5',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords5',
                ),
                'hierarchicalkeywords4' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords4',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords4',
                ),
                'hierarchicalkeywords3' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords3',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords3',
                ),
                'hierarchicalkeywords2' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords2',
                ),
                'hierarchicalkeywords1' => array(
                    'namespace' => 'XMP-mwg-kw',
                    'tagname' => 'HierarchicalKeywords1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgKw\HierarchicalKeywords1',
                ),

            ),
            'xmp-mwg-rs' => array(
                'regioninfo' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionInfo',
                ),
                'regionappliedtodimensions' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAppliedToDimensions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAppliedToDimensions',
                ),
                'regionappliedtodimensionsh' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAppliedToDimensionsH',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAppliedToDimensionsH',
                ),
                'regionappliedtodimensionsunit' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAppliedToDimensionsUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAppliedToDimensionsUnit',
                ),
                'regionappliedtodimensionsw' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAppliedToDimensionsW',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAppliedToDimensionsW',
                ),
                'regionlist' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionList',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionList',
                ),
                'regionarea' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionArea',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionArea',
                ),
                'regionaread' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAreaD',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaD',
                ),
                'regionareah' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAreaH',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaH',
                ),
                'regionareaunit' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAreaUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaUnit',
                ),
                'regionareaw' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAreaW',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaW',
                ),
                'regionareax' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAreaX',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaX',
                ),
                'regionareay' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionAreaY',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionAreaY',
                ),
                'regionbarcodevalue' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionBarCodeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionBarCodeValue',
                ),
                'regiondescription' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionDescription',
                ),
                'regionextensions' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionExtensions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionExtensions',
                ),
                'regionfocususage' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionFocusUsage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionFocusUsage',
                ),
                'regionname' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionName',
                ),
                'regionseealso' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionSeeAlso',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionSeeAlso',
                ),
                'regiontype' => array(
                    'namespace' => 'XMP-mwg-rs',
                    'tagname' => 'RegionType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPMwgRs\RegionType',
                ),

            ),
            'xmp-pdf' => array(
                'author' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Author',
                ),
                'copyright' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Copyright',
                ),
                'creationdate' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'CreationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\CreationDate',
                ),
                'creator' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Creator',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Creator',
                ),
                'keywords' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Keywords',
                ),
                'marked' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Marked',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Marked',
                ),
                'moddate' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'ModDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\ModDate',
                ),
                'pdfversion' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'PDFVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\PDFVersion',
                ),
                'producer' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Producer',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Producer',
                ),
                'subject' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Subject',
                ),
                'title' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Title',
                ),
                'trapped' => array(
                    'namespace' => 'XMP-pdf',
                    'tagname' => 'Trapped',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPdf\Trapped',
                ),

            ),
            'xmp-photoshop' => array(
                'authorsposition' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'AuthorsPosition',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\AuthorsPosition',
                ),
                'captionwriter' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'CaptionWriter',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\CaptionWriter',
                ),
                'category' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'Category',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\Category',
                ),
                'city' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'City',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\City',
                ),
                'colormode' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'ColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\ColorMode',
                ),
                'country' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'Country',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\Country',
                ),
                'credit' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'Credit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\Credit',
                ),
                'datecreated' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'DateCreated',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\DateCreated',
                ),
                'documentancestors' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'DocumentAncestors',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\DocumentAncestors',
                ),
                'documentancestorid' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'DocumentAncestorID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\DocumentAncestorID',
                ),
                'headline' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'Headline',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\Headline',
                ),
                'history' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'History',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\History',
                ),
                'iccprofilename' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'ICCProfileName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\ICCProfileName',
                ),
                'instructions' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'Instructions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\Instructions',
                ),
                'legacyiptcdigest' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'LegacyIPTCDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\LegacyIPTCDigest',
                ),
                'sidecarforextension' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'SidecarForExtension',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\SidecarForExtension',
                ),
                'source' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'Source',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\Source',
                ),
                'state' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'State',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\State',
                ),
                'supplementalcategories' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'SupplementalCategories',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\SupplementalCategories',
                ),
                'textlayers' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'TextLayers',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\TextLayers',
                ),
                'textlayername' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'TextLayerName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\TextLayerName',
                ),
                'textlayertext' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'TextLayerText',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\TextLayerText',
                ),
                'transmissionreference' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'TransmissionReference',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\TransmissionReference',
                ),
                'urgency' => array(
                    'namespace' => 'XMP-photoshop',
                    'tagname' => 'Urgency',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPhotoshop\Urgency',
                ),

            ),
            'xmp-plus' => array(
                'adultcontentwarning' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'AdultContentWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\AdultContentWarning',
                ),
                'copyrightowner' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'CopyrightOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwner',
                ),
                'copyrightownerid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'CopyrightOwnerID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerID',
                ),
                'copyrightownername' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'CopyrightOwnerName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerName',
                ),
                'copyrightownerimageid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'CopyrightOwnerImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerImageID',
                ),
                'copyrightregistrationnumber' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'CopyrightRegistrationNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\CopyrightRegistrationNumber',
                ),
                'copyrightstatus' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'CopyrightStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\CopyrightStatus',
                ),
                'creditlinerequired' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'CreditLineRequired',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\CreditLineRequired',
                ),
                'custom1' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom1',
                ),
                'custom10' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom10',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom10',
                ),
                'custom2' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom2',
                ),
                'custom3' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom3',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom3',
                ),
                'custom4' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom4',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom4',
                ),
                'custom5' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom5',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom5',
                ),
                'custom6' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom6',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom6',
                ),
                'custom7' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom7',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom7',
                ),
                'custom8' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom8',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom8',
                ),
                'custom9' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Custom9',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Custom9',
                ),
                'enduser' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'EndUser',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\EndUser',
                ),
                'enduserid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'EndUserID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\EndUserID',
                ),
                'endusername' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'EndUserName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\EndUserName',
                ),
                'filenameasdelivered' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'FileNameAsDelivered',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\FileNameAsDelivered',
                ),
                'firstpublicationdate' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'FirstPublicationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\FirstPublicationDate',
                ),
                'imagealterationconstraints' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageAlterationConstraints',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageAlterationConstraints',
                ),
                'imagecreator' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageCreator',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageCreator',
                ),
                'imagecreatorid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageCreatorID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorID',
                ),
                'imagecreatorname' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageCreatorName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorName',
                ),
                'imagecreatorimageid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageCreatorImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorImageID',
                ),
                'imageduplicationconstraints' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageDuplicationConstraints',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageDuplicationConstraints',
                ),
                'imagefileconstraints' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageFileConstraints',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageFileConstraints',
                ),
                'imagefileformatasdelivered' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageFileFormatAsDelivered',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageFileFormatAsDelivered',
                ),
                'imagefilesizeasdelivered' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageFileSizeAsDelivered',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageFileSizeAsDelivered',
                ),
                'imagesupplier' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageSupplier',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageSupplier',
                ),
                'imagesupplierimageid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageSupplierImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageSupplierImageID',
                ),
                'imagesupplierid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageSupplierID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageSupplierID',
                ),
                'imagesuppliername' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageSupplierName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageSupplierName',
                ),
                'imagetype' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ImageType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ImageType',
                ),
                'licensee' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Licensee',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Licensee',
                ),
                'licenseeimageid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseeImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseeImageID',
                ),
                'licenseeimagenotes' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseeImageNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseeImageNotes',
                ),
                'licenseeid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseeID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseeID',
                ),
                'licenseename' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseeName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseeName',
                ),
                'licenseenddate' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseEndDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseEndDate',
                ),
                'licenseeprojectreference' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseeProjectReference',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseeProjectReference',
                ),
                'licenseetransactionid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseeTransactionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseeTransactionID',
                ),
                'licenseid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseID',
                ),
                'licensestartdate' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseStartDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseStartDate',
                ),
                'licensetransactiondate' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicenseTransactionDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicenseTransactionDate',
                ),
                'licensor' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Licensor',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Licensor',
                ),
                'licensorimageid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorImageID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorImageID',
                ),
                'licensorcity' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorCity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorCity',
                ),
                'licensorcountry' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorCountry',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorCountry',
                ),
                'licensoremail' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorEmail',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorEmail',
                ),
                'licensorextendedaddress' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorExtendedAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorExtendedAddress',
                ),
                'licensorid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorID',
                ),
                'licensorname' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorName',
                ),
                'licensorpostalcode' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorPostalCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorPostalCode',
                ),
                'licensorregion' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorRegion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorRegion',
                ),
                'licensorstreetaddress' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorStreetAddress',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorStreetAddress',
                ),
                'licensortelephone1' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorTelephone1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorTelephone1',
                ),
                'licensortelephone2' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorTelephone2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorTelephone2',
                ),
                'licensortelephonetype1' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorTelephoneType1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorTelephoneType1',
                ),
                'licensortelephonetype2' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorTelephoneType2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorTelephoneType2',
                ),
                'licensorurl' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorURL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorURL',
                ),
                'licensornotes' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorNotes',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorNotes',
                ),
                'licensortransactionid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'LicensorTransactionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\LicensorTransactionID',
                ),
                'mediaconstraints' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'MediaConstraints',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\MediaConstraints',
                ),
                'mediasummarycode' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'MediaSummaryCode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\MediaSummaryCode',
                ),
                'minormodelagedisclosure' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'MinorModelAgeDisclosure',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\MinorModelAgeDisclosure',
                ),
                'modelreleaseid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ModelReleaseID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ModelReleaseID',
                ),
                'modelreleasestatus' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ModelReleaseStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ModelReleaseStatus',
                ),
                'otherconditions' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'OtherConditions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\OtherConditions',
                ),
                'otherconstraints' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'OtherConstraints',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\OtherConstraints',
                ),
                'otherimageinfo' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'OtherImageInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\OtherImageInfo',
                ),
                'otherlicensedocuments' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'OtherLicenseDocuments',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\OtherLicenseDocuments',
                ),
                'otherlicenseinfo' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'OtherLicenseInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\OtherLicenseInfo',
                ),
                'otherlicenserequirements' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'OtherLicenseRequirements',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\OtherLicenseRequirements',
                ),
                'productorserviceconstraints' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'ProductOrServiceConstraints',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\ProductOrServiceConstraints',
                ),
                'propertyreleaseid' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'PropertyReleaseID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\PropertyReleaseID',
                ),
                'propertyreleasestatus' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'PropertyReleaseStatus',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\PropertyReleaseStatus',
                ),
                'regionconstraints' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'RegionConstraints',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\RegionConstraints',
                ),
                'reuse' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'Reuse',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\Reuse',
                ),
                'termsandconditionstext' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'TermsAndConditionsText',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\TermsAndConditionsText',
                ),
                'termsandconditionsurl' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'TermsAndConditionsURL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\TermsAndConditionsURL',
                ),
                'plusversion' => array(
                    'namespace' => 'XMP-plus',
                    'tagname' => 'PLUSVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPlus\PLUSVersion',
                ),

            ),
            'xmp-prism' => array(
                'aggregationtype' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'AggregationType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\AggregationType',
                ),
                'alternatetitle' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'AlternateTitle',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\AlternateTitle',
                ),
                'bytecount' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'ByteCount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\ByteCount',
                ),
                'channel' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Channel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Channel',
                ),
                'complianceprofile' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'ComplianceProfile',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\ComplianceProfile',
                ),
                'copyright' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Copyright',
                ),
                'corporateentity' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'CorporateEntity',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\CorporateEntity',
                ),
                'coverdate' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'CoverDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\CoverDate',
                ),
                'coverdisplaydate' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'CoverDisplayDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\CoverDisplayDate',
                ),
                'creationdate' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'CreationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\CreationDate',
                ),
                'daterecieved' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'DateRecieved',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\DateRecieved',
                ),
                'distributor' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Distributor',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Distributor',
                ),
                'doi' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'DOI',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\DOI',
                ),
                'edition' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Edition',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Edition',
                ),
                'eissn' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'EIssn',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\EIssn',
                ),
                'embargodate' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'EmbargoDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\EmbargoDate',
                ),
                'endingpage' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'EndingPage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\EndingPage',
                ),
                'event' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Event',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Event',
                ),
                'expirationdate' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'ExpirationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\ExpirationDate',
                ),
                'genre' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Genre',
                ),
                'hasalternative' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'HasAlternative',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\HasAlternative',
                ),
                'hascorrection' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'HasCorrection',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\HasCorrection',
                ),
                'haspreviousversion' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'HasPreviousVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\HasPreviousVersion',
                ),
                'hastranslation' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'HasTranslation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\HasTranslation',
                ),
                'industry' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Industry',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Industry',
                ),
                'isbn' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'ISBN',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\ISBN',
                ),
                'iscorrectionof' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'IsCorrectionOf',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\IsCorrectionOf',
                ),
                'issn' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'ISSN',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\ISSN',
                ),
                'issueidentifier' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'IssueIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\IssueIdentifier',
                ),
                'issuename' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'IssueName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\IssueName',
                ),
                'istranslationof' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'IsTranslationOf',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\IsTranslationOf',
                ),
                'keyword' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Keyword',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Keyword',
                ),
                'killdate' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'KillDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\KillDate',
                ),
                'location' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Location',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Location',
                ),
                'modificationdate' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'ModificationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\ModificationDate',
                ),
                'number' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Number',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Number',
                ),
                'object' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Object',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Object',
                ),
                'organization' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Organization',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Organization',
                ),
                'originplatform' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'OriginPlatform',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\OriginPlatform',
                ),
                'pagerange' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'PageRange',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\PageRange',
                ),
                'person' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Person',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Person',
                ),
                'publicationdate' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'PublicationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\PublicationDate',
                ),
                'publicationname' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'PublicationName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\PublicationName',
                ),
                'rightsagent' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'RightsAgent',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\RightsAgent',
                ),
                'section' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Section',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Section',
                ),
                'startingpage' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'StartingPage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\StartingPage',
                ),
                'subsection1' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Subsection1',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Subsection1',
                ),
                'subsection2' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Subsection2',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Subsection2',
                ),
                'subsection3' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Subsection3',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Subsection3',
                ),
                'subsection4' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Subsection4',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Subsection4',
                ),
                'teaser' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Teaser',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Teaser',
                ),
                'ticker' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Ticker',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Ticker',
                ),
                'timeperiod' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'TimePeriod',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\TimePeriod',
                ),
                'url' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'URL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\URL',
                ),
                'versionidentifier' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'VersionIdentifier',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\VersionIdentifier',
                ),
                'volume' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'Volume',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\Volume',
                ),
                'wordcount' => array(
                    'namespace' => 'XMP-prism',
                    'tagname' => 'WordCount',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrism\WordCount',
                ),

            ),
            'xmp-prl' => array(
                'geography' => array(
                    'namespace' => 'XMP-prl',
                    'tagname' => 'Geography',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrl\Geography',
                ),
                'industry' => array(
                    'namespace' => 'XMP-prl',
                    'tagname' => 'Industry',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrl\Industry',
                ),
                'usage' => array(
                    'namespace' => 'XMP-prl',
                    'tagname' => 'Usage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPrl\Usage',
                ),

            ),
            'xmp-pur' => array(
                'adultcontentwarning' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'AdultContentWarning',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\AdultContentWarning',
                ),
                'agreement' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'Agreement',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\Agreement',
                ),
                'copyright' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\Copyright',
                ),
                'creditline' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'CreditLine',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\CreditLine',
                ),
                'embargodate' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'EmbargoDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\EmbargoDate',
                ),
                'exclusivityenddate' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'ExclusivityEndDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\ExclusivityEndDate',
                ),
                'expirationdate' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'ExpirationDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\ExpirationDate',
                ),
                'imagesizerestriction' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'ImageSizeRestriction',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\ImageSizeRestriction',
                ),
                'optionenddate' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'OptionEndDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\OptionEndDate',
                ),
                'permissions' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'Permissions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\Permissions',
                ),
                'restrictions' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'Restrictions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\Restrictions',
                ),
                'reuseprohibited' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'ReuseProhibited',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\ReuseProhibited',
                ),
                'rightsagent' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'RightsAgent',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\RightsAgent',
                ),
                'rightsowner' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'RightsOwner',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\RightsOwner',
                ),
                'usagefee' => array(
                    'namespace' => 'XMP-pur',
                    'tagname' => 'UsageFee',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPPur\UsageFee',
                ),

            ),
            'xmp-rdf' => array(
                'about' => array(
                    'namespace' => 'XMP-rdf',
                    'tagname' => 'About',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPRdf\About',
                ),

            ),
            'xmp-swf' => array(
                'backgroundalpha' => array(
                    'namespace' => 'XMP-swf',
                    'tagname' => 'BackgroundAlpha',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPSwf\BackgroundAlpha',
                ),
                'forwardlock' => array(
                    'namespace' => 'XMP-swf',
                    'tagname' => 'ForwardLock',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPSwf\ForwardLock',
                ),
                'maxstorage' => array(
                    'namespace' => 'XMP-swf',
                    'tagname' => 'MaxStorage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPSwf\MaxStorage',
                ),
                'type' => array(
                    'namespace' => 'XMP-swf',
                    'tagname' => 'Type',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPSwf\Type',
                ),

            ),
            'xmp-tiff' => array(
                'artist' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\Artist',
                ),
                'bitspersample' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'BitsPerSample',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\BitsPerSample',
                ),
                'compression' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\Compression',
                ),
                'copyright' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\Copyright',
                ),
                'datetime' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'DateTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\DateTime',
                ),
                'imagedescription' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'ImageDescription',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\ImageDescription',
                ),
                'imageheight' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'ImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\ImageHeight',
                ),
                'imagewidth' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'ImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\ImageWidth',
                ),
                'make' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'Make',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\Make',
                ),
                'model' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'Model',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\Model',
                ),
                'nativedigest' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'NativeDigest',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\NativeDigest',
                ),
                'orientation' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'Orientation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\Orientation',
                ),
                'photometricinterpretation' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'PhotometricInterpretation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\PhotometricInterpretation',
                ),
                'planarconfiguration' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'PlanarConfiguration',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\PlanarConfiguration',
                ),
                'primarychromaticities' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'PrimaryChromaticities',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\PrimaryChromaticities',
                ),
                'referenceblackwhite' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'ReferenceBlackWhite',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\ReferenceBlackWhite',
                ),
                'resolutionunit' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'ResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\ResolutionUnit',
                ),
                'samplesperpixel' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'SamplesPerPixel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\SamplesPerPixel',
                ),
                'software' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'Software',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\Software',
                ),
                'transferfunction' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'TransferFunction',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\TransferFunction',
                ),
                'whitepoint' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'WhitePoint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\WhitePoint',
                ),
                'xresolution' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'XResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\XResolution',
                ),
                'ycbcrcoefficients' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'YCbCrCoefficients',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\YCbCrCoefficients',
                ),
                'ycbcrpositioning' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'YCbCrPositioning',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\YCbCrPositioning',
                ),
                'ycbcrsubsampling' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'YCbCrSubSampling',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\YCbCrSubSampling',
                ),
                'yresolution' => array(
                    'namespace' => 'XMP-tiff',
                    'tagname' => 'YResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPTiff\YResolution',
                ),

            ),
            'xmp-x' => array(
                'xmptoolkit' => array(
                    'namespace' => 'XMP-x',
                    'tagname' => 'XMPToolkit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPX\XMPToolkit',
                ),

            ),
            'xmp-xmp' => array(
                'advisory' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Advisory',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Advisory',
                ),
                'author' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Author',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Author',
                ),
                'baseurl' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'BaseURL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\BaseURL',
                ),
                'createdate' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'CreateDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\CreateDate',
                ),
                'creatortool' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'CreatorTool',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\CreatorTool',
                ),
                'description' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Description',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Description',
                ),
                'format' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Format',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Format',
                ),
                'identifier' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Identifier',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Identifier',
                ),
                'keywords' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Keywords',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Keywords',
                ),
                'label' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Label',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Label',
                ),
                'metadatadate' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'MetadataDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\MetadataDate',
                ),
                'modifydate' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\ModifyDate',
                ),
                'nickname' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Nickname',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Nickname',
                ),
                'pageinfo' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'PageInfo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\PageInfo',
                ),
                'pageimageformat' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'PageImageFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\PageImageFormat',
                ),
                'pageimageheight' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'PageImageHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\PageImageHeight',
                ),
                'pageimage' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'PageImage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\PageImage',
                ),
                'pageimagepagenumber' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'PageImagePageNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\PageImagePageNumber',
                ),
                'pageimagewidth' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'PageImageWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\PageImageWidth',
                ),
                'rating' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Rating',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Rating',
                ),
                'thumbnails' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Thumbnails',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Thumbnails',
                ),
                'thumbnailformat' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'ThumbnailFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\ThumbnailFormat',
                ),
                'thumbnailheight' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'ThumbnailHeight',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\ThumbnailHeight',
                ),
                'thumbnailimage' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'ThumbnailImage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\ThumbnailImage',
                ),
                'thumbnailwidth' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'ThumbnailWidth',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\ThumbnailWidth',
                ),
                'title' => array(
                    'namespace' => 'XMP-xmp',
                    'tagname' => 'Title',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmp\Title',
                ),

            ),
            'xmp-xmpbj' => array(
                'jobref' => array(
                    'namespace' => 'XMP-xmpBJ',
                    'tagname' => 'JobRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpBJ\JobRef',
                ),
                'jobrefid' => array(
                    'namespace' => 'XMP-xmpBJ',
                    'tagname' => 'JobRefId',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpBJ\JobRefId',
                ),
                'jobrefname' => array(
                    'namespace' => 'XMP-xmpBJ',
                    'tagname' => 'JobRefName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpBJ\JobRefName',
                ),
                'jobrefurl' => array(
                    'namespace' => 'XMP-xmpBJ',
                    'tagname' => 'JobRefUrl',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpBJ\JobRefUrl',
                ),

            ),
            'xmp-xmpdm' => array(
                'abspeakaudiofilepath' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AbsPeakAudioFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AbsPeakAudioFilePath',
                ),
                'album' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Album',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Album',
                ),
                'alttapename' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AltTapeName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AltTapeName',
                ),
                'alttimecode' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AltTimecode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AltTimecode',
                ),
                'alttimecodetimeformat' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AltTimecodeTimeFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AltTimecodeTimeFormat',
                ),
                'alttimecodetimevalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AltTimecodeTimeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AltTimecodeTimeValue',
                ),
                'alttimecodevalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AltTimecodeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AltTimecodeValue',
                ),
                'artist' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Artist',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Artist',
                ),
                'audiochanneltype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AudioChannelType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AudioChannelType',
                ),
                'audiocompressor' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AudioCompressor',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AudioCompressor',
                ),
                'audiomoddate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AudioModDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AudioModDate',
                ),
                'audiosamplerate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AudioSampleRate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AudioSampleRate',
                ),
                'audiosampletype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'AudioSampleType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\AudioSampleType',
                ),
                'beatspliceparams' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'BeatSpliceParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParams',
                ),
                'beatspliceparamsriseindecibel' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'BeatSpliceParamsRiseInDecibel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsRiseInDecibel',
                ),
                'beatspliceparamsriseintimeduration' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'BeatSpliceParamsRiseInTimeDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsRiseInTimeDuration',
                ),
                'beatspliceparamsriseintimedurationscale' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'BeatSpliceParamsRiseInTimeDurationScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsRiseInTimeDurationScale',
                ),
                'beatspliceparamsriseintimedurationvalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'BeatSpliceParamsRiseInTimeDurationValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsRiseInTimeDurationValue',
                ),
                'beatspliceparamsusefilebeatsmarker' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'BeatSpliceParamsUseFileBeatsMarker',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\BeatSpliceParamsUseFileBeatsMarker',
                ),
                'cameraangle' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'CameraAngle',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\CameraAngle',
                ),
                'cameralabel' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'CameraLabel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\CameraLabel',
                ),
                'cameramodel' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'CameraModel',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\CameraModel',
                ),
                'cameramove' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'CameraMove',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\CameraMove',
                ),
                'client' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Client',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Client',
                ),
                'dmcomment' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'DMComment',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\DMComment',
                ),
                'composer' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Composer',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Composer',
                ),
                'contributedmedia' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMedia',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMedia',
                ),
                'contributedmediaduration' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaDuration',
                ),
                'contributedmediadurationscale' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaDurationScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaDurationScale',
                ),
                'contributedmediadurationvalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaDurationValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaDurationValue',
                ),
                'contributedmediamanaged' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaManaged',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaManaged',
                ),
                'contributedmediapath' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaPath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaPath',
                ),
                'contributedmediastarttime' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaStartTime',
                ),
                'contributedmediastarttimescale' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaStartTimeScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaStartTimeScale',
                ),
                'contributedmediastarttimevalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaStartTimeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaStartTimeValue',
                ),
                'contributedmediatrack' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaTrack',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaTrack',
                ),
                'contributedmediawebstatement' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ContributedMediaWebStatement',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ContributedMediaWebStatement',
                ),
                'copyright' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Copyright',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Copyright',
                ),
                'director' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Director',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Director',
                ),
                'directorphotography' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'DirectorPhotography',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\DirectorPhotography',
                ),
                'duration' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Duration',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Duration',
                ),
                'durationscale' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'DurationScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\DurationScale',
                ),
                'durationvalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'DurationValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\DurationValue',
                ),
                'engineer' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Engineer',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Engineer',
                ),
                'filedatarate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'FileDataRate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\FileDataRate',
                ),
                'genre' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Genre',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Genre',
                ),
                'good' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Good',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Good',
                ),
                'instrument' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Instrument',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Instrument',
                ),
                'introtime' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'IntroTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\IntroTime',
                ),
                'introtimescale' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'IntroTimeScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\IntroTimeScale',
                ),
                'introtimevalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'IntroTimeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\IntroTimeValue',
                ),
                'key' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Key',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Key',
                ),
                'logcomment' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'LogComment',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\LogComment',
                ),
                'loop' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Loop',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Loop',
                ),
                'markers' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Markers',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Markers',
                ),
                'markerscomment' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersComment',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersComment',
                ),
                'markerscuepointparams' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersCuePointParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersCuePointParams',
                ),
                'markerscuepointparamskey' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersCuePointParamsKey',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersCuePointParamsKey',
                ),
                'markerscuepointparamsvalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersCuePointParamsValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersCuePointParamsValue',
                ),
                'markerscuepointtype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersCuePointType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersCuePointType',
                ),
                'markersduration' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersDuration',
                ),
                'markerslocation' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersLocation',
                ),
                'markersname' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersName',
                ),
                'markersprobability' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersProbability',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersProbability',
                ),
                'markersspeaker' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersSpeaker',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersSpeaker',
                ),
                'markersstarttime' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersStartTime',
                ),
                'markerstarget' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersTarget',
                ),
                'markerstype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MarkersType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MarkersType',
                ),
                'metadatamoddate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'MetadataModDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\MetadataModDate',
                ),
                'numberofbeats' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'NumberOfBeats',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\NumberOfBeats',
                ),
                'outcue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'OutCue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\OutCue',
                ),
                'outcuescale' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'OutCueScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\OutCueScale',
                ),
                'outcuevalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'OutCueValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\OutCueValue',
                ),
                'projectname' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ProjectName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ProjectName',
                ),
                'projectref' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ProjectRef',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ProjectRef',
                ),
                'projectrefpath' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ProjectRefPath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ProjectRefPath',
                ),
                'projectreftype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ProjectRefType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ProjectRefType',
                ),
                'pulldown' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'PullDown',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\PullDown',
                ),
                'relativepeakaudiofilepath' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'RelativePeakAudioFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\RelativePeakAudioFilePath',
                ),
                'relativetimestamp' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'RelativeTimestamp',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\RelativeTimestamp',
                ),
                'relativetimestampscale' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'RelativeTimestampScale',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\RelativeTimestampScale',
                ),
                'relativetimestampvalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'RelativeTimestampValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\RelativeTimestampValue',
                ),
                'releasedate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ReleaseDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ReleaseDate',
                ),
                'resampleparams' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ResampleParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ResampleParams',
                ),
                'resampleparamsquality' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ResampleParamsQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ResampleParamsQuality',
                ),
                'scaletype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ScaleType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ScaleType',
                ),
                'scene' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Scene',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Scene',
                ),
                'shotdate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ShotDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ShotDate',
                ),
                'shotday' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ShotDay',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ShotDay',
                ),
                'shotlocation' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ShotLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ShotLocation',
                ),
                'shotname' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ShotName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ShotName',
                ),
                'shotnumber' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ShotNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ShotNumber',
                ),
                'shotsize' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'ShotSize',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\ShotSize',
                ),
                'speakerplacement' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'SpeakerPlacement',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\SpeakerPlacement',
                ),
                'starttimecode' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'StartTimecode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\StartTimecode',
                ),
                'starttimecodetimeformat' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'StartTimecodeTimeFormat',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\StartTimecodeTimeFormat',
                ),
                'starttimecodetimevalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'StartTimecodeTimeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\StartTimecodeTimeValue',
                ),
                'starttimecodevalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'StartTimecodeValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\StartTimecodeValue',
                ),
                'stretchmode' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'StretchMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\StretchMode',
                ),
                'takenumber' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TakeNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TakeNumber',
                ),
                'tapename' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TapeName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TapeName',
                ),
                'tempo' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Tempo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Tempo',
                ),
                'timescaleparams' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TimeScaleParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TimeScaleParams',
                ),
                'timescaleparamsframeoverlappingpercentage' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TimeScaleParamsFrameOverlappingPercentage',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TimeScaleParamsFrameOverlappingPercentage',
                ),
                'timescaleparamsframesize' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TimeScaleParamsFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TimeScaleParamsFrameSize',
                ),
                'timescaleparamsquality' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TimeScaleParamsQuality',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TimeScaleParamsQuality',
                ),
                'timesignature' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TimeSignature',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TimeSignature',
                ),
                'tracknumber' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TrackNumber',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TrackNumber',
                ),
                'tracks' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'Tracks',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\Tracks',
                ),
                'tracksframerate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksFrameRate',
                ),
                'tracksmarkers' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkers',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkers',
                ),
                'tracksmarkerscomment' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersComment',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersComment',
                ),
                'tracksmarkerscuepointparams' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersCuePointParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersCuePointParams',
                ),
                'tracksmarkerscuepointparamskey' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersCuePointParamsKey',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersCuePointParamsKey',
                ),
                'tracksmarkerscuepointparamsvalue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersCuePointParamsValue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersCuePointParamsValue',
                ),
                'tracksmarkerscuepointtype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersCuePointType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersCuePointType',
                ),
                'tracksmarkersduration' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersDuration',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersDuration',
                ),
                'tracksmarkerslocation' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersLocation',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersLocation',
                ),
                'tracksmarkersname' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersName',
                ),
                'tracksmarkersprobability' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersProbability',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersProbability',
                ),
                'tracksmarkersspeaker' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersSpeaker',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersSpeaker',
                ),
                'tracksmarkersstarttime' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersStartTime',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersStartTime',
                ),
                'tracksmarkerstarget' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersTarget',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersTarget',
                ),
                'tracksmarkerstype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksMarkersType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksMarkersType',
                ),
                'trackstrackname' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksTrackName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksTrackName',
                ),
                'trackstracktype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'TracksTrackType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\TracksTrackType',
                ),
                'videoalphamode' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaMode',
                ),
                'videoalphapremultiplecolor' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColor',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColor',
                ),
                'videoalphapremultiplecolora' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorA',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorA',
                ),
                'videoalphapremultiplecolorb' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorB',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorB',
                ),
                'videoalphapremultiplecolorblack' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorBlack',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorBlack',
                ),
                'videoalphapremultiplecolorblue' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorBlue',
                ),
                'videoalphapremultiplecolorcyan' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorCyan',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorCyan',
                ),
                'videoalphapremultiplecolorgreen' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorGreen',
                ),
                'videoalphapremultiplecolorl' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorL',
                ),
                'videoalphapremultiplecolormagenta' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorMagenta',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorMagenta',
                ),
                'videoalphapremultiplecolormode' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorMode',
                ),
                'videoalphapremultiplecolorred' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorRed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorRed',
                ),
                'videoalphapremultiplecolorswatchname' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorSwatchName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorSwatchName',
                ),
                'videoalphapremultiplecolortint' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorTint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorTint',
                ),
                'videoalphapremultiplecolortype' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorType',
                ),
                'videoalphapremultiplecoloryellow' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaPremultipleColorYellow',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaPremultipleColorYellow',
                ),
                'videoalphaunityistransparent' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoAlphaUnityIsTransparent',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoAlphaUnityIsTransparent',
                ),
                'videocolorspace' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoColorSpace',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoColorSpace',
                ),
                'videocompressor' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoCompressor',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoCompressor',
                ),
                'videofieldorder' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoFieldOrder',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoFieldOrder',
                ),
                'videoframerate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoFrameRate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameRate',
                ),
                'videoframesize' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoFrameSize',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameSize',
                ),
                'videoframesizeh' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoFrameSizeH',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameSizeH',
                ),
                'videoframesizeunit' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoFrameSizeUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameSizeUnit',
                ),
                'videoframesizew' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoFrameSizeW',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoFrameSizeW',
                ),
                'videomoddate' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoModDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoModDate',
                ),
                'videopixelaspectratio' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoPixelAspectRatio',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoPixelAspectRatio',
                ),
                'videopixeldepth' => array(
                    'namespace' => 'XMP-xmpDM',
                    'tagname' => 'VideoPixelDepth',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpDM\VideoPixelDepth',
                ),

            ),
            'xmp-xmpmm' => array(
                'derivedfrom' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFrom',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFrom',
                ),
                'derivedfromalternatepaths' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromAlternatePaths',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromAlternatePaths',
                ),
                'derivedfromdocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromDocumentID',
                ),
                'derivedfromfilepath' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromFilePath',
                ),
                'derivedfromfrompart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromFromPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromFromPart',
                ),
                'derivedfrominstanceid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromInstanceID',
                ),
                'derivedfromlastmodifydate' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromLastModifyDate',
                ),
                'derivedfrommanager' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromManager',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromManager',
                ),
                'derivedfrommanagervariant' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromManagerVariant',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromManagerVariant',
                ),
                'derivedfrommanageto' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromManageTo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromManageTo',
                ),
                'derivedfrommanageui' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromManageUI',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromManageUI',
                ),
                'derivedfrommaskmarkers' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromMaskMarkers',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromMaskMarkers',
                ),
                'derivedfromoriginaldocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromOriginalDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromOriginalDocumentID',
                ),
                'derivedfrompartmapping' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromPartMapping',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromPartMapping',
                ),
                'derivedfromrenditionclass' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromRenditionClass',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromRenditionClass',
                ),
                'derivedfromrenditionparams' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromRenditionParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromRenditionParams',
                ),
                'derivedfromtopart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromToPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromToPart',
                ),
                'derivedfromversionid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DerivedFromVersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DerivedFromVersionID',
                ),
                'documentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'DocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\DocumentID',
                ),
                'history' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'History',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\History',
                ),
                'historyaction' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'HistoryAction',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\HistoryAction',
                ),
                'historychanged' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'HistoryChanged',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\HistoryChanged',
                ),
                'historyinstanceid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'HistoryInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\HistoryInstanceID',
                ),
                'historyparameters' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'HistoryParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\HistoryParameters',
                ),
                'historysoftwareagent' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'HistorySoftwareAgent',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\HistorySoftwareAgent',
                ),
                'historywhen' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'HistoryWhen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\HistoryWhen',
                ),
                'ingredients' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'Ingredients',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\Ingredients',
                ),
                'ingredientsalternatepaths' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsAlternatePaths',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsAlternatePaths',
                ),
                'ingredientsdocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsDocumentID',
                ),
                'ingredientsfilepath' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsFilePath',
                ),
                'ingredientsfrompart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsFromPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsFromPart',
                ),
                'ingredientsinstanceid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsInstanceID',
                ),
                'ingredientslastmodifydate' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsLastModifyDate',
                ),
                'ingredientsmanager' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsManager',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsManager',
                ),
                'ingredientsmanagervariant' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsManagerVariant',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsManagerVariant',
                ),
                'ingredientsmanageto' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsManageTo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsManageTo',
                ),
                'ingredientsmanageui' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsManageUI',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsManageUI',
                ),
                'ingredientsmaskmarkers' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsMaskMarkers',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsMaskMarkers',
                ),
                'ingredientsoriginaldocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsOriginalDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsOriginalDocumentID',
                ),
                'ingredientspartmapping' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsPartMapping',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsPartMapping',
                ),
                'ingredientsrenditionclass' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsRenditionClass',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsRenditionClass',
                ),
                'ingredientsrenditionparams' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsRenditionParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsRenditionParams',
                ),
                'ingredientstopart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsToPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsToPart',
                ),
                'ingredientsversionid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'IngredientsVersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\IngredientsVersionID',
                ),
                'instanceid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'InstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\InstanceID',
                ),
                'lasturl' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'LastURL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\LastURL',
                ),
                'managedfrom' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFrom',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFrom',
                ),
                'managedfromalternatepaths' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromAlternatePaths',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromAlternatePaths',
                ),
                'managedfromdocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromDocumentID',
                ),
                'managedfromfilepath' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromFilePath',
                ),
                'managedfromfrompart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromFromPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromFromPart',
                ),
                'managedfrominstanceid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromInstanceID',
                ),
                'managedfromlastmodifydate' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromLastModifyDate',
                ),
                'managedfrommanager' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromManager',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromManager',
                ),
                'managedfrommanagervariant' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromManagerVariant',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromManagerVariant',
                ),
                'managedfrommanageto' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromManageTo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromManageTo',
                ),
                'managedfrommanageui' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromManageUI',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromManageUI',
                ),
                'managedfrommaskmarkers' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromMaskMarkers',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromMaskMarkers',
                ),
                'managedfromoriginaldocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromOriginalDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromOriginalDocumentID',
                ),
                'managedfrompartmapping' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromPartMapping',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromPartMapping',
                ),
                'managedfromrenditionclass' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromRenditionClass',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromRenditionClass',
                ),
                'managedfromrenditionparams' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromRenditionParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromRenditionParams',
                ),
                'managedfromtopart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromToPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromToPart',
                ),
                'managedfromversionid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagedFromVersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagedFromVersionID',
                ),
                'manager' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'Manager',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\Manager',
                ),
                'managervariant' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManagerVariant',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManagerVariant',
                ),
                'manageto' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManageTo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManageTo',
                ),
                'manageui' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManageUI',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManageUI',
                ),
                'manifest' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'Manifest',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\Manifest',
                ),
                'manifestlinkform' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestLinkForm',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestLinkForm',
                ),
                'manifestplacedresolutionunit' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestPlacedResolutionUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestPlacedResolutionUnit',
                ),
                'manifestplacedxresolution' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestPlacedXResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestPlacedXResolution',
                ),
                'manifestplacedyresolution' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestPlacedYResolution',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestPlacedYResolution',
                ),
                'manifestreference' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReference',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReference',
                ),
                'manifestreferencealternatepaths' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceAlternatePaths',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceAlternatePaths',
                ),
                'manifestreferencedocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceDocumentID',
                ),
                'manifestreferencefilepath' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceFilePath',
                ),
                'manifestreferencefrompart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceFromPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceFromPart',
                ),
                'manifestreferenceinstanceid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceInstanceID',
                ),
                'manifestreferencelastmodifydate' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceLastModifyDate',
                ),
                'manifestreferencemanager' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceManager',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceManager',
                ),
                'manifestreferencemanagervariant' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceManagerVariant',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceManagerVariant',
                ),
                'manifestreferencemanageto' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceManageTo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceManageTo',
                ),
                'manifestreferencemanageui' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceManageUI',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceManageUI',
                ),
                'manifestreferencemaskmarkers' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceMaskMarkers',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceMaskMarkers',
                ),
                'manifestreferenceoriginaldocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceOriginalDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceOriginalDocumentID',
                ),
                'manifestreferencepartmapping' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferencePartMapping',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferencePartMapping',
                ),
                'manifestreferencerenditionclass' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceRenditionClass',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceRenditionClass',
                ),
                'manifestreferencerenditionparams' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceRenditionParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceRenditionParams',
                ),
                'manifestreferencetopart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceToPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceToPart',
                ),
                'manifestreferenceversionid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'ManifestReferenceVersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\ManifestReferenceVersionID',
                ),
                'originaldocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'OriginalDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\OriginalDocumentID',
                ),
                'pantry' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'Pantry',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\Pantry',
                ),
                'preservedfilename' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'PreservedFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\PreservedFileName',
                ),
                'renditionclass' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionClass',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionClass',
                ),
                'renditionof' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOf',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOf',
                ),
                'renditionofalternatepaths' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfAlternatePaths',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfAlternatePaths',
                ),
                'renditionofdocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfDocumentID',
                ),
                'renditionoffilepath' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfFilePath',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfFilePath',
                ),
                'renditionoffrompart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfFromPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfFromPart',
                ),
                'renditionofinstanceid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfInstanceID',
                ),
                'renditionoflastmodifydate' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfLastModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfLastModifyDate',
                ),
                'renditionofmanager' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfManager',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfManager',
                ),
                'renditionofmanagervariant' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfManagerVariant',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfManagerVariant',
                ),
                'renditionofmanageto' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfManageTo',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfManageTo',
                ),
                'renditionofmanageui' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfManageUI',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfManageUI',
                ),
                'renditionofmaskmarkers' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfMaskMarkers',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfMaskMarkers',
                ),
                'renditionoforiginaldocumentid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfOriginalDocumentID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfOriginalDocumentID',
                ),
                'renditionofpartmapping' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfPartMapping',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfPartMapping',
                ),
                'renditionofrenditionclass' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfRenditionClass',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfRenditionClass',
                ),
                'renditionofrenditionparams' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfRenditionParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfRenditionParams',
                ),
                'renditionoftopart' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfToPart',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfToPart',
                ),
                'renditionofversionid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionOfVersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionOfVersionID',
                ),
                'renditionparams' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'RenditionParams',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\RenditionParams',
                ),
                'saveid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'SaveID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\SaveID',
                ),
                'subject' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'Subject',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\Subject',
                ),
                'versionid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionID',
                ),
                'versions' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'Versions',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\Versions',
                ),
                'versionscomments' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsComments',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsComments',
                ),
                'versionsevent' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsEvent',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEvent',
                ),
                'versionseventaction' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsEventAction',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventAction',
                ),
                'versionseventchanged' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsEventChanged',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventChanged',
                ),
                'versionseventinstanceid' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsEventInstanceID',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventInstanceID',
                ),
                'versionseventparameters' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsEventParameters',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventParameters',
                ),
                'versionseventsoftwareagent' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsEventSoftwareAgent',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventSoftwareAgent',
                ),
                'versionseventwhen' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsEventWhen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsEventWhen',
                ),
                'versionsmodifier' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsModifier',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsModifier',
                ),
                'versionsmodifydate' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsModifyDate',
                ),
                'versionsversion' => array(
                    'namespace' => 'XMP-xmpMM',
                    'tagname' => 'VersionsVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpMM\VersionsVersion',
                ),

            ),
            'xmp-xmpnote' => array(
                'hasextendedxmp' => array(
                    'namespace' => 'XMP-xmpNote',
                    'tagname' => 'HasExtendedXMP',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpNote\HasExtendedXMP',
                ),

            ),
            'xmp-xmpplus' => array(
                'creditlinereq' => array(
                    'namespace' => 'XMP-xmpPLUS',
                    'tagname' => 'CreditLineReq',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpPLUS\CreditLineReq',
                ),
                'reuseallowed' => array(
                    'namespace' => 'XMP-xmpPLUS',
                    'tagname' => 'ReuseAllowed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpPLUS\ReuseAllowed',
                ),

            ),
            'xmp-xmprights' => array(
                'certificate' => array(
                    'namespace' => 'XMP-xmpRights',
                    'tagname' => 'Certificate',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpRights\Certificate',
                ),
                'marked' => array(
                    'namespace' => 'XMP-xmpRights',
                    'tagname' => 'Marked',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpRights\Marked',
                ),
                'owner' => array(
                    'namespace' => 'XMP-xmpRights',
                    'tagname' => 'Owner',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpRights\Owner',
                ),
                'usageterms' => array(
                    'namespace' => 'XMP-xmpRights',
                    'tagname' => 'UsageTerms',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpRights\UsageTerms',
                ),
                'webstatement' => array(
                    'namespace' => 'XMP-xmpRights',
                    'tagname' => 'WebStatement',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpRights\WebStatement',
                ),

            ),
            'xmp-xmptpg' => array(
                'colorants' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'Colorants',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\Colorants',
                ),
                'coloranta' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantA',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantA',
                ),
                'colorantb' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantB',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantB',
                ),
                'colorantblack' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantBlack',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantBlack',
                ),
                'colorantblue' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantBlue',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantBlue',
                ),
                'colorantcyan' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantCyan',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantCyan',
                ),
                'colorantgreen' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantGreen',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantGreen',
                ),
                'colorantl' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantL',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantL',
                ),
                'colorantmagenta' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantMagenta',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantMagenta',
                ),
                'colorantmode' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantMode',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantMode',
                ),
                'colorantred' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantRed',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantRed',
                ),
                'colorantswatchname' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantSwatchName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantSwatchName',
                ),
                'coloranttint' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantTint',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantTint',
                ),
                'coloranttype' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantType',
                ),
                'colorantyellow' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ColorantYellow',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ColorantYellow',
                ),
                'fonts' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'Fonts',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\Fonts',
                ),
                'childfontfiles' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'ChildFontFiles',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\ChildFontFiles',
                ),
                'fontcomposite' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'FontComposite',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\FontComposite',
                ),
                'fontface' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'FontFace',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\FontFace',
                ),
                'fontfamily' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'FontFamily',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\FontFamily',
                ),
                'fontfilename' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'FontFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\FontFileName',
                ),
                'fontname' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'FontName',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\FontName',
                ),
                'fonttype' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'FontType',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\FontType',
                ),
                'fontversion' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'FontVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\FontVersion',
                ),
                'maxpagesize' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'MaxPageSize',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\MaxPageSize',
                ),
                'maxpagesizeh' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'MaxPageSizeH',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\MaxPageSizeH',
                ),
                'maxpagesizeunit' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'MaxPageSizeUnit',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\MaxPageSizeUnit',
                ),
                'maxpagesizew' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'MaxPageSizeW',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\MaxPageSizeW',
                ),
                'npages' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'NPages',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\NPages',
                ),
                'platenames' => array(
                    'namespace' => 'XMP-xmpTPg',
                    'tagname' => 'PlateNames',
                    'classname' => 'PHPExiftool\Driver\Tag\XMPXmpTPg\PlateNames',
                ),

            ),
            'zip' => array(
                'compression' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'Compression',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\Compression',
                ),
                'flags' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'Flags',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\Flags',
                ),
                'modifydate' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ModifyDate',
                ),
                'extraflags' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ExtraFlags',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ExtraFlags',
                ),
                'operatingsystem' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'OperatingSystem',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\OperatingSystem',
                ),
                'archivedfilename' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ArchivedFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ArchivedFileName',
                ),
                'comment' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'Comment',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\Comment',
                ),
                'ziprequiredversion' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipRequiredVersion',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipRequiredVersion',
                ),
                'zipbitflag' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipBitFlag',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipBitFlag',
                ),
                'zipcompression' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipCompression',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipCompression',
                ),
                'zipmodifydate' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipModifyDate',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipModifyDate',
                ),
                'zipcrc' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipCRC',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipCRC',
                ),
                'zipcompressedsize' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipCompressedSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipCompressedSize',
                ),
                'zipuncompressedsize' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipUncompressedSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipUncompressedSize',
                ),
                'zipfilenamelength' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipFileNameLength',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipFileNameLength',
                ),
                'zipfilename' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'ZipFileName',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\ZipFileName',
                ),
                'compressedsize' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'CompressedSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\CompressedSize',
                ),
                'uncompressedsize' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'UncompressedSize',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\UncompressedSize',
                ),
                'packingmethod' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'PackingMethod',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\PackingMethod',
                ),
                'filenamelength' => array(
                    'namespace' => 'ZIP',
                    'tagname' => 'FileNameLength',
                    'classname' => 'PHPExiftool\Driver\Tag\ZIP\FileNameLength',
                ),

            ),

        );

    }

}
